@charset "UTF-8";
/*
 * Constant values
 */
@import url("https://fonts.googleapis.com/css2?family=Courier+Prime:ital,wght@0,400;0,700;1,400;1,700&family=Josefin+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700&display=swap");
/*! bulma.io v0.9.3 | MIT License | github.com/jgthms/bulma */
/* Bulma Utilities */
.pagination-previous,
.pagination-next,
.pagination-link,
.pagination-ellipsis, .file-cta,
.file-name, .select select, .textarea, .input, .button {
  -moz-appearance: none;
  -webkit-appearance: none;
  align-items: center;
  border: 1px solid transparent;
  border-radius: 4px;
  box-shadow: none;
  display: inline-flex;
  font-size: 1rem;
  height: 2.5em;
  justify-content: flex-start;
  line-height: 1.5;
  padding-bottom: calc(0.5em - 1px);
  padding-left: calc(0.75em - 1px);
  padding-right: calc(0.75em - 1px);
  padding-top: calc(0.5em - 1px);
  position: relative;
  vertical-align: top;
}
.pagination-previous:focus,
.pagination-next:focus,
.pagination-link:focus,
.pagination-ellipsis:focus, .file-cta:focus,
.file-name:focus, .select select:focus, .textarea:focus, .input:focus, .button:focus, .is-focused.pagination-previous,
.is-focused.pagination-next,
.is-focused.pagination-link,
.is-focused.pagination-ellipsis, .is-focused.file-cta,
.is-focused.file-name, .select select.is-focused, .is-focused.textarea, .is-focused.input, .is-focused.button, .pagination-previous:active,
.pagination-next:active,
.pagination-link:active,
.pagination-ellipsis:active, .file-cta:active,
.file-name:active, .select select:active, .textarea:active, .input:active, .button:active, .is-active.pagination-previous,
.is-active.pagination-next,
.is-active.pagination-link,
.is-active.pagination-ellipsis, .is-active.file-cta,
.is-active.file-name, .select select.is-active, .is-active.textarea, .is-active.input, .is-active.button {
  outline: none;
}
[disabled].pagination-previous,
[disabled].pagination-next,
[disabled].pagination-link,
[disabled].pagination-ellipsis, [disabled].file-cta,
[disabled].file-name, .select select[disabled], [disabled].textarea, [disabled].input, [disabled].button, fieldset[disabled] .pagination-previous,
fieldset[disabled] .pagination-next,
fieldset[disabled] .pagination-link,
fieldset[disabled] .pagination-ellipsis, fieldset[disabled] .file-cta,
fieldset[disabled] .file-name, fieldset[disabled] .select select, .select fieldset[disabled] select, fieldset[disabled] .textarea, fieldset[disabled] .input, fieldset[disabled] .button {
  cursor: not-allowed;
}

.is-unselectable, .tabs, .pagination-previous,
.pagination-next,
.pagination-link,
.pagination-ellipsis, .breadcrumb, .file, .button {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.navbar-link:not(.is-arrowless)::after, .select:not(.is-multiple):not(.is-loading)::after {
  border: 3px solid transparent;
  border-radius: 2px;
  border-right: 0;
  border-top: 0;
  content: " ";
  display: block;
  height: 0.625em;
  margin-top: -0.4375em;
  pointer-events: none;
  position: absolute;
  top: 50%;
  transform: rotate(-45deg);
  transform-origin: center;
  width: 0.625em;
}

.tabs:not(:last-child), .pagination:not(:last-child), .message:not(:last-child), .level:not(:last-child), .breadcrumb:not(:last-child), .block:not(:last-child), .title:not(:last-child), .dark-palette #search-results .topic-title:not(:last-child),
.dark-palette .content .topic-title:not(:last-child),
.dark-palette .document .topic-title:not(:last-child), .light-palette #search-results .topic-title:not(:last-child),
.light-palette .content .topic-title:not(:last-child),
.light-palette .document .topic-title:not(:last-child),
.subtitle:not(:last-child), .table-container:not(:last-child), .table:not(:last-child), .progress:not(:last-child), .notification:not(:last-child), .content:not(:last-child), .box:not(:last-child) {
  margin-bottom: 1.5rem;
}

.modal-close, .delete {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -moz-appearance: none;
  -webkit-appearance: none;
  background-color: rgba(13, 17, 23, 0.2);
  border: none;
  border-radius: 9999px;
  cursor: pointer;
  pointer-events: auto;
  display: inline-block;
  flex-grow: 0;
  flex-shrink: 0;
  font-size: 0;
  height: 20px;
  max-height: 20px;
  max-width: 20px;
  min-height: 20px;
  min-width: 20px;
  outline: none;
  position: relative;
  vertical-align: top;
  width: 20px;
}
.modal-close::before, .delete::before, .modal-close::after, .delete::after {
  background-color: #fafafa;
  content: "";
  display: block;
  left: 50%;
  position: absolute;
  top: 50%;
  transform: translateX(-50%) translateY(-50%) rotate(45deg);
  transform-origin: center center;
}
.modal-close::before, .delete::before {
  height: 2px;
  width: 50%;
}
.modal-close::after, .delete::after {
  height: 50%;
  width: 2px;
}
.modal-close:hover, .delete:hover, .modal-close:focus, .delete:focus {
  background-color: rgba(13, 17, 23, 0.3);
}
.modal-close:active, .delete:active {
  background-color: rgba(13, 17, 23, 0.4);
}
.is-small.modal-close, .is-small.delete {
  height: 16px;
  max-height: 16px;
  max-width: 16px;
  min-height: 16px;
  min-width: 16px;
  width: 16px;
}
.is-medium.modal-close, .is-medium.delete {
  height: 24px;
  max-height: 24px;
  max-width: 24px;
  min-height: 24px;
  min-width: 24px;
  width: 24px;
}
.is-large.modal-close, .is-large.delete {
  height: 32px;
  max-height: 32px;
  max-width: 32px;
  min-height: 32px;
  min-width: 32px;
  width: 32px;
}

.control.is-loading::after, .select.is-loading::after, .loader, .button.is-loading::after {
  animation: spinAround 500ms infinite linear;
  border: 2px solid #c9d1d9;
  border-radius: 9999px;
  border-right-color: transparent;
  border-top-color: transparent;
  content: "";
  display: block;
  height: 1em;
  position: relative;
  width: 1em;
}

.hero-video, .is-overlay, .modal-background, .modal, .image.is-square img, #search-results figure.is-square img,
.content figure.is-square img,
.document figure.is-square img,
.image.is-square .has-ratio,
#search-results figure.is-square .has-ratio,
.content figure.is-square .has-ratio,
.document figure.is-square .has-ratio, .image.is-1by1 img, #search-results figure.is-1by1 img,
.content figure.is-1by1 img,
.document figure.is-1by1 img,
.image.is-1by1 .has-ratio,
#search-results figure.is-1by1 .has-ratio,
.content figure.is-1by1 .has-ratio,
.document figure.is-1by1 .has-ratio, .image.is-5by4 img, #search-results figure.is-5by4 img,
.content figure.is-5by4 img,
.document figure.is-5by4 img,
.image.is-5by4 .has-ratio,
#search-results figure.is-5by4 .has-ratio,
.content figure.is-5by4 .has-ratio,
.document figure.is-5by4 .has-ratio, .image.is-4by3 img, #search-results figure.is-4by3 img,
.content figure.is-4by3 img,
.document figure.is-4by3 img,
.image.is-4by3 .has-ratio,
#search-results figure.is-4by3 .has-ratio,
.content figure.is-4by3 .has-ratio,
.document figure.is-4by3 .has-ratio, .image.is-3by2 img, #search-results figure.is-3by2 img,
.content figure.is-3by2 img,
.document figure.is-3by2 img,
.image.is-3by2 .has-ratio,
#search-results figure.is-3by2 .has-ratio,
.content figure.is-3by2 .has-ratio,
.document figure.is-3by2 .has-ratio, .image.is-5by3 img, #search-results figure.is-5by3 img,
.content figure.is-5by3 img,
.document figure.is-5by3 img,
.image.is-5by3 .has-ratio,
#search-results figure.is-5by3 .has-ratio,
.content figure.is-5by3 .has-ratio,
.document figure.is-5by3 .has-ratio, .image.is-16by9 img, #search-results figure.is-16by9 img,
.content figure.is-16by9 img,
.document figure.is-16by9 img,
.image.is-16by9 .has-ratio,
#search-results figure.is-16by9 .has-ratio,
.content figure.is-16by9 .has-ratio,
.document figure.is-16by9 .has-ratio, .image.is-2by1 img, #search-results figure.is-2by1 img,
.content figure.is-2by1 img,
.document figure.is-2by1 img,
.image.is-2by1 .has-ratio,
#search-results figure.is-2by1 .has-ratio,
.content figure.is-2by1 .has-ratio,
.document figure.is-2by1 .has-ratio, .image.is-3by1 img, #search-results figure.is-3by1 img,
.content figure.is-3by1 img,
.document figure.is-3by1 img,
.image.is-3by1 .has-ratio,
#search-results figure.is-3by1 .has-ratio,
.content figure.is-3by1 .has-ratio,
.document figure.is-3by1 .has-ratio, .image.is-4by5 img, #search-results figure.is-4by5 img,
.content figure.is-4by5 img,
.document figure.is-4by5 img,
.image.is-4by5 .has-ratio,
#search-results figure.is-4by5 .has-ratio,
.content figure.is-4by5 .has-ratio,
.document figure.is-4by5 .has-ratio, .image.is-3by4 img, #search-results figure.is-3by4 img,
.content figure.is-3by4 img,
.document figure.is-3by4 img,
.image.is-3by4 .has-ratio,
#search-results figure.is-3by4 .has-ratio,
.content figure.is-3by4 .has-ratio,
.document figure.is-3by4 .has-ratio, .image.is-2by3 img, #search-results figure.is-2by3 img,
.content figure.is-2by3 img,
.document figure.is-2by3 img,
.image.is-2by3 .has-ratio,
#search-results figure.is-2by3 .has-ratio,
.content figure.is-2by3 .has-ratio,
.document figure.is-2by3 .has-ratio, .image.is-3by5 img, #search-results figure.is-3by5 img,
.content figure.is-3by5 img,
.document figure.is-3by5 img,
.image.is-3by5 .has-ratio,
#search-results figure.is-3by5 .has-ratio,
.content figure.is-3by5 .has-ratio,
.document figure.is-3by5 .has-ratio, .image.is-9by16 img, #search-results figure.is-9by16 img,
.content figure.is-9by16 img,
.document figure.is-9by16 img,
.image.is-9by16 .has-ratio,
#search-results figure.is-9by16 .has-ratio,
.content figure.is-9by16 .has-ratio,
.document figure.is-9by16 .has-ratio, .image.is-1by2 img, #search-results figure.is-1by2 img,
.content figure.is-1by2 img,
.document figure.is-1by2 img,
.image.is-1by2 .has-ratio,
#search-results figure.is-1by2 .has-ratio,
.content figure.is-1by2 .has-ratio,
.document figure.is-1by2 .has-ratio, .image.is-1by3 img, #search-results figure.is-1by3 img,
.content figure.is-1by3 img,
.document figure.is-1by3 img,
.image.is-1by3 .has-ratio,
#search-results figure.is-1by3 .has-ratio,
.content figure.is-1by3 .has-ratio,
.document figure.is-1by3 .has-ratio {
  bottom: 0;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}

.navbar-burger {
  -moz-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  background: none;
  border: none;
  color: currentColor;
  font-family: inherit;
  font-size: 1em;
  margin: 0;
  padding: 0;
}

/* Bulma Base */
/*! minireset.css v0.0.6 | MIT License | github.com/jgthms/minireset.css */
html,
body,
p,
ol,
ul,
li,
dl,
dt,
dd,
blockquote,
figure,
fieldset,
legend,
textarea,
pre,
iframe,
hr,
h1,
h2,
h3,
h4,
h5,
h6 {
  margin: 0;
  padding: 0;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  font-size: 100%;
  font-weight: normal;
}

ul {
  list-style: none;
}

button,
input,
select,
textarea {
  margin: 0;
}

html {
  box-sizing: border-box;
}

*, *::before, *::after {
  box-sizing: inherit;
}

img,
video {
  height: auto;
  max-width: 100%;
}

iframe {
  border: 0;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

td,
th {
  padding: 0;
}
td:not([align]),
th:not([align]) {
  text-align: inherit;
}

html {
  background-color: #fafafa;
  font-size: 16px;
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  min-width: 300px;
  overflow-x: hidden;
  overflow-y: scroll;
  text-rendering: optimizeLegibility;
  text-size-adjust: 100%;
}

article,
aside,
figure,
footer,
header,
hgroup,
section {
  display: block;
}

body,
button,
input,
optgroup,
select,
textarea {
  font-family: "Josefin Sans", sans-serif;
}

code,
pre {
  -moz-osx-font-smoothing: auto;
  -webkit-font-smoothing: auto;
  font-family: "Courier Prime", monospace;
}

body {
  color: #3e4551;
  font-size: 1em;
  font-weight: 400;
  line-height: 1.5;
}

a {
  color: #4078f2;
  cursor: pointer;
  text-decoration: none;
}
a strong {
  color: currentColor;
}
a:hover {
  color: #4068bf;
}

code {
  background-color: #faf0f0;
  color: #c32b1d;
  font-size: 0.875em;
  font-weight: normal;
  padding: 0.25em 0.5em 0.25em;
}

hr {
  background-color: #faf0f0;
  border: none;
  display: block;
  height: 2px;
  margin: 1.5rem 0;
}

img {
  height: auto;
  max-width: 100%;
}

input[type=checkbox],
input[type=radio] {
  vertical-align: baseline;
}

small {
  font-size: 0.875em;
}

span {
  font-style: inherit;
  font-weight: inherit;
}

strong {
  color: #2f3546;
  font-weight: 700;
}

fieldset {
  border: none;
}

pre {
  -webkit-overflow-scrolling: touch;
  background-color: #faf0f0;
  color: #3e4551;
  font-size: 0.875em;
  overflow-x: auto;
  padding: 1.25rem 1.5rem;
  white-space: pre;
  word-wrap: normal;
}
pre code {
  background-color: transparent;
  color: currentColor;
  font-size: 1em;
  padding: 0;
}

table td,
table th {
  vertical-align: top;
}
table td:not([align]),
table th:not([align]) {
  text-align: inherit;
}
table th {
  color: #2f3546;
}

@keyframes spinAround {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(359deg);
  }
}
/* Bulma Elements */
.box {
  background-color: #fafafa;
  border-radius: 6px;
  box-shadow: 0 0.5em 1em -0.125em rgba(13, 17, 23, 0.1), 0 0px 0 1px rgba(13, 17, 23, 0.02);
  color: #3e4551;
  display: block;
  padding: 1.25rem;
}

a.box:hover, a.box:focus {
  box-shadow: 0 0.5em 1em -0.125em rgba(13, 17, 23, 0.1), 0 0 0 1px #4078f2;
}
a.box:active {
  box-shadow: inset 0 1px 2px rgba(13, 17, 23, 0.2), 0 0 0 1px #4078f2;
}

.button {
  background-color: #fafafa;
  border-color: #c9d1d9;
  border-width: 1px;
  color: #2f3546;
  cursor: pointer;
  justify-content: center;
  padding-bottom: calc(0.5em - 1px);
  padding-left: 1em;
  padding-right: 1em;
  padding-top: calc(0.5em - 1px);
  text-align: center;
  white-space: nowrap;
}
.button strong {
  color: inherit;
}
.button .icon, .button .icon.is-small, .button .icon.is-medium, .button .icon.is-large {
  height: 1.5em;
  width: 1.5em;
}
.button .icon:first-child:not(:last-child) {
  margin-left: calc(-0.5em - 1px);
  margin-right: 0.25em;
}
.button .icon:last-child:not(:first-child) {
  margin-left: 0.25em;
  margin-right: calc(-0.5em - 1px);
}
.button .icon:first-child:last-child {
  margin-left: calc(-0.5em - 1px);
  margin-right: calc(-0.5em - 1px);
}
.button:hover, .button.is-hovered {
  border-color: #a1b1bf;
  color: #4068bf;
}
.button:focus, .button.is-focused {
  border-color: #4078f2;
  color: #4068bf;
}
.button:focus:not(:active), .button.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(64, 120, 242, 0.25);
}
.button:active, .button.is-active {
  border-color: #3e4551;
  color: #4068bf;
}
.button.is-text {
  background-color: transparent;
  border-color: transparent;
  color: #3e4551;
  text-decoration: underline;
}
.button.is-text:hover, .button.is-text.is-hovered, .button.is-text:focus, .button.is-text.is-focused {
  background-color: #faf0f0;
  color: #2f3546;
}
.button.is-text:active, .button.is-text.is-active {
  background-color: #f4dddd;
  color: #2f3546;
}
.button.is-text[disabled], fieldset[disabled] .button.is-text {
  background-color: transparent;
  border-color: transparent;
  box-shadow: none;
}
.button.is-ghost {
  background: none;
  border-color: transparent;
  color: #4078f2;
  text-decoration: none;
}
.button.is-ghost:hover, .button.is-ghost.is-hovered {
  color: #4078f2;
  text-decoration: underline;
}
.button.is-white {
  background-color: #fafafa;
  border-color: transparent;
  color: #0d1117;
}
.button.is-white:hover, .button.is-white.is-hovered {
  background-color: #f4f4f4;
  border-color: transparent;
  color: #0d1117;
}
.button.is-white:focus, .button.is-white.is-focused {
  border-color: transparent;
  color: #0d1117;
}
.button.is-white:focus:not(:active), .button.is-white.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(250, 250, 250, 0.25);
}
.button.is-white:active, .button.is-white.is-active {
  background-color: #ededed;
  border-color: transparent;
  color: #0d1117;
}
.button.is-white[disabled], fieldset[disabled] .button.is-white {
  background-color: #fafafa;
  border-color: transparent;
  box-shadow: none;
}
.button.is-white.is-inverted {
  background-color: #0d1117;
  color: #fafafa;
}
.button.is-white.is-inverted:hover, .button.is-white.is-inverted.is-hovered {
  background-color: #040507;
}
.button.is-white.is-inverted[disabled], fieldset[disabled] .button.is-white.is-inverted {
  background-color: #0d1117;
  border-color: transparent;
  box-shadow: none;
  color: #fafafa;
}
.button.is-white.is-loading::after {
  border-color: transparent transparent #0d1117 #0d1117 !important;
}
.button.is-white.is-outlined {
  background-color: transparent;
  border-color: #fafafa;
  color: #fafafa;
}
.button.is-white.is-outlined:hover, .button.is-white.is-outlined.is-hovered, .button.is-white.is-outlined:focus, .button.is-white.is-outlined.is-focused {
  background-color: #fafafa;
  border-color: #fafafa;
  color: #0d1117;
}
.button.is-white.is-outlined.is-loading::after {
  border-color: transparent transparent #fafafa #fafafa !important;
}
.button.is-white.is-outlined.is-loading:hover::after, .button.is-white.is-outlined.is-loading.is-hovered::after, .button.is-white.is-outlined.is-loading:focus::after, .button.is-white.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #0d1117 #0d1117 !important;
}
.button.is-white.is-outlined[disabled], fieldset[disabled] .button.is-white.is-outlined {
  background-color: transparent;
  border-color: #fafafa;
  box-shadow: none;
  color: #fafafa;
}
.button.is-white.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #0d1117;
  color: #0d1117;
}
.button.is-white.is-inverted.is-outlined:hover, .button.is-white.is-inverted.is-outlined.is-hovered, .button.is-white.is-inverted.is-outlined:focus, .button.is-white.is-inverted.is-outlined.is-focused {
  background-color: #0d1117;
  color: #fafafa;
}
.button.is-white.is-inverted.is-outlined.is-loading:hover::after, .button.is-white.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-white.is-inverted.is-outlined.is-loading:focus::after, .button.is-white.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fafafa #fafafa !important;
}
.button.is-white.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-white.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #0d1117;
  box-shadow: none;
  color: #0d1117;
}
.button.is-black {
  background-color: #0d1117;
  border-color: transparent;
  color: #fafafa;
}
.button.is-black:hover, .button.is-black.is-hovered {
  background-color: #080b0f;
  border-color: transparent;
  color: #fafafa;
}
.button.is-black:focus, .button.is-black.is-focused {
  border-color: transparent;
  color: #fafafa;
}
.button.is-black:focus:not(:active), .button.is-black.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(13, 17, 23, 0.25);
}
.button.is-black:active, .button.is-black.is-active {
  background-color: #040507;
  border-color: transparent;
  color: #fafafa;
}
.button.is-black[disabled], fieldset[disabled] .button.is-black {
  background-color: #0d1117;
  border-color: transparent;
  box-shadow: none;
}
.button.is-black.is-inverted {
  background-color: #fafafa;
  color: #0d1117;
}
.button.is-black.is-inverted:hover, .button.is-black.is-inverted.is-hovered {
  background-color: #ededed;
}
.button.is-black.is-inverted[disabled], fieldset[disabled] .button.is-black.is-inverted {
  background-color: #fafafa;
  border-color: transparent;
  box-shadow: none;
  color: #0d1117;
}
.button.is-black.is-loading::after {
  border-color: transparent transparent #fafafa #fafafa !important;
}
.button.is-black.is-outlined {
  background-color: transparent;
  border-color: #0d1117;
  color: #0d1117;
}
.button.is-black.is-outlined:hover, .button.is-black.is-outlined.is-hovered, .button.is-black.is-outlined:focus, .button.is-black.is-outlined.is-focused {
  background-color: #0d1117;
  border-color: #0d1117;
  color: #fafafa;
}
.button.is-black.is-outlined.is-loading::after {
  border-color: transparent transparent #0d1117 #0d1117 !important;
}
.button.is-black.is-outlined.is-loading:hover::after, .button.is-black.is-outlined.is-loading.is-hovered::after, .button.is-black.is-outlined.is-loading:focus::after, .button.is-black.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fafafa #fafafa !important;
}
.button.is-black.is-outlined[disabled], fieldset[disabled] .button.is-black.is-outlined {
  background-color: transparent;
  border-color: #0d1117;
  box-shadow: none;
  color: #0d1117;
}
.button.is-black.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fafafa;
  color: #fafafa;
}
.button.is-black.is-inverted.is-outlined:hover, .button.is-black.is-inverted.is-outlined.is-hovered, .button.is-black.is-inverted.is-outlined:focus, .button.is-black.is-inverted.is-outlined.is-focused {
  background-color: #fafafa;
  color: #0d1117;
}
.button.is-black.is-inverted.is-outlined.is-loading:hover::after, .button.is-black.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-black.is-inverted.is-outlined.is-loading:focus::after, .button.is-black.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #0d1117 #0d1117 !important;
}
.button.is-black.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-black.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fafafa;
  box-shadow: none;
  color: #fafafa;
}
.button.is-light {
  background-color: #faf0f0;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-light:hover, .button.is-light.is-hovered {
  background-color: #f7e6e6;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-light:focus, .button.is-light.is-focused {
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-light:focus:not(:active), .button.is-light.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(250, 240, 240, 0.25);
}
.button.is-light:active, .button.is-light.is-active {
  background-color: #f4dddd;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-light[disabled], fieldset[disabled] .button.is-light {
  background-color: #faf0f0;
  border-color: transparent;
  box-shadow: none;
}
.button.is-light.is-inverted {
  background-color: rgba(0, 0, 0, 0.7);
  color: #faf0f0;
}
.button.is-light.is-inverted:hover, .button.is-light.is-inverted.is-hovered {
  background-color: rgba(0, 0, 0, 0.7);
}
.button.is-light.is-inverted[disabled], fieldset[disabled] .button.is-light.is-inverted {
  background-color: rgba(0, 0, 0, 0.7);
  border-color: transparent;
  box-shadow: none;
  color: #faf0f0;
}
.button.is-light.is-loading::after {
  border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important;
}
.button.is-light.is-outlined {
  background-color: transparent;
  border-color: #faf0f0;
  color: #faf0f0;
}
.button.is-light.is-outlined:hover, .button.is-light.is-outlined.is-hovered, .button.is-light.is-outlined:focus, .button.is-light.is-outlined.is-focused {
  background-color: #faf0f0;
  border-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-light.is-outlined.is-loading::after {
  border-color: transparent transparent #faf0f0 #faf0f0 !important;
}
.button.is-light.is-outlined.is-loading:hover::after, .button.is-light.is-outlined.is-loading.is-hovered::after, .button.is-light.is-outlined.is-loading:focus::after, .button.is-light.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important;
}
.button.is-light.is-outlined[disabled], fieldset[disabled] .button.is-light.is-outlined {
  background-color: transparent;
  border-color: #faf0f0;
  box-shadow: none;
  color: #faf0f0;
}
.button.is-light.is-inverted.is-outlined {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.7);
  color: rgba(0, 0, 0, 0.7);
}
.button.is-light.is-inverted.is-outlined:hover, .button.is-light.is-inverted.is-outlined.is-hovered, .button.is-light.is-inverted.is-outlined:focus, .button.is-light.is-inverted.is-outlined.is-focused {
  background-color: rgba(0, 0, 0, 0.7);
  color: #faf0f0;
}
.button.is-light.is-inverted.is-outlined.is-loading:hover::after, .button.is-light.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-light.is-inverted.is-outlined.is-loading:focus::after, .button.is-light.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #faf0f0 #faf0f0 !important;
}
.button.is-light.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-light.is-inverted.is-outlined {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.7);
  box-shadow: none;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-dark {
  background-color: #2f3546;
  border-color: transparent;
  color: #fff;
}
.button.is-dark:hover, .button.is-dark.is-hovered {
  background-color: #2a2f3f;
  border-color: transparent;
  color: #fff;
}
.button.is-dark:focus, .button.is-dark.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-dark:focus:not(:active), .button.is-dark.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(47, 53, 70, 0.25);
}
.button.is-dark:active, .button.is-dark.is-active {
  background-color: #252937;
  border-color: transparent;
  color: #fff;
}
.button.is-dark[disabled], fieldset[disabled] .button.is-dark {
  background-color: #2f3546;
  border-color: transparent;
  box-shadow: none;
}
.button.is-dark.is-inverted {
  background-color: #fff;
  color: #2f3546;
}
.button.is-dark.is-inverted:hover, .button.is-dark.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-dark.is-inverted[disabled], fieldset[disabled] .button.is-dark.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #2f3546;
}
.button.is-dark.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-dark.is-outlined {
  background-color: transparent;
  border-color: #2f3546;
  color: #2f3546;
}
.button.is-dark.is-outlined:hover, .button.is-dark.is-outlined.is-hovered, .button.is-dark.is-outlined:focus, .button.is-dark.is-outlined.is-focused {
  background-color: #2f3546;
  border-color: #2f3546;
  color: #fff;
}
.button.is-dark.is-outlined.is-loading::after {
  border-color: transparent transparent #2f3546 #2f3546 !important;
}
.button.is-dark.is-outlined.is-loading:hover::after, .button.is-dark.is-outlined.is-loading.is-hovered::after, .button.is-dark.is-outlined.is-loading:focus::after, .button.is-dark.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-dark.is-outlined[disabled], fieldset[disabled] .button.is-dark.is-outlined {
  background-color: transparent;
  border-color: #2f3546;
  box-shadow: none;
  color: #2f3546;
}
.button.is-dark.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-dark.is-inverted.is-outlined:hover, .button.is-dark.is-inverted.is-outlined.is-hovered, .button.is-dark.is-inverted.is-outlined:focus, .button.is-dark.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #2f3546;
}
.button.is-dark.is-inverted.is-outlined.is-loading:hover::after, .button.is-dark.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-dark.is-inverted.is-outlined.is-loading:focus::after, .button.is-dark.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #2f3546 #2f3546 !important;
}
.button.is-dark.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-dark.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-primary {
  background-color: #885bfb;
  border-color: transparent;
  color: white;
}
.button.is-primary:hover, .button.is-primary.is-hovered {
  background-color: #7f4efa;
  border-color: transparent;
  color: white;
}
.button.is-primary:focus, .button.is-primary.is-focused {
  border-color: transparent;
  color: white;
}
.button.is-primary:focus:not(:active), .button.is-primary.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(136, 91, 251, 0.25);
}
.button.is-primary:active, .button.is-primary.is-active {
  background-color: #7642fa;
  border-color: transparent;
  color: white;
}
.button.is-primary[disabled], fieldset[disabled] .button.is-primary {
  background-color: #885bfb;
  border-color: transparent;
  box-shadow: none;
}
.button.is-primary.is-inverted {
  background-color: white;
  color: #885bfb;
}
.button.is-primary.is-inverted:hover, .button.is-primary.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-primary.is-inverted[disabled], fieldset[disabled] .button.is-primary.is-inverted {
  background-color: white;
  border-color: transparent;
  box-shadow: none;
  color: #885bfb;
}
.button.is-primary.is-loading::after {
  border-color: transparent transparent white white !important;
}
.button.is-primary.is-outlined {
  background-color: transparent;
  border-color: #885bfb;
  color: #885bfb;
}
.button.is-primary.is-outlined:hover, .button.is-primary.is-outlined.is-hovered, .button.is-primary.is-outlined:focus, .button.is-primary.is-outlined.is-focused {
  background-color: #885bfb;
  border-color: #885bfb;
  color: white;
}
.button.is-primary.is-outlined.is-loading::after {
  border-color: transparent transparent #885bfb #885bfb !important;
}
.button.is-primary.is-outlined.is-loading:hover::after, .button.is-primary.is-outlined.is-loading.is-hovered::after, .button.is-primary.is-outlined.is-loading:focus::after, .button.is-primary.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent white white !important;
}
.button.is-primary.is-outlined[disabled], fieldset[disabled] .button.is-primary.is-outlined {
  background-color: transparent;
  border-color: #885bfb;
  box-shadow: none;
  color: #885bfb;
}
.button.is-primary.is-inverted.is-outlined {
  background-color: transparent;
  border-color: white;
  color: white;
}
.button.is-primary.is-inverted.is-outlined:hover, .button.is-primary.is-inverted.is-outlined.is-hovered, .button.is-primary.is-inverted.is-outlined:focus, .button.is-primary.is-inverted.is-outlined.is-focused {
  background-color: white;
  color: #885bfb;
}
.button.is-primary.is-inverted.is-outlined.is-loading:hover::after, .button.is-primary.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-primary.is-inverted.is-outlined.is-loading:focus::after, .button.is-primary.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #885bfb #885bfb !important;
}
.button.is-primary.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-primary.is-inverted.is-outlined {
  background-color: transparent;
  border-color: white;
  box-shadow: none;
  color: white;
}
.button.is-primary.is-light {
  background-color: #f1ebfe;
  color: #4206db;
}
.button.is-primary.is-light:hover, .button.is-primary.is-light.is-hovered {
  background-color: #e8dffe;
  border-color: transparent;
  color: #4206db;
}
.button.is-primary.is-light:active, .button.is-primary.is-light.is-active {
  background-color: #dfd2fe;
  border-color: transparent;
  color: #4206db;
}
.button.is-link {
  background-color: #4078f2;
  border-color: transparent;
  color: #736a59;
}
.button.is-link:hover, .button.is-link.is-hovered {
  background-color: #3470f1;
  border-color: transparent;
  color: #736a59;
}
.button.is-link:focus, .button.is-link.is-focused {
  border-color: transparent;
  color: #736a59;
}
.button.is-link:focus:not(:active), .button.is-link.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(64, 120, 242, 0.25);
}
.button.is-link:active, .button.is-link.is-active {
  background-color: #2868f0;
  border-color: transparent;
  color: #736a59;
}
.button.is-link[disabled], fieldset[disabled] .button.is-link {
  background-color: #4078f2;
  border-color: transparent;
  box-shadow: none;
}
.button.is-link.is-inverted {
  background-color: #736a59;
  color: #4078f2;
}
.button.is-link.is-inverted:hover, .button.is-link.is-inverted.is-hovered {
  background-color: #655d4e;
}
.button.is-link.is-inverted[disabled], fieldset[disabled] .button.is-link.is-inverted {
  background-color: #736a59;
  border-color: transparent;
  box-shadow: none;
  color: #4078f2;
}
.button.is-link.is-loading::after {
  border-color: transparent transparent #736a59 #736a59 !important;
}
.button.is-link.is-outlined {
  background-color: transparent;
  border-color: #4078f2;
  color: #4078f2;
}
.button.is-link.is-outlined:hover, .button.is-link.is-outlined.is-hovered, .button.is-link.is-outlined:focus, .button.is-link.is-outlined.is-focused {
  background-color: #4078f2;
  border-color: #4078f2;
  color: #736a59;
}
.button.is-link.is-outlined.is-loading::after {
  border-color: transparent transparent #4078f2 #4078f2 !important;
}
.button.is-link.is-outlined.is-loading:hover::after, .button.is-link.is-outlined.is-loading.is-hovered::after, .button.is-link.is-outlined.is-loading:focus::after, .button.is-link.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #736a59 #736a59 !important;
}
.button.is-link.is-outlined[disabled], fieldset[disabled] .button.is-link.is-outlined {
  background-color: transparent;
  border-color: #4078f2;
  box-shadow: none;
  color: #4078f2;
}
.button.is-link.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #736a59;
  color: #736a59;
}
.button.is-link.is-inverted.is-outlined:hover, .button.is-link.is-inverted.is-outlined.is-hovered, .button.is-link.is-inverted.is-outlined:focus, .button.is-link.is-inverted.is-outlined.is-focused {
  background-color: #736a59;
  color: #4078f2;
}
.button.is-link.is-inverted.is-outlined.is-loading:hover::after, .button.is-link.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-link.is-inverted.is-outlined.is-loading:focus::after, .button.is-link.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #4078f2 #4078f2 !important;
}
.button.is-link.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-link.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #736a59;
  box-shadow: none;
  color: #736a59;
}
.button.is-link.is-light {
  background-color: #88abf7;
  color: #30529c;
}
.button.is-link.is-light:hover, .button.is-link.is-light.is-hovered {
  background-color: #7ca3f6;
  border-color: transparent;
  color: #30529c;
}
.button.is-link.is-light:active, .button.is-link.is-light.is-active {
  background-color: #709af5;
  border-color: transparent;
  color: #30529c;
}
.button.is-info {
  background-color: #449cc5;
  border-color: transparent;
  color: #fff;
}
.button.is-info:hover, .button.is-info.is-hovered {
  background-color: #3b97c1;
  border-color: transparent;
  color: #fff;
}
.button.is-info:focus, .button.is-info.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-info:focus:not(:active), .button.is-info.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(68, 156, 197, 0.25);
}
.button.is-info:active, .button.is-info.is-active {
  background-color: #388fb7;
  border-color: transparent;
  color: #fff;
}
.button.is-info[disabled], fieldset[disabled] .button.is-info {
  background-color: #449cc5;
  border-color: transparent;
  box-shadow: none;
}
.button.is-info.is-inverted {
  background-color: #fff;
  color: #449cc5;
}
.button.is-info.is-inverted:hover, .button.is-info.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-info.is-inverted[disabled], fieldset[disabled] .button.is-info.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #449cc5;
}
.button.is-info.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-info.is-outlined {
  background-color: transparent;
  border-color: #449cc5;
  color: #449cc5;
}
.button.is-info.is-outlined:hover, .button.is-info.is-outlined.is-hovered, .button.is-info.is-outlined:focus, .button.is-info.is-outlined.is-focused {
  background-color: #449cc5;
  border-color: #449cc5;
  color: #fff;
}
.button.is-info.is-outlined.is-loading::after {
  border-color: transparent transparent #449cc5 #449cc5 !important;
}
.button.is-info.is-outlined.is-loading:hover::after, .button.is-info.is-outlined.is-loading.is-hovered::after, .button.is-info.is-outlined.is-loading:focus::after, .button.is-info.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-info.is-outlined[disabled], fieldset[disabled] .button.is-info.is-outlined {
  background-color: transparent;
  border-color: #449cc5;
  box-shadow: none;
  color: #449cc5;
}
.button.is-info.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-info.is-inverted.is-outlined:hover, .button.is-info.is-inverted.is-outlined.is-hovered, .button.is-info.is-inverted.is-outlined:focus, .button.is-info.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #449cc5;
}
.button.is-info.is-inverted.is-outlined.is-loading:hover::after, .button.is-info.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-info.is-inverted.is-outlined.is-loading:focus::after, .button.is-info.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #449cc5 #449cc5 !important;
}
.button.is-info.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-info.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-info.is-light {
  background-color: #eff7fa;
  color: #2f7798;
}
.button.is-info.is-light:hover, .button.is-info.is-light.is-hovered {
  background-color: #e6f2f7;
  border-color: transparent;
  color: #2f7798;
}
.button.is-info.is-light:active, .button.is-info.is-light.is-active {
  background-color: #dcedf4;
  border-color: transparent;
  color: #2f7798;
}
.button.is-success {
  background-color: #00ad6b;
  border-color: transparent;
  color: #fff;
}
.button.is-success:hover, .button.is-success.is-hovered {
  background-color: #00a163;
  border-color: transparent;
  color: #fff;
}
.button.is-success:focus, .button.is-success.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-success:focus:not(:active), .button.is-success.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(0, 173, 107, 0.25);
}
.button.is-success:active, .button.is-success.is-active {
  background-color: #00945b;
  border-color: transparent;
  color: #fff;
}
.button.is-success[disabled], fieldset[disabled] .button.is-success {
  background-color: #00ad6b;
  border-color: transparent;
  box-shadow: none;
}
.button.is-success.is-inverted {
  background-color: #fff;
  color: #00ad6b;
}
.button.is-success.is-inverted:hover, .button.is-success.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-success.is-inverted[disabled], fieldset[disabled] .button.is-success.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #00ad6b;
}
.button.is-success.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-success.is-outlined {
  background-color: transparent;
  border-color: #00ad6b;
  color: #00ad6b;
}
.button.is-success.is-outlined:hover, .button.is-success.is-outlined.is-hovered, .button.is-success.is-outlined:focus, .button.is-success.is-outlined.is-focused {
  background-color: #00ad6b;
  border-color: #00ad6b;
  color: #fff;
}
.button.is-success.is-outlined.is-loading::after {
  border-color: transparent transparent #00ad6b #00ad6b !important;
}
.button.is-success.is-outlined.is-loading:hover::after, .button.is-success.is-outlined.is-loading.is-hovered::after, .button.is-success.is-outlined.is-loading:focus::after, .button.is-success.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-success.is-outlined[disabled], fieldset[disabled] .button.is-success.is-outlined {
  background-color: transparent;
  border-color: #00ad6b;
  box-shadow: none;
  color: #00ad6b;
}
.button.is-success.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-success.is-inverted.is-outlined:hover, .button.is-success.is-inverted.is-outlined.is-hovered, .button.is-success.is-inverted.is-outlined:focus, .button.is-success.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #00ad6b;
}
.button.is-success.is-inverted.is-outlined.is-loading:hover::after, .button.is-success.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-success.is-inverted.is-outlined.is-loading:focus::after, .button.is-success.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #00ad6b #00ad6b !important;
}
.button.is-success.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-success.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-success.is-light {
  background-color: #ebfff7;
  color: #00c278;
}
.button.is-success.is-light:hover, .button.is-success.is-light.is-hovered {
  background-color: #defff2;
  border-color: transparent;
  color: #00c278;
}
.button.is-success.is-light:active, .button.is-success.is-light.is-active {
  background-color: #d1ffed;
  border-color: transparent;
  color: #00c278;
}
.button.is-warning {
  background-color: #ffc400;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-warning:hover, .button.is-warning.is-hovered {
  background-color: #f2ba00;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-warning:focus, .button.is-warning.is-focused {
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-warning:focus:not(:active), .button.is-warning.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(255, 196, 0, 0.25);
}
.button.is-warning:active, .button.is-warning.is-active {
  background-color: #e6b000;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-warning[disabled], fieldset[disabled] .button.is-warning {
  background-color: #ffc400;
  border-color: transparent;
  box-shadow: none;
}
.button.is-warning.is-inverted {
  background-color: rgba(0, 0, 0, 0.7);
  color: #ffc400;
}
.button.is-warning.is-inverted:hover, .button.is-warning.is-inverted.is-hovered {
  background-color: rgba(0, 0, 0, 0.7);
}
.button.is-warning.is-inverted[disabled], fieldset[disabled] .button.is-warning.is-inverted {
  background-color: rgba(0, 0, 0, 0.7);
  border-color: transparent;
  box-shadow: none;
  color: #ffc400;
}
.button.is-warning.is-loading::after {
  border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important;
}
.button.is-warning.is-outlined {
  background-color: transparent;
  border-color: #ffc400;
  color: #ffc400;
}
.button.is-warning.is-outlined:hover, .button.is-warning.is-outlined.is-hovered, .button.is-warning.is-outlined:focus, .button.is-warning.is-outlined.is-focused {
  background-color: #ffc400;
  border-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-warning.is-outlined.is-loading::after {
  border-color: transparent transparent #ffc400 #ffc400 !important;
}
.button.is-warning.is-outlined.is-loading:hover::after, .button.is-warning.is-outlined.is-loading.is-hovered::after, .button.is-warning.is-outlined.is-loading:focus::after, .button.is-warning.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important;
}
.button.is-warning.is-outlined[disabled], fieldset[disabled] .button.is-warning.is-outlined {
  background-color: transparent;
  border-color: #ffc400;
  box-shadow: none;
  color: #ffc400;
}
.button.is-warning.is-inverted.is-outlined {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.7);
  color: rgba(0, 0, 0, 0.7);
}
.button.is-warning.is-inverted.is-outlined:hover, .button.is-warning.is-inverted.is-outlined.is-hovered, .button.is-warning.is-inverted.is-outlined:focus, .button.is-warning.is-inverted.is-outlined.is-focused {
  background-color: rgba(0, 0, 0, 0.7);
  color: #ffc400;
}
.button.is-warning.is-inverted.is-outlined.is-loading:hover::after, .button.is-warning.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-warning.is-inverted.is-outlined.is-loading:focus::after, .button.is-warning.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #ffc400 #ffc400 !important;
}
.button.is-warning.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-warning.is-inverted.is-outlined {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.7);
  box-shadow: none;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-warning.is-light {
  background-color: #fffaeb;
  color: #947100;
}
.button.is-warning.is-light:hover, .button.is-warning.is-light.is-hovered {
  background-color: #fff7de;
  border-color: transparent;
  color: #947100;
}
.button.is-warning.is-light:active, .button.is-warning.is-light.is-active {
  background-color: #fff4d1;
  border-color: transparent;
  color: #947100;
}
.button.is-danger {
  background-color: #e45649;
  border-color: transparent;
  color: #fff;
}
.button.is-danger:hover, .button.is-danger.is-hovered {
  background-color: #e24c3e;
  border-color: transparent;
  color: #fff;
}
.button.is-danger:focus, .button.is-danger.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-danger:focus:not(:active), .button.is-danger.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(228, 86, 73, 0.25);
}
.button.is-danger:active, .button.is-danger.is-active {
  background-color: #e14133;
  border-color: transparent;
  color: #fff;
}
.button.is-danger[disabled], fieldset[disabled] .button.is-danger {
  background-color: #e45649;
  border-color: transparent;
  box-shadow: none;
}
.button.is-danger.is-inverted {
  background-color: #fff;
  color: #e45649;
}
.button.is-danger.is-inverted:hover, .button.is-danger.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-danger.is-inverted[disabled], fieldset[disabled] .button.is-danger.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #e45649;
}
.button.is-danger.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-danger.is-outlined {
  background-color: transparent;
  border-color: #e45649;
  color: #e45649;
}
.button.is-danger.is-outlined:hover, .button.is-danger.is-outlined.is-hovered, .button.is-danger.is-outlined:focus, .button.is-danger.is-outlined.is-focused {
  background-color: #e45649;
  border-color: #e45649;
  color: #fff;
}
.button.is-danger.is-outlined.is-loading::after {
  border-color: transparent transparent #e45649 #e45649 !important;
}
.button.is-danger.is-outlined.is-loading:hover::after, .button.is-danger.is-outlined.is-loading.is-hovered::after, .button.is-danger.is-outlined.is-loading:focus::after, .button.is-danger.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-danger.is-outlined[disabled], fieldset[disabled] .button.is-danger.is-outlined {
  background-color: transparent;
  border-color: #e45649;
  box-shadow: none;
  color: #e45649;
}
.button.is-danger.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-danger.is-inverted.is-outlined:hover, .button.is-danger.is-inverted.is-outlined.is-hovered, .button.is-danger.is-inverted.is-outlined:focus, .button.is-danger.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #e45649;
}
.button.is-danger.is-inverted.is-outlined.is-loading:hover::after, .button.is-danger.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-danger.is-inverted.is-outlined.is-loading:focus::after, .button.is-danger.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #e45649 #e45649 !important;
}
.button.is-danger.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-danger.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-danger.is-light {
  background-color: #fcefed;
  color: #ba291c;
}
.button.is-danger.is-light:hover, .button.is-danger.is-light.is-hovered {
  background-color: #fbe4e2;
  border-color: transparent;
  color: #ba291c;
}
.button.is-danger.is-light:active, .button.is-danger.is-light.is-active {
  background-color: #f9dad7;
  border-color: transparent;
  color: #ba291c;
}
.button.is-redish {
  background-color: #ca1243;
  border-color: transparent;
  color: #fff;
}
.button.is-redish:hover, .button.is-redish.is-hovered {
  background-color: #be113f;
  border-color: transparent;
  color: #fff;
}
.button.is-redish:focus, .button.is-redish.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-redish:focus:not(:active), .button.is-redish.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(202, 18, 67, 0.25);
}
.button.is-redish:active, .button.is-redish.is-active {
  background-color: #b2103b;
  border-color: transparent;
  color: #fff;
}
.button.is-redish[disabled], fieldset[disabled] .button.is-redish {
  background-color: #ca1243;
  border-color: transparent;
  box-shadow: none;
}
.button.is-redish.is-inverted {
  background-color: #fff;
  color: #ca1243;
}
.button.is-redish.is-inverted:hover, .button.is-redish.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-redish.is-inverted[disabled], fieldset[disabled] .button.is-redish.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #ca1243;
}
.button.is-redish.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-redish.is-outlined {
  background-color: transparent;
  border-color: #ca1243;
  color: #ca1243;
}
.button.is-redish.is-outlined:hover, .button.is-redish.is-outlined.is-hovered, .button.is-redish.is-outlined:focus, .button.is-redish.is-outlined.is-focused {
  background-color: #ca1243;
  border-color: #ca1243;
  color: #fff;
}
.button.is-redish.is-outlined.is-loading::after {
  border-color: transparent transparent #ca1243 #ca1243 !important;
}
.button.is-redish.is-outlined.is-loading:hover::after, .button.is-redish.is-outlined.is-loading.is-hovered::after, .button.is-redish.is-outlined.is-loading:focus::after, .button.is-redish.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-redish.is-outlined[disabled], fieldset[disabled] .button.is-redish.is-outlined {
  background-color: transparent;
  border-color: #ca1243;
  box-shadow: none;
  color: #ca1243;
}
.button.is-redish.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-redish.is-inverted.is-outlined:hover, .button.is-redish.is-inverted.is-outlined.is-hovered, .button.is-redish.is-inverted.is-outlined:focus, .button.is-redish.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #ca1243;
}
.button.is-redish.is-inverted.is-outlined.is-loading:hover::after, .button.is-redish.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-redish.is-inverted.is-outlined.is-loading:focus::after, .button.is-redish.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #ca1243 #ca1243 !important;
}
.button.is-redish.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-redish.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-redish.is-light {
  background-color: #fdecf1;
  color: #e6144c;
}
.button.is-redish.is-light:hover, .button.is-redish.is-light.is-hovered {
  background-color: #fce1e8;
  border-color: transparent;
  color: #e6144c;
}
.button.is-redish.is-light:active, .button.is-redish.is-light.is-active {
  background-color: #fbd5df;
  border-color: transparent;
  color: #e6144c;
}
.button.is-blueish {
  background-color: #a3c0ff;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish:hover, .button.is-blueish.is-hovered {
  background-color: #96b7ff;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish:focus, .button.is-blueish.is-focused {
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish:focus:not(:active), .button.is-blueish.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(163, 192, 255, 0.25);
}
.button.is-blueish:active, .button.is-blueish.is-active {
  background-color: #8aafff;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish[disabled], fieldset[disabled] .button.is-blueish {
  background-color: #a3c0ff;
  border-color: transparent;
  box-shadow: none;
}
.button.is-blueish.is-inverted {
  background-color: rgba(0, 0, 0, 0.7);
  color: #a3c0ff;
}
.button.is-blueish.is-inverted:hover, .button.is-blueish.is-inverted.is-hovered {
  background-color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish.is-inverted[disabled], fieldset[disabled] .button.is-blueish.is-inverted {
  background-color: rgba(0, 0, 0, 0.7);
  border-color: transparent;
  box-shadow: none;
  color: #a3c0ff;
}
.button.is-blueish.is-loading::after {
  border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important;
}
.button.is-blueish.is-outlined {
  background-color: transparent;
  border-color: #a3c0ff;
  color: #a3c0ff;
}
.button.is-blueish.is-outlined:hover, .button.is-blueish.is-outlined.is-hovered, .button.is-blueish.is-outlined:focus, .button.is-blueish.is-outlined.is-focused {
  background-color: #a3c0ff;
  border-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish.is-outlined.is-loading::after {
  border-color: transparent transparent #a3c0ff #a3c0ff !important;
}
.button.is-blueish.is-outlined.is-loading:hover::after, .button.is-blueish.is-outlined.is-loading.is-hovered::after, .button.is-blueish.is-outlined.is-loading:focus::after, .button.is-blueish.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important;
}
.button.is-blueish.is-outlined[disabled], fieldset[disabled] .button.is-blueish.is-outlined {
  background-color: transparent;
  border-color: #a3c0ff;
  box-shadow: none;
  color: #a3c0ff;
}
.button.is-blueish.is-inverted.is-outlined {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.7);
  color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish.is-inverted.is-outlined:hover, .button.is-blueish.is-inverted.is-outlined.is-hovered, .button.is-blueish.is-inverted.is-outlined:focus, .button.is-blueish.is-inverted.is-outlined.is-focused {
  background-color: rgba(0, 0, 0, 0.7);
  color: #a3c0ff;
}
.button.is-blueish.is-inverted.is-outlined.is-loading:hover::after, .button.is-blueish.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-blueish.is-inverted.is-outlined.is-loading:focus::after, .button.is-blueish.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #a3c0ff #a3c0ff !important;
}
.button.is-blueish.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-blueish.is-inverted.is-outlined {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.7);
  box-shadow: none;
  color: rgba(0, 0, 0, 0.7);
}
.button.is-blueish.is-light {
  background-color: #ebf1ff;
  color: #002f94;
}
.button.is-blueish.is-light:hover, .button.is-blueish.is-light.is-hovered {
  background-color: #dee8ff;
  border-color: transparent;
  color: #002f94;
}
.button.is-blueish.is-light:active, .button.is-blueish.is-light.is-active {
  background-color: #d1e0ff;
  border-color: transparent;
  color: #002f94;
}
.button.is-pink {
  background-color: #f57fef;
  border-color: transparent;
  color: #fff;
}
.button.is-pink:hover, .button.is-pink.is-hovered {
  background-color: #f473ee;
  border-color: transparent;
  color: #fff;
}
.button.is-pink:focus, .button.is-pink.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-pink:focus:not(:active), .button.is-pink.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(245, 127, 239, 0.25);
}
.button.is-pink:active, .button.is-pink.is-active {
  background-color: #f467ed;
  border-color: transparent;
  color: #fff;
}
.button.is-pink[disabled], fieldset[disabled] .button.is-pink {
  background-color: #f57fef;
  border-color: transparent;
  box-shadow: none;
}
.button.is-pink.is-inverted {
  background-color: #fff;
  color: #f57fef;
}
.button.is-pink.is-inverted:hover, .button.is-pink.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-pink.is-inverted[disabled], fieldset[disabled] .button.is-pink.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #f57fef;
}
.button.is-pink.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-pink.is-outlined {
  background-color: transparent;
  border-color: #f57fef;
  color: #f57fef;
}
.button.is-pink.is-outlined:hover, .button.is-pink.is-outlined.is-hovered, .button.is-pink.is-outlined:focus, .button.is-pink.is-outlined.is-focused {
  background-color: #f57fef;
  border-color: #f57fef;
  color: #fff;
}
.button.is-pink.is-outlined.is-loading::after {
  border-color: transparent transparent #f57fef #f57fef !important;
}
.button.is-pink.is-outlined.is-loading:hover::after, .button.is-pink.is-outlined.is-loading.is-hovered::after, .button.is-pink.is-outlined.is-loading:focus::after, .button.is-pink.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-pink.is-outlined[disabled], fieldset[disabled] .button.is-pink.is-outlined {
  background-color: transparent;
  border-color: #f57fef;
  box-shadow: none;
  color: #f57fef;
}
.button.is-pink.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-pink.is-inverted.is-outlined:hover, .button.is-pink.is-inverted.is-outlined.is-hovered, .button.is-pink.is-inverted.is-outlined:focus, .button.is-pink.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #f57fef;
}
.button.is-pink.is-inverted.is-outlined.is-loading:hover::after, .button.is-pink.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-pink.is-inverted.is-outlined.is-loading:focus::after, .button.is-pink.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #f57fef #f57fef !important;
}
.button.is-pink.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-pink.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-pink.is-light {
  background-color: #feecfd;
  color: #9d0c95;
}
.button.is-pink.is-light:hover, .button.is-pink.is-light.is-hovered {
  background-color: #fde0fb;
  border-color: transparent;
  color: #9d0c95;
}
.button.is-pink.is-light:active, .button.is-pink.is-light.is-active {
  background-color: #fcd4fa;
  border-color: transparent;
  color: #9d0c95;
}
.button.is-gold {
  background-color: #c18401;
  border-color: transparent;
  color: #fff;
}
.button.is-gold:hover, .button.is-gold.is-hovered {
  background-color: #b47b01;
  border-color: transparent;
  color: #fff;
}
.button.is-gold:focus, .button.is-gold.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-gold:focus:not(:active), .button.is-gold.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(193, 132, 1, 0.25);
}
.button.is-gold:active, .button.is-gold.is-active {
  background-color: #a77301;
  border-color: transparent;
  color: #fff;
}
.button.is-gold[disabled], fieldset[disabled] .button.is-gold {
  background-color: #c18401;
  border-color: transparent;
  box-shadow: none;
}
.button.is-gold.is-inverted {
  background-color: #fff;
  color: #c18401;
}
.button.is-gold.is-inverted:hover, .button.is-gold.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-gold.is-inverted[disabled], fieldset[disabled] .button.is-gold.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #c18401;
}
.button.is-gold.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-gold.is-outlined {
  background-color: transparent;
  border-color: #c18401;
  color: #c18401;
}
.button.is-gold.is-outlined:hover, .button.is-gold.is-outlined.is-hovered, .button.is-gold.is-outlined:focus, .button.is-gold.is-outlined.is-focused {
  background-color: #c18401;
  border-color: #c18401;
  color: #fff;
}
.button.is-gold.is-outlined.is-loading::after {
  border-color: transparent transparent #c18401 #c18401 !important;
}
.button.is-gold.is-outlined.is-loading:hover::after, .button.is-gold.is-outlined.is-loading.is-hovered::after, .button.is-gold.is-outlined.is-loading:focus::after, .button.is-gold.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-gold.is-outlined[disabled], fieldset[disabled] .button.is-gold.is-outlined {
  background-color: transparent;
  border-color: #c18401;
  box-shadow: none;
  color: #c18401;
}
.button.is-gold.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-gold.is-inverted.is-outlined:hover, .button.is-gold.is-inverted.is-outlined.is-hovered, .button.is-gold.is-inverted.is-outlined:focus, .button.is-gold.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #c18401;
}
.button.is-gold.is-inverted.is-outlined.is-loading:hover::after, .button.is-gold.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-gold.is-inverted.is-outlined.is-loading:focus::after, .button.is-gold.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #c18401 #c18401 !important;
}
.button.is-gold.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-gold.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-gold.is-light {
  background-color: #fff9eb;
  color: #c68801;
}
.button.is-gold.is-light:hover, .button.is-gold.is-light.is-hovered {
  background-color: #fff4de;
  border-color: transparent;
  color: #c68801;
}
.button.is-gold.is-light:active, .button.is-gold.is-light.is-active {
  background-color: #fff0d1;
  border-color: transparent;
  color: #c68801;
}
.button.is-greenish {
  background-color: #5ea14f;
  border-color: transparent;
  color: #fff;
}
.button.is-greenish:hover, .button.is-greenish.is-hovered {
  background-color: #59984b;
  border-color: transparent;
  color: #fff;
}
.button.is-greenish:focus, .button.is-greenish.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-greenish:focus:not(:active), .button.is-greenish.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(94, 161, 79, 0.25);
}
.button.is-greenish:active, .button.is-greenish.is-active {
  background-color: #549047;
  border-color: transparent;
  color: #fff;
}
.button.is-greenish[disabled], fieldset[disabled] .button.is-greenish {
  background-color: #5ea14f;
  border-color: transparent;
  box-shadow: none;
}
.button.is-greenish.is-inverted {
  background-color: #fff;
  color: #5ea14f;
}
.button.is-greenish.is-inverted:hover, .button.is-greenish.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-greenish.is-inverted[disabled], fieldset[disabled] .button.is-greenish.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #5ea14f;
}
.button.is-greenish.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-greenish.is-outlined {
  background-color: transparent;
  border-color: #5ea14f;
  color: #5ea14f;
}
.button.is-greenish.is-outlined:hover, .button.is-greenish.is-outlined.is-hovered, .button.is-greenish.is-outlined:focus, .button.is-greenish.is-outlined.is-focused {
  background-color: #5ea14f;
  border-color: #5ea14f;
  color: #fff;
}
.button.is-greenish.is-outlined.is-loading::after {
  border-color: transparent transparent #5ea14f #5ea14f !important;
}
.button.is-greenish.is-outlined.is-loading:hover::after, .button.is-greenish.is-outlined.is-loading.is-hovered::after, .button.is-greenish.is-outlined.is-loading:focus::after, .button.is-greenish.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-greenish.is-outlined[disabled], fieldset[disabled] .button.is-greenish.is-outlined {
  background-color: transparent;
  border-color: #5ea14f;
  box-shadow: none;
  color: #5ea14f;
}
.button.is-greenish.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-greenish.is-inverted.is-outlined:hover, .button.is-greenish.is-inverted.is-outlined.is-hovered, .button.is-greenish.is-inverted.is-outlined:focus, .button.is-greenish.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #5ea14f;
}
.button.is-greenish.is-inverted.is-outlined.is-loading:hover::after, .button.is-greenish.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-greenish.is-inverted.is-outlined.is-loading:focus::after, .button.is-greenish.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #5ea14f #5ea14f !important;
}
.button.is-greenish.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-greenish.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-greenish.is-light {
  background-color: #f3f8f1;
  color: #4e8542;
}
.button.is-greenish.is-light:hover, .button.is-greenish.is-light.is-hovered {
  background-color: #ebf4e9;
  border-color: transparent;
  color: #4e8542;
}
.button.is-greenish.is-light:active, .button.is-greenish.is-light.is-active {
  background-color: #e3f0e0;
  border-color: transparent;
  color: #4e8542;
}
.button.is-blood {
  background-color: #39040c;
  border-color: transparent;
  color: #fff;
}
.button.is-blood:hover, .button.is-blood.is-hovered {
  background-color: #2d0309;
  border-color: transparent;
  color: #fff;
}
.button.is-blood:focus, .button.is-blood.is-focused {
  border-color: transparent;
  color: #fff;
}
.button.is-blood:focus:not(:active), .button.is-blood.is-focused:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(57, 4, 12, 0.25);
}
.button.is-blood:active, .button.is-blood.is-active {
  background-color: #210207;
  border-color: transparent;
  color: #fff;
}
.button.is-blood[disabled], fieldset[disabled] .button.is-blood {
  background-color: #39040c;
  border-color: transparent;
  box-shadow: none;
}
.button.is-blood.is-inverted {
  background-color: #fff;
  color: #39040c;
}
.button.is-blood.is-inverted:hover, .button.is-blood.is-inverted.is-hovered {
  background-color: #f2f2f2;
}
.button.is-blood.is-inverted[disabled], fieldset[disabled] .button.is-blood.is-inverted {
  background-color: #fff;
  border-color: transparent;
  box-shadow: none;
  color: #39040c;
}
.button.is-blood.is-loading::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-blood.is-outlined {
  background-color: transparent;
  border-color: #39040c;
  color: #39040c;
}
.button.is-blood.is-outlined:hover, .button.is-blood.is-outlined.is-hovered, .button.is-blood.is-outlined:focus, .button.is-blood.is-outlined.is-focused {
  background-color: #39040c;
  border-color: #39040c;
  color: #fff;
}
.button.is-blood.is-outlined.is-loading::after {
  border-color: transparent transparent #39040c #39040c !important;
}
.button.is-blood.is-outlined.is-loading:hover::after, .button.is-blood.is-outlined.is-loading.is-hovered::after, .button.is-blood.is-outlined.is-loading:focus::after, .button.is-blood.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #fff #fff !important;
}
.button.is-blood.is-outlined[disabled], fieldset[disabled] .button.is-blood.is-outlined {
  background-color: transparent;
  border-color: #39040c;
  box-shadow: none;
  color: #39040c;
}
.button.is-blood.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  color: #fff;
}
.button.is-blood.is-inverted.is-outlined:hover, .button.is-blood.is-inverted.is-outlined.is-hovered, .button.is-blood.is-inverted.is-outlined:focus, .button.is-blood.is-inverted.is-outlined.is-focused {
  background-color: #fff;
  color: #39040c;
}
.button.is-blood.is-inverted.is-outlined.is-loading:hover::after, .button.is-blood.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-blood.is-inverted.is-outlined.is-loading:focus::after, .button.is-blood.is-inverted.is-outlined.is-loading.is-focused::after {
  border-color: transparent transparent #39040c #39040c !important;
}
.button.is-blood.is-inverted.is-outlined[disabled], fieldset[disabled] .button.is-blood.is-inverted.is-outlined {
  background-color: transparent;
  border-color: #fff;
  box-shadow: none;
  color: #fff;
}
.button.is-blood.is-light {
  background-color: #feecef;
  color: #f02d4a;
}
.button.is-blood.is-light:hover, .button.is-blood.is-light.is-hovered {
  background-color: #fde0e4;
  border-color: transparent;
  color: #f02d4a;
}
.button.is-blood.is-light:active, .button.is-blood.is-light.is-active {
  background-color: #fcd4da;
  border-color: transparent;
  color: #f02d4a;
}
.button.is-small {
  font-size: 0.75rem;
}
.button.is-small:not(.is-rounded) {
  border-radius: 2px;
}
.button.is-normal {
  font-size: 1rem;
}
.button.is-medium {
  font-size: 1.25rem;
}
.button.is-large {
  font-size: 1.5rem;
}
.button[disabled], fieldset[disabled] .button {
  background-color: #fafafa;
  border-color: #c9d1d9;
  box-shadow: none;
  opacity: 0.5;
}
.button.is-fullwidth {
  display: flex;
  width: 100%;
}
.button.is-loading {
  color: transparent !important;
  pointer-events: none;
}
.button.is-loading::after {
  position: absolute;
  left: calc(50% - (1em * 0.5));
  top: calc(50% - (1em * 0.5));
  position: absolute !important;
}
.button.is-static {
  background-color: #faf0f0;
  border-color: #c9d1d9;
  color: #6f727b;
  box-shadow: none;
  pointer-events: none;
}
.button.is-rounded {
  border-radius: 9999px;
  padding-left: calc(1em + 0.25em);
  padding-right: calc(1em + 0.25em);
}

.buttons {
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-start;
}
.buttons .button {
  margin-bottom: 0.5rem;
}
.buttons .button:not(:last-child):not(.is-fullwidth) {
  margin-right: 0.5rem;
}
.buttons:last-child {
  margin-bottom: -0.5rem;
}
.buttons:not(:last-child) {
  margin-bottom: 1rem;
}
.buttons.are-small .button:not(.is-normal):not(.is-medium):not(.is-large) {
  font-size: 0.75rem;
}
.buttons.are-small .button:not(.is-normal):not(.is-medium):not(.is-large):not(.is-rounded) {
  border-radius: 2px;
}
.buttons.are-medium .button:not(.is-small):not(.is-normal):not(.is-large) {
  font-size: 1.25rem;
}
.buttons.are-large .button:not(.is-small):not(.is-normal):not(.is-medium) {
  font-size: 1.5rem;
}
.buttons.has-addons .button:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.buttons.has-addons .button:not(:last-child) {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
  margin-right: -1px;
}
.buttons.has-addons .button:last-child {
  margin-right: 0;
}
.buttons.has-addons .button:hover, .buttons.has-addons .button.is-hovered {
  z-index: 2;
}
.buttons.has-addons .button:focus, .buttons.has-addons .button.is-focused, .buttons.has-addons .button:active, .buttons.has-addons .button.is-active, .buttons.has-addons .button.is-selected {
  z-index: 3;
}
.buttons.has-addons .button:focus:hover, .buttons.has-addons .button.is-focused:hover, .buttons.has-addons .button:active:hover, .buttons.has-addons .button.is-active:hover, .buttons.has-addons .button.is-selected:hover {
  z-index: 4;
}
.buttons.has-addons .button.is-expanded {
  flex-grow: 1;
  flex-shrink: 1;
}
.buttons.is-centered {
  justify-content: center;
}
.buttons.is-centered:not(.has-addons) .button:not(.is-fullwidth) {
  margin-left: 0.25rem;
  margin-right: 0.25rem;
}
.buttons.is-right {
  justify-content: flex-end;
}
.buttons.is-right:not(.has-addons) .button:not(.is-fullwidth) {
  margin-left: 0.25rem;
  margin-right: 0.25rem;
}

.container {
  flex-grow: 1;
  margin: 0 auto;
  position: relative;
  width: auto;
}
.container.is-fluid {
  max-width: none !important;
  padding-left: 32px;
  padding-right: 32px;
  width: 100%;
}
@media screen and (min-width: 1024px) {
  .container {
    max-width: 960px;
  }
}
@media screen and (max-width: 1215px) {
  .container.is-widescreen:not(.is-max-desktop) {
    max-width: 1152px;
  }
}
@media screen and (max-width: 1407px) {
  .container.is-fullhd:not(.is-max-desktop):not(.is-max-widescreen) {
    max-width: 1344px;
  }
}
@media screen and (min-width: 1216px) {
  .container:not(.is-max-desktop) {
    max-width: 1152px;
  }
}
@media screen and (min-width: 1408px) {
  .container:not(.is-max-desktop):not(.is-max-widescreen) {
    max-width: 1344px;
  }
}

.content li + li {
  margin-top: 0.25em;
}
.content p:not(:last-child),
.content dl:not(:last-child),
.content ol:not(:last-child),
.content ul:not(:last-child),
.content blockquote:not(:last-child),
.content pre:not(:last-child),
.content table:not(:last-child) {
  margin-bottom: 1em;
}
.content h1,
.content h2,
.content h3,
.content h4,
.content h5,
.content h6 {
  color: #2f3546;
  font-weight: 600;
  line-height: 1.125;
}
.content h1 {
  font-size: 2em;
  margin-bottom: 0.5em;
}
.content h1:not(:first-child) {
  margin-top: 1em;
}
.content h2 {
  font-size: 1.75em;
  margin-bottom: 0.5714em;
}
.content h2:not(:first-child) {
  margin-top: 1.1428em;
}
.content h3 {
  font-size: 1.5em;
  margin-bottom: 0.6666em;
}
.content h3:not(:first-child) {
  margin-top: 1.3333em;
}
.content h4 {
  font-size: 1.25em;
  margin-bottom: 0.8em;
}
.content h5 {
  font-size: 1.125em;
  margin-bottom: 0.8888em;
}
.content h6 {
  font-size: 1em;
  margin-bottom: 1em;
}
.content blockquote {
  background-color: #faf0f0;
  border-left: 5px solid #c9d1d9;
  padding: 1.25em 1.5em;
}
.content ol {
  list-style-position: outside;
  margin-left: 2em;
  margin-top: 1em;
}
.content ol:not([type]) {
  list-style-type: decimal;
}
.content ol:not([type]).is-lower-alpha {
  list-style-type: lower-alpha;
}
.content ol:not([type]).is-lower-roman {
  list-style-type: lower-roman;
}
.content ol:not([type]).is-upper-alpha {
  list-style-type: upper-alpha;
}
.content ol:not([type]).is-upper-roman {
  list-style-type: upper-roman;
}
.content ul {
  list-style: disc outside;
  margin-left: 2em;
  margin-top: 1em;
}
.content ul ul {
  list-style-type: circle;
  margin-top: 0.5em;
}
.content ul ul ul {
  list-style-type: square;
}
.content dd {
  margin-left: 2em;
}
.content figure {
  margin-left: 2em;
  margin-right: 2em;
  text-align: center;
}
.content figure:not(:first-child) {
  margin-top: 2em;
}
.content figure:not(:last-child) {
  margin-bottom: 2em;
}
.content figure img {
  display: inline-block;
}
.content figure figcaption {
  font-style: italic;
}
.content pre {
  -webkit-overflow-scrolling: touch;
  overflow-x: auto;
  padding: 1.25em 1.5em;
  white-space: pre;
  word-wrap: normal;
}
.content sup,
.content sub {
  font-size: 75%;
}
.content table {
  width: 100%;
}
.content table td,
.content table th {
  border: 1px solid #c9d1d9;
  border-width: 0 0 1px;
  padding: 0.5em 0.75em;
  vertical-align: top;
}
.content table th {
  color: #2f3546;
}
.content table th:not([align]) {
  text-align: inherit;
}
.content table thead td,
.content table thead th {
  border-width: 0 0 2px;
  color: #2f3546;
}
.content table tfoot td,
.content table tfoot th {
  border-width: 2px 0 0;
  color: #2f3546;
}
.content table tbody tr:last-child td,
.content table tbody tr:last-child th {
  border-bottom-width: 0;
}
.content .tabs li + li {
  margin-top: 0;
}
.content.is-small {
  font-size: 0.75rem;
}
.content.is-normal {
  font-size: 1rem;
}
.content.is-medium {
  font-size: 1.25rem;
}
.content.is-large {
  font-size: 1.5rem;
}

.icon {
  align-items: center;
  display: inline-flex;
  justify-content: center;
  height: 1.5rem;
  width: 1.5rem;
}
.icon.is-small {
  height: 1rem;
  width: 1rem;
}
.icon.is-medium {
  height: 2rem;
  width: 2rem;
}
.icon.is-large {
  height: 3rem;
  width: 3rem;
}

.icon-text {
  align-items: flex-start;
  color: inherit;
  display: inline-flex;
  flex-wrap: wrap;
  line-height: 1.5rem;
  vertical-align: top;
}
.icon-text .icon {
  flex-grow: 0;
  flex-shrink: 0;
}
.icon-text .icon:not(:last-child) {
  margin-right: 0.25em;
}
.icon-text .icon:not(:first-child) {
  margin-left: 0.25em;
}

div.icon-text {
  display: flex;
}

.image, #search-results figure,
.content figure,
.document figure {
  display: block;
  position: relative;
}
.image img, #search-results figure img,
.content figure img,
.document figure img {
  display: block;
  height: auto;
  width: 100%;
}
.image img.is-rounded, #search-results figure img.is-rounded,
.content figure img.is-rounded,
.document figure img.is-rounded {
  border-radius: 9999px;
}
.image.is-fullwidth, #search-results figure.is-fullwidth,
.content figure.is-fullwidth,
.document figure.is-fullwidth {
  width: 100%;
}
.image.is-square img, #search-results figure.is-square img,
.content figure.is-square img,
.document figure.is-square img,
.image.is-square .has-ratio,
#search-results figure.is-square .has-ratio,
.content figure.is-square .has-ratio,
.document figure.is-square .has-ratio, .image.is-1by1 img, #search-results figure.is-1by1 img,
.content figure.is-1by1 img,
.document figure.is-1by1 img,
.image.is-1by1 .has-ratio,
#search-results figure.is-1by1 .has-ratio,
.content figure.is-1by1 .has-ratio,
.document figure.is-1by1 .has-ratio, .image.is-5by4 img, #search-results figure.is-5by4 img,
.content figure.is-5by4 img,
.document figure.is-5by4 img,
.image.is-5by4 .has-ratio,
#search-results figure.is-5by4 .has-ratio,
.content figure.is-5by4 .has-ratio,
.document figure.is-5by4 .has-ratio, .image.is-4by3 img, #search-results figure.is-4by3 img,
.content figure.is-4by3 img,
.document figure.is-4by3 img,
.image.is-4by3 .has-ratio,
#search-results figure.is-4by3 .has-ratio,
.content figure.is-4by3 .has-ratio,
.document figure.is-4by3 .has-ratio, .image.is-3by2 img, #search-results figure.is-3by2 img,
.content figure.is-3by2 img,
.document figure.is-3by2 img,
.image.is-3by2 .has-ratio,
#search-results figure.is-3by2 .has-ratio,
.content figure.is-3by2 .has-ratio,
.document figure.is-3by2 .has-ratio, .image.is-5by3 img, #search-results figure.is-5by3 img,
.content figure.is-5by3 img,
.document figure.is-5by3 img,
.image.is-5by3 .has-ratio,
#search-results figure.is-5by3 .has-ratio,
.content figure.is-5by3 .has-ratio,
.document figure.is-5by3 .has-ratio, .image.is-16by9 img, #search-results figure.is-16by9 img,
.content figure.is-16by9 img,
.document figure.is-16by9 img,
.image.is-16by9 .has-ratio,
#search-results figure.is-16by9 .has-ratio,
.content figure.is-16by9 .has-ratio,
.document figure.is-16by9 .has-ratio, .image.is-2by1 img, #search-results figure.is-2by1 img,
.content figure.is-2by1 img,
.document figure.is-2by1 img,
.image.is-2by1 .has-ratio,
#search-results figure.is-2by1 .has-ratio,
.content figure.is-2by1 .has-ratio,
.document figure.is-2by1 .has-ratio, .image.is-3by1 img, #search-results figure.is-3by1 img,
.content figure.is-3by1 img,
.document figure.is-3by1 img,
.image.is-3by1 .has-ratio,
#search-results figure.is-3by1 .has-ratio,
.content figure.is-3by1 .has-ratio,
.document figure.is-3by1 .has-ratio, .image.is-4by5 img, #search-results figure.is-4by5 img,
.content figure.is-4by5 img,
.document figure.is-4by5 img,
.image.is-4by5 .has-ratio,
#search-results figure.is-4by5 .has-ratio,
.content figure.is-4by5 .has-ratio,
.document figure.is-4by5 .has-ratio, .image.is-3by4 img, #search-results figure.is-3by4 img,
.content figure.is-3by4 img,
.document figure.is-3by4 img,
.image.is-3by4 .has-ratio,
#search-results figure.is-3by4 .has-ratio,
.content figure.is-3by4 .has-ratio,
.document figure.is-3by4 .has-ratio, .image.is-2by3 img, #search-results figure.is-2by3 img,
.content figure.is-2by3 img,
.document figure.is-2by3 img,
.image.is-2by3 .has-ratio,
#search-results figure.is-2by3 .has-ratio,
.content figure.is-2by3 .has-ratio,
.document figure.is-2by3 .has-ratio, .image.is-3by5 img, #search-results figure.is-3by5 img,
.content figure.is-3by5 img,
.document figure.is-3by5 img,
.image.is-3by5 .has-ratio,
#search-results figure.is-3by5 .has-ratio,
.content figure.is-3by5 .has-ratio,
.document figure.is-3by5 .has-ratio, .image.is-9by16 img, #search-results figure.is-9by16 img,
.content figure.is-9by16 img,
.document figure.is-9by16 img,
.image.is-9by16 .has-ratio,
#search-results figure.is-9by16 .has-ratio,
.content figure.is-9by16 .has-ratio,
.document figure.is-9by16 .has-ratio, .image.is-1by2 img, #search-results figure.is-1by2 img,
.content figure.is-1by2 img,
.document figure.is-1by2 img,
.image.is-1by2 .has-ratio,
#search-results figure.is-1by2 .has-ratio,
.content figure.is-1by2 .has-ratio,
.document figure.is-1by2 .has-ratio, .image.is-1by3 img, #search-results figure.is-1by3 img,
.content figure.is-1by3 img,
.document figure.is-1by3 img,
.image.is-1by3 .has-ratio,
#search-results figure.is-1by3 .has-ratio,
.content figure.is-1by3 .has-ratio,
.document figure.is-1by3 .has-ratio {
  height: 100%;
  width: 100%;
}
.image.is-square, #search-results figure.is-square,
.content figure.is-square,
.document figure.is-square, .image.is-1by1, #search-results figure.is-1by1,
.content figure.is-1by1,
.document figure.is-1by1 {
  padding-top: 100%;
}
.image.is-5by4, #search-results figure.is-5by4,
.content figure.is-5by4,
.document figure.is-5by4 {
  padding-top: 80%;
}
.image.is-4by3, #search-results figure.is-4by3,
.content figure.is-4by3,
.document figure.is-4by3 {
  padding-top: 75%;
}
.image.is-3by2, #search-results figure.is-3by2,
.content figure.is-3by2,
.document figure.is-3by2 {
  padding-top: 66.6666%;
}
.image.is-5by3, #search-results figure.is-5by3,
.content figure.is-5by3,
.document figure.is-5by3 {
  padding-top: 60%;
}
.image.is-16by9, #search-results figure.is-16by9,
.content figure.is-16by9,
.document figure.is-16by9 {
  padding-top: 56.25%;
}
.image.is-2by1, #search-results figure.is-2by1,
.content figure.is-2by1,
.document figure.is-2by1 {
  padding-top: 50%;
}
.image.is-3by1, #search-results figure.is-3by1,
.content figure.is-3by1,
.document figure.is-3by1 {
  padding-top: 33.3333%;
}
.image.is-4by5, #search-results figure.is-4by5,
.content figure.is-4by5,
.document figure.is-4by5 {
  padding-top: 125%;
}
.image.is-3by4, #search-results figure.is-3by4,
.content figure.is-3by4,
.document figure.is-3by4 {
  padding-top: 133.3333%;
}
.image.is-2by3, #search-results figure.is-2by3,
.content figure.is-2by3,
.document figure.is-2by3 {
  padding-top: 150%;
}
.image.is-3by5, #search-results figure.is-3by5,
.content figure.is-3by5,
.document figure.is-3by5 {
  padding-top: 166.6666%;
}
.image.is-9by16, #search-results figure.is-9by16,
.content figure.is-9by16,
.document figure.is-9by16 {
  padding-top: 177.7777%;
}
.image.is-1by2, #search-results figure.is-1by2,
.content figure.is-1by2,
.document figure.is-1by2 {
  padding-top: 200%;
}
.image.is-1by3, #search-results figure.is-1by3,
.content figure.is-1by3,
.document figure.is-1by3 {
  padding-top: 300%;
}
.image.is-16x16, #search-results figure.is-16x16,
.content figure.is-16x16,
.document figure.is-16x16 {
  height: 16px;
  width: 16px;
}
.image.is-24x24, #search-results figure.is-24x24,
.content figure.is-24x24,
.document figure.is-24x24 {
  height: 24px;
  width: 24px;
}
.image.is-32x32, #search-results figure.is-32x32,
.content figure.is-32x32,
.document figure.is-32x32 {
  height: 32px;
  width: 32px;
}
.image.is-48x48, #search-results figure.is-48x48,
.content figure.is-48x48,
.document figure.is-48x48 {
  height: 48px;
  width: 48px;
}
.image.is-64x64, #search-results figure.is-64x64,
.content figure.is-64x64,
.document figure.is-64x64 {
  height: 64px;
  width: 64px;
}
.image.is-96x96, #search-results figure.is-96x96,
.content figure.is-96x96,
.document figure.is-96x96 {
  height: 96px;
  width: 96px;
}
.image.is-128x128, #search-results figure.is-128x128,
.content figure.is-128x128,
.document figure.is-128x128 {
  height: 128px;
  width: 128px;
}

.notification {
  background-color: #faf0f0;
  border-radius: 4px;
  position: relative;
  padding: 1.25rem 2.5rem 1.25rem 1.5rem;
}
.notification a:not(.button):not(.dropdown-item) {
  color: currentColor;
  text-decoration: underline;
}
.notification strong {
  color: currentColor;
}
.notification code,
.notification pre {
  background: #fafafa;
}
.notification pre code {
  background: transparent;
}
.notification > .delete {
  right: 0.5rem;
  position: absolute;
  top: 0.5rem;
}
.notification .title, .notification .dark-palette #search-results .topic-title, .dark-palette #search-results .notification .topic-title,
.notification .dark-palette .content .topic-title,
.dark-palette .content .notification .topic-title,
.notification .dark-palette .document .topic-title,
.dark-palette .document .notification .topic-title, .notification .light-palette #search-results .topic-title, .light-palette #search-results .notification .topic-title,
.notification .light-palette .content .topic-title,
.light-palette .content .notification .topic-title,
.notification .light-palette .document .topic-title,
.light-palette .document .notification .topic-title,
.notification .subtitle,
.notification .content {
  color: currentColor;
}
.notification.is-white {
  background-color: #fafafa;
  color: #0d1117;
}
.notification.is-black {
  background-color: #0d1117;
  color: #fafafa;
}
.notification.is-light {
  background-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.notification.is-dark {
  background-color: #2f3546;
  color: #fff;
}
.notification.is-primary {
  background-color: #885bfb;
  color: white;
}
.notification.is-primary.is-light {
  background-color: #f1ebfe;
  color: #4206db;
}
.notification.is-link {
  background-color: #4078f2;
  color: #736a59;
}
.notification.is-link.is-light {
  background-color: #88abf7;
  color: #30529c;
}
.notification.is-info {
  background-color: #449cc5;
  color: #fff;
}
.notification.is-info.is-light {
  background-color: #eff7fa;
  color: #2f7798;
}
.notification.is-success {
  background-color: #00ad6b;
  color: #fff;
}
.notification.is-success.is-light {
  background-color: #ebfff7;
  color: #00c278;
}
.notification.is-warning {
  background-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.notification.is-warning.is-light {
  background-color: #fffaeb;
  color: #947100;
}
.notification.is-danger {
  background-color: #e45649;
  color: #fff;
}
.notification.is-danger.is-light {
  background-color: #fcefed;
  color: #ba291c;
}
.notification.is-redish {
  background-color: #ca1243;
  color: #fff;
}
.notification.is-redish.is-light {
  background-color: #fdecf1;
  color: #e6144c;
}
.notification.is-blueish {
  background-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.notification.is-blueish.is-light {
  background-color: #ebf1ff;
  color: #002f94;
}
.notification.is-pink {
  background-color: #f57fef;
  color: #fff;
}
.notification.is-pink.is-light {
  background-color: #feecfd;
  color: #9d0c95;
}
.notification.is-gold {
  background-color: #c18401;
  color: #fff;
}
.notification.is-gold.is-light {
  background-color: #fff9eb;
  color: #c68801;
}
.notification.is-greenish {
  background-color: #5ea14f;
  color: #fff;
}
.notification.is-greenish.is-light {
  background-color: #f3f8f1;
  color: #4e8542;
}
.notification.is-blood {
  background-color: #39040c;
  color: #fff;
}
.notification.is-blood.is-light {
  background-color: #feecef;
  color: #f02d4a;
}

.progress {
  -moz-appearance: none;
  -webkit-appearance: none;
  border: none;
  border-radius: 9999px;
  display: block;
  height: 1rem;
  overflow: hidden;
  padding: 0;
  width: 100%;
}
.progress::-webkit-progress-bar {
  background-color: #e5dcdc;
}
.progress::-webkit-progress-value {
  background-color: #3e4551;
}
.progress::-moz-progress-bar {
  background-color: #3e4551;
}
.progress::-ms-fill {
  background-color: #3e4551;
  border: none;
}
.progress.is-white::-webkit-progress-value {
  background-color: #fafafa;
}
.progress.is-white::-moz-progress-bar {
  background-color: #fafafa;
}
.progress.is-white::-ms-fill {
  background-color: #fafafa;
}
.progress.is-white:indeterminate {
  background-image: linear-gradient(to right, #fafafa 30%, #e5dcdc 30%);
}
.progress.is-black::-webkit-progress-value {
  background-color: #0d1117;
}
.progress.is-black::-moz-progress-bar {
  background-color: #0d1117;
}
.progress.is-black::-ms-fill {
  background-color: #0d1117;
}
.progress.is-black:indeterminate {
  background-image: linear-gradient(to right, #0d1117 30%, #e5dcdc 30%);
}
.progress.is-light::-webkit-progress-value {
  background-color: #faf0f0;
}
.progress.is-light::-moz-progress-bar {
  background-color: #faf0f0;
}
.progress.is-light::-ms-fill {
  background-color: #faf0f0;
}
.progress.is-light:indeterminate {
  background-image: linear-gradient(to right, #faf0f0 30%, #e5dcdc 30%);
}
.progress.is-dark::-webkit-progress-value {
  background-color: #2f3546;
}
.progress.is-dark::-moz-progress-bar {
  background-color: #2f3546;
}
.progress.is-dark::-ms-fill {
  background-color: #2f3546;
}
.progress.is-dark:indeterminate {
  background-image: linear-gradient(to right, #2f3546 30%, #e5dcdc 30%);
}
.progress.is-primary::-webkit-progress-value {
  background-color: #885bfb;
}
.progress.is-primary::-moz-progress-bar {
  background-color: #885bfb;
}
.progress.is-primary::-ms-fill {
  background-color: #885bfb;
}
.progress.is-primary:indeterminate {
  background-image: linear-gradient(to right, #885bfb 30%, #e5dcdc 30%);
}
.progress.is-link::-webkit-progress-value {
  background-color: #4078f2;
}
.progress.is-link::-moz-progress-bar {
  background-color: #4078f2;
}
.progress.is-link::-ms-fill {
  background-color: #4078f2;
}
.progress.is-link:indeterminate {
  background-image: linear-gradient(to right, #4078f2 30%, #e5dcdc 30%);
}
.progress.is-info::-webkit-progress-value {
  background-color: #449cc5;
}
.progress.is-info::-moz-progress-bar {
  background-color: #449cc5;
}
.progress.is-info::-ms-fill {
  background-color: #449cc5;
}
.progress.is-info:indeterminate {
  background-image: linear-gradient(to right, #449cc5 30%, #e5dcdc 30%);
}
.progress.is-success::-webkit-progress-value {
  background-color: #00ad6b;
}
.progress.is-success::-moz-progress-bar {
  background-color: #00ad6b;
}
.progress.is-success::-ms-fill {
  background-color: #00ad6b;
}
.progress.is-success:indeterminate {
  background-image: linear-gradient(to right, #00ad6b 30%, #e5dcdc 30%);
}
.progress.is-warning::-webkit-progress-value {
  background-color: #ffc400;
}
.progress.is-warning::-moz-progress-bar {
  background-color: #ffc400;
}
.progress.is-warning::-ms-fill {
  background-color: #ffc400;
}
.progress.is-warning:indeterminate {
  background-image: linear-gradient(to right, #ffc400 30%, #e5dcdc 30%);
}
.progress.is-danger::-webkit-progress-value {
  background-color: #e45649;
}
.progress.is-danger::-moz-progress-bar {
  background-color: #e45649;
}
.progress.is-danger::-ms-fill {
  background-color: #e45649;
}
.progress.is-danger:indeterminate {
  background-image: linear-gradient(to right, #e45649 30%, #e5dcdc 30%);
}
.progress.is-redish::-webkit-progress-value {
  background-color: #ca1243;
}
.progress.is-redish::-moz-progress-bar {
  background-color: #ca1243;
}
.progress.is-redish::-ms-fill {
  background-color: #ca1243;
}
.progress.is-redish:indeterminate {
  background-image: linear-gradient(to right, #ca1243 30%, #e5dcdc 30%);
}
.progress.is-blueish::-webkit-progress-value {
  background-color: #a3c0ff;
}
.progress.is-blueish::-moz-progress-bar {
  background-color: #a3c0ff;
}
.progress.is-blueish::-ms-fill {
  background-color: #a3c0ff;
}
.progress.is-blueish:indeterminate {
  background-image: linear-gradient(to right, #a3c0ff 30%, #e5dcdc 30%);
}
.progress.is-pink::-webkit-progress-value {
  background-color: #f57fef;
}
.progress.is-pink::-moz-progress-bar {
  background-color: #f57fef;
}
.progress.is-pink::-ms-fill {
  background-color: #f57fef;
}
.progress.is-pink:indeterminate {
  background-image: linear-gradient(to right, #f57fef 30%, #e5dcdc 30%);
}
.progress.is-gold::-webkit-progress-value {
  background-color: #c18401;
}
.progress.is-gold::-moz-progress-bar {
  background-color: #c18401;
}
.progress.is-gold::-ms-fill {
  background-color: #c18401;
}
.progress.is-gold:indeterminate {
  background-image: linear-gradient(to right, #c18401 30%, #e5dcdc 30%);
}
.progress.is-greenish::-webkit-progress-value {
  background-color: #5ea14f;
}
.progress.is-greenish::-moz-progress-bar {
  background-color: #5ea14f;
}
.progress.is-greenish::-ms-fill {
  background-color: #5ea14f;
}
.progress.is-greenish:indeterminate {
  background-image: linear-gradient(to right, #5ea14f 30%, #e5dcdc 30%);
}
.progress.is-blood::-webkit-progress-value {
  background-color: #39040c;
}
.progress.is-blood::-moz-progress-bar {
  background-color: #39040c;
}
.progress.is-blood::-ms-fill {
  background-color: #39040c;
}
.progress.is-blood:indeterminate {
  background-image: linear-gradient(to right, #39040c 30%, #e5dcdc 30%);
}
.progress:indeterminate {
  animation-duration: 1.5s;
  animation-iteration-count: infinite;
  animation-name: moveIndeterminate;
  animation-timing-function: linear;
  background-color: #e5dcdc;
  background-image: linear-gradient(to right, #3e4551 30%, #e5dcdc 30%);
  background-position: top left;
  background-repeat: no-repeat;
  background-size: 150% 150%;
}
.progress:indeterminate::-webkit-progress-bar {
  background-color: transparent;
}
.progress:indeterminate::-moz-progress-bar {
  background-color: transparent;
}
.progress:indeterminate::-ms-fill {
  animation-name: none;
}
.progress.is-small {
  height: 0.75rem;
}
.progress.is-medium {
  height: 1.25rem;
}
.progress.is-large {
  height: 1.5rem;
}

@keyframes moveIndeterminate {
  from {
    background-position: 200% 0;
  }
  to {
    background-position: -200% 0;
  }
}
.table {
  background-color: #fafafa;
  color: #2f3546;
}
.table td,
.table th {
  border: 1px solid #c9d1d9;
  border-width: 0 0 1px;
  padding: 0.5em 0.75em;
  vertical-align: top;
}
.table td.is-white,
.table th.is-white {
  background-color: #fafafa;
  border-color: #fafafa;
  color: #0d1117;
}
.table td.is-black,
.table th.is-black {
  background-color: #0d1117;
  border-color: #0d1117;
  color: #fafafa;
}
.table td.is-light,
.table th.is-light {
  background-color: #faf0f0;
  border-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.table td.is-dark,
.table th.is-dark {
  background-color: #2f3546;
  border-color: #2f3546;
  color: #fff;
}
.table td.is-primary,
.table th.is-primary {
  background-color: #885bfb;
  border-color: #885bfb;
  color: white;
}
.table td.is-link,
.table th.is-link {
  background-color: #4078f2;
  border-color: #4078f2;
  color: #736a59;
}
.table td.is-info,
.table th.is-info {
  background-color: #449cc5;
  border-color: #449cc5;
  color: #fff;
}
.table td.is-success,
.table th.is-success {
  background-color: #00ad6b;
  border-color: #00ad6b;
  color: #fff;
}
.table td.is-warning,
.table th.is-warning {
  background-color: #ffc400;
  border-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.table td.is-danger,
.table th.is-danger {
  background-color: #e45649;
  border-color: #e45649;
  color: #fff;
}
.table td.is-redish,
.table th.is-redish {
  background-color: #ca1243;
  border-color: #ca1243;
  color: #fff;
}
.table td.is-blueish,
.table th.is-blueish {
  background-color: #a3c0ff;
  border-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.table td.is-pink,
.table th.is-pink {
  background-color: #f57fef;
  border-color: #f57fef;
  color: #fff;
}
.table td.is-gold,
.table th.is-gold {
  background-color: #c18401;
  border-color: #c18401;
  color: #fff;
}
.table td.is-greenish,
.table th.is-greenish {
  background-color: #5ea14f;
  border-color: #5ea14f;
  color: #fff;
}
.table td.is-blood,
.table th.is-blood {
  background-color: #39040c;
  border-color: #39040c;
  color: #fff;
}
.table td.is-narrow,
.table th.is-narrow {
  white-space: nowrap;
  width: 1%;
}
.table td.is-selected,
.table th.is-selected {
  background-color: #885bfb;
  color: white;
}
.table td.is-selected a,
.table td.is-selected strong,
.table th.is-selected a,
.table th.is-selected strong {
  color: currentColor;
}
.table td.is-vcentered,
.table th.is-vcentered {
  vertical-align: middle;
}
.table th {
  color: #2f3546;
}
.table th:not([align]) {
  text-align: inherit;
}
.table tr.is-selected {
  background-color: #885bfb;
  color: white;
}
.table tr.is-selected a,
.table tr.is-selected strong {
  color: currentColor;
}
.table tr.is-selected td,
.table tr.is-selected th {
  border-color: white;
  color: currentColor;
}
.table thead {
  background-color: transparent;
}
.table thead td,
.table thead th {
  border-width: 0 0 2px;
  color: #2f3546;
}
.table tfoot {
  background-color: transparent;
}
.table tfoot td,
.table tfoot th {
  border-width: 2px 0 0;
  color: #2f3546;
}
.table tbody {
  background-color: transparent;
}
.table tbody tr:last-child td,
.table tbody tr:last-child th {
  border-bottom-width: 0;
}
.table.is-bordered td,
.table.is-bordered th {
  border-width: 1px;
}
.table.is-bordered tr:last-child td,
.table.is-bordered tr:last-child th {
  border-bottom-width: 1px;
}
.table.is-fullwidth {
  width: 100%;
}
.table.is-hoverable tbody tr:not(.is-selected):hover {
  background-color: whitesmoke;
}
.table.is-hoverable.is-striped tbody tr:not(.is-selected):hover {
  background-color: whitesmoke;
}
.table.is-hoverable.is-striped tbody tr:not(.is-selected):hover:nth-child(even) {
  background-color: #faf0f0;
}
.table.is-narrow td,
.table.is-narrow th {
  padding: 0.25em 0.5em;
}
.table.is-striped tbody tr:not(.is-selected):nth-child(even) {
  background-color: whitesmoke;
}

.table-container {
  -webkit-overflow-scrolling: touch;
  overflow: auto;
  overflow-y: hidden;
  max-width: 100%;
}

.tags {
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-start;
}
.tags .tag {
  margin-bottom: 0.5rem;
}
.tags .tag:not(:last-child) {
  margin-right: 0.5rem;
}
.tags:last-child {
  margin-bottom: -0.5rem;
}
.tags:not(:last-child) {
  margin-bottom: 1rem;
}
.tags.are-medium .tag:not(.is-normal):not(.is-large) {
  font-size: 1rem;
}
.tags.are-large .tag:not(.is-normal):not(.is-medium) {
  font-size: 1.25rem;
}
.tags.is-centered {
  justify-content: center;
}
.tags.is-centered .tag {
  margin-right: 0.25rem;
  margin-left: 0.25rem;
}
.tags.is-right {
  justify-content: flex-end;
}
.tags.is-right .tag:not(:first-child) {
  margin-left: 0.5rem;
}
.tags.is-right .tag:not(:last-child) {
  margin-right: 0;
}
.tags.has-addons .tag {
  margin-right: 0;
}
.tags.has-addons .tag:not(:first-child) {
  margin-left: 0;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.tags.has-addons .tag:not(:last-child) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.tag:not(body) {
  align-items: center;
  background-color: #faf0f0;
  border-radius: 4px;
  color: #3e4551;
  display: inline-flex;
  font-size: 0.75rem;
  height: 2em;
  justify-content: center;
  line-height: 1.5;
  padding-left: 0.75em;
  padding-right: 0.75em;
  white-space: nowrap;
}
.tag:not(body) .delete {
  margin-left: 0.25rem;
  margin-right: -0.375rem;
}
.tag:not(body).is-white {
  background-color: #fafafa;
  color: #0d1117;
}
.tag:not(body).is-black {
  background-color: #0d1117;
  color: #fafafa;
}
.tag:not(body).is-light {
  background-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.tag:not(body).is-dark {
  background-color: #2f3546;
  color: #fff;
}
.tag:not(body).is-primary {
  background-color: #885bfb;
  color: white;
}
.tag:not(body).is-primary.is-light {
  background-color: #f1ebfe;
  color: #4206db;
}
.tag:not(body).is-link {
  background-color: #4078f2;
  color: #736a59;
}
.tag:not(body).is-link.is-light {
  background-color: #88abf7;
  color: #30529c;
}
.tag:not(body).is-info {
  background-color: #449cc5;
  color: #fff;
}
.tag:not(body).is-info.is-light {
  background-color: #eff7fa;
  color: #2f7798;
}
.tag:not(body).is-success {
  background-color: #00ad6b;
  color: #fff;
}
.tag:not(body).is-success.is-light {
  background-color: #ebfff7;
  color: #00c278;
}
.tag:not(body).is-warning {
  background-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.tag:not(body).is-warning.is-light {
  background-color: #fffaeb;
  color: #947100;
}
.tag:not(body).is-danger {
  background-color: #e45649;
  color: #fff;
}
.tag:not(body).is-danger.is-light {
  background-color: #fcefed;
  color: #ba291c;
}
.tag:not(body).is-redish {
  background-color: #ca1243;
  color: #fff;
}
.tag:not(body).is-redish.is-light {
  background-color: #fdecf1;
  color: #e6144c;
}
.tag:not(body).is-blueish {
  background-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.tag:not(body).is-blueish.is-light {
  background-color: #ebf1ff;
  color: #002f94;
}
.tag:not(body).is-pink {
  background-color: #f57fef;
  color: #fff;
}
.tag:not(body).is-pink.is-light {
  background-color: #feecfd;
  color: #9d0c95;
}
.tag:not(body).is-gold {
  background-color: #c18401;
  color: #fff;
}
.tag:not(body).is-gold.is-light {
  background-color: #fff9eb;
  color: #c68801;
}
.tag:not(body).is-greenish {
  background-color: #5ea14f;
  color: #fff;
}
.tag:not(body).is-greenish.is-light {
  background-color: #f3f8f1;
  color: #4e8542;
}
.tag:not(body).is-blood {
  background-color: #39040c;
  color: #fff;
}
.tag:not(body).is-blood.is-light {
  background-color: #feecef;
  color: #f02d4a;
}
.tag:not(body).is-normal {
  font-size: 0.75rem;
}
.tag:not(body).is-medium {
  font-size: 1rem;
}
.tag:not(body).is-large {
  font-size: 1.25rem;
}
.tag:not(body) .icon:first-child:not(:last-child) {
  margin-left: -0.375em;
  margin-right: 0.1875em;
}
.tag:not(body) .icon:last-child:not(:first-child) {
  margin-left: 0.1875em;
  margin-right: -0.375em;
}
.tag:not(body) .icon:first-child:last-child {
  margin-left: -0.375em;
  margin-right: -0.375em;
}
.tag:not(body).is-delete {
  margin-left: 1px;
  padding: 0;
  position: relative;
  width: 2em;
}
.tag:not(body).is-delete::before, .tag:not(body).is-delete::after {
  background-color: currentColor;
  content: "";
  display: block;
  left: 50%;
  position: absolute;
  top: 50%;
  transform: translateX(-50%) translateY(-50%) rotate(45deg);
  transform-origin: center center;
}
.tag:not(body).is-delete::before {
  height: 1px;
  width: 50%;
}
.tag:not(body).is-delete::after {
  height: 50%;
  width: 1px;
}
.tag:not(body).is-delete:hover, .tag:not(body).is-delete:focus {
  background-color: #f4dddd;
}
.tag:not(body).is-delete:active {
  background-color: #edc9c9;
}
.tag:not(body).is-rounded {
  border-radius: 9999px;
}

a.tag:hover {
  text-decoration: underline;
}

.title, .dark-palette #search-results .topic-title,
.dark-palette .content .topic-title,
.dark-palette .document .topic-title, .light-palette #search-results .topic-title,
.light-palette .content .topic-title,
.light-palette .document .topic-title,
.subtitle {
  word-break: break-word;
}
.title em, .dark-palette #search-results .topic-title em,
.dark-palette .content .topic-title em,
.dark-palette .document .topic-title em, .light-palette #search-results .topic-title em,
.light-palette .content .topic-title em,
.light-palette .document .topic-title em,
.title span,
.dark-palette #search-results .topic-title span,
.dark-palette .content .topic-title span,
.dark-palette .document .topic-title span,
.light-palette #search-results .topic-title span,
.light-palette .content .topic-title span,
.light-palette .document .topic-title span,
.subtitle em,
.subtitle span {
  font-weight: inherit;
}
.title sub, .dark-palette #search-results .topic-title sub,
.dark-palette .content .topic-title sub,
.dark-palette .document .topic-title sub, .light-palette #search-results .topic-title sub,
.light-palette .content .topic-title sub,
.light-palette .document .topic-title sub,
.subtitle sub {
  font-size: 0.75em;
}
.title sup, .dark-palette #search-results .topic-title sup,
.dark-palette .content .topic-title sup,
.dark-palette .document .topic-title sup, .light-palette #search-results .topic-title sup,
.light-palette .content .topic-title sup,
.light-palette .document .topic-title sup,
.subtitle sup {
  font-size: 0.75em;
}
.title .tag, .dark-palette #search-results .topic-title .tag,
.dark-palette .content .topic-title .tag,
.dark-palette .document .topic-title .tag, .light-palette #search-results .topic-title .tag,
.light-palette .content .topic-title .tag,
.light-palette .document .topic-title .tag,
.subtitle .tag {
  vertical-align: middle;
}

.title, .dark-palette #search-results .topic-title,
.dark-palette .content .topic-title,
.dark-palette .document .topic-title, .light-palette #search-results .topic-title,
.light-palette .content .topic-title,
.light-palette .document .topic-title {
  color: #2f3546;
  font-size: 2rem;
  font-weight: 600;
  line-height: 1.125;
}
.title strong, .dark-palette #search-results .topic-title strong,
.dark-palette .content .topic-title strong,
.dark-palette .document .topic-title strong, .light-palette #search-results .topic-title strong,
.light-palette .content .topic-title strong,
.light-palette .document .topic-title strong {
  color: inherit;
  font-weight: inherit;
}
.title:not(.is-spaced) + .subtitle, .dark-palette #search-results .topic-title:not(.is-spaced) + .subtitle,
.dark-palette .content .topic-title:not(.is-spaced) + .subtitle,
.dark-palette .document .topic-title:not(.is-spaced) + .subtitle, .light-palette #search-results .topic-title:not(.is-spaced) + .subtitle,
.light-palette .content .topic-title:not(.is-spaced) + .subtitle,
.light-palette .document .topic-title:not(.is-spaced) + .subtitle {
  margin-top: -1.25rem;
}
.title.is-1, .dark-palette #search-results .is-1.topic-title,
.dark-palette .content .is-1.topic-title,
.dark-palette .document .is-1.topic-title, .light-palette #search-results .is-1.topic-title,
.light-palette .content .is-1.topic-title,
.light-palette .document .is-1.topic-title {
  font-size: 3rem;
}
.title.is-2, .dark-palette #search-results .is-2.topic-title,
.dark-palette .content .is-2.topic-title,
.dark-palette .document .is-2.topic-title, .light-palette #search-results .is-2.topic-title,
.light-palette .content .is-2.topic-title,
.light-palette .document .is-2.topic-title {
  font-size: 2.5rem;
}
.title.is-3, .dark-palette #search-results .is-3.topic-title,
.dark-palette .content .is-3.topic-title,
.dark-palette .document .is-3.topic-title, .light-palette #search-results .is-3.topic-title,
.light-palette .content .is-3.topic-title,
.light-palette .document .is-3.topic-title {
  font-size: 2rem;
}
.title.is-4, .dark-palette #search-results .is-4.topic-title,
.dark-palette .content .is-4.topic-title,
.dark-palette .document .is-4.topic-title, .light-palette #search-results .is-4.topic-title,
.light-palette .content .is-4.topic-title,
.light-palette .document .is-4.topic-title {
  font-size: 1.5rem;
}
.title.is-5, .dark-palette #search-results .is-5.topic-title,
.dark-palette .content .is-5.topic-title,
.dark-palette .document .is-5.topic-title, .light-palette #search-results .is-5.topic-title,
.light-palette .content .is-5.topic-title,
.light-palette .document .is-5.topic-title {
  font-size: 1.25rem;
}
.title.is-6, .dark-palette #search-results .is-6.topic-title,
.dark-palette .content .is-6.topic-title,
.dark-palette .document .is-6.topic-title, .light-palette #search-results .is-6.topic-title,
.light-palette .content .is-6.topic-title,
.light-palette .document .is-6.topic-title {
  font-size: 1rem;
}
.title.is-7, .dark-palette #search-results .is-7.topic-title,
.dark-palette .content .is-7.topic-title,
.dark-palette .document .is-7.topic-title, .light-palette #search-results .is-7.topic-title,
.light-palette .content .is-7.topic-title,
.light-palette .document .is-7.topic-title {
  font-size: 0.75rem;
}

.subtitle {
  color: #3e4551;
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.25;
}
.subtitle strong {
  color: #2f3546;
  font-weight: 600;
}
.subtitle:not(.is-spaced) + .title, .dark-palette #search-results .subtitle:not(.is-spaced) + .topic-title,
.dark-palette .content .subtitle:not(.is-spaced) + .topic-title,
.dark-palette .document .subtitle:not(.is-spaced) + .topic-title, .light-palette #search-results .subtitle:not(.is-spaced) + .topic-title,
.light-palette .content .subtitle:not(.is-spaced) + .topic-title,
.light-palette .document .subtitle:not(.is-spaced) + .topic-title {
  margin-top: -1.25rem;
}
.subtitle.is-1 {
  font-size: 3rem;
}
.subtitle.is-2 {
  font-size: 2.5rem;
}
.subtitle.is-3 {
  font-size: 2rem;
}
.subtitle.is-4 {
  font-size: 1.5rem;
}
.subtitle.is-5 {
  font-size: 1.25rem;
}
.subtitle.is-6 {
  font-size: 1rem;
}
.subtitle.is-7 {
  font-size: 0.75rem;
}

.heading {
  display: block;
  font-size: 11px;
  letter-spacing: 1px;
  margin-bottom: 5px;
  text-transform: uppercase;
}

.number {
  align-items: center;
  background-color: #faf0f0;
  border-radius: 9999px;
  display: inline-flex;
  font-size: 1.25rem;
  height: 2em;
  justify-content: center;
  margin-right: 1.5rem;
  min-width: 2.5em;
  padding: 0.25rem 0.5rem;
  text-align: center;
  vertical-align: top;
}

/* Bulma Form */
.select select, .textarea, .input {
  background-color: #fafafa;
  border-color: #c9d1d9;
  border-radius: 4px;
  color: #2f3546;
}
.select select::-moz-placeholder, .textarea::-moz-placeholder, .input::-moz-placeholder {
  color: rgba(47, 53, 70, 0.3);
}
.select select::-webkit-input-placeholder, .textarea::-webkit-input-placeholder, .input::-webkit-input-placeholder {
  color: rgba(47, 53, 70, 0.3);
}
.select select:-moz-placeholder, .textarea:-moz-placeholder, .input:-moz-placeholder {
  color: rgba(47, 53, 70, 0.3);
}
.select select:-ms-input-placeholder, .textarea:-ms-input-placeholder, .input:-ms-input-placeholder {
  color: rgba(47, 53, 70, 0.3);
}
.select select:hover, .textarea:hover, .input:hover, .select select.is-hovered, .is-hovered.textarea, .is-hovered.input {
  border-color: #a1b1bf;
}
.select select:focus, .textarea:focus, .input:focus, .select select.is-focused, .is-focused.textarea, .is-focused.input, .select select:active, .textarea:active, .input:active, .select select.is-active, .is-active.textarea, .is-active.input {
  border-color: #4078f2;
  box-shadow: 0 0 0 0.125em rgba(64, 120, 242, 0.25);
}
.select select[disabled], [disabled].textarea, [disabled].input, fieldset[disabled] .select select, .select fieldset[disabled] select, fieldset[disabled] .textarea, fieldset[disabled] .input {
  background-color: #faf0f0;
  border-color: #faf0f0;
  box-shadow: none;
  color: #6f727b;
}
.select select[disabled]::-moz-placeholder, [disabled].textarea::-moz-placeholder, [disabled].input::-moz-placeholder, fieldset[disabled] .select select::-moz-placeholder, .select fieldset[disabled] select::-moz-placeholder, fieldset[disabled] .textarea::-moz-placeholder, fieldset[disabled] .input::-moz-placeholder {
  color: rgba(111, 114, 123, 0.3);
}
.select select[disabled]::-webkit-input-placeholder, [disabled].textarea::-webkit-input-placeholder, [disabled].input::-webkit-input-placeholder, fieldset[disabled] .select select::-webkit-input-placeholder, .select fieldset[disabled] select::-webkit-input-placeholder, fieldset[disabled] .textarea::-webkit-input-placeholder, fieldset[disabled] .input::-webkit-input-placeholder {
  color: rgba(111, 114, 123, 0.3);
}
.select select[disabled]:-moz-placeholder, [disabled].textarea:-moz-placeholder, [disabled].input:-moz-placeholder, fieldset[disabled] .select select:-moz-placeholder, .select fieldset[disabled] select:-moz-placeholder, fieldset[disabled] .textarea:-moz-placeholder, fieldset[disabled] .input:-moz-placeholder {
  color: rgba(111, 114, 123, 0.3);
}
.select select[disabled]:-ms-input-placeholder, [disabled].textarea:-ms-input-placeholder, [disabled].input:-ms-input-placeholder, fieldset[disabled] .select select:-ms-input-placeholder, .select fieldset[disabled] select:-ms-input-placeholder, fieldset[disabled] .textarea:-ms-input-placeholder, fieldset[disabled] .input:-ms-input-placeholder {
  color: rgba(111, 114, 123, 0.3);
}

.textarea, .input {
  box-shadow: inset 0 0.0625em 0.125em rgba(13, 17, 23, 0.05);
  max-width: 100%;
  width: 100%;
}
[readonly].textarea, [readonly].input {
  box-shadow: none;
}
.is-white.textarea, .is-white.input {
  border-color: #fafafa;
}
.is-white.textarea:focus, .is-white.input:focus, .is-white.is-focused.textarea, .is-white.is-focused.input, .is-white.textarea:active, .is-white.input:active, .is-white.is-active.textarea, .is-white.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(250, 250, 250, 0.25);
}
.is-black.textarea, .is-black.input {
  border-color: #0d1117;
}
.is-black.textarea:focus, .is-black.input:focus, .is-black.is-focused.textarea, .is-black.is-focused.input, .is-black.textarea:active, .is-black.input:active, .is-black.is-active.textarea, .is-black.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(13, 17, 23, 0.25);
}
.is-light.textarea, .is-light.input {
  border-color: #faf0f0;
}
.is-light.textarea:focus, .is-light.input:focus, .is-light.is-focused.textarea, .is-light.is-focused.input, .is-light.textarea:active, .is-light.input:active, .is-light.is-active.textarea, .is-light.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(250, 240, 240, 0.25);
}
.is-dark.textarea, .is-dark.input {
  border-color: #2f3546;
}
.is-dark.textarea:focus, .is-dark.input:focus, .is-dark.is-focused.textarea, .is-dark.is-focused.input, .is-dark.textarea:active, .is-dark.input:active, .is-dark.is-active.textarea, .is-dark.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(47, 53, 70, 0.25);
}
.is-primary.textarea, .is-primary.input {
  border-color: #885bfb;
}
.is-primary.textarea:focus, .is-primary.input:focus, .is-primary.is-focused.textarea, .is-primary.is-focused.input, .is-primary.textarea:active, .is-primary.input:active, .is-primary.is-active.textarea, .is-primary.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(136, 91, 251, 0.25);
}
.is-link.textarea, .is-link.input {
  border-color: #4078f2;
}
.is-link.textarea:focus, .is-link.input:focus, .is-link.is-focused.textarea, .is-link.is-focused.input, .is-link.textarea:active, .is-link.input:active, .is-link.is-active.textarea, .is-link.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(64, 120, 242, 0.25);
}
.is-info.textarea, .is-info.input {
  border-color: #449cc5;
}
.is-info.textarea:focus, .is-info.input:focus, .is-info.is-focused.textarea, .is-info.is-focused.input, .is-info.textarea:active, .is-info.input:active, .is-info.is-active.textarea, .is-info.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(68, 156, 197, 0.25);
}
.is-success.textarea, .is-success.input {
  border-color: #00ad6b;
}
.is-success.textarea:focus, .is-success.input:focus, .is-success.is-focused.textarea, .is-success.is-focused.input, .is-success.textarea:active, .is-success.input:active, .is-success.is-active.textarea, .is-success.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(0, 173, 107, 0.25);
}
.is-warning.textarea, .is-warning.input {
  border-color: #ffc400;
}
.is-warning.textarea:focus, .is-warning.input:focus, .is-warning.is-focused.textarea, .is-warning.is-focused.input, .is-warning.textarea:active, .is-warning.input:active, .is-warning.is-active.textarea, .is-warning.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(255, 196, 0, 0.25);
}
.is-danger.textarea, .is-danger.input {
  border-color: #e45649;
}
.is-danger.textarea:focus, .is-danger.input:focus, .is-danger.is-focused.textarea, .is-danger.is-focused.input, .is-danger.textarea:active, .is-danger.input:active, .is-danger.is-active.textarea, .is-danger.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(228, 86, 73, 0.25);
}
.is-redish.textarea, .is-redish.input {
  border-color: #ca1243;
}
.is-redish.textarea:focus, .is-redish.input:focus, .is-redish.is-focused.textarea, .is-redish.is-focused.input, .is-redish.textarea:active, .is-redish.input:active, .is-redish.is-active.textarea, .is-redish.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(202, 18, 67, 0.25);
}
.is-blueish.textarea, .is-blueish.input {
  border-color: #a3c0ff;
}
.is-blueish.textarea:focus, .is-blueish.input:focus, .is-blueish.is-focused.textarea, .is-blueish.is-focused.input, .is-blueish.textarea:active, .is-blueish.input:active, .is-blueish.is-active.textarea, .is-blueish.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(163, 192, 255, 0.25);
}
.is-pink.textarea, .is-pink.input {
  border-color: #f57fef;
}
.is-pink.textarea:focus, .is-pink.input:focus, .is-pink.is-focused.textarea, .is-pink.is-focused.input, .is-pink.textarea:active, .is-pink.input:active, .is-pink.is-active.textarea, .is-pink.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(245, 127, 239, 0.25);
}
.is-gold.textarea, .is-gold.input {
  border-color: #c18401;
}
.is-gold.textarea:focus, .is-gold.input:focus, .is-gold.is-focused.textarea, .is-gold.is-focused.input, .is-gold.textarea:active, .is-gold.input:active, .is-gold.is-active.textarea, .is-gold.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(193, 132, 1, 0.25);
}
.is-greenish.textarea, .is-greenish.input {
  border-color: #5ea14f;
}
.is-greenish.textarea:focus, .is-greenish.input:focus, .is-greenish.is-focused.textarea, .is-greenish.is-focused.input, .is-greenish.textarea:active, .is-greenish.input:active, .is-greenish.is-active.textarea, .is-greenish.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(94, 161, 79, 0.25);
}
.is-blood.textarea, .is-blood.input {
  border-color: #39040c;
}
.is-blood.textarea:focus, .is-blood.input:focus, .is-blood.is-focused.textarea, .is-blood.is-focused.input, .is-blood.textarea:active, .is-blood.input:active, .is-blood.is-active.textarea, .is-blood.is-active.input {
  box-shadow: 0 0 0 0.125em rgba(57, 4, 12, 0.25);
}
.is-small.textarea, .is-small.input {
  border-radius: 2px;
  font-size: 0.75rem;
}
.is-medium.textarea, .is-medium.input {
  font-size: 1.25rem;
}
.is-large.textarea, .is-large.input {
  font-size: 1.5rem;
}
.is-fullwidth.textarea, .is-fullwidth.input {
  display: block;
  width: 100%;
}
.is-inline.textarea, .is-inline.input {
  display: inline;
  width: auto;
}

.input.is-rounded {
  border-radius: 9999px;
  padding-left: calc(calc(0.75em - 1px) + 0.375em);
  padding-right: calc(calc(0.75em - 1px) + 0.375em);
}
.input.is-static {
  background-color: transparent;
  border-color: transparent;
  box-shadow: none;
  padding-left: 0;
  padding-right: 0;
}

.textarea {
  display: block;
  max-width: 100%;
  min-width: 100%;
  padding: calc(0.75em - 1px);
  resize: vertical;
}
.textarea:not([rows]) {
  max-height: 40em;
  min-height: 8em;
}
.textarea[rows] {
  height: initial;
}
.textarea.has-fixed-size {
  resize: none;
}

.radio, .checkbox {
  cursor: pointer;
  display: inline-block;
  line-height: 1.25;
  position: relative;
}
.radio input, .checkbox input {
  cursor: pointer;
}
.radio:hover, .checkbox:hover {
  color: #2f3546;
}
[disabled].radio, [disabled].checkbox, fieldset[disabled] .radio, fieldset[disabled] .checkbox,
.radio input[disabled],
.checkbox input[disabled] {
  color: #6f727b;
  cursor: not-allowed;
}

.radio + .radio {
  margin-left: 0.5em;
}

.select {
  display: inline-block;
  max-width: 100%;
  position: relative;
  vertical-align: top;
}
.select:not(.is-multiple) {
  height: 2.5em;
}
.select:not(.is-multiple):not(.is-loading)::after {
  border-color: #4078f2;
  right: 1.125em;
  z-index: 4;
}
.select.is-rounded select {
  border-radius: 9999px;
  padding-left: 1em;
}
.select select {
  cursor: pointer;
  display: block;
  font-size: 1em;
  max-width: 100%;
  outline: none;
}
.select select::-ms-expand {
  display: none;
}
.select select[disabled]:hover, fieldset[disabled] .select select:hover {
  border-color: #faf0f0;
}
.select select:not([multiple]) {
  padding-right: 2.5em;
}
.select select[multiple] {
  height: auto;
  padding: 0;
}
.select select[multiple] option {
  padding: 0.5em 1em;
}
.select:not(.is-multiple):not(.is-loading):hover::after {
  border-color: #2f3546;
}
.select.is-white:not(:hover)::after {
  border-color: #fafafa;
}
.select.is-white select {
  border-color: #fafafa;
}
.select.is-white select:hover, .select.is-white select.is-hovered {
  border-color: #ededed;
}
.select.is-white select:focus, .select.is-white select.is-focused, .select.is-white select:active, .select.is-white select.is-active {
  box-shadow: 0 0 0 0.125em rgba(250, 250, 250, 0.25);
}
.select.is-black:not(:hover)::after {
  border-color: #0d1117;
}
.select.is-black select {
  border-color: #0d1117;
}
.select.is-black select:hover, .select.is-black select.is-hovered {
  border-color: #040507;
}
.select.is-black select:focus, .select.is-black select.is-focused, .select.is-black select:active, .select.is-black select.is-active {
  box-shadow: 0 0 0 0.125em rgba(13, 17, 23, 0.25);
}
.select.is-light:not(:hover)::after {
  border-color: #faf0f0;
}
.select.is-light select {
  border-color: #faf0f0;
}
.select.is-light select:hover, .select.is-light select.is-hovered {
  border-color: #f4dddd;
}
.select.is-light select:focus, .select.is-light select.is-focused, .select.is-light select:active, .select.is-light select.is-active {
  box-shadow: 0 0 0 0.125em rgba(250, 240, 240, 0.25);
}
.select.is-dark:not(:hover)::after {
  border-color: #2f3546;
}
.select.is-dark select {
  border-color: #2f3546;
}
.select.is-dark select:hover, .select.is-dark select.is-hovered {
  border-color: #252937;
}
.select.is-dark select:focus, .select.is-dark select.is-focused, .select.is-dark select:active, .select.is-dark select.is-active {
  box-shadow: 0 0 0 0.125em rgba(47, 53, 70, 0.25);
}
.select.is-primary:not(:hover)::after {
  border-color: #885bfb;
}
.select.is-primary select {
  border-color: #885bfb;
}
.select.is-primary select:hover, .select.is-primary select.is-hovered {
  border-color: #7642fa;
}
.select.is-primary select:focus, .select.is-primary select.is-focused, .select.is-primary select:active, .select.is-primary select.is-active {
  box-shadow: 0 0 0 0.125em rgba(136, 91, 251, 0.25);
}
.select.is-link:not(:hover)::after {
  border-color: #4078f2;
}
.select.is-link select {
  border-color: #4078f2;
}
.select.is-link select:hover, .select.is-link select.is-hovered {
  border-color: #2868f0;
}
.select.is-link select:focus, .select.is-link select.is-focused, .select.is-link select:active, .select.is-link select.is-active {
  box-shadow: 0 0 0 0.125em rgba(64, 120, 242, 0.25);
}
.select.is-info:not(:hover)::after {
  border-color: #449cc5;
}
.select.is-info select {
  border-color: #449cc5;
}
.select.is-info select:hover, .select.is-info select.is-hovered {
  border-color: #388fb7;
}
.select.is-info select:focus, .select.is-info select.is-focused, .select.is-info select:active, .select.is-info select.is-active {
  box-shadow: 0 0 0 0.125em rgba(68, 156, 197, 0.25);
}
.select.is-success:not(:hover)::after {
  border-color: #00ad6b;
}
.select.is-success select {
  border-color: #00ad6b;
}
.select.is-success select:hover, .select.is-success select.is-hovered {
  border-color: #00945b;
}
.select.is-success select:focus, .select.is-success select.is-focused, .select.is-success select:active, .select.is-success select.is-active {
  box-shadow: 0 0 0 0.125em rgba(0, 173, 107, 0.25);
}
.select.is-warning:not(:hover)::after {
  border-color: #ffc400;
}
.select.is-warning select {
  border-color: #ffc400;
}
.select.is-warning select:hover, .select.is-warning select.is-hovered {
  border-color: #e6b000;
}
.select.is-warning select:focus, .select.is-warning select.is-focused, .select.is-warning select:active, .select.is-warning select.is-active {
  box-shadow: 0 0 0 0.125em rgba(255, 196, 0, 0.25);
}
.select.is-danger:not(:hover)::after {
  border-color: #e45649;
}
.select.is-danger select {
  border-color: #e45649;
}
.select.is-danger select:hover, .select.is-danger select.is-hovered {
  border-color: #e14133;
}
.select.is-danger select:focus, .select.is-danger select.is-focused, .select.is-danger select:active, .select.is-danger select.is-active {
  box-shadow: 0 0 0 0.125em rgba(228, 86, 73, 0.25);
}
.select.is-redish:not(:hover)::after {
  border-color: #ca1243;
}
.select.is-redish select {
  border-color: #ca1243;
}
.select.is-redish select:hover, .select.is-redish select.is-hovered {
  border-color: #b2103b;
}
.select.is-redish select:focus, .select.is-redish select.is-focused, .select.is-redish select:active, .select.is-redish select.is-active {
  box-shadow: 0 0 0 0.125em rgba(202, 18, 67, 0.25);
}
.select.is-blueish:not(:hover)::after {
  border-color: #a3c0ff;
}
.select.is-blueish select {
  border-color: #a3c0ff;
}
.select.is-blueish select:hover, .select.is-blueish select.is-hovered {
  border-color: #8aafff;
}
.select.is-blueish select:focus, .select.is-blueish select.is-focused, .select.is-blueish select:active, .select.is-blueish select.is-active {
  box-shadow: 0 0 0 0.125em rgba(163, 192, 255, 0.25);
}
.select.is-pink:not(:hover)::after {
  border-color: #f57fef;
}
.select.is-pink select {
  border-color: #f57fef;
}
.select.is-pink select:hover, .select.is-pink select.is-hovered {
  border-color: #f467ed;
}
.select.is-pink select:focus, .select.is-pink select.is-focused, .select.is-pink select:active, .select.is-pink select.is-active {
  box-shadow: 0 0 0 0.125em rgba(245, 127, 239, 0.25);
}
.select.is-gold:not(:hover)::after {
  border-color: #c18401;
}
.select.is-gold select {
  border-color: #c18401;
}
.select.is-gold select:hover, .select.is-gold select.is-hovered {
  border-color: #a77301;
}
.select.is-gold select:focus, .select.is-gold select.is-focused, .select.is-gold select:active, .select.is-gold select.is-active {
  box-shadow: 0 0 0 0.125em rgba(193, 132, 1, 0.25);
}
.select.is-greenish:not(:hover)::after {
  border-color: #5ea14f;
}
.select.is-greenish select {
  border-color: #5ea14f;
}
.select.is-greenish select:hover, .select.is-greenish select.is-hovered {
  border-color: #549047;
}
.select.is-greenish select:focus, .select.is-greenish select.is-focused, .select.is-greenish select:active, .select.is-greenish select.is-active {
  box-shadow: 0 0 0 0.125em rgba(94, 161, 79, 0.25);
}
.select.is-blood:not(:hover)::after {
  border-color: #39040c;
}
.select.is-blood select {
  border-color: #39040c;
}
.select.is-blood select:hover, .select.is-blood select.is-hovered {
  border-color: #210207;
}
.select.is-blood select:focus, .select.is-blood select.is-focused, .select.is-blood select:active, .select.is-blood select.is-active {
  box-shadow: 0 0 0 0.125em rgba(57, 4, 12, 0.25);
}
.select.is-small {
  border-radius: 2px;
  font-size: 0.75rem;
}
.select.is-medium {
  font-size: 1.25rem;
}
.select.is-large {
  font-size: 1.5rem;
}
.select.is-disabled::after {
  border-color: #6f727b;
}
.select.is-fullwidth {
  width: 100%;
}
.select.is-fullwidth select {
  width: 100%;
}
.select.is-loading::after {
  margin-top: 0;
  position: absolute;
  right: 0.625em;
  top: 0.625em;
  transform: none;
}
.select.is-loading.is-small:after {
  font-size: 0.75rem;
}
.select.is-loading.is-medium:after {
  font-size: 1.25rem;
}
.select.is-loading.is-large:after {
  font-size: 1.5rem;
}

.file {
  align-items: stretch;
  display: flex;
  justify-content: flex-start;
  position: relative;
}
.file.is-white .file-cta {
  background-color: #fafafa;
  border-color: transparent;
  color: #0d1117;
}
.file.is-white:hover .file-cta, .file.is-white.is-hovered .file-cta {
  background-color: #f4f4f4;
  border-color: transparent;
  color: #0d1117;
}
.file.is-white:focus .file-cta, .file.is-white.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(250, 250, 250, 0.25);
  color: #0d1117;
}
.file.is-white:active .file-cta, .file.is-white.is-active .file-cta {
  background-color: #ededed;
  border-color: transparent;
  color: #0d1117;
}
.file.is-black .file-cta {
  background-color: #0d1117;
  border-color: transparent;
  color: #fafafa;
}
.file.is-black:hover .file-cta, .file.is-black.is-hovered .file-cta {
  background-color: #080b0f;
  border-color: transparent;
  color: #fafafa;
}
.file.is-black:focus .file-cta, .file.is-black.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(13, 17, 23, 0.25);
  color: #fafafa;
}
.file.is-black:active .file-cta, .file.is-black.is-active .file-cta {
  background-color: #040507;
  border-color: transparent;
  color: #fafafa;
}
.file.is-light .file-cta {
  background-color: #faf0f0;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-light:hover .file-cta, .file.is-light.is-hovered .file-cta {
  background-color: #f7e6e6;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-light:focus .file-cta, .file.is-light.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(250, 240, 240, 0.25);
  color: rgba(0, 0, 0, 0.7);
}
.file.is-light:active .file-cta, .file.is-light.is-active .file-cta {
  background-color: #f4dddd;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-dark .file-cta {
  background-color: #2f3546;
  border-color: transparent;
  color: #fff;
}
.file.is-dark:hover .file-cta, .file.is-dark.is-hovered .file-cta {
  background-color: #2a2f3f;
  border-color: transparent;
  color: #fff;
}
.file.is-dark:focus .file-cta, .file.is-dark.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(47, 53, 70, 0.25);
  color: #fff;
}
.file.is-dark:active .file-cta, .file.is-dark.is-active .file-cta {
  background-color: #252937;
  border-color: transparent;
  color: #fff;
}
.file.is-primary .file-cta {
  background-color: #885bfb;
  border-color: transparent;
  color: white;
}
.file.is-primary:hover .file-cta, .file.is-primary.is-hovered .file-cta {
  background-color: #7f4efa;
  border-color: transparent;
  color: white;
}
.file.is-primary:focus .file-cta, .file.is-primary.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(136, 91, 251, 0.25);
  color: white;
}
.file.is-primary:active .file-cta, .file.is-primary.is-active .file-cta {
  background-color: #7642fa;
  border-color: transparent;
  color: white;
}
.file.is-link .file-cta {
  background-color: #4078f2;
  border-color: transparent;
  color: #736a59;
}
.file.is-link:hover .file-cta, .file.is-link.is-hovered .file-cta {
  background-color: #3470f1;
  border-color: transparent;
  color: #736a59;
}
.file.is-link:focus .file-cta, .file.is-link.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(64, 120, 242, 0.25);
  color: #736a59;
}
.file.is-link:active .file-cta, .file.is-link.is-active .file-cta {
  background-color: #2868f0;
  border-color: transparent;
  color: #736a59;
}
.file.is-info .file-cta {
  background-color: #449cc5;
  border-color: transparent;
  color: #fff;
}
.file.is-info:hover .file-cta, .file.is-info.is-hovered .file-cta {
  background-color: #3b97c1;
  border-color: transparent;
  color: #fff;
}
.file.is-info:focus .file-cta, .file.is-info.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(68, 156, 197, 0.25);
  color: #fff;
}
.file.is-info:active .file-cta, .file.is-info.is-active .file-cta {
  background-color: #388fb7;
  border-color: transparent;
  color: #fff;
}
.file.is-success .file-cta {
  background-color: #00ad6b;
  border-color: transparent;
  color: #fff;
}
.file.is-success:hover .file-cta, .file.is-success.is-hovered .file-cta {
  background-color: #00a163;
  border-color: transparent;
  color: #fff;
}
.file.is-success:focus .file-cta, .file.is-success.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(0, 173, 107, 0.25);
  color: #fff;
}
.file.is-success:active .file-cta, .file.is-success.is-active .file-cta {
  background-color: #00945b;
  border-color: transparent;
  color: #fff;
}
.file.is-warning .file-cta {
  background-color: #ffc400;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-warning:hover .file-cta, .file.is-warning.is-hovered .file-cta {
  background-color: #f2ba00;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-warning:focus .file-cta, .file.is-warning.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(255, 196, 0, 0.25);
  color: rgba(0, 0, 0, 0.7);
}
.file.is-warning:active .file-cta, .file.is-warning.is-active .file-cta {
  background-color: #e6b000;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-danger .file-cta {
  background-color: #e45649;
  border-color: transparent;
  color: #fff;
}
.file.is-danger:hover .file-cta, .file.is-danger.is-hovered .file-cta {
  background-color: #e24c3e;
  border-color: transparent;
  color: #fff;
}
.file.is-danger:focus .file-cta, .file.is-danger.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(228, 86, 73, 0.25);
  color: #fff;
}
.file.is-danger:active .file-cta, .file.is-danger.is-active .file-cta {
  background-color: #e14133;
  border-color: transparent;
  color: #fff;
}
.file.is-redish .file-cta {
  background-color: #ca1243;
  border-color: transparent;
  color: #fff;
}
.file.is-redish:hover .file-cta, .file.is-redish.is-hovered .file-cta {
  background-color: #be113f;
  border-color: transparent;
  color: #fff;
}
.file.is-redish:focus .file-cta, .file.is-redish.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(202, 18, 67, 0.25);
  color: #fff;
}
.file.is-redish:active .file-cta, .file.is-redish.is-active .file-cta {
  background-color: #b2103b;
  border-color: transparent;
  color: #fff;
}
.file.is-blueish .file-cta {
  background-color: #a3c0ff;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-blueish:hover .file-cta, .file.is-blueish.is-hovered .file-cta {
  background-color: #96b7ff;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-blueish:focus .file-cta, .file.is-blueish.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(163, 192, 255, 0.25);
  color: rgba(0, 0, 0, 0.7);
}
.file.is-blueish:active .file-cta, .file.is-blueish.is-active .file-cta {
  background-color: #8aafff;
  border-color: transparent;
  color: rgba(0, 0, 0, 0.7);
}
.file.is-pink .file-cta {
  background-color: #f57fef;
  border-color: transparent;
  color: #fff;
}
.file.is-pink:hover .file-cta, .file.is-pink.is-hovered .file-cta {
  background-color: #f473ee;
  border-color: transparent;
  color: #fff;
}
.file.is-pink:focus .file-cta, .file.is-pink.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(245, 127, 239, 0.25);
  color: #fff;
}
.file.is-pink:active .file-cta, .file.is-pink.is-active .file-cta {
  background-color: #f467ed;
  border-color: transparent;
  color: #fff;
}
.file.is-gold .file-cta {
  background-color: #c18401;
  border-color: transparent;
  color: #fff;
}
.file.is-gold:hover .file-cta, .file.is-gold.is-hovered .file-cta {
  background-color: #b47b01;
  border-color: transparent;
  color: #fff;
}
.file.is-gold:focus .file-cta, .file.is-gold.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(193, 132, 1, 0.25);
  color: #fff;
}
.file.is-gold:active .file-cta, .file.is-gold.is-active .file-cta {
  background-color: #a77301;
  border-color: transparent;
  color: #fff;
}
.file.is-greenish .file-cta {
  background-color: #5ea14f;
  border-color: transparent;
  color: #fff;
}
.file.is-greenish:hover .file-cta, .file.is-greenish.is-hovered .file-cta {
  background-color: #59984b;
  border-color: transparent;
  color: #fff;
}
.file.is-greenish:focus .file-cta, .file.is-greenish.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(94, 161, 79, 0.25);
  color: #fff;
}
.file.is-greenish:active .file-cta, .file.is-greenish.is-active .file-cta {
  background-color: #549047;
  border-color: transparent;
  color: #fff;
}
.file.is-blood .file-cta {
  background-color: #39040c;
  border-color: transparent;
  color: #fff;
}
.file.is-blood:hover .file-cta, .file.is-blood.is-hovered .file-cta {
  background-color: #2d0309;
  border-color: transparent;
  color: #fff;
}
.file.is-blood:focus .file-cta, .file.is-blood.is-focused .file-cta {
  border-color: transparent;
  box-shadow: 0 0 0.5em rgba(57, 4, 12, 0.25);
  color: #fff;
}
.file.is-blood:active .file-cta, .file.is-blood.is-active .file-cta {
  background-color: #210207;
  border-color: transparent;
  color: #fff;
}
.file.is-small {
  font-size: 0.75rem;
}
.file.is-normal {
  font-size: 1rem;
}
.file.is-medium {
  font-size: 1.25rem;
}
.file.is-medium .file-icon .fa {
  font-size: 21px;
}
.file.is-large {
  font-size: 1.5rem;
}
.file.is-large .file-icon .fa {
  font-size: 28px;
}
.file.has-name .file-cta {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}
.file.has-name .file-name {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.file.has-name.is-empty .file-cta {
  border-radius: 4px;
}
.file.has-name.is-empty .file-name {
  display: none;
}
.file.is-boxed .file-label {
  flex-direction: column;
}
.file.is-boxed .file-cta {
  flex-direction: column;
  height: auto;
  padding: 1em 3em;
}
.file.is-boxed .file-name {
  border-width: 0 1px 1px;
}
.file.is-boxed .file-icon {
  height: 1.5em;
  width: 1.5em;
}
.file.is-boxed .file-icon .fa {
  font-size: 21px;
}
.file.is-boxed.is-small .file-icon .fa {
  font-size: 14px;
}
.file.is-boxed.is-medium .file-icon .fa {
  font-size: 28px;
}
.file.is-boxed.is-large .file-icon .fa {
  font-size: 35px;
}
.file.is-boxed.has-name .file-cta {
  border-radius: 4px 4px 0 0;
}
.file.is-boxed.has-name .file-name {
  border-radius: 0 0 4px 4px;
  border-width: 0 1px 1px;
}
.file.is-centered {
  justify-content: center;
}
.file.is-fullwidth .file-label {
  width: 100%;
}
.file.is-fullwidth .file-name {
  flex-grow: 1;
  max-width: none;
}
.file.is-right {
  justify-content: flex-end;
}
.file.is-right .file-cta {
  border-radius: 0 4px 4px 0;
}
.file.is-right .file-name {
  border-radius: 4px 0 0 4px;
  border-width: 1px 0 1px 1px;
  order: -1;
}

.file-label {
  align-items: stretch;
  display: flex;
  cursor: pointer;
  justify-content: flex-start;
  overflow: hidden;
  position: relative;
}
.file-label:hover .file-cta {
  background-color: #f7e6e6;
  color: #2f3546;
}
.file-label:hover .file-name {
  border-color: #c2cbd4;
}
.file-label:active .file-cta {
  background-color: #f4dddd;
  color: #2f3546;
}
.file-label:active .file-name {
  border-color: #bac4ce;
}

.file-input {
  height: 100%;
  left: 0;
  opacity: 0;
  outline: none;
  position: absolute;
  top: 0;
  width: 100%;
}

.file-cta,
.file-name {
  border-color: #c9d1d9;
  border-radius: 4px;
  font-size: 1em;
  padding-left: 1em;
  padding-right: 1em;
  white-space: nowrap;
}

.file-cta {
  background-color: #faf0f0;
  color: #3e4551;
}

.file-name {
  border-color: #c9d1d9;
  border-style: solid;
  border-width: 1px 1px 1px 0;
  display: block;
  max-width: 16em;
  overflow: hidden;
  text-align: inherit;
  text-overflow: ellipsis;
}

.file-icon {
  align-items: center;
  display: flex;
  height: 1em;
  justify-content: center;
  margin-right: 0.5em;
  width: 1em;
}
.file-icon .fa {
  font-size: 14px;
}

.label {
  color: #2f3546;
  display: block;
  font-size: 1rem;
  font-weight: 700;
}
.label:not(:last-child) {
  margin-bottom: 0.5em;
}
.label.is-small {
  font-size: 0.75rem;
}
.label.is-medium {
  font-size: 1.25rem;
}
.label.is-large {
  font-size: 1.5rem;
}

.help {
  display: block;
  font-size: 0.75rem;
  margin-top: 0.25rem;
}
.help.is-white {
  color: #fafafa;
}
.help.is-black {
  color: #0d1117;
}
.help.is-light {
  color: #faf0f0;
}
.help.is-dark {
  color: #2f3546;
}
.help.is-primary {
  color: #885bfb;
}
.help.is-link {
  color: #4078f2;
}
.help.is-info {
  color: #449cc5;
}
.help.is-success {
  color: #00ad6b;
}
.help.is-warning {
  color: #ffc400;
}
.help.is-danger {
  color: #e45649;
}
.help.is-redish {
  color: #ca1243;
}
.help.is-blueish {
  color: #a3c0ff;
}
.help.is-pink {
  color: #f57fef;
}
.help.is-gold {
  color: #c18401;
}
.help.is-greenish {
  color: #5ea14f;
}
.help.is-blood {
  color: #39040c;
}

.field:not(:last-child) {
  margin-bottom: 0.75rem;
}
.field.has-addons {
  display: flex;
  justify-content: flex-start;
}
.field.has-addons .control:not(:last-child) {
  margin-right: -1px;
}
.field.has-addons .control:not(:first-child):not(:last-child) .button,
.field.has-addons .control:not(:first-child):not(:last-child) .input,
.field.has-addons .control:not(:first-child):not(:last-child) .select select {
  border-radius: 0;
}
.field.has-addons .control:first-child:not(:only-child) .button,
.field.has-addons .control:first-child:not(:only-child) .input,
.field.has-addons .control:first-child:not(:only-child) .select select {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}
.field.has-addons .control:last-child:not(:only-child) .button,
.field.has-addons .control:last-child:not(:only-child) .input,
.field.has-addons .control:last-child:not(:only-child) .select select {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.field.has-addons .control .button:not([disabled]):hover, .field.has-addons .control .button:not([disabled]).is-hovered,
.field.has-addons .control .input:not([disabled]):hover,
.field.has-addons .control .input:not([disabled]).is-hovered,
.field.has-addons .control .select select:not([disabled]):hover,
.field.has-addons .control .select select:not([disabled]).is-hovered {
  z-index: 2;
}
.field.has-addons .control .button:not([disabled]):focus, .field.has-addons .control .button:not([disabled]).is-focused, .field.has-addons .control .button:not([disabled]):active, .field.has-addons .control .button:not([disabled]).is-active,
.field.has-addons .control .input:not([disabled]):focus,
.field.has-addons .control .input:not([disabled]).is-focused,
.field.has-addons .control .input:not([disabled]):active,
.field.has-addons .control .input:not([disabled]).is-active,
.field.has-addons .control .select select:not([disabled]):focus,
.field.has-addons .control .select select:not([disabled]).is-focused,
.field.has-addons .control .select select:not([disabled]):active,
.field.has-addons .control .select select:not([disabled]).is-active {
  z-index: 3;
}
.field.has-addons .control .button:not([disabled]):focus:hover, .field.has-addons .control .button:not([disabled]).is-focused:hover, .field.has-addons .control .button:not([disabled]):active:hover, .field.has-addons .control .button:not([disabled]).is-active:hover,
.field.has-addons .control .input:not([disabled]):focus:hover,
.field.has-addons .control .input:not([disabled]).is-focused:hover,
.field.has-addons .control .input:not([disabled]):active:hover,
.field.has-addons .control .input:not([disabled]).is-active:hover,
.field.has-addons .control .select select:not([disabled]):focus:hover,
.field.has-addons .control .select select:not([disabled]).is-focused:hover,
.field.has-addons .control .select select:not([disabled]):active:hover,
.field.has-addons .control .select select:not([disabled]).is-active:hover {
  z-index: 4;
}
.field.has-addons .control.is-expanded {
  flex-grow: 1;
  flex-shrink: 1;
}
.field.has-addons.has-addons-centered {
  justify-content: center;
}
.field.has-addons.has-addons-right {
  justify-content: flex-end;
}
.field.has-addons.has-addons-fullwidth .control {
  flex-grow: 1;
  flex-shrink: 0;
}
.field.is-grouped {
  display: flex;
  justify-content: flex-start;
}
.field.is-grouped > .control {
  flex-shrink: 0;
}
.field.is-grouped > .control:not(:last-child) {
  margin-bottom: 0;
  margin-right: 0.75rem;
}
.field.is-grouped > .control.is-expanded {
  flex-grow: 1;
  flex-shrink: 1;
}
.field.is-grouped.is-grouped-centered {
  justify-content: center;
}
.field.is-grouped.is-grouped-right {
  justify-content: flex-end;
}
.field.is-grouped.is-grouped-multiline {
  flex-wrap: wrap;
}
.field.is-grouped.is-grouped-multiline > .control:last-child, .field.is-grouped.is-grouped-multiline > .control:not(:last-child) {
  margin-bottom: 0.75rem;
}
.field.is-grouped.is-grouped-multiline:last-child {
  margin-bottom: -0.75rem;
}
.field.is-grouped.is-grouped-multiline:not(:last-child) {
  margin-bottom: 0;
}
@media screen and (min-width: 769px), print {
  .field.is-horizontal {
    display: flex;
  }
}

.field-label .label {
  font-size: inherit;
}
@media screen and (max-width: 768px) {
  .field-label {
    margin-bottom: 0.5rem;
  }
}
@media screen and (min-width: 769px), print {
  .field-label {
    flex-basis: 0;
    flex-grow: 1;
    flex-shrink: 0;
    margin-right: 1.5rem;
    text-align: right;
  }
  .field-label.is-small {
    font-size: 0.75rem;
    padding-top: 0.375em;
  }
  .field-label.is-normal {
    padding-top: 0.375em;
  }
  .field-label.is-medium {
    font-size: 1.25rem;
    padding-top: 0.375em;
  }
  .field-label.is-large {
    font-size: 1.5rem;
    padding-top: 0.375em;
  }
}

.field-body .field .field {
  margin-bottom: 0;
}
@media screen and (min-width: 769px), print {
  .field-body {
    display: flex;
    flex-basis: 0;
    flex-grow: 5;
    flex-shrink: 1;
  }
  .field-body .field {
    margin-bottom: 0;
  }
  .field-body > .field {
    flex-shrink: 1;
  }
  .field-body > .field:not(.is-narrow) {
    flex-grow: 1;
  }
  .field-body > .field:not(:last-child) {
    margin-right: 0.75rem;
  }
}

.control {
  box-sizing: border-box;
  clear: both;
  font-size: 1rem;
  position: relative;
  text-align: inherit;
}
.control.has-icons-left .input:focus ~ .icon,
.control.has-icons-left .select:focus ~ .icon, .control.has-icons-right .input:focus ~ .icon,
.control.has-icons-right .select:focus ~ .icon {
  color: #3e4551;
}
.control.has-icons-left .input.is-small ~ .icon,
.control.has-icons-left .select.is-small ~ .icon, .control.has-icons-right .input.is-small ~ .icon,
.control.has-icons-right .select.is-small ~ .icon {
  font-size: 0.75rem;
}
.control.has-icons-left .input.is-medium ~ .icon,
.control.has-icons-left .select.is-medium ~ .icon, .control.has-icons-right .input.is-medium ~ .icon,
.control.has-icons-right .select.is-medium ~ .icon {
  font-size: 1.25rem;
}
.control.has-icons-left .input.is-large ~ .icon,
.control.has-icons-left .select.is-large ~ .icon, .control.has-icons-right .input.is-large ~ .icon,
.control.has-icons-right .select.is-large ~ .icon {
  font-size: 1.5rem;
}
.control.has-icons-left .icon, .control.has-icons-right .icon {
  color: #c9d1d9;
  height: 2.5em;
  pointer-events: none;
  position: absolute;
  top: 0;
  width: 2.5em;
  z-index: 4;
}
.control.has-icons-left .input,
.control.has-icons-left .select select {
  padding-left: 2.5em;
}
.control.has-icons-left .icon.is-left {
  left: 0;
}
.control.has-icons-right .input,
.control.has-icons-right .select select {
  padding-right: 2.5em;
}
.control.has-icons-right .icon.is-right {
  right: 0;
}
.control.is-loading::after {
  position: absolute !important;
  right: 0.625em;
  top: 0.625em;
  z-index: 4;
}
.control.is-loading.is-small:after {
  font-size: 0.75rem;
}
.control.is-loading.is-medium:after {
  font-size: 1.25rem;
}
.control.is-loading.is-large:after {
  font-size: 1.5rem;
}

/* Bulma Components */
.breadcrumb {
  font-size: 1rem;
  white-space: nowrap;
}
.breadcrumb a {
  align-items: center;
  color: #4078f2;
  display: flex;
  justify-content: center;
  padding: 0 0.75em;
}
.breadcrumb a:hover {
  color: #4068bf;
}
.breadcrumb li {
  align-items: center;
  display: flex;
}
.breadcrumb li:first-child a {
  padding-left: 0;
}
.breadcrumb li.is-active a {
  color: #2f3546;
  cursor: default;
  pointer-events: none;
}
.breadcrumb li + li::before {
  color: #a1b1bf;
  content: "/";
}
.breadcrumb ul,
.breadcrumb ol {
  align-items: flex-start;
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-start;
}
.breadcrumb .icon:first-child {
  margin-right: 0.5em;
}
.breadcrumb .icon:last-child {
  margin-left: 0.5em;
}
.breadcrumb.is-centered ol,
.breadcrumb.is-centered ul {
  justify-content: center;
}
.breadcrumb.is-right ol,
.breadcrumb.is-right ul {
  justify-content: flex-end;
}
.breadcrumb.is-small {
  font-size: 0.75rem;
}
.breadcrumb.is-medium {
  font-size: 1.25rem;
}
.breadcrumb.is-large {
  font-size: 1.5rem;
}
.breadcrumb.has-arrow-separator li + li::before {
  content: "→";
}
.breadcrumb.has-bullet-separator li + li::before {
  content: "•";
}
.breadcrumb.has-dot-separator li + li::before {
  content: "·";
}
.breadcrumb.has-succeeds-separator li + li::before {
  content: "≻";
}

.card, #search-results aside.sidebar,
.content aside.sidebar,
.document aside.sidebar {
  background-color: #fafafa;
  border-radius: 0.25rem;
  box-shadow: 0 0.5em 1em -0.125em rgba(13, 17, 23, 0.1), 0 0px 0 1px rgba(13, 17, 23, 0.02);
  color: #3e4551;
  max-width: 100%;
  position: relative;
}

.card-footer:first-child, .card-content:first-child, .card-header:first-child {
  border-top-left-radius: 0.25rem;
  border-top-right-radius: 0.25rem;
}
.card-footer:last-child, .card-content:last-child, .card-header:last-child {
  border-bottom-left-radius: 0.25rem;
  border-bottom-right-radius: 0.25rem;
}

.card-header {
  background-color: transparent;
  align-items: stretch;
  box-shadow: 0 0.125em 0.25em rgba(13, 17, 23, 0.1);
  display: flex;
}

.card-header-title {
  align-items: center;
  color: #2f3546;
  display: flex;
  flex-grow: 1;
  font-weight: 700;
  padding: 0.75rem 1rem;
}
.card-header-title.is-centered {
  justify-content: center;
}

.card-header-icon {
  -moz-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  background: none;
  border: none;
  color: currentColor;
  font-family: inherit;
  font-size: 1em;
  margin: 0;
  padding: 0;
  align-items: center;
  cursor: pointer;
  display: flex;
  justify-content: center;
  padding: 0.75rem 1rem;
}

.card-image {
  display: block;
  position: relative;
}
.card-image:first-child img {
  border-top-left-radius: 0.25rem;
  border-top-right-radius: 0.25rem;
}
.card-image:last-child img {
  border-bottom-left-radius: 0.25rem;
  border-bottom-right-radius: 0.25rem;
}

.card-content {
  background-color: transparent;
  padding: 1.5rem;
}

.card-footer {
  background-color: transparent;
  border-top: 1px solid #e5dcdc;
  align-items: stretch;
  display: flex;
}

.card-footer-item {
  align-items: center;
  display: flex;
  flex-basis: 0;
  flex-grow: 1;
  flex-shrink: 0;
  justify-content: center;
  padding: 0.75rem;
}
.card-footer-item:not(:last-child) {
  border-right: 1px solid #e5dcdc;
}

.card .media:not(:last-child), #search-results aside.sidebar .media:not(:last-child),
.content aside.sidebar .media:not(:last-child),
.document aside.sidebar .media:not(:last-child) {
  margin-bottom: 1.5rem;
}

.dropdown {
  display: inline-flex;
  position: relative;
  vertical-align: top;
}
.dropdown.is-active .dropdown-menu, .dropdown.is-hoverable:hover .dropdown-menu {
  display: block;
}
.dropdown.is-right .dropdown-menu {
  left: auto;
  right: 0;
}
.dropdown.is-up .dropdown-menu {
  bottom: 100%;
  padding-bottom: 4px;
  padding-top: initial;
  top: auto;
}

.dropdown-menu {
  display: none;
  left: 0;
  min-width: 12rem;
  padding-top: 4px;
  position: absolute;
  top: 100%;
  z-index: 20;
}

.dropdown-content {
  background-color: #fafafa;
  border-radius: 4px;
  box-shadow: 0 0.5em 1em -0.125em rgba(13, 17, 23, 0.1), 0 0px 0 1px rgba(13, 17, 23, 0.02);
  padding-bottom: 0.5rem;
  padding-top: 0.5rem;
}

.dropdown-item {
  color: #3e4551;
  display: block;
  font-size: 0.875rem;
  line-height: 1.5;
  padding: 0.375rem 1rem;
  position: relative;
}

a.dropdown-item,
button.dropdown-item {
  padding-right: 3rem;
  text-align: inherit;
  white-space: nowrap;
  width: 100%;
}
a.dropdown-item:hover,
button.dropdown-item:hover {
  background-color: #faf0f0;
  color: #0d1117;
}
a.dropdown-item.is-active,
button.dropdown-item.is-active {
  background-color: #4078f2;
  color: #736a59;
}

.dropdown-divider {
  background-color: #e5dcdc;
  border: none;
  display: block;
  height: 1px;
  margin: 0.5rem 0;
}

.level {
  align-items: center;
  justify-content: space-between;
}
.level code {
  border-radius: 4px;
}
.level img {
  display: inline-block;
  vertical-align: top;
}
.level.is-mobile {
  display: flex;
}
.level.is-mobile .level-left,
.level.is-mobile .level-right {
  display: flex;
}
.level.is-mobile .level-left + .level-right {
  margin-top: 0;
}
.level.is-mobile .level-item:not(:last-child) {
  margin-bottom: 0;
  margin-right: 0.75rem;
}
.level.is-mobile .level-item:not(.is-narrow) {
  flex-grow: 1;
}
@media screen and (min-width: 769px), print {
  .level {
    display: flex;
  }
  .level > .level-item:not(.is-narrow) {
    flex-grow: 1;
  }
}

.level-item {
  align-items: center;
  display: flex;
  flex-basis: auto;
  flex-grow: 0;
  flex-shrink: 0;
  justify-content: center;
}
.level-item .title, .level-item .dark-palette #search-results .topic-title, .dark-palette #search-results .level-item .topic-title,
.level-item .dark-palette .content .topic-title,
.dark-palette .content .level-item .topic-title,
.level-item .dark-palette .document .topic-title,
.dark-palette .document .level-item .topic-title, .level-item .light-palette #search-results .topic-title, .light-palette #search-results .level-item .topic-title,
.level-item .light-palette .content .topic-title,
.light-palette .content .level-item .topic-title,
.level-item .light-palette .document .topic-title,
.light-palette .document .level-item .topic-title,
.level-item .subtitle {
  margin-bottom: 0;
}
@media screen and (max-width: 768px) {
  .level-item:not(:last-child) {
    margin-bottom: 0.75rem;
  }
}

.level-left,
.level-right {
  flex-basis: auto;
  flex-grow: 0;
  flex-shrink: 0;
}
.level-left .level-item.is-flexible,
.level-right .level-item.is-flexible {
  flex-grow: 1;
}
@media screen and (min-width: 769px), print {
  .level-left .level-item:not(:last-child),
.level-right .level-item:not(:last-child) {
    margin-right: 0.75rem;
  }
}

.level-left {
  align-items: center;
  justify-content: flex-start;
}
@media screen and (max-width: 768px) {
  .level-left + .level-right {
    margin-top: 1.5rem;
  }
}
@media screen and (min-width: 769px), print {
  .level-left {
    display: flex;
  }
}

.level-right {
  align-items: center;
  justify-content: flex-end;
}
@media screen and (min-width: 769px), print {
  .level-right {
    display: flex;
  }
}

.media {
  align-items: flex-start;
  display: flex;
  text-align: inherit;
}
.media .content:not(:last-child) {
  margin-bottom: 0.75rem;
}
.media .media {
  border-top: 1px solid rgba(201, 209, 217, 0.5);
  display: flex;
  padding-top: 0.75rem;
}
.media .media .content:not(:last-child),
.media .media .control:not(:last-child) {
  margin-bottom: 0.5rem;
}
.media .media .media {
  padding-top: 0.5rem;
}
.media .media .media + .media {
  margin-top: 0.5rem;
}
.media + .media {
  border-top: 1px solid rgba(201, 209, 217, 0.5);
  margin-top: 1rem;
  padding-top: 1rem;
}
.media.is-large + .media {
  margin-top: 1.5rem;
  padding-top: 1.5rem;
}

.media-left,
.media-right {
  flex-basis: auto;
  flex-grow: 0;
  flex-shrink: 0;
}

.media-left {
  margin-right: 1rem;
}

.media-right {
  margin-left: 1rem;
}

.media-content {
  flex-basis: auto;
  flex-grow: 1;
  flex-shrink: 1;
  text-align: inherit;
}

@media screen and (max-width: 768px) {
  .media-content {
    overflow-x: auto;
  }
}
.menu {
  font-size: 1rem;
}
.menu.is-small {
  font-size: 0.75rem;
}
.menu.is-medium {
  font-size: 1.25rem;
}
.menu.is-large {
  font-size: 1.5rem;
}

.menu-list {
  line-height: 1.25;
}
.menu-list a {
  border-radius: 2px;
  color: #3e4551;
  display: block;
  padding: 0.5em 0.75em;
}
.menu-list a:hover {
  background-color: #faf0f0;
  color: #2f3546;
}
.menu-list a.is-active {
  background-color: #4078f2;
  color: #736a59;
}
.menu-list li ul {
  border-left: 1px solid #c9d1d9;
  margin: 0.75em;
  padding-left: 0.75em;
}

.menu-label {
  color: #6f727b;
  font-size: 0.75em;
  letter-spacing: 0.1em;
  text-transform: uppercase;
}
.menu-label:not(:first-child) {
  margin-top: 1em;
}
.menu-label:not(:last-child) {
  margin-bottom: 1em;
}

.message {
  background-color: #faf0f0;
  border-radius: 4px;
  font-size: 1rem;
}
.message strong {
  color: currentColor;
}
.message a:not(.button):not(.tag):not(.dropdown-item) {
  color: currentColor;
  text-decoration: underline;
}
.message.is-small {
  font-size: 0.75rem;
}
.message.is-medium {
  font-size: 1.25rem;
}
.message.is-large {
  font-size: 1.5rem;
}
.message.is-white {
  background-color: #fafafa;
}
.message.is-white .message-header {
  background-color: #fafafa;
  color: #0d1117;
}
.message.is-white .message-body {
  border-color: #fafafa;
}
.message.is-black {
  background-color: #f8fafb;
}
.message.is-black .message-header {
  background-color: #0d1117;
  color: #fafafa;
}
.message.is-black .message-body {
  border-color: #0d1117;
}
.message.is-light {
  background-color: #fcf7f7;
}
.message.is-light .message-header {
  background-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.message.is-light .message-body {
  border-color: #faf0f0;
}
.message.is-dark {
  background-color: #f9f9fb;
}
.message.is-dark .message-header {
  background-color: #2f3546;
  color: #fff;
}
.message.is-dark .message-body {
  border-color: #2f3546;
}
.message.is-primary {
  background-color: #f1ebfe;
}
.message.is-primary .message-header {
  background-color: #885bfb;
  color: white;
}
.message.is-primary .message-body {
  border-color: #885bfb;
  color: #4206db;
}
.message.is-link {
  background-color: #88abf7;
}
.message.is-link .message-header {
  background-color: #4078f2;
  color: #736a59;
}
.message.is-link .message-body {
  border-color: #4078f2;
  color: #30529c;
}
.message.is-info {
  background-color: #eff7fa;
}
.message.is-info .message-header {
  background-color: #449cc5;
  color: #fff;
}
.message.is-info .message-body {
  border-color: #449cc5;
  color: #2f7798;
}
.message.is-success {
  background-color: #ebfff7;
}
.message.is-success .message-header {
  background-color: #00ad6b;
  color: #fff;
}
.message.is-success .message-body {
  border-color: #00ad6b;
  color: #00c278;
}
.message.is-warning {
  background-color: #fffaeb;
}
.message.is-warning .message-header {
  background-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.message.is-warning .message-body {
  border-color: #ffc400;
  color: #947100;
}
.message.is-danger {
  background-color: #fcefed;
}
.message.is-danger .message-header {
  background-color: #e45649;
  color: #fff;
}
.message.is-danger .message-body {
  border-color: #e45649;
  color: #ba291c;
}
.message.is-redish {
  background-color: #fdecf1;
}
.message.is-redish .message-header {
  background-color: #ca1243;
  color: #fff;
}
.message.is-redish .message-body {
  border-color: #ca1243;
  color: #e6144c;
}
.message.is-blueish {
  background-color: #ebf1ff;
}
.message.is-blueish .message-header {
  background-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.message.is-blueish .message-body {
  border-color: #a3c0ff;
  color: #002f94;
}
.message.is-pink {
  background-color: #feecfd;
}
.message.is-pink .message-header {
  background-color: #f57fef;
  color: #fff;
}
.message.is-pink .message-body {
  border-color: #f57fef;
  color: #9d0c95;
}
.message.is-gold {
  background-color: #fff9eb;
}
.message.is-gold .message-header {
  background-color: #c18401;
  color: #fff;
}
.message.is-gold .message-body {
  border-color: #c18401;
  color: #c68801;
}
.message.is-greenish {
  background-color: #f3f8f1;
}
.message.is-greenish .message-header {
  background-color: #5ea14f;
  color: #fff;
}
.message.is-greenish .message-body {
  border-color: #5ea14f;
  color: #4e8542;
}
.message.is-blood {
  background-color: #feecef;
}
.message.is-blood .message-header {
  background-color: #39040c;
  color: #fff;
}
.message.is-blood .message-body {
  border-color: #39040c;
  color: #f02d4a;
}

.message-header {
  align-items: center;
  background-color: #3e4551;
  border-radius: 4px 4px 0 0;
  color: #fff;
  display: flex;
  font-weight: 700;
  justify-content: space-between;
  line-height: 1.25;
  padding: 0.75em 1em;
  position: relative;
}
.message-header .delete {
  flex-grow: 0;
  flex-shrink: 0;
  margin-left: 0.75em;
}
.message-header + .message-body {
  border-width: 0;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.message-body {
  border-color: #c9d1d9;
  border-radius: 4px;
  border-style: solid;
  border-width: 0 0 0 4px;
  color: #3e4551;
  padding: 1.25em 1.5em;
}
.message-body code,
.message-body pre {
  background-color: #fafafa;
}
.message-body pre code {
  background-color: transparent;
}

.modal {
  align-items: center;
  display: none;
  flex-direction: column;
  justify-content: center;
  overflow: hidden;
  position: fixed;
  z-index: 40;
}
.modal.is-active {
  display: flex;
}

.modal-background {
  background-color: rgba(13, 17, 23, 0.86);
}

.modal-content,
.modal-card {
  margin: 0 20px;
  max-height: calc(100vh - 160px);
  overflow: auto;
  position: relative;
  width: 100%;
}
@media screen and (min-width: 769px) {
  .modal-content,
.modal-card {
    margin: 0 auto;
    max-height: calc(100vh - 40px);
    width: 640px;
  }
}

.modal-close {
  background: none;
  height: 40px;
  position: fixed;
  right: 20px;
  top: 20px;
  width: 40px;
}

.modal-card {
  display: flex;
  flex-direction: column;
  max-height: calc(100vh - 40px);
  overflow: hidden;
  -ms-overflow-y: visible;
}

.modal-card-head,
.modal-card-foot {
  align-items: center;
  background-color: #faf0f0;
  display: flex;
  flex-shrink: 0;
  justify-content: flex-start;
  padding: 20px;
  position: relative;
}

.modal-card-head {
  border-bottom: 1px solid #c9d1d9;
  border-top-left-radius: 6px;
  border-top-right-radius: 6px;
}

.modal-card-title {
  color: #2f3546;
  flex-grow: 1;
  flex-shrink: 0;
  font-size: 1.5rem;
  line-height: 1;
}

.modal-card-foot {
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
  border-top: 1px solid #c9d1d9;
}
.modal-card-foot .button:not(:last-child) {
  margin-right: 0.5em;
}

.modal-card-body {
  -webkit-overflow-scrolling: touch;
  background-color: #fafafa;
  flex-grow: 1;
  flex-shrink: 1;
  overflow: auto;
  padding: 20px;
}

.navbar {
  background-color: #fafafa;
  min-height: 3.25rem;
  position: relative;
  z-index: 30;
}
.navbar.is-white {
  background-color: #fafafa;
  color: #0d1117;
}
.navbar.is-white .navbar-brand > .navbar-item,
.navbar.is-white .navbar-brand .navbar-link {
  color: #0d1117;
}
.navbar.is-white .navbar-brand > a.navbar-item:focus, .navbar.is-white .navbar-brand > a.navbar-item:hover, .navbar.is-white .navbar-brand > a.navbar-item.is-active,
.navbar.is-white .navbar-brand .navbar-link:focus,
.navbar.is-white .navbar-brand .navbar-link:hover,
.navbar.is-white .navbar-brand .navbar-link.is-active {
  background-color: #ededed;
  color: #0d1117;
}
.navbar.is-white .navbar-brand .navbar-link::after {
  border-color: #0d1117;
}
.navbar.is-white .navbar-burger {
  color: #0d1117;
}
@media screen and (min-width: 1024px) {
  .navbar.is-white .navbar-start > .navbar-item,
.navbar.is-white .navbar-start .navbar-link,
.navbar.is-white .navbar-end > .navbar-item,
.navbar.is-white .navbar-end .navbar-link {
    color: #0d1117;
  }
  .navbar.is-white .navbar-start > a.navbar-item:focus, .navbar.is-white .navbar-start > a.navbar-item:hover, .navbar.is-white .navbar-start > a.navbar-item.is-active,
.navbar.is-white .navbar-start .navbar-link:focus,
.navbar.is-white .navbar-start .navbar-link:hover,
.navbar.is-white .navbar-start .navbar-link.is-active,
.navbar.is-white .navbar-end > a.navbar-item:focus,
.navbar.is-white .navbar-end > a.navbar-item:hover,
.navbar.is-white .navbar-end > a.navbar-item.is-active,
.navbar.is-white .navbar-end .navbar-link:focus,
.navbar.is-white .navbar-end .navbar-link:hover,
.navbar.is-white .navbar-end .navbar-link.is-active {
    background-color: #ededed;
    color: #0d1117;
  }
  .navbar.is-white .navbar-start .navbar-link::after,
.navbar.is-white .navbar-end .navbar-link::after {
    border-color: #0d1117;
  }
  .navbar.is-white .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-white .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-white .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #ededed;
    color: #0d1117;
  }
  .navbar.is-white .navbar-dropdown a.navbar-item.is-active {
    background-color: #fafafa;
    color: #0d1117;
  }
}
.navbar.is-black {
  background-color: #0d1117;
  color: #fafafa;
}
.navbar.is-black .navbar-brand > .navbar-item,
.navbar.is-black .navbar-brand .navbar-link {
  color: #fafafa;
}
.navbar.is-black .navbar-brand > a.navbar-item:focus, .navbar.is-black .navbar-brand > a.navbar-item:hover, .navbar.is-black .navbar-brand > a.navbar-item.is-active,
.navbar.is-black .navbar-brand .navbar-link:focus,
.navbar.is-black .navbar-brand .navbar-link:hover,
.navbar.is-black .navbar-brand .navbar-link.is-active {
  background-color: #040507;
  color: #fafafa;
}
.navbar.is-black .navbar-brand .navbar-link::after {
  border-color: #fafafa;
}
.navbar.is-black .navbar-burger {
  color: #fafafa;
}
@media screen and (min-width: 1024px) {
  .navbar.is-black .navbar-start > .navbar-item,
.navbar.is-black .navbar-start .navbar-link,
.navbar.is-black .navbar-end > .navbar-item,
.navbar.is-black .navbar-end .navbar-link {
    color: #fafafa;
  }
  .navbar.is-black .navbar-start > a.navbar-item:focus, .navbar.is-black .navbar-start > a.navbar-item:hover, .navbar.is-black .navbar-start > a.navbar-item.is-active,
.navbar.is-black .navbar-start .navbar-link:focus,
.navbar.is-black .navbar-start .navbar-link:hover,
.navbar.is-black .navbar-start .navbar-link.is-active,
.navbar.is-black .navbar-end > a.navbar-item:focus,
.navbar.is-black .navbar-end > a.navbar-item:hover,
.navbar.is-black .navbar-end > a.navbar-item.is-active,
.navbar.is-black .navbar-end .navbar-link:focus,
.navbar.is-black .navbar-end .navbar-link:hover,
.navbar.is-black .navbar-end .navbar-link.is-active {
    background-color: #040507;
    color: #fafafa;
  }
  .navbar.is-black .navbar-start .navbar-link::after,
.navbar.is-black .navbar-end .navbar-link::after {
    border-color: #fafafa;
  }
  .navbar.is-black .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-black .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-black .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #040507;
    color: #fafafa;
  }
  .navbar.is-black .navbar-dropdown a.navbar-item.is-active {
    background-color: #0d1117;
    color: #fafafa;
  }
}
.navbar.is-light {
  background-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-light .navbar-brand > .navbar-item,
.navbar.is-light .navbar-brand .navbar-link {
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-light .navbar-brand > a.navbar-item:focus, .navbar.is-light .navbar-brand > a.navbar-item:hover, .navbar.is-light .navbar-brand > a.navbar-item.is-active,
.navbar.is-light .navbar-brand .navbar-link:focus,
.navbar.is-light .navbar-brand .navbar-link:hover,
.navbar.is-light .navbar-brand .navbar-link.is-active {
  background-color: #f4dddd;
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-light .navbar-brand .navbar-link::after {
  border-color: rgba(0, 0, 0, 0.7);
}
.navbar.is-light .navbar-burger {
  color: rgba(0, 0, 0, 0.7);
}
@media screen and (min-width: 1024px) {
  .navbar.is-light .navbar-start > .navbar-item,
.navbar.is-light .navbar-start .navbar-link,
.navbar.is-light .navbar-end > .navbar-item,
.navbar.is-light .navbar-end .navbar-link {
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-light .navbar-start > a.navbar-item:focus, .navbar.is-light .navbar-start > a.navbar-item:hover, .navbar.is-light .navbar-start > a.navbar-item.is-active,
.navbar.is-light .navbar-start .navbar-link:focus,
.navbar.is-light .navbar-start .navbar-link:hover,
.navbar.is-light .navbar-start .navbar-link.is-active,
.navbar.is-light .navbar-end > a.navbar-item:focus,
.navbar.is-light .navbar-end > a.navbar-item:hover,
.navbar.is-light .navbar-end > a.navbar-item.is-active,
.navbar.is-light .navbar-end .navbar-link:focus,
.navbar.is-light .navbar-end .navbar-link:hover,
.navbar.is-light .navbar-end .navbar-link.is-active {
    background-color: #f4dddd;
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-light .navbar-start .navbar-link::after,
.navbar.is-light .navbar-end .navbar-link::after {
    border-color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-light .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-light .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-light .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #f4dddd;
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-light .navbar-dropdown a.navbar-item.is-active {
    background-color: #faf0f0;
    color: rgba(0, 0, 0, 0.7);
  }
}
.navbar.is-dark {
  background-color: #2f3546;
  color: #fff;
}
.navbar.is-dark .navbar-brand > .navbar-item,
.navbar.is-dark .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-dark .navbar-brand > a.navbar-item:focus, .navbar.is-dark .navbar-brand > a.navbar-item:hover, .navbar.is-dark .navbar-brand > a.navbar-item.is-active,
.navbar.is-dark .navbar-brand .navbar-link:focus,
.navbar.is-dark .navbar-brand .navbar-link:hover,
.navbar.is-dark .navbar-brand .navbar-link.is-active {
  background-color: #252937;
  color: #fff;
}
.navbar.is-dark .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-dark .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-dark .navbar-start > .navbar-item,
.navbar.is-dark .navbar-start .navbar-link,
.navbar.is-dark .navbar-end > .navbar-item,
.navbar.is-dark .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-dark .navbar-start > a.navbar-item:focus, .navbar.is-dark .navbar-start > a.navbar-item:hover, .navbar.is-dark .navbar-start > a.navbar-item.is-active,
.navbar.is-dark .navbar-start .navbar-link:focus,
.navbar.is-dark .navbar-start .navbar-link:hover,
.navbar.is-dark .navbar-start .navbar-link.is-active,
.navbar.is-dark .navbar-end > a.navbar-item:focus,
.navbar.is-dark .navbar-end > a.navbar-item:hover,
.navbar.is-dark .navbar-end > a.navbar-item.is-active,
.navbar.is-dark .navbar-end .navbar-link:focus,
.navbar.is-dark .navbar-end .navbar-link:hover,
.navbar.is-dark .navbar-end .navbar-link.is-active {
    background-color: #252937;
    color: #fff;
  }
  .navbar.is-dark .navbar-start .navbar-link::after,
.navbar.is-dark .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-dark .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-dark .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-dark .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #252937;
    color: #fff;
  }
  .navbar.is-dark .navbar-dropdown a.navbar-item.is-active {
    background-color: #2f3546;
    color: #fff;
  }
}
.navbar.is-primary {
  background-color: #885bfb;
  color: white;
}
.navbar.is-primary .navbar-brand > .navbar-item,
.navbar.is-primary .navbar-brand .navbar-link {
  color: white;
}
.navbar.is-primary .navbar-brand > a.navbar-item:focus, .navbar.is-primary .navbar-brand > a.navbar-item:hover, .navbar.is-primary .navbar-brand > a.navbar-item.is-active,
.navbar.is-primary .navbar-brand .navbar-link:focus,
.navbar.is-primary .navbar-brand .navbar-link:hover,
.navbar.is-primary .navbar-brand .navbar-link.is-active {
  background-color: #7642fa;
  color: white;
}
.navbar.is-primary .navbar-brand .navbar-link::after {
  border-color: white;
}
.navbar.is-primary .navbar-burger {
  color: white;
}
@media screen and (min-width: 1024px) {
  .navbar.is-primary .navbar-start > .navbar-item,
.navbar.is-primary .navbar-start .navbar-link,
.navbar.is-primary .navbar-end > .navbar-item,
.navbar.is-primary .navbar-end .navbar-link {
    color: white;
  }
  .navbar.is-primary .navbar-start > a.navbar-item:focus, .navbar.is-primary .navbar-start > a.navbar-item:hover, .navbar.is-primary .navbar-start > a.navbar-item.is-active,
.navbar.is-primary .navbar-start .navbar-link:focus,
.navbar.is-primary .navbar-start .navbar-link:hover,
.navbar.is-primary .navbar-start .navbar-link.is-active,
.navbar.is-primary .navbar-end > a.navbar-item:focus,
.navbar.is-primary .navbar-end > a.navbar-item:hover,
.navbar.is-primary .navbar-end > a.navbar-item.is-active,
.navbar.is-primary .navbar-end .navbar-link:focus,
.navbar.is-primary .navbar-end .navbar-link:hover,
.navbar.is-primary .navbar-end .navbar-link.is-active {
    background-color: #7642fa;
    color: white;
  }
  .navbar.is-primary .navbar-start .navbar-link::after,
.navbar.is-primary .navbar-end .navbar-link::after {
    border-color: white;
  }
  .navbar.is-primary .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-primary .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-primary .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #7642fa;
    color: white;
  }
  .navbar.is-primary .navbar-dropdown a.navbar-item.is-active {
    background-color: #885bfb;
    color: white;
  }
}
.navbar.is-link {
  background-color: #4078f2;
  color: #736a59;
}
.navbar.is-link .navbar-brand > .navbar-item,
.navbar.is-link .navbar-brand .navbar-link {
  color: #736a59;
}
.navbar.is-link .navbar-brand > a.navbar-item:focus, .navbar.is-link .navbar-brand > a.navbar-item:hover, .navbar.is-link .navbar-brand > a.navbar-item.is-active,
.navbar.is-link .navbar-brand .navbar-link:focus,
.navbar.is-link .navbar-brand .navbar-link:hover,
.navbar.is-link .navbar-brand .navbar-link.is-active {
  background-color: #2868f0;
  color: #736a59;
}
.navbar.is-link .navbar-brand .navbar-link::after {
  border-color: #736a59;
}
.navbar.is-link .navbar-burger {
  color: #736a59;
}
@media screen and (min-width: 1024px) {
  .navbar.is-link .navbar-start > .navbar-item,
.navbar.is-link .navbar-start .navbar-link,
.navbar.is-link .navbar-end > .navbar-item,
.navbar.is-link .navbar-end .navbar-link {
    color: #736a59;
  }
  .navbar.is-link .navbar-start > a.navbar-item:focus, .navbar.is-link .navbar-start > a.navbar-item:hover, .navbar.is-link .navbar-start > a.navbar-item.is-active,
.navbar.is-link .navbar-start .navbar-link:focus,
.navbar.is-link .navbar-start .navbar-link:hover,
.navbar.is-link .navbar-start .navbar-link.is-active,
.navbar.is-link .navbar-end > a.navbar-item:focus,
.navbar.is-link .navbar-end > a.navbar-item:hover,
.navbar.is-link .navbar-end > a.navbar-item.is-active,
.navbar.is-link .navbar-end .navbar-link:focus,
.navbar.is-link .navbar-end .navbar-link:hover,
.navbar.is-link .navbar-end .navbar-link.is-active {
    background-color: #2868f0;
    color: #736a59;
  }
  .navbar.is-link .navbar-start .navbar-link::after,
.navbar.is-link .navbar-end .navbar-link::after {
    border-color: #736a59;
  }
  .navbar.is-link .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-link .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-link .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #2868f0;
    color: #736a59;
  }
  .navbar.is-link .navbar-dropdown a.navbar-item.is-active {
    background-color: #4078f2;
    color: #736a59;
  }
}
.navbar.is-info {
  background-color: #449cc5;
  color: #fff;
}
.navbar.is-info .navbar-brand > .navbar-item,
.navbar.is-info .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-info .navbar-brand > a.navbar-item:focus, .navbar.is-info .navbar-brand > a.navbar-item:hover, .navbar.is-info .navbar-brand > a.navbar-item.is-active,
.navbar.is-info .navbar-brand .navbar-link:focus,
.navbar.is-info .navbar-brand .navbar-link:hover,
.navbar.is-info .navbar-brand .navbar-link.is-active {
  background-color: #388fb7;
  color: #fff;
}
.navbar.is-info .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-info .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-info .navbar-start > .navbar-item,
.navbar.is-info .navbar-start .navbar-link,
.navbar.is-info .navbar-end > .navbar-item,
.navbar.is-info .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-info .navbar-start > a.navbar-item:focus, .navbar.is-info .navbar-start > a.navbar-item:hover, .navbar.is-info .navbar-start > a.navbar-item.is-active,
.navbar.is-info .navbar-start .navbar-link:focus,
.navbar.is-info .navbar-start .navbar-link:hover,
.navbar.is-info .navbar-start .navbar-link.is-active,
.navbar.is-info .navbar-end > a.navbar-item:focus,
.navbar.is-info .navbar-end > a.navbar-item:hover,
.navbar.is-info .navbar-end > a.navbar-item.is-active,
.navbar.is-info .navbar-end .navbar-link:focus,
.navbar.is-info .navbar-end .navbar-link:hover,
.navbar.is-info .navbar-end .navbar-link.is-active {
    background-color: #388fb7;
    color: #fff;
  }
  .navbar.is-info .navbar-start .navbar-link::after,
.navbar.is-info .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-info .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-info .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-info .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #388fb7;
    color: #fff;
  }
  .navbar.is-info .navbar-dropdown a.navbar-item.is-active {
    background-color: #449cc5;
    color: #fff;
  }
}
.navbar.is-success {
  background-color: #00ad6b;
  color: #fff;
}
.navbar.is-success .navbar-brand > .navbar-item,
.navbar.is-success .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-success .navbar-brand > a.navbar-item:focus, .navbar.is-success .navbar-brand > a.navbar-item:hover, .navbar.is-success .navbar-brand > a.navbar-item.is-active,
.navbar.is-success .navbar-brand .navbar-link:focus,
.navbar.is-success .navbar-brand .navbar-link:hover,
.navbar.is-success .navbar-brand .navbar-link.is-active {
  background-color: #00945b;
  color: #fff;
}
.navbar.is-success .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-success .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-success .navbar-start > .navbar-item,
.navbar.is-success .navbar-start .navbar-link,
.navbar.is-success .navbar-end > .navbar-item,
.navbar.is-success .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-success .navbar-start > a.navbar-item:focus, .navbar.is-success .navbar-start > a.navbar-item:hover, .navbar.is-success .navbar-start > a.navbar-item.is-active,
.navbar.is-success .navbar-start .navbar-link:focus,
.navbar.is-success .navbar-start .navbar-link:hover,
.navbar.is-success .navbar-start .navbar-link.is-active,
.navbar.is-success .navbar-end > a.navbar-item:focus,
.navbar.is-success .navbar-end > a.navbar-item:hover,
.navbar.is-success .navbar-end > a.navbar-item.is-active,
.navbar.is-success .navbar-end .navbar-link:focus,
.navbar.is-success .navbar-end .navbar-link:hover,
.navbar.is-success .navbar-end .navbar-link.is-active {
    background-color: #00945b;
    color: #fff;
  }
  .navbar.is-success .navbar-start .navbar-link::after,
.navbar.is-success .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-success .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-success .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-success .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #00945b;
    color: #fff;
  }
  .navbar.is-success .navbar-dropdown a.navbar-item.is-active {
    background-color: #00ad6b;
    color: #fff;
  }
}
.navbar.is-warning {
  background-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-warning .navbar-brand > .navbar-item,
.navbar.is-warning .navbar-brand .navbar-link {
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-warning .navbar-brand > a.navbar-item:focus, .navbar.is-warning .navbar-brand > a.navbar-item:hover, .navbar.is-warning .navbar-brand > a.navbar-item.is-active,
.navbar.is-warning .navbar-brand .navbar-link:focus,
.navbar.is-warning .navbar-brand .navbar-link:hover,
.navbar.is-warning .navbar-brand .navbar-link.is-active {
  background-color: #e6b000;
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-warning .navbar-brand .navbar-link::after {
  border-color: rgba(0, 0, 0, 0.7);
}
.navbar.is-warning .navbar-burger {
  color: rgba(0, 0, 0, 0.7);
}
@media screen and (min-width: 1024px) {
  .navbar.is-warning .navbar-start > .navbar-item,
.navbar.is-warning .navbar-start .navbar-link,
.navbar.is-warning .navbar-end > .navbar-item,
.navbar.is-warning .navbar-end .navbar-link {
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-warning .navbar-start > a.navbar-item:focus, .navbar.is-warning .navbar-start > a.navbar-item:hover, .navbar.is-warning .navbar-start > a.navbar-item.is-active,
.navbar.is-warning .navbar-start .navbar-link:focus,
.navbar.is-warning .navbar-start .navbar-link:hover,
.navbar.is-warning .navbar-start .navbar-link.is-active,
.navbar.is-warning .navbar-end > a.navbar-item:focus,
.navbar.is-warning .navbar-end > a.navbar-item:hover,
.navbar.is-warning .navbar-end > a.navbar-item.is-active,
.navbar.is-warning .navbar-end .navbar-link:focus,
.navbar.is-warning .navbar-end .navbar-link:hover,
.navbar.is-warning .navbar-end .navbar-link.is-active {
    background-color: #e6b000;
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-warning .navbar-start .navbar-link::after,
.navbar.is-warning .navbar-end .navbar-link::after {
    border-color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-warning .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-warning .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-warning .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #e6b000;
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-warning .navbar-dropdown a.navbar-item.is-active {
    background-color: #ffc400;
    color: rgba(0, 0, 0, 0.7);
  }
}
.navbar.is-danger {
  background-color: #e45649;
  color: #fff;
}
.navbar.is-danger .navbar-brand > .navbar-item,
.navbar.is-danger .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-danger .navbar-brand > a.navbar-item:focus, .navbar.is-danger .navbar-brand > a.navbar-item:hover, .navbar.is-danger .navbar-brand > a.navbar-item.is-active,
.navbar.is-danger .navbar-brand .navbar-link:focus,
.navbar.is-danger .navbar-brand .navbar-link:hover,
.navbar.is-danger .navbar-brand .navbar-link.is-active {
  background-color: #e14133;
  color: #fff;
}
.navbar.is-danger .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-danger .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-danger .navbar-start > .navbar-item,
.navbar.is-danger .navbar-start .navbar-link,
.navbar.is-danger .navbar-end > .navbar-item,
.navbar.is-danger .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-danger .navbar-start > a.navbar-item:focus, .navbar.is-danger .navbar-start > a.navbar-item:hover, .navbar.is-danger .navbar-start > a.navbar-item.is-active,
.navbar.is-danger .navbar-start .navbar-link:focus,
.navbar.is-danger .navbar-start .navbar-link:hover,
.navbar.is-danger .navbar-start .navbar-link.is-active,
.navbar.is-danger .navbar-end > a.navbar-item:focus,
.navbar.is-danger .navbar-end > a.navbar-item:hover,
.navbar.is-danger .navbar-end > a.navbar-item.is-active,
.navbar.is-danger .navbar-end .navbar-link:focus,
.navbar.is-danger .navbar-end .navbar-link:hover,
.navbar.is-danger .navbar-end .navbar-link.is-active {
    background-color: #e14133;
    color: #fff;
  }
  .navbar.is-danger .navbar-start .navbar-link::after,
.navbar.is-danger .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-danger .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-danger .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-danger .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #e14133;
    color: #fff;
  }
  .navbar.is-danger .navbar-dropdown a.navbar-item.is-active {
    background-color: #e45649;
    color: #fff;
  }
}
.navbar.is-redish {
  background-color: #ca1243;
  color: #fff;
}
.navbar.is-redish .navbar-brand > .navbar-item,
.navbar.is-redish .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-redish .navbar-brand > a.navbar-item:focus, .navbar.is-redish .navbar-brand > a.navbar-item:hover, .navbar.is-redish .navbar-brand > a.navbar-item.is-active,
.navbar.is-redish .navbar-brand .navbar-link:focus,
.navbar.is-redish .navbar-brand .navbar-link:hover,
.navbar.is-redish .navbar-brand .navbar-link.is-active {
  background-color: #b2103b;
  color: #fff;
}
.navbar.is-redish .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-redish .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-redish .navbar-start > .navbar-item,
.navbar.is-redish .navbar-start .navbar-link,
.navbar.is-redish .navbar-end > .navbar-item,
.navbar.is-redish .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-redish .navbar-start > a.navbar-item:focus, .navbar.is-redish .navbar-start > a.navbar-item:hover, .navbar.is-redish .navbar-start > a.navbar-item.is-active,
.navbar.is-redish .navbar-start .navbar-link:focus,
.navbar.is-redish .navbar-start .navbar-link:hover,
.navbar.is-redish .navbar-start .navbar-link.is-active,
.navbar.is-redish .navbar-end > a.navbar-item:focus,
.navbar.is-redish .navbar-end > a.navbar-item:hover,
.navbar.is-redish .navbar-end > a.navbar-item.is-active,
.navbar.is-redish .navbar-end .navbar-link:focus,
.navbar.is-redish .navbar-end .navbar-link:hover,
.navbar.is-redish .navbar-end .navbar-link.is-active {
    background-color: #b2103b;
    color: #fff;
  }
  .navbar.is-redish .navbar-start .navbar-link::after,
.navbar.is-redish .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-redish .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-redish .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-redish .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #b2103b;
    color: #fff;
  }
  .navbar.is-redish .navbar-dropdown a.navbar-item.is-active {
    background-color: #ca1243;
    color: #fff;
  }
}
.navbar.is-blueish {
  background-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-blueish .navbar-brand > .navbar-item,
.navbar.is-blueish .navbar-brand .navbar-link {
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-blueish .navbar-brand > a.navbar-item:focus, .navbar.is-blueish .navbar-brand > a.navbar-item:hover, .navbar.is-blueish .navbar-brand > a.navbar-item.is-active,
.navbar.is-blueish .navbar-brand .navbar-link:focus,
.navbar.is-blueish .navbar-brand .navbar-link:hover,
.navbar.is-blueish .navbar-brand .navbar-link.is-active {
  background-color: #8aafff;
  color: rgba(0, 0, 0, 0.7);
}
.navbar.is-blueish .navbar-brand .navbar-link::after {
  border-color: rgba(0, 0, 0, 0.7);
}
.navbar.is-blueish .navbar-burger {
  color: rgba(0, 0, 0, 0.7);
}
@media screen and (min-width: 1024px) {
  .navbar.is-blueish .navbar-start > .navbar-item,
.navbar.is-blueish .navbar-start .navbar-link,
.navbar.is-blueish .navbar-end > .navbar-item,
.navbar.is-blueish .navbar-end .navbar-link {
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-blueish .navbar-start > a.navbar-item:focus, .navbar.is-blueish .navbar-start > a.navbar-item:hover, .navbar.is-blueish .navbar-start > a.navbar-item.is-active,
.navbar.is-blueish .navbar-start .navbar-link:focus,
.navbar.is-blueish .navbar-start .navbar-link:hover,
.navbar.is-blueish .navbar-start .navbar-link.is-active,
.navbar.is-blueish .navbar-end > a.navbar-item:focus,
.navbar.is-blueish .navbar-end > a.navbar-item:hover,
.navbar.is-blueish .navbar-end > a.navbar-item.is-active,
.navbar.is-blueish .navbar-end .navbar-link:focus,
.navbar.is-blueish .navbar-end .navbar-link:hover,
.navbar.is-blueish .navbar-end .navbar-link.is-active {
    background-color: #8aafff;
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-blueish .navbar-start .navbar-link::after,
.navbar.is-blueish .navbar-end .navbar-link::after {
    border-color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-blueish .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-blueish .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-blueish .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #8aafff;
    color: rgba(0, 0, 0, 0.7);
  }
  .navbar.is-blueish .navbar-dropdown a.navbar-item.is-active {
    background-color: #a3c0ff;
    color: rgba(0, 0, 0, 0.7);
  }
}
.navbar.is-pink {
  background-color: #f57fef;
  color: #fff;
}
.navbar.is-pink .navbar-brand > .navbar-item,
.navbar.is-pink .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-pink .navbar-brand > a.navbar-item:focus, .navbar.is-pink .navbar-brand > a.navbar-item:hover, .navbar.is-pink .navbar-brand > a.navbar-item.is-active,
.navbar.is-pink .navbar-brand .navbar-link:focus,
.navbar.is-pink .navbar-brand .navbar-link:hover,
.navbar.is-pink .navbar-brand .navbar-link.is-active {
  background-color: #f467ed;
  color: #fff;
}
.navbar.is-pink .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-pink .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-pink .navbar-start > .navbar-item,
.navbar.is-pink .navbar-start .navbar-link,
.navbar.is-pink .navbar-end > .navbar-item,
.navbar.is-pink .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-pink .navbar-start > a.navbar-item:focus, .navbar.is-pink .navbar-start > a.navbar-item:hover, .navbar.is-pink .navbar-start > a.navbar-item.is-active,
.navbar.is-pink .navbar-start .navbar-link:focus,
.navbar.is-pink .navbar-start .navbar-link:hover,
.navbar.is-pink .navbar-start .navbar-link.is-active,
.navbar.is-pink .navbar-end > a.navbar-item:focus,
.navbar.is-pink .navbar-end > a.navbar-item:hover,
.navbar.is-pink .navbar-end > a.navbar-item.is-active,
.navbar.is-pink .navbar-end .navbar-link:focus,
.navbar.is-pink .navbar-end .navbar-link:hover,
.navbar.is-pink .navbar-end .navbar-link.is-active {
    background-color: #f467ed;
    color: #fff;
  }
  .navbar.is-pink .navbar-start .navbar-link::after,
.navbar.is-pink .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-pink .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-pink .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-pink .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #f467ed;
    color: #fff;
  }
  .navbar.is-pink .navbar-dropdown a.navbar-item.is-active {
    background-color: #f57fef;
    color: #fff;
  }
}
.navbar.is-gold {
  background-color: #c18401;
  color: #fff;
}
.navbar.is-gold .navbar-brand > .navbar-item,
.navbar.is-gold .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-gold .navbar-brand > a.navbar-item:focus, .navbar.is-gold .navbar-brand > a.navbar-item:hover, .navbar.is-gold .navbar-brand > a.navbar-item.is-active,
.navbar.is-gold .navbar-brand .navbar-link:focus,
.navbar.is-gold .navbar-brand .navbar-link:hover,
.navbar.is-gold .navbar-brand .navbar-link.is-active {
  background-color: #a77301;
  color: #fff;
}
.navbar.is-gold .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-gold .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-gold .navbar-start > .navbar-item,
.navbar.is-gold .navbar-start .navbar-link,
.navbar.is-gold .navbar-end > .navbar-item,
.navbar.is-gold .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-gold .navbar-start > a.navbar-item:focus, .navbar.is-gold .navbar-start > a.navbar-item:hover, .navbar.is-gold .navbar-start > a.navbar-item.is-active,
.navbar.is-gold .navbar-start .navbar-link:focus,
.navbar.is-gold .navbar-start .navbar-link:hover,
.navbar.is-gold .navbar-start .navbar-link.is-active,
.navbar.is-gold .navbar-end > a.navbar-item:focus,
.navbar.is-gold .navbar-end > a.navbar-item:hover,
.navbar.is-gold .navbar-end > a.navbar-item.is-active,
.navbar.is-gold .navbar-end .navbar-link:focus,
.navbar.is-gold .navbar-end .navbar-link:hover,
.navbar.is-gold .navbar-end .navbar-link.is-active {
    background-color: #a77301;
    color: #fff;
  }
  .navbar.is-gold .navbar-start .navbar-link::after,
.navbar.is-gold .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-gold .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-gold .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-gold .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #a77301;
    color: #fff;
  }
  .navbar.is-gold .navbar-dropdown a.navbar-item.is-active {
    background-color: #c18401;
    color: #fff;
  }
}
.navbar.is-greenish {
  background-color: #5ea14f;
  color: #fff;
}
.navbar.is-greenish .navbar-brand > .navbar-item,
.navbar.is-greenish .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-greenish .navbar-brand > a.navbar-item:focus, .navbar.is-greenish .navbar-brand > a.navbar-item:hover, .navbar.is-greenish .navbar-brand > a.navbar-item.is-active,
.navbar.is-greenish .navbar-brand .navbar-link:focus,
.navbar.is-greenish .navbar-brand .navbar-link:hover,
.navbar.is-greenish .navbar-brand .navbar-link.is-active {
  background-color: #549047;
  color: #fff;
}
.navbar.is-greenish .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-greenish .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-greenish .navbar-start > .navbar-item,
.navbar.is-greenish .navbar-start .navbar-link,
.navbar.is-greenish .navbar-end > .navbar-item,
.navbar.is-greenish .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-greenish .navbar-start > a.navbar-item:focus, .navbar.is-greenish .navbar-start > a.navbar-item:hover, .navbar.is-greenish .navbar-start > a.navbar-item.is-active,
.navbar.is-greenish .navbar-start .navbar-link:focus,
.navbar.is-greenish .navbar-start .navbar-link:hover,
.navbar.is-greenish .navbar-start .navbar-link.is-active,
.navbar.is-greenish .navbar-end > a.navbar-item:focus,
.navbar.is-greenish .navbar-end > a.navbar-item:hover,
.navbar.is-greenish .navbar-end > a.navbar-item.is-active,
.navbar.is-greenish .navbar-end .navbar-link:focus,
.navbar.is-greenish .navbar-end .navbar-link:hover,
.navbar.is-greenish .navbar-end .navbar-link.is-active {
    background-color: #549047;
    color: #fff;
  }
  .navbar.is-greenish .navbar-start .navbar-link::after,
.navbar.is-greenish .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-greenish .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-greenish .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-greenish .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #549047;
    color: #fff;
  }
  .navbar.is-greenish .navbar-dropdown a.navbar-item.is-active {
    background-color: #5ea14f;
    color: #fff;
  }
}
.navbar.is-blood {
  background-color: #39040c;
  color: #fff;
}
.navbar.is-blood .navbar-brand > .navbar-item,
.navbar.is-blood .navbar-brand .navbar-link {
  color: #fff;
}
.navbar.is-blood .navbar-brand > a.navbar-item:focus, .navbar.is-blood .navbar-brand > a.navbar-item:hover, .navbar.is-blood .navbar-brand > a.navbar-item.is-active,
.navbar.is-blood .navbar-brand .navbar-link:focus,
.navbar.is-blood .navbar-brand .navbar-link:hover,
.navbar.is-blood .navbar-brand .navbar-link.is-active {
  background-color: #210207;
  color: #fff;
}
.navbar.is-blood .navbar-brand .navbar-link::after {
  border-color: #fff;
}
.navbar.is-blood .navbar-burger {
  color: #fff;
}
@media screen and (min-width: 1024px) {
  .navbar.is-blood .navbar-start > .navbar-item,
.navbar.is-blood .navbar-start .navbar-link,
.navbar.is-blood .navbar-end > .navbar-item,
.navbar.is-blood .navbar-end .navbar-link {
    color: #fff;
  }
  .navbar.is-blood .navbar-start > a.navbar-item:focus, .navbar.is-blood .navbar-start > a.navbar-item:hover, .navbar.is-blood .navbar-start > a.navbar-item.is-active,
.navbar.is-blood .navbar-start .navbar-link:focus,
.navbar.is-blood .navbar-start .navbar-link:hover,
.navbar.is-blood .navbar-start .navbar-link.is-active,
.navbar.is-blood .navbar-end > a.navbar-item:focus,
.navbar.is-blood .navbar-end > a.navbar-item:hover,
.navbar.is-blood .navbar-end > a.navbar-item.is-active,
.navbar.is-blood .navbar-end .navbar-link:focus,
.navbar.is-blood .navbar-end .navbar-link:hover,
.navbar.is-blood .navbar-end .navbar-link.is-active {
    background-color: #210207;
    color: #fff;
  }
  .navbar.is-blood .navbar-start .navbar-link::after,
.navbar.is-blood .navbar-end .navbar-link::after {
    border-color: #fff;
  }
  .navbar.is-blood .navbar-item.has-dropdown:focus .navbar-link,
.navbar.is-blood .navbar-item.has-dropdown:hover .navbar-link,
.navbar.is-blood .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: #210207;
    color: #fff;
  }
  .navbar.is-blood .navbar-dropdown a.navbar-item.is-active {
    background-color: #39040c;
    color: #fff;
  }
}
.navbar > .container {
  align-items: stretch;
  display: flex;
  min-height: 3.25rem;
  width: 100%;
}
.navbar.has-shadow {
  box-shadow: 0 2px 0 0 #faf0f0;
}
.navbar.is-fixed-bottom, .navbar.is-fixed-top {
  left: 0;
  position: fixed;
  right: 0;
  z-index: 30;
}
.navbar.is-fixed-bottom {
  bottom: 0;
}
.navbar.is-fixed-bottom.has-shadow {
  box-shadow: 0 -2px 0 0 #faf0f0;
}
.navbar.is-fixed-top {
  top: 0;
}

html.has-navbar-fixed-top,
body.has-navbar-fixed-top {
  padding-top: 3.25rem;
}
html.has-navbar-fixed-bottom,
body.has-navbar-fixed-bottom {
  padding-bottom: 3.25rem;
}

.navbar-brand,
.navbar-tabs {
  align-items: stretch;
  display: flex;
  flex-shrink: 0;
  min-height: 3.25rem;
}

.navbar-brand a.navbar-item:focus, .navbar-brand a.navbar-item:hover {
  background-color: transparent;
}

.navbar-tabs {
  -webkit-overflow-scrolling: touch;
  max-width: 100vw;
  overflow-x: auto;
  overflow-y: hidden;
}

.navbar-burger {
  color: #3e4551;
  cursor: pointer;
  display: block;
  height: 3.25rem;
  position: relative;
  width: 3.25rem;
  margin-left: auto;
}
.navbar-burger span {
  background-color: currentColor;
  display: block;
  height: 1px;
  left: calc(50% - 8px);
  position: absolute;
  transform-origin: center;
  transition-duration: 86ms;
  transition-property: background-color, opacity, transform;
  transition-timing-function: ease-out;
  width: 16px;
}
.navbar-burger span:nth-child(1) {
  top: calc(50% - 6px);
}
.navbar-burger span:nth-child(2) {
  top: calc(50% - 1px);
}
.navbar-burger span:nth-child(3) {
  top: calc(50% + 4px);
}
.navbar-burger:hover {
  background-color: rgba(0, 0, 0, 0.05);
}
.navbar-burger.is-active span:nth-child(1) {
  transform: translateY(5px) rotate(45deg);
}
.navbar-burger.is-active span:nth-child(2) {
  opacity: 0;
}
.navbar-burger.is-active span:nth-child(3) {
  transform: translateY(-5px) rotate(-45deg);
}

.navbar-menu {
  display: none;
}

.navbar-item,
.navbar-link {
  color: #3e4551;
  display: block;
  line-height: 1.5;
  padding: 0.5rem 0.75rem;
  position: relative;
}
.navbar-item .icon:only-child,
.navbar-link .icon:only-child {
  margin-left: -0.25rem;
  margin-right: -0.25rem;
}

a.navbar-item,
.navbar-link {
  cursor: pointer;
}
a.navbar-item:focus, a.navbar-item:focus-within, a.navbar-item:hover, a.navbar-item.is-active,
.navbar-link:focus,
.navbar-link:focus-within,
.navbar-link:hover,
.navbar-link.is-active {
  background-color: whitesmoke;
  color: #4078f2;
}

.navbar-item {
  flex-grow: 0;
  flex-shrink: 0;
}
.navbar-item img {
  max-height: 1.75rem;
}
.navbar-item.has-dropdown {
  padding: 0;
}
.navbar-item.is-expanded {
  flex-grow: 1;
  flex-shrink: 1;
}
.navbar-item.is-tab {
  border-bottom: 1px solid transparent;
  min-height: 3.25rem;
  padding-bottom: calc(0.5rem - 1px);
}
.navbar-item.is-tab:focus, .navbar-item.is-tab:hover {
  background-color: transparent;
  border-bottom-color: #4078f2;
}
.navbar-item.is-tab.is-active {
  background-color: transparent;
  border-bottom-color: #4078f2;
  border-bottom-style: solid;
  border-bottom-width: 3px;
  color: #4078f2;
  padding-bottom: calc(0.5rem - 3px);
}

.navbar-content {
  flex-grow: 1;
  flex-shrink: 1;
}

.navbar-link:not(.is-arrowless) {
  padding-right: 2.5em;
}
.navbar-link:not(.is-arrowless)::after {
  border-color: #4078f2;
  margin-top: -0.375em;
  right: 1.125em;
}

.navbar-dropdown {
  font-size: 0.875rem;
  padding-bottom: 0.5rem;
  padding-top: 0.5rem;
}
.navbar-dropdown .navbar-item {
  padding-left: 1.5rem;
  padding-right: 1.5rem;
}

.navbar-divider {
  background-color: #faf0f0;
  border: none;
  display: none;
  height: 2px;
  margin: 0.5rem 0;
}

@media screen and (max-width: 1023px) {
  .navbar > .container {
    display: block;
  }

  .navbar-brand .navbar-item,
.navbar-tabs .navbar-item {
    align-items: center;
    display: flex;
  }

  .navbar-link::after {
    display: none;
  }

  .navbar-menu {
    background-color: #fafafa;
    box-shadow: 0 8px 16px rgba(13, 17, 23, 0.1);
    padding: 0.5rem 0;
  }
  .navbar-menu.is-active {
    display: block;
  }

  .navbar.is-fixed-bottom-touch, .navbar.is-fixed-top-touch {
    left: 0;
    position: fixed;
    right: 0;
    z-index: 30;
  }
  .navbar.is-fixed-bottom-touch {
    bottom: 0;
  }
  .navbar.is-fixed-bottom-touch.has-shadow {
    box-shadow: 0 -2px 3px rgba(13, 17, 23, 0.1);
  }
  .navbar.is-fixed-top-touch {
    top: 0;
  }
  .navbar.is-fixed-top .navbar-menu, .navbar.is-fixed-top-touch .navbar-menu {
    -webkit-overflow-scrolling: touch;
    max-height: calc(100vh - 3.25rem);
    overflow: auto;
  }

  html.has-navbar-fixed-top-touch,
body.has-navbar-fixed-top-touch {
    padding-top: 3.25rem;
  }
  html.has-navbar-fixed-bottom-touch,
body.has-navbar-fixed-bottom-touch {
    padding-bottom: 3.25rem;
  }
}
@media screen and (min-width: 1024px) {
  .navbar,
.navbar-menu,
.navbar-start,
.navbar-end {
    align-items: stretch;
    display: flex;
  }

  .navbar {
    min-height: 3.25rem;
  }
  .navbar.is-spaced {
    padding: 1rem 2rem;
  }
  .navbar.is-spaced .navbar-start,
.navbar.is-spaced .navbar-end {
    align-items: center;
  }
  .navbar.is-spaced a.navbar-item,
.navbar.is-spaced .navbar-link {
    border-radius: 4px;
  }
  .navbar.is-transparent a.navbar-item:focus, .navbar.is-transparent a.navbar-item:hover, .navbar.is-transparent a.navbar-item.is-active,
.navbar.is-transparent .navbar-link:focus,
.navbar.is-transparent .navbar-link:hover,
.navbar.is-transparent .navbar-link.is-active {
    background-color: transparent !important;
  }
  .navbar.is-transparent .navbar-item.has-dropdown.is-active .navbar-link, .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:focus .navbar-link, .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:focus-within .navbar-link, .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:hover .navbar-link {
    background-color: transparent !important;
  }
  .navbar.is-transparent .navbar-dropdown a.navbar-item:focus, .navbar.is-transparent .navbar-dropdown a.navbar-item:hover {
    background-color: #faf0f0;
    color: #0d1117;
  }
  .navbar.is-transparent .navbar-dropdown a.navbar-item.is-active {
    background-color: #faf0f0;
    color: #4078f2;
  }

  .navbar-burger {
    display: none;
  }

  .navbar-item,
.navbar-link {
    align-items: center;
    display: flex;
  }

  .navbar-item.has-dropdown {
    align-items: stretch;
  }
  .navbar-item.has-dropdown-up .navbar-link::after {
    transform: rotate(135deg) translate(0.25em, -0.25em);
  }
  .navbar-item.has-dropdown-up .navbar-dropdown {
    border-bottom: 2px solid #c9d1d9;
    border-radius: 6px 6px 0 0;
    border-top: none;
    bottom: 100%;
    box-shadow: 0 -8px 8px rgba(13, 17, 23, 0.1);
    top: auto;
  }
  .navbar-item.is-active .navbar-dropdown, .navbar-item.is-hoverable:focus .navbar-dropdown, .navbar-item.is-hoverable:focus-within .navbar-dropdown, .navbar-item.is-hoverable:hover .navbar-dropdown {
    display: block;
  }
  .navbar.is-spaced .navbar-item.is-active .navbar-dropdown, .navbar-item.is-active .navbar-dropdown.is-boxed, .navbar.is-spaced .navbar-item.is-hoverable:focus .navbar-dropdown, .navbar-item.is-hoverable:focus .navbar-dropdown.is-boxed, .navbar.is-spaced .navbar-item.is-hoverable:focus-within .navbar-dropdown, .navbar-item.is-hoverable:focus-within .navbar-dropdown.is-boxed, .navbar.is-spaced .navbar-item.is-hoverable:hover .navbar-dropdown, .navbar-item.is-hoverable:hover .navbar-dropdown.is-boxed {
    opacity: 1;
    pointer-events: auto;
    transform: translateY(0);
  }

  .navbar-menu {
    flex-grow: 1;
    flex-shrink: 0;
  }

  .navbar-start {
    justify-content: flex-start;
    margin-right: auto;
  }

  .navbar-end {
    justify-content: flex-end;
    margin-left: auto;
  }

  .navbar-dropdown {
    background-color: #fafafa;
    border-bottom-left-radius: 6px;
    border-bottom-right-radius: 6px;
    border-top: 2px solid #c9d1d9;
    box-shadow: 0 8px 8px rgba(13, 17, 23, 0.1);
    display: none;
    font-size: 0.875rem;
    left: 0;
    min-width: 100%;
    position: absolute;
    top: 100%;
    z-index: 20;
  }
  .navbar-dropdown .navbar-item {
    padding: 0.375rem 1rem;
    white-space: nowrap;
  }
  .navbar-dropdown a.navbar-item {
    padding-right: 3rem;
  }
  .navbar-dropdown a.navbar-item:focus, .navbar-dropdown a.navbar-item:hover {
    background-color: #faf0f0;
    color: #0d1117;
  }
  .navbar-dropdown a.navbar-item.is-active {
    background-color: #faf0f0;
    color: #4078f2;
  }
  .navbar.is-spaced .navbar-dropdown, .navbar-dropdown.is-boxed {
    border-radius: 6px;
    border-top: none;
    box-shadow: 0 8px 8px rgba(13, 17, 23, 0.1), 0 0 0 1px rgba(13, 17, 23, 0.1);
    display: block;
    opacity: 0;
    pointer-events: none;
    top: calc(100% + (-4px));
    transform: translateY(-5px);
    transition-duration: 86ms;
    transition-property: opacity, transform;
  }
  .navbar-dropdown.is-right {
    left: auto;
    right: 0;
  }

  .navbar-divider {
    display: block;
  }

  .navbar > .container .navbar-brand,
.container > .navbar .navbar-brand {
    margin-left: -0.75rem;
  }
  .navbar > .container .navbar-menu,
.container > .navbar .navbar-menu {
    margin-right: -0.75rem;
  }

  .navbar.is-fixed-bottom-desktop, .navbar.is-fixed-top-desktop {
    left: 0;
    position: fixed;
    right: 0;
    z-index: 30;
  }
  .navbar.is-fixed-bottom-desktop {
    bottom: 0;
  }
  .navbar.is-fixed-bottom-desktop.has-shadow {
    box-shadow: 0 -2px 3px rgba(13, 17, 23, 0.1);
  }
  .navbar.is-fixed-top-desktop {
    top: 0;
  }

  html.has-navbar-fixed-top-desktop,
body.has-navbar-fixed-top-desktop {
    padding-top: 3.25rem;
  }
  html.has-navbar-fixed-bottom-desktop,
body.has-navbar-fixed-bottom-desktop {
    padding-bottom: 3.25rem;
  }
  html.has-spaced-navbar-fixed-top,
body.has-spaced-navbar-fixed-top {
    padding-top: 5.25rem;
  }
  html.has-spaced-navbar-fixed-bottom,
body.has-spaced-navbar-fixed-bottom {
    padding-bottom: 5.25rem;
  }

  a.navbar-item.is-active,
.navbar-link.is-active {
    color: #0d1117;
  }
  a.navbar-item.is-active:not(:focus):not(:hover),
.navbar-link.is-active:not(:focus):not(:hover) {
    background-color: transparent;
  }

  .navbar-item.has-dropdown:focus .navbar-link, .navbar-item.has-dropdown:hover .navbar-link, .navbar-item.has-dropdown.is-active .navbar-link {
    background-color: whitesmoke;
  }
}
.hero.is-fullheight-with-navbar {
  min-height: calc(100vh - 3.25rem);
}

.pagination {
  font-size: 1rem;
  margin: -0.25rem;
}
.pagination.is-small {
  font-size: 0.75rem;
}
.pagination.is-medium {
  font-size: 1.25rem;
}
.pagination.is-large {
  font-size: 1.5rem;
}
.pagination.is-rounded .pagination-previous,
.pagination.is-rounded .pagination-next {
  padding-left: 1em;
  padding-right: 1em;
  border-radius: 9999px;
}
.pagination.is-rounded .pagination-link {
  border-radius: 9999px;
}

.pagination,
.pagination-list {
  align-items: center;
  display: flex;
  justify-content: center;
  text-align: center;
}

.pagination-previous,
.pagination-next,
.pagination-link,
.pagination-ellipsis {
  font-size: 1em;
  justify-content: center;
  margin: 0.25rem;
  padding-left: 0.5em;
  padding-right: 0.5em;
  text-align: center;
}

.pagination-previous,
.pagination-next,
.pagination-link {
  border-color: #c9d1d9;
  color: #2f3546;
  min-width: 2.5em;
}
.pagination-previous:hover,
.pagination-next:hover,
.pagination-link:hover {
  border-color: #a1b1bf;
  color: #4068bf;
}
.pagination-previous:focus,
.pagination-next:focus,
.pagination-link:focus {
  border-color: #4078f2;
}
.pagination-previous:active,
.pagination-next:active,
.pagination-link:active {
  box-shadow: inset 0 1px 2px rgba(13, 17, 23, 0.2);
}
.pagination-previous[disabled],
.pagination-next[disabled],
.pagination-link[disabled] {
  background-color: #c9d1d9;
  border-color: #c9d1d9;
  box-shadow: none;
  color: #6f727b;
  opacity: 0.5;
}

.pagination-previous,
.pagination-next {
  padding-left: 0.75em;
  padding-right: 0.75em;
  white-space: nowrap;
}

.pagination-link.is-current {
  background-color: #4078f2;
  border-color: #4078f2;
  color: #736a59;
}

.pagination-ellipsis {
  color: #a1b1bf;
  pointer-events: none;
}

.pagination-list {
  flex-wrap: wrap;
}
.pagination-list li {
  list-style: none;
}

@media screen and (max-width: 768px) {
  .pagination {
    flex-wrap: wrap;
  }

  .pagination-previous,
.pagination-next {
    flex-grow: 1;
    flex-shrink: 1;
  }

  .pagination-list li {
    flex-grow: 1;
    flex-shrink: 1;
  }
}
@media screen and (min-width: 769px), print {
  .pagination-list {
    flex-grow: 1;
    flex-shrink: 1;
    justify-content: flex-start;
    order: 1;
  }

  .pagination-previous,
.pagination-next,
.pagination-link,
.pagination-ellipsis {
    margin-bottom: 0;
    margin-top: 0;
  }

  .pagination-previous {
    order: 2;
  }

  .pagination-next {
    order: 3;
  }

  .pagination {
    justify-content: space-between;
    margin-bottom: 0;
    margin-top: 0;
  }
  .pagination.is-centered .pagination-previous {
    order: 1;
  }
  .pagination.is-centered .pagination-list {
    justify-content: center;
    order: 2;
  }
  .pagination.is-centered .pagination-next {
    order: 3;
  }
  .pagination.is-right .pagination-previous {
    order: 1;
  }
  .pagination.is-right .pagination-next {
    order: 2;
  }
  .pagination.is-right .pagination-list {
    justify-content: flex-end;
    order: 3;
  }
}
.panel {
  border-radius: 6px;
  box-shadow: 0 0.5em 1em -0.125em rgba(13, 17, 23, 0.1), 0 0px 0 1px rgba(13, 17, 23, 0.02);
  font-size: 1rem;
}
.panel:not(:last-child) {
  margin-bottom: 1.5rem;
}
.panel.is-white .panel-heading {
  background-color: #fafafa;
  color: #0d1117;
}
.panel.is-white .panel-tabs a.is-active {
  border-bottom-color: #fafafa;
}
.panel.is-white .panel-block.is-active .panel-icon {
  color: #fafafa;
}
.panel.is-black .panel-heading {
  background-color: #0d1117;
  color: #fafafa;
}
.panel.is-black .panel-tabs a.is-active {
  border-bottom-color: #0d1117;
}
.panel.is-black .panel-block.is-active .panel-icon {
  color: #0d1117;
}
.panel.is-light .panel-heading {
  background-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.panel.is-light .panel-tabs a.is-active {
  border-bottom-color: #faf0f0;
}
.panel.is-light .panel-block.is-active .panel-icon {
  color: #faf0f0;
}
.panel.is-dark .panel-heading {
  background-color: #2f3546;
  color: #fff;
}
.panel.is-dark .panel-tabs a.is-active {
  border-bottom-color: #2f3546;
}
.panel.is-dark .panel-block.is-active .panel-icon {
  color: #2f3546;
}
.panel.is-primary .panel-heading {
  background-color: #885bfb;
  color: white;
}
.panel.is-primary .panel-tabs a.is-active {
  border-bottom-color: #885bfb;
}
.panel.is-primary .panel-block.is-active .panel-icon {
  color: #885bfb;
}
.panel.is-link .panel-heading {
  background-color: #4078f2;
  color: #736a59;
}
.panel.is-link .panel-tabs a.is-active {
  border-bottom-color: #4078f2;
}
.panel.is-link .panel-block.is-active .panel-icon {
  color: #4078f2;
}
.panel.is-info .panel-heading {
  background-color: #449cc5;
  color: #fff;
}
.panel.is-info .panel-tabs a.is-active {
  border-bottom-color: #449cc5;
}
.panel.is-info .panel-block.is-active .panel-icon {
  color: #449cc5;
}
.panel.is-success .panel-heading {
  background-color: #00ad6b;
  color: #fff;
}
.panel.is-success .panel-tabs a.is-active {
  border-bottom-color: #00ad6b;
}
.panel.is-success .panel-block.is-active .panel-icon {
  color: #00ad6b;
}
.panel.is-warning .panel-heading {
  background-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.panel.is-warning .panel-tabs a.is-active {
  border-bottom-color: #ffc400;
}
.panel.is-warning .panel-block.is-active .panel-icon {
  color: #ffc400;
}
.panel.is-danger .panel-heading {
  background-color: #e45649;
  color: #fff;
}
.panel.is-danger .panel-tabs a.is-active {
  border-bottom-color: #e45649;
}
.panel.is-danger .panel-block.is-active .panel-icon {
  color: #e45649;
}
.panel.is-redish .panel-heading {
  background-color: #ca1243;
  color: #fff;
}
.panel.is-redish .panel-tabs a.is-active {
  border-bottom-color: #ca1243;
}
.panel.is-redish .panel-block.is-active .panel-icon {
  color: #ca1243;
}
.panel.is-blueish .panel-heading {
  background-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.panel.is-blueish .panel-tabs a.is-active {
  border-bottom-color: #a3c0ff;
}
.panel.is-blueish .panel-block.is-active .panel-icon {
  color: #a3c0ff;
}
.panel.is-pink .panel-heading {
  background-color: #f57fef;
  color: #fff;
}
.panel.is-pink .panel-tabs a.is-active {
  border-bottom-color: #f57fef;
}
.panel.is-pink .panel-block.is-active .panel-icon {
  color: #f57fef;
}
.panel.is-gold .panel-heading {
  background-color: #c18401;
  color: #fff;
}
.panel.is-gold .panel-tabs a.is-active {
  border-bottom-color: #c18401;
}
.panel.is-gold .panel-block.is-active .panel-icon {
  color: #c18401;
}
.panel.is-greenish .panel-heading {
  background-color: #5ea14f;
  color: #fff;
}
.panel.is-greenish .panel-tabs a.is-active {
  border-bottom-color: #5ea14f;
}
.panel.is-greenish .panel-block.is-active .panel-icon {
  color: #5ea14f;
}
.panel.is-blood .panel-heading {
  background-color: #39040c;
  color: #fff;
}
.panel.is-blood .panel-tabs a.is-active {
  border-bottom-color: #39040c;
}
.panel.is-blood .panel-block.is-active .panel-icon {
  color: #39040c;
}

.panel-tabs:not(:last-child),
.panel-block:not(:last-child) {
  border-bottom: 1px solid #e5dcdc;
}

.panel-heading {
  background-color: #e5dcdc;
  border-radius: 6px 6px 0 0;
  color: #2f3546;
  font-size: 1.25em;
  font-weight: 700;
  line-height: 1.25;
  padding: 0.75em 1em;
}

.panel-tabs {
  align-items: flex-end;
  display: flex;
  font-size: 0.875em;
  justify-content: center;
}
.panel-tabs a {
  border-bottom: 1px solid #c9d1d9;
  margin-bottom: -1px;
  padding: 0.5em;
}
.panel-tabs a.is-active {
  border-bottom-color: #3e4551;
  color: #4068bf;
}

.panel-list a {
  color: #3e4551;
}
.panel-list a:hover {
  color: #4078f2;
}

.panel-block {
  align-items: center;
  color: #2f3546;
  display: flex;
  justify-content: flex-start;
  padding: 0.5em 0.75em;
}
.panel-block input[type=checkbox] {
  margin-right: 0.75em;
}
.panel-block > .control {
  flex-grow: 1;
  flex-shrink: 1;
  width: 100%;
}
.panel-block.is-wrapped {
  flex-wrap: wrap;
}
.panel-block.is-active {
  border-left-color: #4078f2;
  color: #4068bf;
}
.panel-block.is-active .panel-icon {
  color: #4078f2;
}
.panel-block:last-child {
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
}

a.panel-block,
label.panel-block {
  cursor: pointer;
}
a.panel-block:hover,
label.panel-block:hover {
  background-color: #faf0f0;
}

.panel-icon {
  display: inline-block;
  font-size: 14px;
  height: 1em;
  line-height: 1em;
  text-align: center;
  vertical-align: top;
  width: 1em;
  color: #6f727b;
  margin-right: 0.75em;
}
.panel-icon .fa {
  font-size: inherit;
  line-height: inherit;
}

.tabs {
  -webkit-overflow-scrolling: touch;
  align-items: stretch;
  display: flex;
  font-size: 1rem;
  justify-content: space-between;
  overflow: hidden;
  overflow-x: auto;
  white-space: nowrap;
}
.tabs a {
  align-items: center;
  border-bottom-color: #c9d1d9;
  border-bottom-style: solid;
  border-bottom-width: 1px;
  color: #3e4551;
  display: flex;
  justify-content: center;
  margin-bottom: -1px;
  padding: 0.5em 1em;
  vertical-align: top;
}
.tabs a:hover {
  border-bottom-color: #2f3546;
  color: #2f3546;
}
.tabs li {
  display: block;
}
.tabs li.is-active a {
  border-bottom-color: #4078f2;
  color: #4078f2;
}
.tabs ul {
  align-items: center;
  border-bottom-color: #c9d1d9;
  border-bottom-style: solid;
  border-bottom-width: 1px;
  display: flex;
  flex-grow: 1;
  flex-shrink: 0;
  justify-content: flex-start;
}
.tabs ul.is-left {
  padding-right: 0.75em;
}
.tabs ul.is-center {
  flex: none;
  justify-content: center;
  padding-left: 0.75em;
  padding-right: 0.75em;
}
.tabs ul.is-right {
  justify-content: flex-end;
  padding-left: 0.75em;
}
.tabs .icon:first-child {
  margin-right: 0.5em;
}
.tabs .icon:last-child {
  margin-left: 0.5em;
}
.tabs.is-centered ul {
  justify-content: center;
}
.tabs.is-right ul {
  justify-content: flex-end;
}
.tabs.is-boxed a {
  border: 1px solid transparent;
  border-radius: 4px 4px 0 0;
}
.tabs.is-boxed a:hover {
  background-color: #faf0f0;
  border-bottom-color: #c9d1d9;
}
.tabs.is-boxed li.is-active a {
  background-color: #fafafa;
  border-color: #c9d1d9;
  border-bottom-color: transparent !important;
}
.tabs.is-fullwidth li {
  flex-grow: 1;
  flex-shrink: 0;
}
.tabs.is-toggle a {
  border-color: #c9d1d9;
  border-style: solid;
  border-width: 1px;
  margin-bottom: 0;
  position: relative;
}
.tabs.is-toggle a:hover {
  background-color: #faf0f0;
  border-color: #a1b1bf;
  z-index: 2;
}
.tabs.is-toggle li + li {
  margin-left: -1px;
}
.tabs.is-toggle li:first-child a {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
.tabs.is-toggle li:last-child a {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}
.tabs.is-toggle li.is-active a {
  background-color: #4078f2;
  border-color: #4078f2;
  color: #736a59;
  z-index: 1;
}
.tabs.is-toggle ul {
  border-bottom: none;
}
.tabs.is-toggle.is-toggle-rounded li:first-child a {
  border-bottom-left-radius: 9999px;
  border-top-left-radius: 9999px;
  padding-left: 1.25em;
}
.tabs.is-toggle.is-toggle-rounded li:last-child a {
  border-bottom-right-radius: 9999px;
  border-top-right-radius: 9999px;
  padding-right: 1.25em;
}
.tabs.is-small {
  font-size: 0.75rem;
}
.tabs.is-medium {
  font-size: 1.25rem;
}
.tabs.is-large {
  font-size: 1.5rem;
}

/* Bulma Grid */
.column {
  display: block;
  flex-basis: 0;
  flex-grow: 1;
  flex-shrink: 1;
  padding: 0.75rem;
}
.columns.is-mobile > .column.is-narrow {
  flex: none;
  width: unset;
}
.columns.is-mobile > .column.is-full {
  flex: none;
  width: 100%;
}
.columns.is-mobile > .column.is-three-quarters {
  flex: none;
  width: 75%;
}
.columns.is-mobile > .column.is-two-thirds {
  flex: none;
  width: 66.6666%;
}
.columns.is-mobile > .column.is-half {
  flex: none;
  width: 50%;
}
.columns.is-mobile > .column.is-one-third {
  flex: none;
  width: 33.3333%;
}
.columns.is-mobile > .column.is-one-quarter {
  flex: none;
  width: 25%;
}
.columns.is-mobile > .column.is-one-fifth {
  flex: none;
  width: 20%;
}
.columns.is-mobile > .column.is-two-fifths {
  flex: none;
  width: 40%;
}
.columns.is-mobile > .column.is-three-fifths {
  flex: none;
  width: 60%;
}
.columns.is-mobile > .column.is-four-fifths {
  flex: none;
  width: 80%;
}
.columns.is-mobile > .column.is-offset-three-quarters {
  margin-left: 75%;
}
.columns.is-mobile > .column.is-offset-two-thirds {
  margin-left: 66.6666%;
}
.columns.is-mobile > .column.is-offset-half {
  margin-left: 50%;
}
.columns.is-mobile > .column.is-offset-one-third {
  margin-left: 33.3333%;
}
.columns.is-mobile > .column.is-offset-one-quarter {
  margin-left: 25%;
}
.columns.is-mobile > .column.is-offset-one-fifth {
  margin-left: 20%;
}
.columns.is-mobile > .column.is-offset-two-fifths {
  margin-left: 40%;
}
.columns.is-mobile > .column.is-offset-three-fifths {
  margin-left: 60%;
}
.columns.is-mobile > .column.is-offset-four-fifths {
  margin-left: 80%;
}
.columns.is-mobile > .column.is-0 {
  flex: none;
  width: 0%;
}
.columns.is-mobile > .column.is-offset-0 {
  margin-left: 0%;
}
.columns.is-mobile > .column.is-1 {
  flex: none;
  width: 8.33333337%;
}
.columns.is-mobile > .column.is-offset-1 {
  margin-left: 8.33333337%;
}
.columns.is-mobile > .column.is-2 {
  flex: none;
  width: 16.66666674%;
}
.columns.is-mobile > .column.is-offset-2 {
  margin-left: 16.66666674%;
}
.columns.is-mobile > .column.is-3 {
  flex: none;
  width: 25%;
}
.columns.is-mobile > .column.is-offset-3 {
  margin-left: 25%;
}
.columns.is-mobile > .column.is-4 {
  flex: none;
  width: 33.33333337%;
}
.columns.is-mobile > .column.is-offset-4 {
  margin-left: 33.33333337%;
}
.columns.is-mobile > .column.is-5 {
  flex: none;
  width: 41.66666674%;
}
.columns.is-mobile > .column.is-offset-5 {
  margin-left: 41.66666674%;
}
.columns.is-mobile > .column.is-6 {
  flex: none;
  width: 50%;
}
.columns.is-mobile > .column.is-offset-6 {
  margin-left: 50%;
}
.columns.is-mobile > .column.is-7 {
  flex: none;
  width: 58.33333337%;
}
.columns.is-mobile > .column.is-offset-7 {
  margin-left: 58.33333337%;
}
.columns.is-mobile > .column.is-8 {
  flex: none;
  width: 66.66666674%;
}
.columns.is-mobile > .column.is-offset-8 {
  margin-left: 66.66666674%;
}
.columns.is-mobile > .column.is-9 {
  flex: none;
  width: 75%;
}
.columns.is-mobile > .column.is-offset-9 {
  margin-left: 75%;
}
.columns.is-mobile > .column.is-10 {
  flex: none;
  width: 83.33333337%;
}
.columns.is-mobile > .column.is-offset-10 {
  margin-left: 83.33333337%;
}
.columns.is-mobile > .column.is-11 {
  flex: none;
  width: 91.66666674%;
}
.columns.is-mobile > .column.is-offset-11 {
  margin-left: 91.66666674%;
}
.columns.is-mobile > .column.is-12 {
  flex: none;
  width: 100%;
}
.columns.is-mobile > .column.is-offset-12 {
  margin-left: 100%;
}
@media screen and (max-width: 768px) {
  .column.is-narrow-mobile {
    flex: none;
    width: unset;
  }
  .column.is-full-mobile {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-mobile {
    flex: none;
    width: 75%;
  }
  .column.is-two-thirds-mobile {
    flex: none;
    width: 66.6666%;
  }
  .column.is-half-mobile {
    flex: none;
    width: 50%;
  }
  .column.is-one-third-mobile {
    flex: none;
    width: 33.3333%;
  }
  .column.is-one-quarter-mobile {
    flex: none;
    width: 25%;
  }
  .column.is-one-fifth-mobile {
    flex: none;
    width: 20%;
  }
  .column.is-two-fifths-mobile {
    flex: none;
    width: 40%;
  }
  .column.is-three-fifths-mobile {
    flex: none;
    width: 60%;
  }
  .column.is-four-fifths-mobile {
    flex: none;
    width: 80%;
  }
  .column.is-offset-three-quarters-mobile {
    margin-left: 75%;
  }
  .column.is-offset-two-thirds-mobile {
    margin-left: 66.6666%;
  }
  .column.is-offset-half-mobile {
    margin-left: 50%;
  }
  .column.is-offset-one-third-mobile {
    margin-left: 33.3333%;
  }
  .column.is-offset-one-quarter-mobile {
    margin-left: 25%;
  }
  .column.is-offset-one-fifth-mobile {
    margin-left: 20%;
  }
  .column.is-offset-two-fifths-mobile {
    margin-left: 40%;
  }
  .column.is-offset-three-fifths-mobile {
    margin-left: 60%;
  }
  .column.is-offset-four-fifths-mobile {
    margin-left: 80%;
  }
  .column.is-0-mobile {
    flex: none;
    width: 0%;
  }
  .column.is-offset-0-mobile {
    margin-left: 0%;
  }
  .column.is-1-mobile {
    flex: none;
    width: 8.33333337%;
  }
  .column.is-offset-1-mobile {
    margin-left: 8.33333337%;
  }
  .column.is-2-mobile {
    flex: none;
    width: 16.66666674%;
  }
  .column.is-offset-2-mobile {
    margin-left: 16.66666674%;
  }
  .column.is-3-mobile {
    flex: none;
    width: 25%;
  }
  .column.is-offset-3-mobile {
    margin-left: 25%;
  }
  .column.is-4-mobile {
    flex: none;
    width: 33.33333337%;
  }
  .column.is-offset-4-mobile {
    margin-left: 33.33333337%;
  }
  .column.is-5-mobile {
    flex: none;
    width: 41.66666674%;
  }
  .column.is-offset-5-mobile {
    margin-left: 41.66666674%;
  }
  .column.is-6-mobile {
    flex: none;
    width: 50%;
  }
  .column.is-offset-6-mobile {
    margin-left: 50%;
  }
  .column.is-7-mobile {
    flex: none;
    width: 58.33333337%;
  }
  .column.is-offset-7-mobile {
    margin-left: 58.33333337%;
  }
  .column.is-8-mobile {
    flex: none;
    width: 66.66666674%;
  }
  .column.is-offset-8-mobile {
    margin-left: 66.66666674%;
  }
  .column.is-9-mobile {
    flex: none;
    width: 75%;
  }
  .column.is-offset-9-mobile {
    margin-left: 75%;
  }
  .column.is-10-mobile {
    flex: none;
    width: 83.33333337%;
  }
  .column.is-offset-10-mobile {
    margin-left: 83.33333337%;
  }
  .column.is-11-mobile {
    flex: none;
    width: 91.66666674%;
  }
  .column.is-offset-11-mobile {
    margin-left: 91.66666674%;
  }
  .column.is-12-mobile {
    flex: none;
    width: 100%;
  }
  .column.is-offset-12-mobile {
    margin-left: 100%;
  }
}
@media screen and (min-width: 769px), print {
  .column.is-narrow, .column.is-narrow-tablet {
    flex: none;
    width: unset;
  }
  .column.is-full, .column.is-full-tablet {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters, .column.is-three-quarters-tablet {
    flex: none;
    width: 75%;
  }
  .column.is-two-thirds, .column.is-two-thirds-tablet {
    flex: none;
    width: 66.6666%;
  }
  .column.is-half, .column.is-half-tablet {
    flex: none;
    width: 50%;
  }
  .column.is-one-third, .column.is-one-third-tablet {
    flex: none;
    width: 33.3333%;
  }
  .column.is-one-quarter, .column.is-one-quarter-tablet {
    flex: none;
    width: 25%;
  }
  .column.is-one-fifth, .column.is-one-fifth-tablet {
    flex: none;
    width: 20%;
  }
  .column.is-two-fifths, .column.is-two-fifths-tablet {
    flex: none;
    width: 40%;
  }
  .column.is-three-fifths, .column.is-three-fifths-tablet {
    flex: none;
    width: 60%;
  }
  .column.is-four-fifths, .column.is-four-fifths-tablet {
    flex: none;
    width: 80%;
  }
  .column.is-offset-three-quarters, .column.is-offset-three-quarters-tablet {
    margin-left: 75%;
  }
  .column.is-offset-two-thirds, .column.is-offset-two-thirds-tablet {
    margin-left: 66.6666%;
  }
  .column.is-offset-half, .column.is-offset-half-tablet {
    margin-left: 50%;
  }
  .column.is-offset-one-third, .column.is-offset-one-third-tablet {
    margin-left: 33.3333%;
  }
  .column.is-offset-one-quarter, .column.is-offset-one-quarter-tablet {
    margin-left: 25%;
  }
  .column.is-offset-one-fifth, .column.is-offset-one-fifth-tablet {
    margin-left: 20%;
  }
  .column.is-offset-two-fifths, .column.is-offset-two-fifths-tablet {
    margin-left: 40%;
  }
  .column.is-offset-three-fifths, .column.is-offset-three-fifths-tablet {
    margin-left: 60%;
  }
  .column.is-offset-four-fifths, .column.is-offset-four-fifths-tablet {
    margin-left: 80%;
  }
  .column.is-0, .column.is-0-tablet {
    flex: none;
    width: 0%;
  }
  .column.is-offset-0, .column.is-offset-0-tablet {
    margin-left: 0%;
  }
  .column.is-1, .column.is-1-tablet {
    flex: none;
    width: 8.33333337%;
  }
  .column.is-offset-1, .column.is-offset-1-tablet {
    margin-left: 8.33333337%;
  }
  .column.is-2, .column.is-2-tablet {
    flex: none;
    width: 16.66666674%;
  }
  .column.is-offset-2, .column.is-offset-2-tablet {
    margin-left: 16.66666674%;
  }
  .column.is-3, .column.is-3-tablet {
    flex: none;
    width: 25%;
  }
  .column.is-offset-3, .column.is-offset-3-tablet {
    margin-left: 25%;
  }
  .column.is-4, .column.is-4-tablet {
    flex: none;
    width: 33.33333337%;
  }
  .column.is-offset-4, .column.is-offset-4-tablet {
    margin-left: 33.33333337%;
  }
  .column.is-5, .column.is-5-tablet {
    flex: none;
    width: 41.66666674%;
  }
  .column.is-offset-5, .column.is-offset-5-tablet {
    margin-left: 41.66666674%;
  }
  .column.is-6, .column.is-6-tablet {
    flex: none;
    width: 50%;
  }
  .column.is-offset-6, .column.is-offset-6-tablet {
    margin-left: 50%;
  }
  .column.is-7, .column.is-7-tablet {
    flex: none;
    width: 58.33333337%;
  }
  .column.is-offset-7, .column.is-offset-7-tablet {
    margin-left: 58.33333337%;
  }
  .column.is-8, .column.is-8-tablet {
    flex: none;
    width: 66.66666674%;
  }
  .column.is-offset-8, .column.is-offset-8-tablet {
    margin-left: 66.66666674%;
  }
  .column.is-9, .column.is-9-tablet {
    flex: none;
    width: 75%;
  }
  .column.is-offset-9, .column.is-offset-9-tablet {
    margin-left: 75%;
  }
  .column.is-10, .column.is-10-tablet {
    flex: none;
    width: 83.33333337%;
  }
  .column.is-offset-10, .column.is-offset-10-tablet {
    margin-left: 83.33333337%;
  }
  .column.is-11, .column.is-11-tablet {
    flex: none;
    width: 91.66666674%;
  }
  .column.is-offset-11, .column.is-offset-11-tablet {
    margin-left: 91.66666674%;
  }
  .column.is-12, .column.is-12-tablet {
    flex: none;
    width: 100%;
  }
  .column.is-offset-12, .column.is-offset-12-tablet {
    margin-left: 100%;
  }
}
@media screen and (max-width: 1023px) {
  .column.is-narrow-touch {
    flex: none;
    width: unset;
  }
  .column.is-full-touch {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-touch {
    flex: none;
    width: 75%;
  }
  .column.is-two-thirds-touch {
    flex: none;
    width: 66.6666%;
  }
  .column.is-half-touch {
    flex: none;
    width: 50%;
  }
  .column.is-one-third-touch {
    flex: none;
    width: 33.3333%;
  }
  .column.is-one-quarter-touch {
    flex: none;
    width: 25%;
  }
  .column.is-one-fifth-touch {
    flex: none;
    width: 20%;
  }
  .column.is-two-fifths-touch {
    flex: none;
    width: 40%;
  }
  .column.is-three-fifths-touch {
    flex: none;
    width: 60%;
  }
  .column.is-four-fifths-touch {
    flex: none;
    width: 80%;
  }
  .column.is-offset-three-quarters-touch {
    margin-left: 75%;
  }
  .column.is-offset-two-thirds-touch {
    margin-left: 66.6666%;
  }
  .column.is-offset-half-touch {
    margin-left: 50%;
  }
  .column.is-offset-one-third-touch {
    margin-left: 33.3333%;
  }
  .column.is-offset-one-quarter-touch {
    margin-left: 25%;
  }
  .column.is-offset-one-fifth-touch {
    margin-left: 20%;
  }
  .column.is-offset-two-fifths-touch {
    margin-left: 40%;
  }
  .column.is-offset-three-fifths-touch {
    margin-left: 60%;
  }
  .column.is-offset-four-fifths-touch {
    margin-left: 80%;
  }
  .column.is-0-touch {
    flex: none;
    width: 0%;
  }
  .column.is-offset-0-touch {
    margin-left: 0%;
  }
  .column.is-1-touch {
    flex: none;
    width: 8.33333337%;
  }
  .column.is-offset-1-touch {
    margin-left: 8.33333337%;
  }
  .column.is-2-touch {
    flex: none;
    width: 16.66666674%;
  }
  .column.is-offset-2-touch {
    margin-left: 16.66666674%;
  }
  .column.is-3-touch {
    flex: none;
    width: 25%;
  }
  .column.is-offset-3-touch {
    margin-left: 25%;
  }
  .column.is-4-touch {
    flex: none;
    width: 33.33333337%;
  }
  .column.is-offset-4-touch {
    margin-left: 33.33333337%;
  }
  .column.is-5-touch {
    flex: none;
    width: 41.66666674%;
  }
  .column.is-offset-5-touch {
    margin-left: 41.66666674%;
  }
  .column.is-6-touch {
    flex: none;
    width: 50%;
  }
  .column.is-offset-6-touch {
    margin-left: 50%;
  }
  .column.is-7-touch {
    flex: none;
    width: 58.33333337%;
  }
  .column.is-offset-7-touch {
    margin-left: 58.33333337%;
  }
  .column.is-8-touch {
    flex: none;
    width: 66.66666674%;
  }
  .column.is-offset-8-touch {
    margin-left: 66.66666674%;
  }
  .column.is-9-touch {
    flex: none;
    width: 75%;
  }
  .column.is-offset-9-touch {
    margin-left: 75%;
  }
  .column.is-10-touch {
    flex: none;
    width: 83.33333337%;
  }
  .column.is-offset-10-touch {
    margin-left: 83.33333337%;
  }
  .column.is-11-touch {
    flex: none;
    width: 91.66666674%;
  }
  .column.is-offset-11-touch {
    margin-left: 91.66666674%;
  }
  .column.is-12-touch {
    flex: none;
    width: 100%;
  }
  .column.is-offset-12-touch {
    margin-left: 100%;
  }
}
@media screen and (min-width: 1024px) {
  .column.is-narrow-desktop {
    flex: none;
    width: unset;
  }
  .column.is-full-desktop {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-desktop {
    flex: none;
    width: 75%;
  }
  .column.is-two-thirds-desktop {
    flex: none;
    width: 66.6666%;
  }
  .column.is-half-desktop {
    flex: none;
    width: 50%;
  }
  .column.is-one-third-desktop {
    flex: none;
    width: 33.3333%;
  }
  .column.is-one-quarter-desktop {
    flex: none;
    width: 25%;
  }
  .column.is-one-fifth-desktop {
    flex: none;
    width: 20%;
  }
  .column.is-two-fifths-desktop {
    flex: none;
    width: 40%;
  }
  .column.is-three-fifths-desktop {
    flex: none;
    width: 60%;
  }
  .column.is-four-fifths-desktop {
    flex: none;
    width: 80%;
  }
  .column.is-offset-three-quarters-desktop {
    margin-left: 75%;
  }
  .column.is-offset-two-thirds-desktop {
    margin-left: 66.6666%;
  }
  .column.is-offset-half-desktop {
    margin-left: 50%;
  }
  .column.is-offset-one-third-desktop {
    margin-left: 33.3333%;
  }
  .column.is-offset-one-quarter-desktop {
    margin-left: 25%;
  }
  .column.is-offset-one-fifth-desktop {
    margin-left: 20%;
  }
  .column.is-offset-two-fifths-desktop {
    margin-left: 40%;
  }
  .column.is-offset-three-fifths-desktop {
    margin-left: 60%;
  }
  .column.is-offset-four-fifths-desktop {
    margin-left: 80%;
  }
  .column.is-0-desktop {
    flex: none;
    width: 0%;
  }
  .column.is-offset-0-desktop {
    margin-left: 0%;
  }
  .column.is-1-desktop {
    flex: none;
    width: 8.33333337%;
  }
  .column.is-offset-1-desktop {
    margin-left: 8.33333337%;
  }
  .column.is-2-desktop {
    flex: none;
    width: 16.66666674%;
  }
  .column.is-offset-2-desktop {
    margin-left: 16.66666674%;
  }
  .column.is-3-desktop {
    flex: none;
    width: 25%;
  }
  .column.is-offset-3-desktop {
    margin-left: 25%;
  }
  .column.is-4-desktop {
    flex: none;
    width: 33.33333337%;
  }
  .column.is-offset-4-desktop {
    margin-left: 33.33333337%;
  }
  .column.is-5-desktop {
    flex: none;
    width: 41.66666674%;
  }
  .column.is-offset-5-desktop {
    margin-left: 41.66666674%;
  }
  .column.is-6-desktop {
    flex: none;
    width: 50%;
  }
  .column.is-offset-6-desktop {
    margin-left: 50%;
  }
  .column.is-7-desktop {
    flex: none;
    width: 58.33333337%;
  }
  .column.is-offset-7-desktop {
    margin-left: 58.33333337%;
  }
  .column.is-8-desktop {
    flex: none;
    width: 66.66666674%;
  }
  .column.is-offset-8-desktop {
    margin-left: 66.66666674%;
  }
  .column.is-9-desktop {
    flex: none;
    width: 75%;
  }
  .column.is-offset-9-desktop {
    margin-left: 75%;
  }
  .column.is-10-desktop {
    flex: none;
    width: 83.33333337%;
  }
  .column.is-offset-10-desktop {
    margin-left: 83.33333337%;
  }
  .column.is-11-desktop {
    flex: none;
    width: 91.66666674%;
  }
  .column.is-offset-11-desktop {
    margin-left: 91.66666674%;
  }
  .column.is-12-desktop {
    flex: none;
    width: 100%;
  }
  .column.is-offset-12-desktop {
    margin-left: 100%;
  }
}
@media screen and (min-width: 1216px) {
  .column.is-narrow-widescreen {
    flex: none;
    width: unset;
  }
  .column.is-full-widescreen {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-widescreen {
    flex: none;
    width: 75%;
  }
  .column.is-two-thirds-widescreen {
    flex: none;
    width: 66.6666%;
  }
  .column.is-half-widescreen {
    flex: none;
    width: 50%;
  }
  .column.is-one-third-widescreen {
    flex: none;
    width: 33.3333%;
  }
  .column.is-one-quarter-widescreen {
    flex: none;
    width: 25%;
  }
  .column.is-one-fifth-widescreen {
    flex: none;
    width: 20%;
  }
  .column.is-two-fifths-widescreen {
    flex: none;
    width: 40%;
  }
  .column.is-three-fifths-widescreen {
    flex: none;
    width: 60%;
  }
  .column.is-four-fifths-widescreen {
    flex: none;
    width: 80%;
  }
  .column.is-offset-three-quarters-widescreen {
    margin-left: 75%;
  }
  .column.is-offset-two-thirds-widescreen {
    margin-left: 66.6666%;
  }
  .column.is-offset-half-widescreen {
    margin-left: 50%;
  }
  .column.is-offset-one-third-widescreen {
    margin-left: 33.3333%;
  }
  .column.is-offset-one-quarter-widescreen {
    margin-left: 25%;
  }
  .column.is-offset-one-fifth-widescreen {
    margin-left: 20%;
  }
  .column.is-offset-two-fifths-widescreen {
    margin-left: 40%;
  }
  .column.is-offset-three-fifths-widescreen {
    margin-left: 60%;
  }
  .column.is-offset-four-fifths-widescreen {
    margin-left: 80%;
  }
  .column.is-0-widescreen {
    flex: none;
    width: 0%;
  }
  .column.is-offset-0-widescreen {
    margin-left: 0%;
  }
  .column.is-1-widescreen {
    flex: none;
    width: 8.33333337%;
  }
  .column.is-offset-1-widescreen {
    margin-left: 8.33333337%;
  }
  .column.is-2-widescreen {
    flex: none;
    width: 16.66666674%;
  }
  .column.is-offset-2-widescreen {
    margin-left: 16.66666674%;
  }
  .column.is-3-widescreen {
    flex: none;
    width: 25%;
  }
  .column.is-offset-3-widescreen {
    margin-left: 25%;
  }
  .column.is-4-widescreen {
    flex: none;
    width: 33.33333337%;
  }
  .column.is-offset-4-widescreen {
    margin-left: 33.33333337%;
  }
  .column.is-5-widescreen {
    flex: none;
    width: 41.66666674%;
  }
  .column.is-offset-5-widescreen {
    margin-left: 41.66666674%;
  }
  .column.is-6-widescreen {
    flex: none;
    width: 50%;
  }
  .column.is-offset-6-widescreen {
    margin-left: 50%;
  }
  .column.is-7-widescreen {
    flex: none;
    width: 58.33333337%;
  }
  .column.is-offset-7-widescreen {
    margin-left: 58.33333337%;
  }
  .column.is-8-widescreen {
    flex: none;
    width: 66.66666674%;
  }
  .column.is-offset-8-widescreen {
    margin-left: 66.66666674%;
  }
  .column.is-9-widescreen {
    flex: none;
    width: 75%;
  }
  .column.is-offset-9-widescreen {
    margin-left: 75%;
  }
  .column.is-10-widescreen {
    flex: none;
    width: 83.33333337%;
  }
  .column.is-offset-10-widescreen {
    margin-left: 83.33333337%;
  }
  .column.is-11-widescreen {
    flex: none;
    width: 91.66666674%;
  }
  .column.is-offset-11-widescreen {
    margin-left: 91.66666674%;
  }
  .column.is-12-widescreen {
    flex: none;
    width: 100%;
  }
  .column.is-offset-12-widescreen {
    margin-left: 100%;
  }
}
@media screen and (min-width: 1408px) {
  .column.is-narrow-fullhd {
    flex: none;
    width: unset;
  }
  .column.is-full-fullhd {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-fullhd {
    flex: none;
    width: 75%;
  }
  .column.is-two-thirds-fullhd {
    flex: none;
    width: 66.6666%;
  }
  .column.is-half-fullhd {
    flex: none;
    width: 50%;
  }
  .column.is-one-third-fullhd {
    flex: none;
    width: 33.3333%;
  }
  .column.is-one-quarter-fullhd {
    flex: none;
    width: 25%;
  }
  .column.is-one-fifth-fullhd {
    flex: none;
    width: 20%;
  }
  .column.is-two-fifths-fullhd {
    flex: none;
    width: 40%;
  }
  .column.is-three-fifths-fullhd {
    flex: none;
    width: 60%;
  }
  .column.is-four-fifths-fullhd {
    flex: none;
    width: 80%;
  }
  .column.is-offset-three-quarters-fullhd {
    margin-left: 75%;
  }
  .column.is-offset-two-thirds-fullhd {
    margin-left: 66.6666%;
  }
  .column.is-offset-half-fullhd {
    margin-left: 50%;
  }
  .column.is-offset-one-third-fullhd {
    margin-left: 33.3333%;
  }
  .column.is-offset-one-quarter-fullhd {
    margin-left: 25%;
  }
  .column.is-offset-one-fifth-fullhd {
    margin-left: 20%;
  }
  .column.is-offset-two-fifths-fullhd {
    margin-left: 40%;
  }
  .column.is-offset-three-fifths-fullhd {
    margin-left: 60%;
  }
  .column.is-offset-four-fifths-fullhd {
    margin-left: 80%;
  }
  .column.is-0-fullhd {
    flex: none;
    width: 0%;
  }
  .column.is-offset-0-fullhd {
    margin-left: 0%;
  }
  .column.is-1-fullhd {
    flex: none;
    width: 8.33333337%;
  }
  .column.is-offset-1-fullhd {
    margin-left: 8.33333337%;
  }
  .column.is-2-fullhd {
    flex: none;
    width: 16.66666674%;
  }
  .column.is-offset-2-fullhd {
    margin-left: 16.66666674%;
  }
  .column.is-3-fullhd {
    flex: none;
    width: 25%;
  }
  .column.is-offset-3-fullhd {
    margin-left: 25%;
  }
  .column.is-4-fullhd {
    flex: none;
    width: 33.33333337%;
  }
  .column.is-offset-4-fullhd {
    margin-left: 33.33333337%;
  }
  .column.is-5-fullhd {
    flex: none;
    width: 41.66666674%;
  }
  .column.is-offset-5-fullhd {
    margin-left: 41.66666674%;
  }
  .column.is-6-fullhd {
    flex: none;
    width: 50%;
  }
  .column.is-offset-6-fullhd {
    margin-left: 50%;
  }
  .column.is-7-fullhd {
    flex: none;
    width: 58.33333337%;
  }
  .column.is-offset-7-fullhd {
    margin-left: 58.33333337%;
  }
  .column.is-8-fullhd {
    flex: none;
    width: 66.66666674%;
  }
  .column.is-offset-8-fullhd {
    margin-left: 66.66666674%;
  }
  .column.is-9-fullhd {
    flex: none;
    width: 75%;
  }
  .column.is-offset-9-fullhd {
    margin-left: 75%;
  }
  .column.is-10-fullhd {
    flex: none;
    width: 83.33333337%;
  }
  .column.is-offset-10-fullhd {
    margin-left: 83.33333337%;
  }
  .column.is-11-fullhd {
    flex: none;
    width: 91.66666674%;
  }
  .column.is-offset-11-fullhd {
    margin-left: 91.66666674%;
  }
  .column.is-12-fullhd {
    flex: none;
    width: 100%;
  }
  .column.is-offset-12-fullhd {
    margin-left: 100%;
  }
}

.columns {
  margin-left: -0.75rem;
  margin-right: -0.75rem;
  margin-top: -0.75rem;
}
.columns:last-child {
  margin-bottom: -0.75rem;
}
.columns:not(:last-child) {
  margin-bottom: calc(1.5rem - 0.75rem);
}
.columns.is-centered {
  justify-content: center;
}
.columns.is-gapless {
  margin-left: 0;
  margin-right: 0;
  margin-top: 0;
}
.columns.is-gapless > .column {
  margin: 0;
  padding: 0 !important;
}
.columns.is-gapless:not(:last-child) {
  margin-bottom: 1.5rem;
}
.columns.is-gapless:last-child {
  margin-bottom: 0;
}
.columns.is-mobile {
  display: flex;
}
.columns.is-multiline {
  flex-wrap: wrap;
}
.columns.is-vcentered {
  align-items: center;
}
@media screen and (min-width: 769px), print {
  .columns:not(.is-desktop) {
    display: flex;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-desktop {
    display: flex;
  }
}

.columns.is-variable {
  --columnGap: 0.75rem;
  margin-left: calc(-1 * var(--columnGap));
  margin-right: calc(-1 * var(--columnGap));
}
.columns.is-variable > .column {
  padding-left: var(--columnGap);
  padding-right: var(--columnGap);
}
.columns.is-variable.is-0 {
  --columnGap: 0rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-0-mobile {
    --columnGap: 0rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-0-tablet {
    --columnGap: 0rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-0-tablet-only {
    --columnGap: 0rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-0-touch {
    --columnGap: 0rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-0-desktop {
    --columnGap: 0rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-0-desktop-only {
    --columnGap: 0rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-0-widescreen {
    --columnGap: 0rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-0-widescreen-only {
    --columnGap: 0rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-0-fullhd {
    --columnGap: 0rem;
  }
}
.columns.is-variable.is-1 {
  --columnGap: 0.25rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-1-mobile {
    --columnGap: 0.25rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-1-tablet {
    --columnGap: 0.25rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-1-tablet-only {
    --columnGap: 0.25rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-1-touch {
    --columnGap: 0.25rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-1-desktop {
    --columnGap: 0.25rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-1-desktop-only {
    --columnGap: 0.25rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-1-widescreen {
    --columnGap: 0.25rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-1-widescreen-only {
    --columnGap: 0.25rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-1-fullhd {
    --columnGap: 0.25rem;
  }
}
.columns.is-variable.is-2 {
  --columnGap: 0.5rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-2-mobile {
    --columnGap: 0.5rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-2-tablet {
    --columnGap: 0.5rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-2-tablet-only {
    --columnGap: 0.5rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-2-touch {
    --columnGap: 0.5rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-2-desktop {
    --columnGap: 0.5rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-2-desktop-only {
    --columnGap: 0.5rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-2-widescreen {
    --columnGap: 0.5rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-2-widescreen-only {
    --columnGap: 0.5rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-2-fullhd {
    --columnGap: 0.5rem;
  }
}
.columns.is-variable.is-3 {
  --columnGap: 0.75rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-3-mobile {
    --columnGap: 0.75rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-3-tablet {
    --columnGap: 0.75rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-3-tablet-only {
    --columnGap: 0.75rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-3-touch {
    --columnGap: 0.75rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-3-desktop {
    --columnGap: 0.75rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-3-desktop-only {
    --columnGap: 0.75rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-3-widescreen {
    --columnGap: 0.75rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-3-widescreen-only {
    --columnGap: 0.75rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-3-fullhd {
    --columnGap: 0.75rem;
  }
}
.columns.is-variable.is-4 {
  --columnGap: 1rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-4-mobile {
    --columnGap: 1rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-4-tablet {
    --columnGap: 1rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-4-tablet-only {
    --columnGap: 1rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-4-touch {
    --columnGap: 1rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-4-desktop {
    --columnGap: 1rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-4-desktop-only {
    --columnGap: 1rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-4-widescreen {
    --columnGap: 1rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-4-widescreen-only {
    --columnGap: 1rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-4-fullhd {
    --columnGap: 1rem;
  }
}
.columns.is-variable.is-5 {
  --columnGap: 1.25rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-5-mobile {
    --columnGap: 1.25rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-5-tablet {
    --columnGap: 1.25rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-5-tablet-only {
    --columnGap: 1.25rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-5-touch {
    --columnGap: 1.25rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-5-desktop {
    --columnGap: 1.25rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-5-desktop-only {
    --columnGap: 1.25rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-5-widescreen {
    --columnGap: 1.25rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-5-widescreen-only {
    --columnGap: 1.25rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-5-fullhd {
    --columnGap: 1.25rem;
  }
}
.columns.is-variable.is-6 {
  --columnGap: 1.5rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-6-mobile {
    --columnGap: 1.5rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-6-tablet {
    --columnGap: 1.5rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-6-tablet-only {
    --columnGap: 1.5rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-6-touch {
    --columnGap: 1.5rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-6-desktop {
    --columnGap: 1.5rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-6-desktop-only {
    --columnGap: 1.5rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-6-widescreen {
    --columnGap: 1.5rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-6-widescreen-only {
    --columnGap: 1.5rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-6-fullhd {
    --columnGap: 1.5rem;
  }
}
.columns.is-variable.is-7 {
  --columnGap: 1.75rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-7-mobile {
    --columnGap: 1.75rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-7-tablet {
    --columnGap: 1.75rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-7-tablet-only {
    --columnGap: 1.75rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-7-touch {
    --columnGap: 1.75rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-7-desktop {
    --columnGap: 1.75rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-7-desktop-only {
    --columnGap: 1.75rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-7-widescreen {
    --columnGap: 1.75rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-7-widescreen-only {
    --columnGap: 1.75rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-7-fullhd {
    --columnGap: 1.75rem;
  }
}
.columns.is-variable.is-8 {
  --columnGap: 2rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-8-mobile {
    --columnGap: 2rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-8-tablet {
    --columnGap: 2rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-8-tablet-only {
    --columnGap: 2rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-8-touch {
    --columnGap: 2rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-8-desktop {
    --columnGap: 2rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-8-desktop-only {
    --columnGap: 2rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-8-widescreen {
    --columnGap: 2rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-8-widescreen-only {
    --columnGap: 2rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-8-fullhd {
    --columnGap: 2rem;
  }
}

.tile {
  align-items: stretch;
  display: block;
  flex-basis: 0;
  flex-grow: 1;
  flex-shrink: 1;
  min-height: min-content;
}
.tile.is-ancestor {
  margin-left: -0.75rem;
  margin-right: -0.75rem;
  margin-top: -0.75rem;
}
.tile.is-ancestor:last-child {
  margin-bottom: -0.75rem;
}
.tile.is-ancestor:not(:last-child) {
  margin-bottom: 0.75rem;
}
.tile.is-child {
  margin: 0 !important;
}
.tile.is-parent {
  padding: 0.75rem;
}
.tile.is-vertical {
  flex-direction: column;
}
.tile.is-vertical > .tile.is-child:not(:last-child) {
  margin-bottom: 1.5rem !important;
}
@media screen and (min-width: 769px), print {
  .tile:not(.is-child) {
    display: flex;
  }
  .tile.is-1 {
    flex: none;
    width: 8.33333337%;
  }
  .tile.is-2 {
    flex: none;
    width: 16.66666674%;
  }
  .tile.is-3 {
    flex: none;
    width: 25%;
  }
  .tile.is-4 {
    flex: none;
    width: 33.33333337%;
  }
  .tile.is-5 {
    flex: none;
    width: 41.66666674%;
  }
  .tile.is-6 {
    flex: none;
    width: 50%;
  }
  .tile.is-7 {
    flex: none;
    width: 58.33333337%;
  }
  .tile.is-8 {
    flex: none;
    width: 66.66666674%;
  }
  .tile.is-9 {
    flex: none;
    width: 75%;
  }
  .tile.is-10 {
    flex: none;
    width: 83.33333337%;
  }
  .tile.is-11 {
    flex: none;
    width: 91.66666674%;
  }
  .tile.is-12 {
    flex: none;
    width: 100%;
  }
}

/* Bulma Helpers */
.has-text-white {
  color: #fafafa !important;
}

a.has-text-white:hover, a.has-text-white:focus {
  color: #e0e0e0 !important;
}

.has-background-white {
  background-color: #fafafa !important;
}

.has-text-black {
  color: #0d1117 !important;
}

a.has-text-black:hover, a.has-text-black:focus {
  color: black !important;
}

.has-background-black {
  background-color: #0d1117 !important;
}

.has-text-light {
  color: #faf0f0 !important;
}

a.has-text-light:hover, a.has-text-light:focus {
  color: #edc9c9 !important;
}

.has-background-light {
  background-color: #faf0f0 !important;
}

.has-text-dark {
  color: #2f3546 !important;
}

a.has-text-dark:hover, a.has-text-dark:focus {
  color: #1b1e28 !important;
}

.has-background-dark {
  background-color: #2f3546 !important;
}

.has-text-primary {
  color: #885bfb !important;
}

a.has-text-primary:hover, a.has-text-primary:focus {
  color: #6429fa !important;
}

.has-background-primary {
  background-color: #885bfb !important;
}

.has-text-primary-light {
  color: #f1ebfe !important;
}

a.has-text-primary-light:hover, a.has-text-primary-light:focus {
  color: #cdb9fd !important;
}

.has-background-primary-light {
  background-color: #f1ebfe !important;
}

.has-text-primary-dark {
  color: #4206db !important;
}

a.has-text-primary-dark:hover, a.has-text-primary-dark:focus {
  color: #591af9 !important;
}

.has-background-primary-dark {
  background-color: #4206db !important;
}

.has-text-link {
  color: #4078f2 !important;
}

a.has-text-link:hover, a.has-text-link:focus {
  color: #1157ee !important;
}

.has-background-link {
  background-color: #4078f2 !important;
}

.has-text-link-light {
  color: #88abf7 !important;
}

a.has-text-link-light:hover, a.has-text-link-light:focus {
  color: #5889f3 !important;
}

.has-background-link-light {
  background-color: #88abf7 !important;
}

.has-text-link-dark {
  color: #30529c !important;
}

a.has-text-link-dark:hover, a.has-text-link-dark:focus {
  color: #3c67c3 !important;
}

.has-background-link-dark {
  background-color: #30529c !important;
}

.has-text-info {
  color: #449cc5 !important;
}

a.has-text-info:hover, a.has-text-info:focus {
  color: #3280a4 !important;
}

.has-background-info {
  background-color: #449cc5 !important;
}

.has-text-info-light {
  color: #eff7fa !important;
}

a.has-text-info-light:hover, a.has-text-info-light:focus {
  color: #c8e2ee !important;
}

.has-background-info-light {
  background-color: #eff7fa !important;
}

.has-text-info-dark {
  color: #2f7798 !important;
}

a.has-text-info-dark:hover, a.has-text-info-dark:focus {
  color: #3b95bf !important;
}

.has-background-info-dark {
  background-color: #2f7798 !important;
}

.has-text-success {
  color: #00ad6b !important;
}

a.has-text-success:hover, a.has-text-success:focus {
  color: #007a4b !important;
}

.has-background-success {
  background-color: #00ad6b !important;
}

.has-text-success-light {
  color: #ebfff7 !important;
}

a.has-text-success-light:hover, a.has-text-success-light:focus {
  color: #b8ffe4 !important;
}

.has-background-success-light {
  background-color: #ebfff7 !important;
}

.has-text-success-dark {
  color: #00c278 !important;
}

a.has-text-success-dark:hover, a.has-text-success-dark:focus {
  color: #00f597 !important;
}

.has-background-success-dark {
  background-color: #00c278 !important;
}

.has-text-warning {
  color: #ffc400 !important;
}

a.has-text-warning:hover, a.has-text-warning:focus {
  color: #cc9c00 !important;
}

.has-background-warning {
  background-color: #ffc400 !important;
}

.has-text-warning-light {
  color: #fffaeb !important;
}

a.has-text-warning-light:hover, a.has-text-warning-light:focus {
  color: #ffeeb8 !important;
}

.has-background-warning-light {
  background-color: #fffaeb !important;
}

.has-text-warning-dark {
  color: #947100 !important;
}

a.has-text-warning-dark:hover, a.has-text-warning-dark:focus {
  color: #c79800 !important;
}

.has-background-warning-dark {
  background-color: #947100 !important;
}

.has-text-danger {
  color: #e45649 !important;
}

a.has-text-danger:hover, a.has-text-danger:focus {
  color: #d93020 !important;
}

.has-background-danger {
  background-color: #e45649 !important;
}

.has-text-danger-light {
  color: #fcefed !important;
}

a.has-text-danger-light:hover, a.has-text-danger-light:focus {
  color: #f6c5c1 !important;
}

.has-background-danger-light {
  background-color: #fcefed !important;
}

.has-text-danger-dark {
  color: #ba291c !important;
}

a.has-text-danger-dark:hover, a.has-text-danger-dark:focus {
  color: #df392a !important;
}

.has-background-danger-dark {
  background-color: #ba291c !important;
}

.has-text-redish {
  color: #ca1243 !important;
}

a.has-text-redish:hover, a.has-text-redish:focus {
  color: #9b0d33 !important;
}

.has-background-redish {
  background-color: #ca1243 !important;
}

.has-text-redish-light {
  color: #fdecf1 !important;
}

a.has-text-redish-light:hover, a.has-text-redish-light:focus {
  color: #f9bdcd !important;
}

.has-background-redish-light {
  background-color: #fdecf1 !important;
}

.has-text-redish-dark {
  color: #e6144c !important;
}

a.has-text-redish-dark:hover, a.has-text-redish-dark:focus {
  color: #ee3f6d !important;
}

.has-background-redish-dark {
  background-color: #e6144c !important;
}

.has-text-blueish {
  color: #a3c0ff !important;
}

a.has-text-blueish:hover, a.has-text-blueish:focus {
  color: #709dff !important;
}

.has-background-blueish {
  background-color: #a3c0ff !important;
}

.has-text-blueish-light {
  color: #ebf1ff !important;
}

a.has-text-blueish-light:hover, a.has-text-blueish-light:focus {
  color: #b8ceff !important;
}

.has-background-blueish-light {
  background-color: #ebf1ff !important;
}

.has-text-blueish-dark {
  color: #002f94 !important;
}

a.has-text-blueish-dark:hover, a.has-text-blueish-dark:focus {
  color: #003fc7 !important;
}

.has-background-blueish-dark {
  background-color: #002f94 !important;
}

.has-text-pink {
  color: #f57fef !important;
}

a.has-text-pink:hover, a.has-text-pink:focus {
  color: #f250ea !important;
}

.has-background-pink {
  background-color: #f57fef !important;
}

.has-text-pink-light {
  color: #feecfd !important;
}

a.has-text-pink-light:hover, a.has-text-pink-light:focus {
  color: #fabdf7 !important;
}

.has-background-pink-light {
  background-color: #feecfd !important;
}

.has-text-pink-dark {
  color: #9d0c95 !important;
}

a.has-text-pink-dark:hover, a.has-text-pink-dark:focus {
  color: #cc0fc3 !important;
}

.has-background-pink-dark {
  background-color: #9d0c95 !important;
}

.has-text-gold {
  color: #c18401 !important;
}

a.has-text-gold:hover, a.has-text-gold:focus {
  color: #8e6101 !important;
}

.has-background-gold {
  background-color: #c18401 !important;
}

.has-text-gold-light {
  color: #fff9eb !important;
}

a.has-text-gold-light:hover, a.has-text-gold-light:focus {
  color: #ffe8b8 !important;
}

.has-background-gold-light {
  background-color: #fff9eb !important;
}

.has-text-gold-dark {
  color: #c68801 !important;
}

a.has-text-gold-dark:hover, a.has-text-gold-dark:focus {
  color: #f9aa01 !important;
}

.has-background-gold-dark {
  background-color: #c68801 !important;
}

.has-text-greenish {
  color: #5ea14f !important;
}

a.has-text-greenish:hover, a.has-text-greenish:focus {
  color: #4a7e3e !important;
}

.has-background-greenish {
  background-color: #5ea14f !important;
}

.has-text-greenish-light {
  color: #f3f8f1 !important;
}

a.has-text-greenish-light:hover, a.has-text-greenish-light:focus {
  color: #d4e7cf !important;
}

.has-background-greenish-light {
  background-color: #f3f8f1 !important;
}

.has-text-greenish-dark {
  color: #4e8542 !important;
}

a.has-text-greenish-dark:hover, a.has-text-greenish-dark:focus {
  color: #62a752 !important;
}

.has-background-greenish-dark {
  background-color: #4e8542 !important;
}

.has-text-blood {
  color: #39040c !important;
}

a.has-text-blood:hover, a.has-text-blood:focus {
  color: #0a0102 !important;
}

.has-background-blood {
  background-color: #39040c !important;
}

.has-text-blood-light {
  color: #feecef !important;
}

a.has-text-blood-light:hover, a.has-text-blood-light:focus {
  color: #fabcc6 !important;
}

.has-background-blood-light {
  background-color: #feecef !important;
}

.has-text-blood-dark {
  color: #f02d4a !important;
}

a.has-text-blood-dark:hover, a.has-text-blood-dark:focus {
  color: #f45d73 !important;
}

.has-background-blood-dark {
  background-color: #f02d4a !important;
}

.has-text-black-bis {
  color: #121921 !important;
}

.has-background-black-bis {
  background-color: #121921 !important;
}

.has-text-black-ter {
  color: #202d3c !important;
}

.has-background-black-ter {
  background-color: #202d3c !important;
}

.has-text-grey-darker {
  color: #2f3546 !important;
}

.has-background-grey-darker {
  background-color: #2f3546 !important;
}

.has-text-grey-dark {
  color: #3e4551 !important;
}

.has-background-grey-dark {
  background-color: #3e4551 !important;
}

.has-text-grey {
  color: #6f727b !important;
}

.has-background-grey {
  background-color: #6f727b !important;
}

.has-text-grey-light {
  color: #a1b1bf !important;
}

.has-background-grey-light {
  background-color: #a1b1bf !important;
}

.has-text-grey-lighter {
  color: #c9d1d9 !important;
}

.has-background-grey-lighter {
  background-color: #c9d1d9 !important;
}

.has-text-white-ter {
  color: #faf0f0 !important;
}

.has-background-white-ter {
  background-color: #faf0f0 !important;
}

.has-text-white-bis {
  color: whitesmoke !important;
}

.has-background-white-bis {
  background-color: whitesmoke !important;
}

.is-flex-direction-row {
  flex-direction: row !important;
}

.is-flex-direction-row-reverse {
  flex-direction: row-reverse !important;
}

.is-flex-direction-column {
  flex-direction: column !important;
}

.is-flex-direction-column-reverse {
  flex-direction: column-reverse !important;
}

.is-flex-wrap-nowrap {
  flex-wrap: nowrap !important;
}

.is-flex-wrap-wrap {
  flex-wrap: wrap !important;
}

.is-flex-wrap-wrap-reverse {
  flex-wrap: wrap-reverse !important;
}

.is-justify-content-flex-start {
  justify-content: flex-start !important;
}

.is-justify-content-flex-end {
  justify-content: flex-end !important;
}

.is-justify-content-center {
  justify-content: center !important;
}

.is-justify-content-space-between {
  justify-content: space-between !important;
}

.is-justify-content-space-around {
  justify-content: space-around !important;
}

.is-justify-content-space-evenly {
  justify-content: space-evenly !important;
}

.is-justify-content-start {
  justify-content: start !important;
}

.is-justify-content-end {
  justify-content: end !important;
}

.is-justify-content-left {
  justify-content: left !important;
}

.is-justify-content-right {
  justify-content: right !important;
}

.is-align-content-flex-start {
  align-content: flex-start !important;
}

.is-align-content-flex-end {
  align-content: flex-end !important;
}

.is-align-content-center {
  align-content: center !important;
}

.is-align-content-space-between {
  align-content: space-between !important;
}

.is-align-content-space-around {
  align-content: space-around !important;
}

.is-align-content-space-evenly {
  align-content: space-evenly !important;
}

.is-align-content-stretch {
  align-content: stretch !important;
}

.is-align-content-start {
  align-content: start !important;
}

.is-align-content-end {
  align-content: end !important;
}

.is-align-content-baseline {
  align-content: baseline !important;
}

.is-align-items-stretch {
  align-items: stretch !important;
}

.is-align-items-flex-start {
  align-items: flex-start !important;
}

.is-align-items-flex-end {
  align-items: flex-end !important;
}

.is-align-items-center {
  align-items: center !important;
}

.is-align-items-baseline {
  align-items: baseline !important;
}

.is-align-items-start {
  align-items: start !important;
}

.is-align-items-end {
  align-items: end !important;
}

.is-align-items-self-start {
  align-items: self-start !important;
}

.is-align-items-self-end {
  align-items: self-end !important;
}

.is-align-self-auto {
  align-self: auto !important;
}

.is-align-self-flex-start {
  align-self: flex-start !important;
}

.is-align-self-flex-end {
  align-self: flex-end !important;
}

.is-align-self-center {
  align-self: center !important;
}

.is-align-self-baseline {
  align-self: baseline !important;
}

.is-align-self-stretch {
  align-self: stretch !important;
}

.is-flex-grow-0 {
  flex-grow: 0 !important;
}

.is-flex-grow-1 {
  flex-grow: 1 !important;
}

.is-flex-grow-2 {
  flex-grow: 2 !important;
}

.is-flex-grow-3 {
  flex-grow: 3 !important;
}

.is-flex-grow-4 {
  flex-grow: 4 !important;
}

.is-flex-grow-5 {
  flex-grow: 5 !important;
}

.is-flex-shrink-0 {
  flex-shrink: 0 !important;
}

.is-flex-shrink-1 {
  flex-shrink: 1 !important;
}

.is-flex-shrink-2 {
  flex-shrink: 2 !important;
}

.is-flex-shrink-3 {
  flex-shrink: 3 !important;
}

.is-flex-shrink-4 {
  flex-shrink: 4 !important;
}

.is-flex-shrink-5 {
  flex-shrink: 5 !important;
}

.is-clearfix::after {
  clear: both;
  content: " ";
  display: table;
}

.is-pulled-left, #search-results .align-left,
.content .align-left,
.document .align-left {
  float: left !important;
}

.is-pulled-right, #search-results .align-right,
.content .align-right,
.document .align-right {
  float: right !important;
}

.is-radiusless {
  border-radius: 0 !important;
}

.is-shadowless {
  box-shadow: none !important;
}

.is-clickable {
  cursor: pointer !important;
  pointer-events: all !important;
}

.is-clipped {
  overflow: hidden !important;
}

.is-relative {
  position: relative !important;
}

.is-marginless {
  margin: 0 !important;
}

.is-paddingless {
  padding: 0 !important;
}

.m-0 {
  margin: 0 !important;
}

.mt-0 {
  margin-top: 0 !important;
}

.mr-0 {
  margin-right: 0 !important;
}

.mb-0 {
  margin-bottom: 0 !important;
}

.ml-0 {
  margin-left: 0 !important;
}

.mx-0 {
  margin-left: 0 !important;
  margin-right: 0 !important;
}

.my-0 {
  margin-top: 0 !important;
  margin-bottom: 0 !important;
}

.m-1 {
  margin: 0.25rem !important;
}

.mt-1 {
  margin-top: 0.25rem !important;
}

.mr-1 {
  margin-right: 0.25rem !important;
}

.mb-1 {
  margin-bottom: 0.25rem !important;
}

.ml-1 {
  margin-left: 0.25rem !important;
}

.mx-1 {
  margin-left: 0.25rem !important;
  margin-right: 0.25rem !important;
}

.my-1 {
  margin-top: 0.25rem !important;
  margin-bottom: 0.25rem !important;
}

.m-2 {
  margin: 0.5rem !important;
}

.mt-2 {
  margin-top: 0.5rem !important;
}

.mr-2 {
  margin-right: 0.5rem !important;
}

.mb-2 {
  margin-bottom: 0.5rem !important;
}

.ml-2 {
  margin-left: 0.5rem !important;
}

.mx-2 {
  margin-left: 0.5rem !important;
  margin-right: 0.5rem !important;
}

.my-2 {
  margin-top: 0.5rem !important;
  margin-bottom: 0.5rem !important;
}

.m-3 {
  margin: 0.75rem !important;
}

.mt-3 {
  margin-top: 0.75rem !important;
}

.mr-3 {
  margin-right: 0.75rem !important;
}

.mb-3 {
  margin-bottom: 0.75rem !important;
}

.ml-3 {
  margin-left: 0.75rem !important;
}

.mx-3 {
  margin-left: 0.75rem !important;
  margin-right: 0.75rem !important;
}

.my-3 {
  margin-top: 0.75rem !important;
  margin-bottom: 0.75rem !important;
}

.m-4 {
  margin: 1rem !important;
}

.mt-4 {
  margin-top: 1rem !important;
}

.mr-4 {
  margin-right: 1rem !important;
}

.mb-4 {
  margin-bottom: 1rem !important;
}

.ml-4 {
  margin-left: 1rem !important;
}

.mx-4 {
  margin-left: 1rem !important;
  margin-right: 1rem !important;
}

.my-4 {
  margin-top: 1rem !important;
  margin-bottom: 1rem !important;
}

.m-5 {
  margin: 1.5rem !important;
}

.mt-5 {
  margin-top: 1.5rem !important;
}

.mr-5 {
  margin-right: 1.5rem !important;
}

.mb-5 {
  margin-bottom: 1.5rem !important;
}

.ml-5 {
  margin-left: 1.5rem !important;
}

.mx-5 {
  margin-left: 1.5rem !important;
  margin-right: 1.5rem !important;
}

.my-5 {
  margin-top: 1.5rem !important;
  margin-bottom: 1.5rem !important;
}

.m-6 {
  margin: 3rem !important;
}

.mt-6 {
  margin-top: 3rem !important;
}

.mr-6 {
  margin-right: 3rem !important;
}

.mb-6 {
  margin-bottom: 3rem !important;
}

.ml-6 {
  margin-left: 3rem !important;
}

.mx-6 {
  margin-left: 3rem !important;
  margin-right: 3rem !important;
}

.my-6 {
  margin-top: 3rem !important;
  margin-bottom: 3rem !important;
}

.m-auto {
  margin: auto !important;
}

.mt-auto {
  margin-top: auto !important;
}

.mr-auto {
  margin-right: auto !important;
}

.mb-auto {
  margin-bottom: auto !important;
}

.ml-auto {
  margin-left: auto !important;
}

.mx-auto {
  margin-left: auto !important;
  margin-right: auto !important;
}

.my-auto {
  margin-top: auto !important;
  margin-bottom: auto !important;
}

.p-0 {
  padding: 0 !important;
}

.pt-0 {
  padding-top: 0 !important;
}

.pr-0 {
  padding-right: 0 !important;
}

.pb-0 {
  padding-bottom: 0 !important;
}

.pl-0 {
  padding-left: 0 !important;
}

.px-0 {
  padding-left: 0 !important;
  padding-right: 0 !important;
}

.py-0 {
  padding-top: 0 !important;
  padding-bottom: 0 !important;
}

.p-1 {
  padding: 0.25rem !important;
}

.pt-1 {
  padding-top: 0.25rem !important;
}

.pr-1 {
  padding-right: 0.25rem !important;
}

.pb-1 {
  padding-bottom: 0.25rem !important;
}

.pl-1 {
  padding-left: 0.25rem !important;
}

.px-1 {
  padding-left: 0.25rem !important;
  padding-right: 0.25rem !important;
}

.py-1 {
  padding-top: 0.25rem !important;
  padding-bottom: 0.25rem !important;
}

.p-2 {
  padding: 0.5rem !important;
}

.pt-2 {
  padding-top: 0.5rem !important;
}

.pr-2 {
  padding-right: 0.5rem !important;
}

.pb-2 {
  padding-bottom: 0.5rem !important;
}

.pl-2 {
  padding-left: 0.5rem !important;
}

.px-2 {
  padding-left: 0.5rem !important;
  padding-right: 0.5rem !important;
}

.py-2 {
  padding-top: 0.5rem !important;
  padding-bottom: 0.5rem !important;
}

.p-3 {
  padding: 0.75rem !important;
}

.pt-3 {
  padding-top: 0.75rem !important;
}

.pr-3 {
  padding-right: 0.75rem !important;
}

.pb-3 {
  padding-bottom: 0.75rem !important;
}

.pl-3 {
  padding-left: 0.75rem !important;
}

.px-3 {
  padding-left: 0.75rem !important;
  padding-right: 0.75rem !important;
}

.py-3 {
  padding-top: 0.75rem !important;
  padding-bottom: 0.75rem !important;
}

.p-4 {
  padding: 1rem !important;
}

.pt-4 {
  padding-top: 1rem !important;
}

.pr-4 {
  padding-right: 1rem !important;
}

.pb-4 {
  padding-bottom: 1rem !important;
}

.pl-4 {
  padding-left: 1rem !important;
}

.px-4 {
  padding-left: 1rem !important;
  padding-right: 1rem !important;
}

.py-4 {
  padding-top: 1rem !important;
  padding-bottom: 1rem !important;
}

.p-5 {
  padding: 1.5rem !important;
}

.pt-5 {
  padding-top: 1.5rem !important;
}

.pr-5 {
  padding-right: 1.5rem !important;
}

.pb-5 {
  padding-bottom: 1.5rem !important;
}

.pl-5 {
  padding-left: 1.5rem !important;
}

.px-5 {
  padding-left: 1.5rem !important;
  padding-right: 1.5rem !important;
}

.py-5 {
  padding-top: 1.5rem !important;
  padding-bottom: 1.5rem !important;
}

.p-6 {
  padding: 3rem !important;
}

.pt-6 {
  padding-top: 3rem !important;
}

.pr-6 {
  padding-right: 3rem !important;
}

.pb-6 {
  padding-bottom: 3rem !important;
}

.pl-6 {
  padding-left: 3rem !important;
}

.px-6 {
  padding-left: 3rem !important;
  padding-right: 3rem !important;
}

.py-6 {
  padding-top: 3rem !important;
  padding-bottom: 3rem !important;
}

.p-auto {
  padding: auto !important;
}

.pt-auto {
  padding-top: auto !important;
}

.pr-auto {
  padding-right: auto !important;
}

.pb-auto {
  padding-bottom: auto !important;
}

.pl-auto {
  padding-left: auto !important;
}

.px-auto {
  padding-left: auto !important;
  padding-right: auto !important;
}

.py-auto {
  padding-top: auto !important;
  padding-bottom: auto !important;
}

.is-size-1 {
  font-size: 3rem !important;
}

.is-size-2 {
  font-size: 2.5rem !important;
}

.is-size-3 {
  font-size: 2rem !important;
}

.is-size-4 {
  font-size: 1.5rem !important;
}

.is-size-5 {
  font-size: 1.25rem !important;
}

.is-size-6 {
  font-size: 1rem !important;
}

.is-size-7 {
  font-size: 0.75rem !important;
}

@media screen and (max-width: 768px) {
  .is-size-1-mobile {
    font-size: 3rem !important;
  }

  .is-size-2-mobile {
    font-size: 2.5rem !important;
  }

  .is-size-3-mobile {
    font-size: 2rem !important;
  }

  .is-size-4-mobile {
    font-size: 1.5rem !important;
  }

  .is-size-5-mobile {
    font-size: 1.25rem !important;
  }

  .is-size-6-mobile {
    font-size: 1rem !important;
  }

  .is-size-7-mobile {
    font-size: 0.75rem !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-size-1-tablet {
    font-size: 3rem !important;
  }

  .is-size-2-tablet {
    font-size: 2.5rem !important;
  }

  .is-size-3-tablet {
    font-size: 2rem !important;
  }

  .is-size-4-tablet {
    font-size: 1.5rem !important;
  }

  .is-size-5-tablet {
    font-size: 1.25rem !important;
  }

  .is-size-6-tablet {
    font-size: 1rem !important;
  }

  .is-size-7-tablet {
    font-size: 0.75rem !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-size-1-touch {
    font-size: 3rem !important;
  }

  .is-size-2-touch {
    font-size: 2.5rem !important;
  }

  .is-size-3-touch {
    font-size: 2rem !important;
  }

  .is-size-4-touch {
    font-size: 1.5rem !important;
  }

  .is-size-5-touch {
    font-size: 1.25rem !important;
  }

  .is-size-6-touch {
    font-size: 1rem !important;
  }

  .is-size-7-touch {
    font-size: 0.75rem !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-size-1-desktop {
    font-size: 3rem !important;
  }

  .is-size-2-desktop {
    font-size: 2.5rem !important;
  }

  .is-size-3-desktop {
    font-size: 2rem !important;
  }

  .is-size-4-desktop {
    font-size: 1.5rem !important;
  }

  .is-size-5-desktop {
    font-size: 1.25rem !important;
  }

  .is-size-6-desktop {
    font-size: 1rem !important;
  }

  .is-size-7-desktop {
    font-size: 0.75rem !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-size-1-widescreen {
    font-size: 3rem !important;
  }

  .is-size-2-widescreen {
    font-size: 2.5rem !important;
  }

  .is-size-3-widescreen {
    font-size: 2rem !important;
  }

  .is-size-4-widescreen {
    font-size: 1.5rem !important;
  }

  .is-size-5-widescreen {
    font-size: 1.25rem !important;
  }

  .is-size-6-widescreen {
    font-size: 1rem !important;
  }

  .is-size-7-widescreen {
    font-size: 0.75rem !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-size-1-fullhd {
    font-size: 3rem !important;
  }

  .is-size-2-fullhd {
    font-size: 2.5rem !important;
  }

  .is-size-3-fullhd {
    font-size: 2rem !important;
  }

  .is-size-4-fullhd {
    font-size: 1.5rem !important;
  }

  .is-size-5-fullhd {
    font-size: 1.25rem !important;
  }

  .is-size-6-fullhd {
    font-size: 1rem !important;
  }

  .is-size-7-fullhd {
    font-size: 0.75rem !important;
  }
}
.has-text-centered {
  text-align: center !important;
}

.has-text-justified {
  text-align: justify !important;
}

.has-text-left {
  text-align: left !important;
}

.has-text-right {
  text-align: right !important;
}

@media screen and (max-width: 768px) {
  .has-text-centered-mobile {
    text-align: center !important;
  }
}
@media screen and (min-width: 769px), print {
  .has-text-centered-tablet {
    text-align: center !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .has-text-centered-tablet-only {
    text-align: center !important;
  }
}
@media screen and (max-width: 1023px) {
  .has-text-centered-touch {
    text-align: center !important;
  }
}
@media screen and (min-width: 1024px) {
  .has-text-centered-desktop {
    text-align: center !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .has-text-centered-desktop-only {
    text-align: center !important;
  }
}
@media screen and (min-width: 1216px) {
  .has-text-centered-widescreen {
    text-align: center !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .has-text-centered-widescreen-only {
    text-align: center !important;
  }
}
@media screen and (min-width: 1408px) {
  .has-text-centered-fullhd {
    text-align: center !important;
  }
}
@media screen and (max-width: 768px) {
  .has-text-justified-mobile {
    text-align: justify !important;
  }
}
@media screen and (min-width: 769px), print {
  .has-text-justified-tablet {
    text-align: justify !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .has-text-justified-tablet-only {
    text-align: justify !important;
  }
}
@media screen and (max-width: 1023px) {
  .has-text-justified-touch {
    text-align: justify !important;
  }
}
@media screen and (min-width: 1024px) {
  .has-text-justified-desktop {
    text-align: justify !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .has-text-justified-desktop-only {
    text-align: justify !important;
  }
}
@media screen and (min-width: 1216px) {
  .has-text-justified-widescreen {
    text-align: justify !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .has-text-justified-widescreen-only {
    text-align: justify !important;
  }
}
@media screen and (min-width: 1408px) {
  .has-text-justified-fullhd {
    text-align: justify !important;
  }
}
@media screen and (max-width: 768px) {
  .has-text-left-mobile {
    text-align: left !important;
  }
}
@media screen and (min-width: 769px), print {
  .has-text-left-tablet {
    text-align: left !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .has-text-left-tablet-only {
    text-align: left !important;
  }
}
@media screen and (max-width: 1023px) {
  .has-text-left-touch {
    text-align: left !important;
  }
}
@media screen and (min-width: 1024px) {
  .has-text-left-desktop {
    text-align: left !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .has-text-left-desktop-only {
    text-align: left !important;
  }
}
@media screen and (min-width: 1216px) {
  .has-text-left-widescreen {
    text-align: left !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .has-text-left-widescreen-only {
    text-align: left !important;
  }
}
@media screen and (min-width: 1408px) {
  .has-text-left-fullhd {
    text-align: left !important;
  }
}
@media screen and (max-width: 768px) {
  .has-text-right-mobile {
    text-align: right !important;
  }
}
@media screen and (min-width: 769px), print {
  .has-text-right-tablet {
    text-align: right !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .has-text-right-tablet-only {
    text-align: right !important;
  }
}
@media screen and (max-width: 1023px) {
  .has-text-right-touch {
    text-align: right !important;
  }
}
@media screen and (min-width: 1024px) {
  .has-text-right-desktop {
    text-align: right !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .has-text-right-desktop-only {
    text-align: right !important;
  }
}
@media screen and (min-width: 1216px) {
  .has-text-right-widescreen {
    text-align: right !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .has-text-right-widescreen-only {
    text-align: right !important;
  }
}
@media screen and (min-width: 1408px) {
  .has-text-right-fullhd {
    text-align: right !important;
  }
}
.is-capitalized {
  text-transform: capitalize !important;
}

.is-lowercase {
  text-transform: lowercase !important;
}

.is-uppercase {
  text-transform: uppercase !important;
}

.is-italic {
  font-style: italic !important;
}

.is-underlined {
  text-decoration: underline !important;
}

.has-text-weight-light {
  font-weight: 300 !important;
}

.has-text-weight-normal {
  font-weight: 400 !important;
}

.has-text-weight-medium {
  font-weight: 500 !important;
}

.has-text-weight-semibold {
  font-weight: 600 !important;
}

.has-text-weight-bold, #search-results aside.sidebar p.sidebar-title,
.content aside.sidebar p.sidebar-title,
.document aside.sidebar p.sidebar-title {
  font-weight: 700 !important;
}

.is-family-primary {
  font-family: "Josefin Sans", sans-serif !important;
}

.is-family-secondary {
  font-family: "Josefin Sans", sans-serif !important;
}

.is-family-sans-serif {
  font-family: "Josefin Sans", sans-serif !important;
}

.is-family-monospace {
  font-family: "Courier Prime", monospace !important;
}

.is-family-code {
  font-family: "Courier Prime", monospace !important;
}

.is-block {
  display: block !important;
}

@media screen and (max-width: 768px) {
  .is-block-mobile {
    display: block !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-block-tablet {
    display: block !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .is-block-tablet-only {
    display: block !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-block-touch {
    display: block !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-block-desktop {
    display: block !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .is-block-desktop-only {
    display: block !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-block-widescreen {
    display: block !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .is-block-widescreen-only {
    display: block !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-block-fullhd {
    display: block !important;
  }
}
.is-flex {
  display: flex !important;
}

@media screen and (max-width: 768px) {
  .is-flex-mobile {
    display: flex !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-flex-tablet {
    display: flex !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .is-flex-tablet-only {
    display: flex !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-flex-touch {
    display: flex !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-flex-desktop {
    display: flex !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .is-flex-desktop-only {
    display: flex !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-flex-widescreen {
    display: flex !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .is-flex-widescreen-only {
    display: flex !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-flex-fullhd {
    display: flex !important;
  }
}
.is-inline {
  display: inline !important;
}

@media screen and (max-width: 768px) {
  .is-inline-mobile {
    display: inline !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-inline-tablet {
    display: inline !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .is-inline-tablet-only {
    display: inline !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-inline-touch {
    display: inline !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-inline-desktop {
    display: inline !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .is-inline-desktop-only {
    display: inline !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-inline-widescreen {
    display: inline !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .is-inline-widescreen-only {
    display: inline !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-inline-fullhd {
    display: inline !important;
  }
}
.is-inline-block {
  display: inline-block !important;
}

@media screen and (max-width: 768px) {
  .is-inline-block-mobile {
    display: inline-block !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-inline-block-tablet {
    display: inline-block !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .is-inline-block-tablet-only {
    display: inline-block !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-inline-block-touch {
    display: inline-block !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-inline-block-desktop {
    display: inline-block !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .is-inline-block-desktop-only {
    display: inline-block !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-inline-block-widescreen {
    display: inline-block !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .is-inline-block-widescreen-only {
    display: inline-block !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-inline-block-fullhd {
    display: inline-block !important;
  }
}
.is-inline-flex {
  display: inline-flex !important;
}

@media screen and (max-width: 768px) {
  .is-inline-flex-mobile {
    display: inline-flex !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-inline-flex-tablet {
    display: inline-flex !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .is-inline-flex-tablet-only {
    display: inline-flex !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-inline-flex-touch {
    display: inline-flex !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-inline-flex-desktop {
    display: inline-flex !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .is-inline-flex-desktop-only {
    display: inline-flex !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-inline-flex-widescreen {
    display: inline-flex !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .is-inline-flex-widescreen-only {
    display: inline-flex !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-inline-flex-fullhd {
    display: inline-flex !important;
  }
}
.is-hidden {
  display: none !important;
}

.is-sr-only {
  border: none !important;
  clip: rect(0, 0, 0, 0) !important;
  height: 0.01em !important;
  overflow: hidden !important;
  padding: 0 !important;
  position: absolute !important;
  white-space: nowrap !important;
  width: 0.01em !important;
}

@media screen and (max-width: 768px) {
  .is-hidden-mobile {
    display: none !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-hidden-tablet {
    display: none !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .is-hidden-tablet-only {
    display: none !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-hidden-touch {
    display: none !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-hidden-desktop {
    display: none !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .is-hidden-desktop-only {
    display: none !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-hidden-widescreen {
    display: none !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .is-hidden-widescreen-only {
    display: none !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-hidden-fullhd {
    display: none !important;
  }
}
.is-invisible {
  visibility: hidden !important;
}

@media screen and (max-width: 768px) {
  .is-invisible-mobile {
    visibility: hidden !important;
  }
}
@media screen and (min-width: 769px), print {
  .is-invisible-tablet {
    visibility: hidden !important;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .is-invisible-tablet-only {
    visibility: hidden !important;
  }
}
@media screen and (max-width: 1023px) {
  .is-invisible-touch {
    visibility: hidden !important;
  }
}
@media screen and (min-width: 1024px) {
  .is-invisible-desktop {
    visibility: hidden !important;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .is-invisible-desktop-only {
    visibility: hidden !important;
  }
}
@media screen and (min-width: 1216px) {
  .is-invisible-widescreen {
    visibility: hidden !important;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .is-invisible-widescreen-only {
    visibility: hidden !important;
  }
}
@media screen and (min-width: 1408px) {
  .is-invisible-fullhd {
    visibility: hidden !important;
  }
}
/* Bulma Layout */
.hero {
  align-items: stretch;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}
.hero .navbar {
  background: none;
}
.hero .tabs ul {
  border-bottom: none;
}
.hero.is-white {
  background-color: #fafafa;
  color: #0d1117;
}
.hero.is-white a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-white strong {
  color: inherit;
}
.hero.is-white .title, .hero.is-white .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-white .topic-title,
.hero.is-white .dark-palette .content .topic-title,
.dark-palette .content .hero.is-white .topic-title,
.hero.is-white .dark-palette .document .topic-title,
.dark-palette .document .hero.is-white .topic-title, .hero.is-white .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-white .topic-title,
.hero.is-white .light-palette .content .topic-title,
.light-palette .content .hero.is-white .topic-title,
.hero.is-white .light-palette .document .topic-title,
.light-palette .document .hero.is-white .topic-title {
  color: #0d1117;
}
.hero.is-white .subtitle {
  color: rgba(13, 17, 23, 0.9);
}
.hero.is-white .subtitle a:not(.button),
.hero.is-white .subtitle strong {
  color: #0d1117;
}
@media screen and (max-width: 1023px) {
  .hero.is-white .navbar-menu {
    background-color: #fafafa;
  }
}
.hero.is-white .navbar-item,
.hero.is-white .navbar-link {
  color: rgba(13, 17, 23, 0.7);
}
.hero.is-white a.navbar-item:hover, .hero.is-white a.navbar-item.is-active,
.hero.is-white .navbar-link:hover,
.hero.is-white .navbar-link.is-active {
  background-color: #ededed;
  color: #0d1117;
}
.hero.is-white .tabs a {
  color: #0d1117;
  opacity: 0.9;
}
.hero.is-white .tabs a:hover {
  opacity: 1;
}
.hero.is-white .tabs li.is-active a {
  color: #fafafa !important;
  opacity: 1;
}
.hero.is-white .tabs.is-boxed a, .hero.is-white .tabs.is-toggle a {
  color: #0d1117;
}
.hero.is-white .tabs.is-boxed a:hover, .hero.is-white .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-white .tabs.is-boxed li.is-active a, .hero.is-white .tabs.is-boxed li.is-active a:hover, .hero.is-white .tabs.is-toggle li.is-active a, .hero.is-white .tabs.is-toggle li.is-active a:hover {
  background-color: #0d1117;
  border-color: #0d1117;
  color: #fafafa;
}
.hero.is-white.is-bold {
  background-image: linear-gradient(141deg, #e3ddde 0%, #fafafa 71%, white 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-white.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #e3ddde 0%, #fafafa 71%, white 100%);
  }
}
.hero.is-black {
  background-color: #0d1117;
  color: #fafafa;
}
.hero.is-black a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-black strong {
  color: inherit;
}
.hero.is-black .title, .hero.is-black .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-black .topic-title,
.hero.is-black .dark-palette .content .topic-title,
.dark-palette .content .hero.is-black .topic-title,
.hero.is-black .dark-palette .document .topic-title,
.dark-palette .document .hero.is-black .topic-title, .hero.is-black .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-black .topic-title,
.hero.is-black .light-palette .content .topic-title,
.light-palette .content .hero.is-black .topic-title,
.hero.is-black .light-palette .document .topic-title,
.light-palette .document .hero.is-black .topic-title {
  color: #fafafa;
}
.hero.is-black .subtitle {
  color: rgba(250, 250, 250, 0.9);
}
.hero.is-black .subtitle a:not(.button),
.hero.is-black .subtitle strong {
  color: #fafafa;
}
@media screen and (max-width: 1023px) {
  .hero.is-black .navbar-menu {
    background-color: #0d1117;
  }
}
.hero.is-black .navbar-item,
.hero.is-black .navbar-link {
  color: rgba(250, 250, 250, 0.7);
}
.hero.is-black a.navbar-item:hover, .hero.is-black a.navbar-item.is-active,
.hero.is-black .navbar-link:hover,
.hero.is-black .navbar-link.is-active {
  background-color: #040507;
  color: #fafafa;
}
.hero.is-black .tabs a {
  color: #fafafa;
  opacity: 0.9;
}
.hero.is-black .tabs a:hover {
  opacity: 1;
}
.hero.is-black .tabs li.is-active a {
  color: #0d1117 !important;
  opacity: 1;
}
.hero.is-black .tabs.is-boxed a, .hero.is-black .tabs.is-toggle a {
  color: #fafafa;
}
.hero.is-black .tabs.is-boxed a:hover, .hero.is-black .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-black .tabs.is-boxed li.is-active a, .hero.is-black .tabs.is-boxed li.is-active a:hover, .hero.is-black .tabs.is-toggle li.is-active a, .hero.is-black .tabs.is-toggle li.is-active a:hover {
  background-color: #fafafa;
  border-color: #fafafa;
  color: #0d1117;
}
.hero.is-black.is-bold {
  background-image: linear-gradient(141deg, black 0%, #0d1117 71%, #151929 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-black.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, black 0%, #0d1117 71%, #151929 100%);
  }
}
.hero.is-light {
  background-color: #faf0f0;
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-light a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-light strong {
  color: inherit;
}
.hero.is-light .title, .hero.is-light .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-light .topic-title,
.hero.is-light .dark-palette .content .topic-title,
.dark-palette .content .hero.is-light .topic-title,
.hero.is-light .dark-palette .document .topic-title,
.dark-palette .document .hero.is-light .topic-title, .hero.is-light .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-light .topic-title,
.hero.is-light .light-palette .content .topic-title,
.light-palette .content .hero.is-light .topic-title,
.hero.is-light .light-palette .document .topic-title,
.light-palette .document .hero.is-light .topic-title {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-light .subtitle {
  color: rgba(0, 0, 0, 0.9);
}
.hero.is-light .subtitle a:not(.button),
.hero.is-light .subtitle strong {
  color: rgba(0, 0, 0, 0.7);
}
@media screen and (max-width: 1023px) {
  .hero.is-light .navbar-menu {
    background-color: #faf0f0;
  }
}
.hero.is-light .navbar-item,
.hero.is-light .navbar-link {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-light a.navbar-item:hover, .hero.is-light a.navbar-item.is-active,
.hero.is-light .navbar-link:hover,
.hero.is-light .navbar-link.is-active {
  background-color: #f4dddd;
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-light .tabs a {
  color: rgba(0, 0, 0, 0.7);
  opacity: 0.9;
}
.hero.is-light .tabs a:hover {
  opacity: 1;
}
.hero.is-light .tabs li.is-active a {
  color: #faf0f0 !important;
  opacity: 1;
}
.hero.is-light .tabs.is-boxed a, .hero.is-light .tabs.is-toggle a {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-light .tabs.is-boxed a:hover, .hero.is-light .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-light .tabs.is-boxed li.is-active a, .hero.is-light .tabs.is-boxed li.is-active a:hover, .hero.is-light .tabs.is-toggle li.is-active a, .hero.is-light .tabs.is-toggle li.is-active a:hover {
  background-color: rgba(0, 0, 0, 0.7);
  border-color: rgba(0, 0, 0, 0.7);
  color: #faf0f0;
}
.hero.is-light.is-bold {
  background-image: linear-gradient(141deg, #f1c6cd 0%, #faf0f0 71%, white 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-light.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #f1c6cd 0%, #faf0f0 71%, white 100%);
  }
}
.hero.is-dark {
  background-color: #2f3546;
  color: #fff;
}
.hero.is-dark a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-dark strong {
  color: inherit;
}
.hero.is-dark .title, .hero.is-dark .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-dark .topic-title,
.hero.is-dark .dark-palette .content .topic-title,
.dark-palette .content .hero.is-dark .topic-title,
.hero.is-dark .dark-palette .document .topic-title,
.dark-palette .document .hero.is-dark .topic-title, .hero.is-dark .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-dark .topic-title,
.hero.is-dark .light-palette .content .topic-title,
.light-palette .content .hero.is-dark .topic-title,
.hero.is-dark .light-palette .document .topic-title,
.light-palette .document .hero.is-dark .topic-title {
  color: #fff;
}
.hero.is-dark .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-dark .subtitle a:not(.button),
.hero.is-dark .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-dark .navbar-menu {
    background-color: #2f3546;
  }
}
.hero.is-dark .navbar-item,
.hero.is-dark .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-dark a.navbar-item:hover, .hero.is-dark a.navbar-item.is-active,
.hero.is-dark .navbar-link:hover,
.hero.is-dark .navbar-link.is-active {
  background-color: #252937;
  color: #fff;
}
.hero.is-dark .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-dark .tabs a:hover {
  opacity: 1;
}
.hero.is-dark .tabs li.is-active a {
  color: #2f3546 !important;
  opacity: 1;
}
.hero.is-dark .tabs.is-boxed a, .hero.is-dark .tabs.is-toggle a {
  color: #fff;
}
.hero.is-dark .tabs.is-boxed a:hover, .hero.is-dark .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-dark .tabs.is-boxed li.is-active a, .hero.is-dark .tabs.is-boxed li.is-active a:hover, .hero.is-dark .tabs.is-toggle li.is-active a, .hero.is-dark .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #2f3546;
}
.hero.is-dark.is-bold {
  background-image: linear-gradient(141deg, #171f2b 0%, #2f3546 71%, #363959 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-dark.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #171f2b 0%, #2f3546 71%, #363959 100%);
  }
}
.hero.is-primary {
  background-color: #885bfb;
  color: white;
}
.hero.is-primary a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-primary strong {
  color: inherit;
}
.hero.is-primary .title, .hero.is-primary .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-primary .topic-title,
.hero.is-primary .dark-palette .content .topic-title,
.dark-palette .content .hero.is-primary .topic-title,
.hero.is-primary .dark-palette .document .topic-title,
.dark-palette .document .hero.is-primary .topic-title, .hero.is-primary .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-primary .topic-title,
.hero.is-primary .light-palette .content .topic-title,
.light-palette .content .hero.is-primary .topic-title,
.hero.is-primary .light-palette .document .topic-title,
.light-palette .document .hero.is-primary .topic-title {
  color: white;
}
.hero.is-primary .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-primary .subtitle a:not(.button),
.hero.is-primary .subtitle strong {
  color: white;
}
@media screen and (max-width: 1023px) {
  .hero.is-primary .navbar-menu {
    background-color: #885bfb;
  }
}
.hero.is-primary .navbar-item,
.hero.is-primary .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-primary a.navbar-item:hover, .hero.is-primary a.navbar-item.is-active,
.hero.is-primary .navbar-link:hover,
.hero.is-primary .navbar-link.is-active {
  background-color: #7642fa;
  color: white;
}
.hero.is-primary .tabs a {
  color: white;
  opacity: 0.9;
}
.hero.is-primary .tabs a:hover {
  opacity: 1;
}
.hero.is-primary .tabs li.is-active a {
  color: #885bfb !important;
  opacity: 1;
}
.hero.is-primary .tabs.is-boxed a, .hero.is-primary .tabs.is-toggle a {
  color: white;
}
.hero.is-primary .tabs.is-boxed a:hover, .hero.is-primary .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-primary .tabs.is-boxed li.is-active a, .hero.is-primary .tabs.is-boxed li.is-active a:hover, .hero.is-primary .tabs.is-toggle li.is-active a, .hero.is-primary .tabs.is-toggle li.is-active a:hover {
  background-color: white;
  border-color: white;
  color: #885bfb;
}
.hero.is-primary.is-bold {
  background-image: linear-gradient(141deg, #3d24ff 0%, #885bfb 71%, #b070ff 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-primary.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #3d24ff 0%, #885bfb 71%, #b070ff 100%);
  }
}
.hero.is-link {
  background-color: #4078f2;
  color: #736a59;
}
.hero.is-link a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-link strong {
  color: inherit;
}
.hero.is-link .title, .hero.is-link .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-link .topic-title,
.hero.is-link .dark-palette .content .topic-title,
.dark-palette .content .hero.is-link .topic-title,
.hero.is-link .dark-palette .document .topic-title,
.dark-palette .document .hero.is-link .topic-title, .hero.is-link .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-link .topic-title,
.hero.is-link .light-palette .content .topic-title,
.light-palette .content .hero.is-link .topic-title,
.hero.is-link .light-palette .document .topic-title,
.light-palette .document .hero.is-link .topic-title {
  color: #736a59;
}
.hero.is-link .subtitle {
  color: rgba(115, 106, 89, 0.9);
}
.hero.is-link .subtitle a:not(.button),
.hero.is-link .subtitle strong {
  color: #736a59;
}
@media screen and (max-width: 1023px) {
  .hero.is-link .navbar-menu {
    background-color: #4078f2;
  }
}
.hero.is-link .navbar-item,
.hero.is-link .navbar-link {
  color: rgba(115, 106, 89, 0.7);
}
.hero.is-link a.navbar-item:hover, .hero.is-link a.navbar-item.is-active,
.hero.is-link .navbar-link:hover,
.hero.is-link .navbar-link.is-active {
  background-color: #2868f0;
  color: #736a59;
}
.hero.is-link .tabs a {
  color: #736a59;
  opacity: 0.9;
}
.hero.is-link .tabs a:hover {
  opacity: 1;
}
.hero.is-link .tabs li.is-active a {
  color: #4078f2 !important;
  opacity: 1;
}
.hero.is-link .tabs.is-boxed a, .hero.is-link .tabs.is-toggle a {
  color: #736a59;
}
.hero.is-link .tabs.is-boxed a:hover, .hero.is-link .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-link .tabs.is-boxed li.is-active a, .hero.is-link .tabs.is-boxed li.is-active a:hover, .hero.is-link .tabs.is-toggle li.is-active a, .hero.is-link .tabs.is-toggle li.is-active a:hover {
  background-color: #736a59;
  border-color: #736a59;
  color: #4078f2;
}
.hero.is-link.is-bold {
  background-image: linear-gradient(141deg, #047bfb 0%, #4078f2 71%, #546cf8 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-link.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #047bfb 0%, #4078f2 71%, #546cf8 100%);
  }
}
.hero.is-info {
  background-color: #449cc5;
  color: #fff;
}
.hero.is-info a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-info strong {
  color: inherit;
}
.hero.is-info .title, .hero.is-info .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-info .topic-title,
.hero.is-info .dark-palette .content .topic-title,
.dark-palette .content .hero.is-info .topic-title,
.hero.is-info .dark-palette .document .topic-title,
.dark-palette .document .hero.is-info .topic-title, .hero.is-info .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-info .topic-title,
.hero.is-info .light-palette .content .topic-title,
.light-palette .content .hero.is-info .topic-title,
.hero.is-info .light-palette .document .topic-title,
.light-palette .document .hero.is-info .topic-title {
  color: #fff;
}
.hero.is-info .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-info .subtitle a:not(.button),
.hero.is-info .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-info .navbar-menu {
    background-color: #449cc5;
  }
}
.hero.is-info .navbar-item,
.hero.is-info .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-info a.navbar-item:hover, .hero.is-info a.navbar-item.is-active,
.hero.is-info .navbar-link:hover,
.hero.is-info .navbar-link.is-active {
  background-color: #388fb7;
  color: #fff;
}
.hero.is-info .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-info .tabs a:hover {
  opacity: 1;
}
.hero.is-info .tabs li.is-active a {
  color: #449cc5 !important;
  opacity: 1;
}
.hero.is-info .tabs.is-boxed a, .hero.is-info .tabs.is-toggle a {
  color: #fff;
}
.hero.is-info .tabs.is-boxed a:hover, .hero.is-info .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-info .tabs.is-boxed li.is-active a, .hero.is-info .tabs.is-boxed li.is-active a:hover, .hero.is-info .tabs.is-toggle li.is-active a, .hero.is-info .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #449cc5;
}
.hero.is-info.is-bold {
  background-image: linear-gradient(141deg, #289aaf 0%, #449cc5 71%, #5293d1 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-info.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #289aaf 0%, #449cc5 71%, #5293d1 100%);
  }
}
.hero.is-success {
  background-color: #00ad6b;
  color: #fff;
}
.hero.is-success a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-success strong {
  color: inherit;
}
.hero.is-success .title, .hero.is-success .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-success .topic-title,
.hero.is-success .dark-palette .content .topic-title,
.dark-palette .content .hero.is-success .topic-title,
.hero.is-success .dark-palette .document .topic-title,
.dark-palette .document .hero.is-success .topic-title, .hero.is-success .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-success .topic-title,
.hero.is-success .light-palette .content .topic-title,
.light-palette .content .hero.is-success .topic-title,
.hero.is-success .light-palette .document .topic-title,
.light-palette .document .hero.is-success .topic-title {
  color: #fff;
}
.hero.is-success .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-success .subtitle a:not(.button),
.hero.is-success .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-success .navbar-menu {
    background-color: #00ad6b;
  }
}
.hero.is-success .navbar-item,
.hero.is-success .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-success a.navbar-item:hover, .hero.is-success a.navbar-item.is-active,
.hero.is-success .navbar-link:hover,
.hero.is-success .navbar-link.is-active {
  background-color: #00945b;
  color: #fff;
}
.hero.is-success .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-success .tabs a:hover {
  opacity: 1;
}
.hero.is-success .tabs li.is-active a {
  color: #00ad6b !important;
  opacity: 1;
}
.hero.is-success .tabs.is-boxed a, .hero.is-success .tabs.is-toggle a {
  color: #fff;
}
.hero.is-success .tabs.is-boxed a:hover, .hero.is-success .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-success .tabs.is-boxed li.is-active a, .hero.is-success .tabs.is-boxed li.is-active a:hover, .hero.is-success .tabs.is-toggle li.is-active a, .hero.is-success .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #00ad6b;
}
.hero.is-success.is-bold {
  background-image: linear-gradient(141deg, #007a37 0%, #00ad6b 71%, #00c79c 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-success.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #007a37 0%, #00ad6b 71%, #00c79c 100%);
  }
}
.hero.is-warning {
  background-color: #ffc400;
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-warning a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-warning strong {
  color: inherit;
}
.hero.is-warning .title, .hero.is-warning .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-warning .topic-title,
.hero.is-warning .dark-palette .content .topic-title,
.dark-palette .content .hero.is-warning .topic-title,
.hero.is-warning .dark-palette .document .topic-title,
.dark-palette .document .hero.is-warning .topic-title, .hero.is-warning .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-warning .topic-title,
.hero.is-warning .light-palette .content .topic-title,
.light-palette .content .hero.is-warning .topic-title,
.hero.is-warning .light-palette .document .topic-title,
.light-palette .document .hero.is-warning .topic-title {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-warning .subtitle {
  color: rgba(0, 0, 0, 0.9);
}
.hero.is-warning .subtitle a:not(.button),
.hero.is-warning .subtitle strong {
  color: rgba(0, 0, 0, 0.7);
}
@media screen and (max-width: 1023px) {
  .hero.is-warning .navbar-menu {
    background-color: #ffc400;
  }
}
.hero.is-warning .navbar-item,
.hero.is-warning .navbar-link {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-warning a.navbar-item:hover, .hero.is-warning a.navbar-item.is-active,
.hero.is-warning .navbar-link:hover,
.hero.is-warning .navbar-link.is-active {
  background-color: #e6b000;
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-warning .tabs a {
  color: rgba(0, 0, 0, 0.7);
  opacity: 0.9;
}
.hero.is-warning .tabs a:hover {
  opacity: 1;
}
.hero.is-warning .tabs li.is-active a {
  color: #ffc400 !important;
  opacity: 1;
}
.hero.is-warning .tabs.is-boxed a, .hero.is-warning .tabs.is-toggle a {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-warning .tabs.is-boxed a:hover, .hero.is-warning .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-warning .tabs.is-boxed li.is-active a, .hero.is-warning .tabs.is-boxed li.is-active a:hover, .hero.is-warning .tabs.is-toggle li.is-active a, .hero.is-warning .tabs.is-toggle li.is-active a:hover {
  background-color: rgba(0, 0, 0, 0.7);
  border-color: rgba(0, 0, 0, 0.7);
  color: #ffc400;
}
.hero.is-warning.is-bold {
  background-image: linear-gradient(141deg, #cc7a00 0%, #ffc400 71%, #fff01a 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-warning.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #cc7a00 0%, #ffc400 71%, #fff01a 100%);
  }
}
.hero.is-danger {
  background-color: #e45649;
  color: #fff;
}
.hero.is-danger a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-danger strong {
  color: inherit;
}
.hero.is-danger .title, .hero.is-danger .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-danger .topic-title,
.hero.is-danger .dark-palette .content .topic-title,
.dark-palette .content .hero.is-danger .topic-title,
.hero.is-danger .dark-palette .document .topic-title,
.dark-palette .document .hero.is-danger .topic-title, .hero.is-danger .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-danger .topic-title,
.hero.is-danger .light-palette .content .topic-title,
.light-palette .content .hero.is-danger .topic-title,
.hero.is-danger .light-palette .document .topic-title,
.light-palette .document .hero.is-danger .topic-title {
  color: #fff;
}
.hero.is-danger .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-danger .subtitle a:not(.button),
.hero.is-danger .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-danger .navbar-menu {
    background-color: #e45649;
  }
}
.hero.is-danger .navbar-item,
.hero.is-danger .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-danger a.navbar-item:hover, .hero.is-danger a.navbar-item.is-active,
.hero.is-danger .navbar-link:hover,
.hero.is-danger .navbar-link.is-active {
  background-color: #e14133;
  color: #fff;
}
.hero.is-danger .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-danger .tabs a:hover {
  opacity: 1;
}
.hero.is-danger .tabs li.is-active a {
  color: #e45649 !important;
  opacity: 1;
}
.hero.is-danger .tabs.is-boxed a, .hero.is-danger .tabs.is-toggle a {
  color: #fff;
}
.hero.is-danger .tabs.is-boxed a:hover, .hero.is-danger .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-danger .tabs.is-boxed li.is-active a, .hero.is-danger .tabs.is-boxed li.is-active a:hover, .hero.is-danger .tabs.is-toggle li.is-active a, .hero.is-danger .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #e45649;
}
.hero.is-danger.is-bold {
  background-image: linear-gradient(141deg, #e61425 0%, #e45649 71%, #ec7f5b 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-danger.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #e61425 0%, #e45649 71%, #ec7f5b 100%);
  }
}
.hero.is-redish {
  background-color: #ca1243;
  color: #fff;
}
.hero.is-redish a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-redish strong {
  color: inherit;
}
.hero.is-redish .title, .hero.is-redish .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-redish .topic-title,
.hero.is-redish .dark-palette .content .topic-title,
.dark-palette .content .hero.is-redish .topic-title,
.hero.is-redish .dark-palette .document .topic-title,
.dark-palette .document .hero.is-redish .topic-title, .hero.is-redish .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-redish .topic-title,
.hero.is-redish .light-palette .content .topic-title,
.light-palette .content .hero.is-redish .topic-title,
.hero.is-redish .light-palette .document .topic-title,
.light-palette .document .hero.is-redish .topic-title {
  color: #fff;
}
.hero.is-redish .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-redish .subtitle a:not(.button),
.hero.is-redish .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-redish .navbar-menu {
    background-color: #ca1243;
  }
}
.hero.is-redish .navbar-item,
.hero.is-redish .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-redish a.navbar-item:hover, .hero.is-redish a.navbar-item.is-active,
.hero.is-redish .navbar-link:hover,
.hero.is-redish .navbar-link.is-active {
  background-color: #b2103b;
  color: #fff;
}
.hero.is-redish .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-redish .tabs a:hover {
  opacity: 1;
}
.hero.is-redish .tabs li.is-active a {
  color: #ca1243 !important;
  opacity: 1;
}
.hero.is-redish .tabs.is-boxed a, .hero.is-redish .tabs.is-toggle a {
  color: #fff;
}
.hero.is-redish .tabs.is-boxed a:hover, .hero.is-redish .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-redish .tabs.is-boxed li.is-active a, .hero.is-redish .tabs.is-boxed li.is-active a:hover, .hero.is-redish .tabs.is-toggle li.is-active a, .hero.is-redish .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #ca1243;
}
.hero.is-redish.is-bold {
  background-image: linear-gradient(141deg, #a3054a 0%, #ca1243 71%, #e70d23 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-redish.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #a3054a 0%, #ca1243 71%, #e70d23 100%);
  }
}
.hero.is-blueish {
  background-color: #a3c0ff;
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-blueish a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-blueish strong {
  color: inherit;
}
.hero.is-blueish .title, .hero.is-blueish .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-blueish .topic-title,
.hero.is-blueish .dark-palette .content .topic-title,
.dark-palette .content .hero.is-blueish .topic-title,
.hero.is-blueish .dark-palette .document .topic-title,
.dark-palette .document .hero.is-blueish .topic-title, .hero.is-blueish .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-blueish .topic-title,
.hero.is-blueish .light-palette .content .topic-title,
.light-palette .content .hero.is-blueish .topic-title,
.hero.is-blueish .light-palette .document .topic-title,
.light-palette .document .hero.is-blueish .topic-title {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-blueish .subtitle {
  color: rgba(0, 0, 0, 0.9);
}
.hero.is-blueish .subtitle a:not(.button),
.hero.is-blueish .subtitle strong {
  color: rgba(0, 0, 0, 0.7);
}
@media screen and (max-width: 1023px) {
  .hero.is-blueish .navbar-menu {
    background-color: #a3c0ff;
  }
}
.hero.is-blueish .navbar-item,
.hero.is-blueish .navbar-link {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-blueish a.navbar-item:hover, .hero.is-blueish a.navbar-item.is-active,
.hero.is-blueish .navbar-link:hover,
.hero.is-blueish .navbar-link.is-active {
  background-color: #8aafff;
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-blueish .tabs a {
  color: rgba(0, 0, 0, 0.7);
  opacity: 0.9;
}
.hero.is-blueish .tabs a:hover {
  opacity: 1;
}
.hero.is-blueish .tabs li.is-active a {
  color: #a3c0ff !important;
  opacity: 1;
}
.hero.is-blueish .tabs.is-boxed a, .hero.is-blueish .tabs.is-toggle a {
  color: rgba(0, 0, 0, 0.7);
}
.hero.is-blueish .tabs.is-boxed a:hover, .hero.is-blueish .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-blueish .tabs.is-boxed li.is-active a, .hero.is-blueish .tabs.is-boxed li.is-active a:hover, .hero.is-blueish .tabs.is-toggle li.is-active a, .hero.is-blueish .tabs.is-toggle li.is-active a:hover {
  background-color: rgba(0, 0, 0, 0.7);
  border-color: rgba(0, 0, 0, 0.7);
  color: #a3c0ff;
}
.hero.is-blueish.is-bold {
  background-image: linear-gradient(141deg, #70b5ff 0%, #a3c0ff 71%, #bdc7ff 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-blueish.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #70b5ff 0%, #a3c0ff 71%, #bdc7ff 100%);
  }
}
.hero.is-pink {
  background-color: #f57fef;
  color: #fff;
}
.hero.is-pink a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-pink strong {
  color: inherit;
}
.hero.is-pink .title, .hero.is-pink .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-pink .topic-title,
.hero.is-pink .dark-palette .content .topic-title,
.dark-palette .content .hero.is-pink .topic-title,
.hero.is-pink .dark-palette .document .topic-title,
.dark-palette .document .hero.is-pink .topic-title, .hero.is-pink .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-pink .topic-title,
.hero.is-pink .light-palette .content .topic-title,
.light-palette .content .hero.is-pink .topic-title,
.hero.is-pink .light-palette .document .topic-title,
.light-palette .document .hero.is-pink .topic-title {
  color: #fff;
}
.hero.is-pink .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-pink .subtitle a:not(.button),
.hero.is-pink .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-pink .navbar-menu {
    background-color: #f57fef;
  }
}
.hero.is-pink .navbar-item,
.hero.is-pink .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-pink a.navbar-item:hover, .hero.is-pink a.navbar-item.is-active,
.hero.is-pink .navbar-link:hover,
.hero.is-pink .navbar-link.is-active {
  background-color: #f467ed;
  color: #fff;
}
.hero.is-pink .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-pink .tabs a:hover {
  opacity: 1;
}
.hero.is-pink .tabs li.is-active a {
  color: #f57fef !important;
  opacity: 1;
}
.hero.is-pink .tabs.is-boxed a, .hero.is-pink .tabs.is-toggle a {
  color: #fff;
}
.hero.is-pink .tabs.is-boxed a:hover, .hero.is-pink .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-pink .tabs.is-boxed li.is-active a, .hero.is-pink .tabs.is-boxed li.is-active a:hover, .hero.is-pink .tabs.is-toggle li.is-active a, .hero.is-pink .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #f57fef;
}
.hero.is-pink.is-bold {
  background-image: linear-gradient(141deg, #e646fb 0%, #f57fef 71%, #fa94e4 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-pink.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #e646fb 0%, #f57fef 71%, #fa94e4 100%);
  }
}
.hero.is-gold {
  background-color: #c18401;
  color: #fff;
}
.hero.is-gold a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-gold strong {
  color: inherit;
}
.hero.is-gold .title, .hero.is-gold .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-gold .topic-title,
.hero.is-gold .dark-palette .content .topic-title,
.dark-palette .content .hero.is-gold .topic-title,
.hero.is-gold .dark-palette .document .topic-title,
.dark-palette .document .hero.is-gold .topic-title, .hero.is-gold .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-gold .topic-title,
.hero.is-gold .light-palette .content .topic-title,
.light-palette .content .hero.is-gold .topic-title,
.hero.is-gold .light-palette .document .topic-title,
.light-palette .document .hero.is-gold .topic-title {
  color: #fff;
}
.hero.is-gold .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-gold .subtitle a:not(.button),
.hero.is-gold .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-gold .navbar-menu {
    background-color: #c18401;
  }
}
.hero.is-gold .navbar-item,
.hero.is-gold .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-gold a.navbar-item:hover, .hero.is-gold a.navbar-item.is-active,
.hero.is-gold .navbar-link:hover,
.hero.is-gold .navbar-link.is-active {
  background-color: #a77301;
  color: #fff;
}
.hero.is-gold .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-gold .tabs a:hover {
  opacity: 1;
}
.hero.is-gold .tabs li.is-active a {
  color: #c18401 !important;
  opacity: 1;
}
.hero.is-gold .tabs.is-boxed a, .hero.is-gold .tabs.is-toggle a {
  color: #fff;
}
.hero.is-gold .tabs.is-boxed a:hover, .hero.is-gold .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-gold .tabs.is-boxed li.is-active a, .hero.is-gold .tabs.is-boxed li.is-active a:hover, .hero.is-gold .tabs.is-toggle li.is-active a, .hero.is-gold .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #c18401;
}
.hero.is-gold.is-bold {
  background-image: linear-gradient(141deg, #8f4a00 0%, #c18401 71%, #dbba00 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-gold.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #8f4a00 0%, #c18401 71%, #dbba00 100%);
  }
}
.hero.is-greenish {
  background-color: #5ea14f;
  color: #fff;
}
.hero.is-greenish a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-greenish strong {
  color: inherit;
}
.hero.is-greenish .title, .hero.is-greenish .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-greenish .topic-title,
.hero.is-greenish .dark-palette .content .topic-title,
.dark-palette .content .hero.is-greenish .topic-title,
.hero.is-greenish .dark-palette .document .topic-title,
.dark-palette .document .hero.is-greenish .topic-title, .hero.is-greenish .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-greenish .topic-title,
.hero.is-greenish .light-palette .content .topic-title,
.light-palette .content .hero.is-greenish .topic-title,
.hero.is-greenish .light-palette .document .topic-title,
.light-palette .document .hero.is-greenish .topic-title {
  color: #fff;
}
.hero.is-greenish .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-greenish .subtitle a:not(.button),
.hero.is-greenish .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-greenish .navbar-menu {
    background-color: #5ea14f;
  }
}
.hero.is-greenish .navbar-item,
.hero.is-greenish .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-greenish a.navbar-item:hover, .hero.is-greenish a.navbar-item.is-active,
.hero.is-greenish .navbar-link:hover,
.hero.is-greenish .navbar-link.is-active {
  background-color: #549047;
  color: #fff;
}
.hero.is-greenish .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-greenish .tabs a:hover {
  opacity: 1;
}
.hero.is-greenish .tabs li.is-active a {
  color: #5ea14f !important;
  opacity: 1;
}
.hero.is-greenish .tabs.is-boxed a, .hero.is-greenish .tabs.is-toggle a {
  color: #fff;
}
.hero.is-greenish .tabs.is-boxed a:hover, .hero.is-greenish .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-greenish .tabs.is-boxed li.is-active a, .hero.is-greenish .tabs.is-boxed li.is-active a:hover, .hero.is-greenish .tabs.is-toggle li.is-active a, .hero.is-greenish .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #5ea14f;
}
.hero.is-greenish.is-bold {
  background-image: linear-gradient(141deg, #528835 0%, #5ea14f 71%, #56b455 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-greenish.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #528835 0%, #5ea14f 71%, #56b455 100%);
  }
}
.hero.is-blood {
  background-color: #39040c;
  color: #fff;
}
.hero.is-blood a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
.hero.is-blood strong {
  color: inherit;
}
.hero.is-blood .title, .hero.is-blood .dark-palette #search-results .topic-title, .dark-palette #search-results .hero.is-blood .topic-title,
.hero.is-blood .dark-palette .content .topic-title,
.dark-palette .content .hero.is-blood .topic-title,
.hero.is-blood .dark-palette .document .topic-title,
.dark-palette .document .hero.is-blood .topic-title, .hero.is-blood .light-palette #search-results .topic-title, .light-palette #search-results .hero.is-blood .topic-title,
.hero.is-blood .light-palette .content .topic-title,
.light-palette .content .hero.is-blood .topic-title,
.hero.is-blood .light-palette .document .topic-title,
.light-palette .document .hero.is-blood .topic-title {
  color: #fff;
}
.hero.is-blood .subtitle {
  color: rgba(255, 255, 255, 0.9);
}
.hero.is-blood .subtitle a:not(.button),
.hero.is-blood .subtitle strong {
  color: #fff;
}
@media screen and (max-width: 1023px) {
  .hero.is-blood .navbar-menu {
    background-color: #39040c;
  }
}
.hero.is-blood .navbar-item,
.hero.is-blood .navbar-link {
  color: rgba(255, 255, 255, 0.7);
}
.hero.is-blood a.navbar-item:hover, .hero.is-blood a.navbar-item.is-active,
.hero.is-blood .navbar-link:hover,
.hero.is-blood .navbar-link.is-active {
  background-color: #210207;
  color: #fff;
}
.hero.is-blood .tabs a {
  color: #fff;
  opacity: 0.9;
}
.hero.is-blood .tabs a:hover {
  opacity: 1;
}
.hero.is-blood .tabs li.is-active a {
  color: #39040c !important;
  opacity: 1;
}
.hero.is-blood .tabs.is-boxed a, .hero.is-blood .tabs.is-toggle a {
  color: #fff;
}
.hero.is-blood .tabs.is-boxed a:hover, .hero.is-blood .tabs.is-toggle a:hover {
  background-color: rgba(13, 17, 23, 0.1);
}
.hero.is-blood .tabs.is-boxed li.is-active a, .hero.is-blood .tabs.is-boxed li.is-active a:hover, .hero.is-blood .tabs.is-toggle li.is-active a, .hero.is-blood .tabs.is-toggle li.is-active a:hover {
  background-color: #fff;
  border-color: #fff;
  color: #39040c;
}
.hero.is-blood.is-bold {
  background-image: linear-gradient(141deg, #0a0003 0%, #39040c 71%, #530503 100%);
}
@media screen and (max-width: 768px) {
  .hero.is-blood.is-bold .navbar-menu {
    background-image: linear-gradient(141deg, #0a0003 0%, #39040c 71%, #530503 100%);
  }
}
.hero.is-small .hero-body {
  padding: 1.5rem;
}
@media screen and (min-width: 769px), print {
  .hero.is-medium .hero-body {
    padding: 9rem 4.5rem;
  }
}
@media screen and (min-width: 769px), print {
  .hero.is-large .hero-body {
    padding: 18rem 6rem;
  }
}
.hero.is-halfheight .hero-body, .hero.is-fullheight .hero-body, .hero.is-fullheight-with-navbar .hero-body {
  align-items: center;
  display: flex;
}
.hero.is-halfheight .hero-body > .container, .hero.is-fullheight .hero-body > .container, .hero.is-fullheight-with-navbar .hero-body > .container {
  flex-grow: 1;
  flex-shrink: 1;
}
.hero.is-halfheight {
  min-height: 50vh;
}
.hero.is-fullheight {
  min-height: 100vh;
}

.hero-video {
  overflow: hidden;
}
.hero-video video {
  left: 50%;
  min-height: 100%;
  min-width: 100%;
  position: absolute;
  top: 50%;
  transform: translate3d(-50%, -50%, 0);
}
.hero-video.is-transparent {
  opacity: 0.3;
}
@media screen and (max-width: 768px) {
  .hero-video {
    display: none;
  }
}

.hero-buttons {
  margin-top: 1.5rem;
}
@media screen and (max-width: 768px) {
  .hero-buttons .button {
    display: flex;
  }
  .hero-buttons .button:not(:last-child) {
    margin-bottom: 0.75rem;
  }
}
@media screen and (min-width: 769px), print {
  .hero-buttons {
    display: flex;
    justify-content: center;
  }
  .hero-buttons .button:not(:last-child) {
    margin-right: 1.5rem;
  }
}

.hero-head,
.hero-foot {
  flex-grow: 0;
  flex-shrink: 0;
}

.hero-body {
  flex-grow: 1;
  flex-shrink: 0;
  padding: 3rem 1.5rem;
}
@media screen and (min-width: 769px), print {
  .hero-body {
    padding: 3rem 3rem;
  }
}

.section {
  padding: 3rem 1.5rem;
}
@media screen and (min-width: 1024px) {
  .section {
    padding: 3rem 3rem;
  }
  .section.is-medium {
    padding: 9rem 4.5rem;
  }
  .section.is-large {
    padding: 18rem 6rem;
  }
}

.footer {
  background-color: whitesmoke;
  padding: 3rem 1.5rem 6rem;
}

/*
 * Palette component
 */
@font-face {
  font-family: "fontello";
  src: url("../font/fontello.eot?76914136");
  src: url("../font/fontello.eot?76914136#iefix") format("embedded-opentype"), url("../font/fontello.woff2?76914136") format("woff2"), url("../font/fontello.woff?76914136") format("woff"), url("../font/fontello.ttf?76914136") format("truetype"), url("../font/fontello.svg?76914136#fontello") format("svg");
  font-weight: normal;
  font-style: normal;
}
/* Chrome hack: SVG is rendered more smooth in Windozze. 100% magic, uncomment if you need it. */
/* Note, that will break hinting! In other OS-es font will be not as sharp as it could be */
/*
@media screen and (-webkit-min-device-pixel-ratio:0) {
  @font-face {
    font-family: 'fontello';
    src: url('../font/fontello.svg?76914136#fontello') format('svg');
  }
}
*/
[class^=icon-]:before, [class*=" icon-"]:before {
  font-family: "fontello";
  font-style: normal;
  font-weight: normal;
  speak: never;
  display: inline-block;
  text-decoration: inherit;
  width: 1em;
  margin-right: 0.2em;
  text-align: center;
  /* opacity: .8; */
  /* For safety - reset parent styles, that can break glyph codes*/
  font-variant: normal;
  text-transform: none;
  /* fix buttons height, for twitter bootstrap */
  line-height: 1em;
  /* Animation center compensation - margins should be symmetric */
  /* remove if not needed */
  margin-left: 0.2em;
  /* you can be more comfortable with increased icons size */
  /* font-size: 120%; */
  /* Font smoothing. That was taken from TWBS */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  /* Uncomment for 3D effect */
  /* text-shadow: 1px 1px 1px rgba(127, 127, 127, 0.3); */
}

.icon-glass:before {
  content: "\e800";
}

/* '' */
.icon-music:before {
  content: "\e801";
}

/* '' */
.icon-search:before {
  content: "\e802";
}

/* '' */
.icon-heart:before {
  content: "\e803";
}

/* '' */
.icon-heart-empty:before {
  content: "\e804";
}

/* '' */
.icon-star:before {
  content: "\e805";
}

/* '' */
.icon-star-empty:before {
  content: "\e806";
}

/* '' */
.icon-video:before {
  content: "\e807";
}

/* '' */
.icon-videocam:before {
  content: "\e808";
}

/* '' */
.icon-picture:before {
  content: "\e809";
}

/* '' */
.icon-camera:before {
  content: "\e80a";
}

/* '' */
.icon-th-large:before {
  content: "\e80b";
}

/* '' */
.icon-th:before {
  content: "\e80c";
}

/* '' */
.icon-th-list:before {
  content: "\e80d";
}

/* '' */
.icon-ok:before {
  content: "\e80e";
}

/* '' */
.icon-ok-circled:before {
  content: "\e80f";
}

/* '' */
.icon-ok-circled2:before {
  content: "\e810";
}

/* '' */
.icon-cancel:before {
  content: "\e811";
}

/* '' */
.icon-cancel-circled:before {
  content: "\e812";
}

/* '' */
.icon-cancel-circled2:before {
  content: "\e813";
}

/* '' */
.icon-plus:before {
  content: "\e814";
}

/* '' */
.icon-plus-circled:before {
  content: "\e815";
}

/* '' */
.icon-minus:before {
  content: "\e816";
}

/* '' */
.icon-minus-circled:before {
  content: "\e817";
}

/* '' */
.icon-help-circled:before {
  content: "\e818";
}

/* '' */
.icon-info-circled:before {
  content: "\e819";
}

/* '' */
.icon-home:before {
  content: "\e81a";
}

/* '' */
.icon-link:before {
  content: "\e81b";
}

/* '' */
.icon-attach:before {
  content: "\e81c";
}

/* '' */
.icon-lock:before {
  content: "\e81d";
}

/* '' */
.icon-lock-open:before {
  content: "\e81e";
}

/* '' */
.icon-pin:before {
  content: "\e81f";
}

/* '' */
.icon-tag:before {
  content: "\e820";
}

/* '' */
.icon-tags:before {
  content: "\e821";
}

/* '' */
.icon-bookmark:before {
  content: "\e822";
}

/* '' */
.icon-flag:before {
  content: "\e823";
}

/* '' */
.icon-download:before {
  content: "\e824";
}

/* '' */
.icon-upload:before {
  content: "\e825";
}

/* '' */
.icon-export:before {
  content: "\e826";
}

/* '' */
.icon-pencil:before {
  content: "\e827";
}

/* '' */
.icon-edit:before {
  content: "\e828";
}

/* '' */
.icon-attention:before {
  content: "\e829";
}

/* '' */
.icon-attention-circled:before {
  content: "\e82a";
}

/* '' */
.icon-doc:before {
  content: "\e82b";
}

/* '' */
.icon-folder:before {
  content: "\e82c";
}

/* '' */
.icon-folder-open:before {
  content: "\e82d";
}

/* '' */
.icon-cog:before {
  content: "\e82e";
}

/* '' */
.icon-cog-alt:before {
  content: "\e82f";
}

/* '' */
.icon-wrench:before {
  content: "\e830";
}

/* '' */
.icon-login:before {
  content: "\e831";
}

/* '' */
.icon-logout:before {
  content: "\e832";
}

/* '' */
.icon-clock:before {
  content: "\e833";
}

/* '' */
.icon-down-circled2:before {
  content: "\e834";
}

/* '' */
.icon-up-circled2:before {
  content: "\e835";
}

/* '' */
.icon-down-dir:before {
  content: "\e836";
}

/* '' */
.icon-up-dir:before {
  content: "\e837";
}

/* '' */
.icon-left-dir:before {
  content: "\e838";
}

/* '' */
.icon-right-dir:before {
  content: "\e839";
}

/* '' */
.icon-down-open:before {
  content: "\e83a";
}

/* '' */
.icon-left-open:before {
  content: "\e83b";
}

/* '' */
.icon-right-open:before {
  content: "\e83c";
}

/* '' */
.icon-up-open:before {
  content: "\e83d";
}

/* '' */
.icon-down-big:before {
  content: "\e83e";
}

/* '' */
.icon-left-big:before {
  content: "\e83f";
}

/* '' */
.icon-firefox:before {
  content: "\e840";
}

/* '' */
.icon-chrome:before {
  content: "\e841";
}

/* '' */
.icon-opera:before {
  content: "\e842";
}

/* '' */
.icon-ie:before {
  content: "\e843";
}

/* '' */
.icon-right-big:before {
  content: "\e844";
}

/* '' */
.icon-up-big:before {
  content: "\e845";
}

/* '' */
.icon-award:before {
  content: "\e846";
}

/* '' */
.icon-inbox:before {
  content: "\e847";
}

/* '' */
.icon-globe:before {
  content: "\e848";
}

/* '' */
.icon-cloud:before {
  content: "\e849";
}

/* '' */
.icon-check:before {
  content: "\e84a";
}

/* '' */
.icon-asterisk:before {
  content: "\e84b";
}

/* '' */
.icon-lemon:before {
  content: "\e84c";
}

/* '' */
.icon-github-circled-1:before {
  content: "\e84d";
}

/* '' */
.icon-duckduckgo:before {
  content: "\e84e";
}

/* '' */
.icon-terminal-1:before {
  content: "\e84f";
}

/* '' */
.icon-code:before {
  content: "\e850";
}

/* '' */
.icon-ok-1:before {
  content: "\e851";
}

/* '' */
.icon-ok-circle:before {
  content: "\e852";
}

/* '' */
.icon-cancel-1:before {
  content: "\e853";
}

/* '' */
.icon-cancel-circle:before {
  content: "\e854";
}

/* '' */
.icon-plus-circle:before {
  content: "\e855";
}

/* '' */
.icon-minus-circle:before {
  content: "\e856";
}

/* '' */
.icon-tag-1:before {
  content: "\e857";
}

/* '' */
.icon-attention-1:before {
  content: "\e858";
}

/* '' */
.icon-comment:before {
  content: "\e859";
}

/* '' */
.icon-cog-1:before {
  content: "\e85a";
}

/* '' */
.icon-rss-alt:before {
  content: "\e85b";
}

/* '' */
.icon-mail:before {
  content: "\e85c";
}

/* '' */
.icon-emo-happy:before {
  content: "\e85d";
}

/* '' */
.icon-emo-wink:before {
  content: "\e85e";
}

/* '' */
.icon-emo-wink2:before {
  content: "\e85f";
}

/* '' */
.icon-emo-unhappy:before {
  content: "\e860";
}

/* '' */
.icon-emo-sleep:before {
  content: "\e861";
}

/* '' */
.icon-emo-thumbsup:before {
  content: "\e862";
}

/* '' */
.icon-emo-devil:before {
  content: "\e863";
}

/* '' */
.icon-emo-surprised:before {
  content: "\e864";
}

/* '' */
.icon-emo-tongue:before {
  content: "\e865";
}

/* '' */
.icon-emo-coffee:before {
  content: "\e866";
}

/* '' */
.icon-emo-sunglasses:before {
  content: "\e867";
}

/* '' */
.icon-emo-displeased:before {
  content: "\e868";
}

/* '' */
.icon-marquee:before {
  content: "\e869";
}

/* '' */
.icon-emo-beer:before {
  content: "\e86a";
}

/* '' */
.icon-emo-grin:before {
  content: "\e86b";
}

/* '' */
.icon-emo-angry:before {
  content: "\e86c";
}

/* '' */
.icon-emo-saint:before {
  content: "\e86d";
}

/* '' */
.icon-emo-cry:before {
  content: "\e86e";
}

/* '' */
.icon-emo-shoot:before {
  content: "\e86f";
}

/* '' */
.icon-emo-squint:before {
  content: "\e870";
}

/* '' */
.icon-emo-laugh:before {
  content: "\e871";
}

/* '' */
.icon-spin1:before {
  content: "\e872";
}

/* '' */
.icon-spin2:before {
  content: "\e873";
}

/* '' */
.icon-spin6:before {
  content: "\e874";
}

/* '' */
.icon-spin5:before {
  content: "\e875";
}

/* '' */
.icon-spin4:before {
  content: "\e876";
}

/* '' */
.icon-spin3:before {
  content: "\e877";
}

/* '' */
.icon-star-half:before {
  content: "\e878";
}

/* '' */
.icon-user:before {
  content: "\e879";
}

/* '' */
.icon-users:before {
  content: "\e87a";
}

/* '' */
.icon-eye-off:before {
  content: "\e87b";
}

/* '' */
.icon-eye:before {
  content: "\e87c";
}

/* '' */
.icon-print:before {
  content: "\e87d";
}

/* '' */
.icon-forward:before {
  content: "\e87e";
}

/* '' */
.icon-thumbs-down:before {
  content: "\e87f";
}

/* '' */
.icon-thumbs-up:before {
  content: "\e880";
}

/* '' */
.icon-retweet:before {
  content: "\e881";
}

/* '' */
.icon-comment-1:before {
  content: "\e882";
}

/* '' */
.icon-chat:before {
  content: "\e883";
}

/* '' */
.icon-bell:before {
  content: "\e884";
}

/* '' */
.icon-location:before {
  content: "\e885";
}

/* '' */
.icon-trash-empty:before {
  content: "\e886";
}

/* '' */
.icon-phone:before {
  content: "\e887";
}

/* '' */
.icon-headphones:before {
  content: "\e888";
}

/* '' */
.icon-volume-up:before {
  content: "\e889";
}

/* '' */
.icon-volume-down:before {
  content: "\e88a";
}

/* '' */
.icon-volume-off:before {
  content: "\e88b";
}

/* '' */
.icon-calendar:before {
  content: "\e88c";
}

/* '' */
.icon-basket:before {
  content: "\e88d";
}

/* '' */
.icon-resize-small:before {
  content: "\e88e";
}

/* '' */
.icon-resize-vertical:before {
  content: "\e88f";
}

/* '' */
.icon-resize-horizontal:before {
  content: "\e890";
}

/* '' */
.icon-zoom-in:before {
  content: "\e891";
}

/* '' */
.icon-zoom-out:before {
  content: "\e892";
}

/* '' */
.icon-block:before {
  content: "\e893";
}

/* '' */
.icon-resize-full:before {
  content: "\e894";
}

/* '' */
.icon-down-hand:before {
  content: "\e895";
}

/* '' */
.icon-up-hand:before {
  content: "\e896";
}

/* '' */
.icon-left-hand:before {
  content: "\e897";
}

/* '' */
.icon-right-hand:before {
  content: "\e898";
}

/* '' */
.icon-shuffle:before {
  content: "\e899";
}

/* '' */
.icon-ccw:before {
  content: "\e89a";
}

/* '' */
.icon-arrows-cw:before {
  content: "\e89b";
}

/* '' */
.icon-cw:before {
  content: "\e89c";
}

/* '' */
.icon-play:before {
  content: "\e89d";
}

/* '' */
.icon-play-circled2:before {
  content: "\e89e";
}

/* '' */
.icon-stop:before {
  content: "\e89f";
}

/* '' */
.icon-pause:before {
  content: "\e8a0";
}

/* '' */
.icon-to-end:before {
  content: "\e8a1";
}

/* '' */
.icon-to-end-alt:before {
  content: "\e8a2";
}

/* '' */
.icon-to-start:before {
  content: "\e8a3";
}

/* '' */
.icon-flight:before {
  content: "\e8a4";
}

/* '' */
.icon-umbrella:before {
  content: "\e8a5";
}

/* '' */
.icon-flash:before {
  content: "\e8a6";
}

/* '' */
.icon-signal:before {
  content: "\e8a7";
}

/* '' */
.icon-target:before {
  content: "\e8a8";
}

/* '' */
.icon-eject:before {
  content: "\e8a9";
}

/* '' */
.icon-fast-bw:before {
  content: "\e8aa";
}

/* '' */
.icon-fast-fw:before {
  content: "\e8ab";
}

/* '' */
.icon-to-start-alt:before {
  content: "\e8ac";
}

/* '' */
.icon-leaf:before {
  content: "\e8ad";
}

/* '' */
.icon-font:before {
  content: "\e8ae";
}

/* '' */
.icon-bold:before {
  content: "\e8af";
}

/* '' */
.icon-scissors:before {
  content: "\e8b0";
}

/* '' */
.icon-italic:before {
  content: "\e8b1";
}

/* '' */
.icon-briefcase:before {
  content: "\e8b2";
}

/* '' */
.icon-text-height:before {
  content: "\e8b3";
}

/* '' */
.icon-text-width:before {
  content: "\e8b4";
}

/* '' */
.icon-align-left:before {
  content: "\e8b5";
}

/* '' */
.icon-align-center:before {
  content: "\e8b6";
}

/* '' */
.icon-align-right:before {
  content: "\e8b7";
}

/* '' */
.icon-list:before {
  content: "\e8b8";
}

/* '' */
.icon-align-justify:before {
  content: "\e8b9";
}

/* '' */
.icon-indent-left:before {
  content: "\e8ba";
}

/* '' */
.icon-indent-right:before {
  content: "\e8bb";
}

/* '' */
.icon-tint:before {
  content: "\e8bc";
}

/* '' */
.icon-adjust:before {
  content: "\e8bd";
}

/* '' */
.icon-book:before {
  content: "\e8be";
}

/* '' */
.icon-barcode:before {
  content: "\e8bf";
}

/* '' */
.icon-qrcode:before {
  content: "\e8c0";
}

/* '' */
.icon-list-alt:before {
  content: "\e8c1";
}

/* '' */
.icon-off:before {
  content: "\e8c2";
}

/* '' */
.icon-road:before {
  content: "\e8c3";
}

/* '' */
.icon-key:before {
  content: "\e8c4";
}

/* '' */
.icon-megaphone:before {
  content: "\e8c5";
}

/* '' */
.icon-floppy:before {
  content: "\e8c6";
}

/* '' */
.icon-credit-card:before {
  content: "\e8c7";
}

/* '' */
.icon-chart-bar:before {
  content: "\e8c8";
}

/* '' */
.icon-magnet:before {
  content: "\e8c9";
}

/* '' */
.icon-fire:before {
  content: "\e8ca";
}

/* '' */
.icon-gift:before {
  content: "\e8cb";
}

/* '' */
.icon-truck:before {
  content: "\e8cc";
}

/* '' */
.icon-hammer:before {
  content: "\e8cd";
}

/* '' */
.icon-flow-split:before {
  content: "\e8ce";
}

/* '' */
.icon-flow-merge:before {
  content: "\e8cf";
}

/* '' */
.icon-flow-parallel:before {
  content: "\e8d0";
}

/* '' */
.icon-flow-cross:before {
  content: "\e8d1";
}

/* '' */
.icon-certificate-outline:before {
  content: "\e8d2";
}

/* '' */
.icon-certificate-1:before {
  content: "\e8d3";
}

/* '' */
.icon-infinity:before {
  content: "\e8d4";
}

/* '' */
.icon-key-1:before {
  content: "\e8d5";
}

/* '' */
.icon-key-outline:before {
  content: "\e8d6";
}

/* '' */
.icon-infinity-outline:before {
  content: "\e8d7";
}

/* '' */
.icon-moon-1:before {
  content: "\e8d8";
}

/* '' */
.icon-sun-filled:before {
  content: "\e8d9";
}

/* '' */
.icon-sun-1:before {
  content: "\e8da";
}

/* '' */
.icon-flash-1:before {
  content: "\e8db";
}

/* '' */
.icon-flash-outline:before {
  content: "\e8dc";
}

/* '' */
.icon-cloud-1:before {
  content: "\e8dd";
}

/* '' */
.icon-check-1:before {
  content: "\e8de";
}

/* '' */
.icon-check-outline:before {
  content: "\e8df";
}

/* '' */
.icon-power:before {
  content: "\e8e0";
}

/* '' */
.icon-power-outline:before {
  content: "\e8e1";
}

/* '' */
.icon-arrows-cw-1:before {
  content: "\e8e2";
}

/* '' */
.icon-loop:before {
  content: "\e8e3";
}

/* '' */
.icon-cw-1:before {
  content: "\e8e4";
}

/* '' */
.icon-record:before {
  content: "\e8e5";
}

/* '' */
.icon-record-outline:before {
  content: "\e8e6";
}

/* '' */
.icon-contrast:before {
  content: "\e8e7";
}

/* '' */
.icon-resize-normal:before {
  content: "\e8e8";
}

/* '' */
.icon-resize-full-1:before {
  content: "\e8e9";
}

/* '' */
.icon-quote-left-1:before {
  content: "\e8ea";
}

/* '' */
.icon-quote-right-1:before {
  content: "\e8eb";
}

/* '' */
.icon-quote-left-alt:before {
  content: "\e8ec";
}

/* '' */
.icon-quote-right-alt:before {
  content: "\e8ed";
}

/* '' */
.icon-ok-2:before {
  content: "\e8ee";
}

/* '' */
.icon-cancel-2:before {
  content: "\e8ef";
}

/* '' */
.icon-cancel-circle-1:before {
  content: "\e8f0";
}

/* '' */
.icon-ok-circle-1:before {
  content: "\e8f1";
}

/* '' */
.icon-plus-1:before {
  content: "\e8f2";
}

/* '' */
.icon-plus-circle-1:before {
  content: "\e8f3";
}

/* '' */
.icon-minus-1:before {
  content: "\e8f4";
}

/* '' */
.icon-minus-circle-1:before {
  content: "\e8f5";
}

/* '' */
.icon-info-1:before {
  content: "\e8f6";
}

/* '' */
.icon-undo:before {
  content: "\e8f7";
}

/* '' */
.icon-cog-2:before {
  content: "\e8f8";
}

/* '' */
.icon-at-1:before {
  content: "\e8f9";
}

/* '' */
.icon-hash:before {
  content: "\e8fa";
}

/* '' */
.icon-pilcrow:before {
  content: "\e8fb";
}

/* '' */
.icon-list-nested:before {
  content: "\e8fc";
}

/* '' */
.icon-list-1:before {
  content: "\e8fd";
}

/* '' */
.icon-layers-alt:before {
  content: "\e8fe";
}

/* '' */
.icon-layers:before {
  content: "\e8ff";
}

/* '' */
.icon-sun-inv:before {
  content: "\e900";
}

/* '' */
.icon-sun-2:before {
  content: "\e901";
}

/* '' */
.icon-moon-inv:before {
  content: "\e902";
}

/* '' */
.icon-moon-2:before {
  content: "\e903";
}

/* '' */
.icon-fahrenheit:before {
  content: "\e904";
}

/* '' */
.icon-celcius:before {
  content: "\e905";
}

/* '' */
.icon-github-1:before {
  content: "\e906";
}

/* '' */
.icon-link-1:before {
  content: "\e907";
}

/* '' */
.icon-chat-1:before {
  content: "\e908";
}

/* '' */
.icon-light-up:before {
  content: "\e909";
}

/* '' */
.icon-adjust-1:before {
  content: "\e90a";
}

/* '' */
.icon-light-down:before {
  content: "\e90b";
}

/* '' */
.icon-sphinx:before {
  content: "\e90c";
}

/* '' */
.icon-bulma:before {
  content: "\e90d";
}

/* '' */
.icon-move:before {
  content: "\f047";
}

/* '' */
.icon-link-ext:before {
  content: "\f08e";
}

/* '' */
.icon-check-empty:before {
  content: "\f096";
}

/* '' */
.icon-bookmark-empty:before {
  content: "\f097";
}

/* '' */
.icon-phone-squared:before {
  content: "\f098";
}

/* '' */
.icon-twitter:before {
  content: "\f099";
}

/* '' */
.icon-facebook:before {
  content: "\f09a";
}

/* '' */
.icon-github-circled:before {
  content: "\f09b";
}

/* '' */
.icon-rss:before {
  content: "\f09e";
}

/* '' */
.icon-hdd:before {
  content: "\f0a0";
}

/* '' */
.icon-certificate:before {
  content: "\f0a3";
}

/* '' */
.icon-left-circled:before {
  content: "\f0a8";
}

/* '' */
.icon-right-circled:before {
  content: "\f0a9";
}

/* '' */
.icon-up-circled:before {
  content: "\f0aa";
}

/* '' */
.icon-down-circled:before {
  content: "\f0ab";
}

/* '' */
.icon-tasks:before {
  content: "\f0ae";
}

/* '' */
.icon-filter:before {
  content: "\f0b0";
}

/* '' */
.icon-resize-full-alt:before {
  content: "\f0b2";
}

/* '' */
.icon-beaker:before {
  content: "\f0c3";
}

/* '' */
.icon-docs:before {
  content: "\f0c5";
}

/* '' */
.icon-blank:before {
  content: "\f0c8";
}

/* '' */
.icon-menu:before {
  content: "\f0c9";
}

/* '' */
.icon-list-bullet:before {
  content: "\f0ca";
}

/* '' */
.icon-list-numbered:before {
  content: "\f0cb";
}

/* '' */
.icon-strike:before {
  content: "\f0cc";
}

/* '' */
.icon-underline:before {
  content: "\f0cd";
}

/* '' */
.icon-table:before {
  content: "\f0ce";
}

/* '' */
.icon-magic:before {
  content: "\f0d0";
}

/* '' */
.icon-pinterest-circled:before {
  content: "\f0d2";
}

/* '' */
.icon-pinterest-squared:before {
  content: "\f0d3";
}

/* '' */
.icon-gplus-squared:before {
  content: "\f0d4";
}

/* '' */
.icon-gplus:before {
  content: "\f0d5";
}

/* '' */
.icon-money:before {
  content: "\f0d6";
}

/* '' */
.icon-columns:before {
  content: "\f0db";
}

/* '' */
.icon-sort:before {
  content: "\f0dc";
}

/* '' */
.icon-sort-down:before {
  content: "\f0dd";
}

/* '' */
.icon-sort-up:before {
  content: "\f0de";
}

/* '' */
.icon-mail-alt:before {
  content: "\f0e0";
}

/* '' */
.icon-linkedin:before {
  content: "\f0e1";
}

/* '' */
.icon-gauge:before {
  content: "\f0e4";
}

/* '' */
.icon-comment-empty:before {
  content: "\f0e5";
}

/* '' */
.icon-chat-empty:before {
  content: "\f0e6";
}

/* '' */
.icon-sitemap:before {
  content: "\f0e8";
}

/* '' */
.icon-paste:before {
  content: "\f0ea";
}

/* '' */
.icon-lightbulb:before {
  content: "\f0eb";
}

/* '' */
.icon-exchange:before {
  content: "\f0ec";
}

/* '' */
.icon-download-cloud:before {
  content: "\f0ed";
}

/* '' */
.icon-upload-cloud:before {
  content: "\f0ee";
}

/* '' */
.icon-user-md:before {
  content: "\f0f0";
}

/* '' */
.icon-stethoscope:before {
  content: "\f0f1";
}

/* '' */
.icon-suitcase:before {
  content: "\f0f2";
}

/* '' */
.icon-bell-alt:before {
  content: "\f0f3";
}

/* '' */
.icon-coffee:before {
  content: "\f0f4";
}

/* '' */
.icon-food:before {
  content: "\f0f5";
}

/* '' */
.icon-doc-text:before {
  content: "\f0f6";
}

/* '' */
.icon-building:before {
  content: "\f0f7";
}

/* '' */
.icon-hospital:before {
  content: "\f0f8";
}

/* '' */
.icon-ambulance:before {
  content: "\f0f9";
}

/* '' */
.icon-medkit:before {
  content: "\f0fa";
}

/* '' */
.icon-fighter-jet:before {
  content: "\f0fb";
}

/* '' */
.icon-beer:before {
  content: "\f0fc";
}

/* '' */
.icon-h-sigh:before {
  content: "\f0fd";
}

/* '' */
.icon-plus-squared:before {
  content: "\f0fe";
}

/* '' */
.icon-angle-double-left:before {
  content: "\f100";
}

/* '' */
.icon-angle-double-right:before {
  content: "\f101";
}

/* '' */
.icon-angle-double-up:before {
  content: "\f102";
}

/* '' */
.icon-angle-double-down:before {
  content: "\f103";
}

/* '' */
.icon-angle-left:before {
  content: "\f104";
}

/* '' */
.icon-angle-right:before {
  content: "\f105";
}

/* '' */
.icon-angle-up:before {
  content: "\f106";
}

/* '' */
.icon-angle-down:before {
  content: "\f107";
}

/* '' */
.icon-desktop:before {
  content: "\f108";
}

/* '' */
.icon-laptop:before {
  content: "\f109";
}

/* '' */
.icon-tablet:before {
  content: "\f10a";
}

/* '' */
.icon-mobile:before {
  content: "\f10b";
}

/* '' */
.icon-circle-empty:before {
  content: "\f10c";
}

/* '' */
.icon-quote-left:before {
  content: "\f10d";
}

/* '' */
.icon-quote-right:before {
  content: "\f10e";
}

/* '' */
.icon-spinner:before {
  content: "\f110";
}

/* '' */
.icon-circle:before {
  content: "\f111";
}

/* '' */
.icon-reply:before {
  content: "\f112";
}

/* '' */
.icon-github:before {
  content: "\f113";
}

/* '' */
.icon-folder-empty:before {
  content: "\f114";
}

/* '' */
.icon-folder-open-empty:before {
  content: "\f115";
}

/* '' */
.icon-smile:before {
  content: "\f118";
}

/* '' */
.icon-frown:before {
  content: "\f119";
}

/* '' */
.icon-meh:before {
  content: "\f11a";
}

/* '' */
.icon-gamepad:before {
  content: "\f11b";
}

/* '' */
.icon-keyboard:before {
  content: "\f11c";
}

/* '' */
.icon-flag-empty:before {
  content: "\f11d";
}

/* '' */
.icon-flag-checkered:before {
  content: "\f11e";
}

/* '' */
.icon-terminal:before {
  content: "\f120";
}

/* '' */
.icon-code-1:before {
  content: "\f121";
}

/* '' */
.icon-reply-all:before {
  content: "\f122";
}

/* '' */
.icon-star-half-alt:before {
  content: "\f123";
}

/* '' */
.icon-direction:before {
  content: "\f124";
}

/* '' */
.icon-crop:before {
  content: "\f125";
}

/* '' */
.icon-fork:before {
  content: "\f126";
}

/* '' */
.icon-unlink:before {
  content: "\f127";
}

/* '' */
.icon-help:before {
  content: "\f128";
}

/* '' */
.icon-info:before {
  content: "\f129";
}

/* '' */
.icon-attention-alt:before {
  content: "\f12a";
}

/* '' */
.icon-superscript:before {
  content: "\f12b";
}

/* '' */
.icon-subscript:before {
  content: "\f12c";
}

/* '' */
.icon-eraser:before {
  content: "\f12d";
}

/* '' */
.icon-puzzle:before {
  content: "\f12e";
}

/* '' */
.icon-mic:before {
  content: "\f130";
}

/* '' */
.icon-mute:before {
  content: "\f131";
}

/* '' */
.icon-shield:before {
  content: "\f132";
}

/* '' */
.icon-calendar-empty:before {
  content: "\f133";
}

/* '' */
.icon-extinguisher:before {
  content: "\f134";
}

/* '' */
.icon-maxcdn:before {
  content: "\f136";
}

/* '' */
.icon-angle-circled-left:before {
  content: "\f137";
}

/* '' */
.icon-angle-circled-right:before {
  content: "\f138";
}

/* '' */
.icon-angle-circled-up:before {
  content: "\f139";
}

/* '' */
.icon-angle-circled-down:before {
  content: "\f13a";
}

/* '' */
.icon-html5:before {
  content: "\f13b";
}

/* '' */
.icon-css3:before {
  content: "\f13c";
}

/* '' */
.icon-anchor:before {
  content: "\f13d";
}

/* '' */
.icon-lock-open-alt:before {
  content: "\f13e";
}

/* '' */
.icon-bullseye:before {
  content: "\f140";
}

/* '' */
.icon-ellipsis:before {
  content: "\f141";
}

/* '' */
.icon-ellipsis-vert:before {
  content: "\f142";
}

/* '' */
.icon-rss-squared:before {
  content: "\f143";
}

/* '' */
.icon-play-circled:before {
  content: "\f144";
}

/* '' */
.icon-ticket:before {
  content: "\f145";
}

/* '' */
.icon-minus-squared:before {
  content: "\f146";
}

/* '' */
.icon-minus-squared-alt:before {
  content: "\f147";
}

/* '' */
.icon-level-up:before {
  content: "\f148";
}

/* '' */
.icon-level-down:before {
  content: "\f149";
}

/* '' */
.icon-ok-squared:before {
  content: "\f14a";
}

/* '' */
.icon-pencil-squared:before {
  content: "\f14b";
}

/* '' */
.icon-link-ext-alt:before {
  content: "\f14c";
}

/* '' */
.icon-export-alt:before {
  content: "\f14d";
}

/* '' */
.icon-compass:before {
  content: "\f14e";
}

/* '' */
.icon-expand:before {
  content: "\f150";
}

/* '' */
.icon-collapse:before {
  content: "\f151";
}

/* '' */
.icon-expand-right:before {
  content: "\f152";
}

/* '' */
.icon-euro:before {
  content: "\f153";
}

/* '' */
.icon-pound:before {
  content: "\f154";
}

/* '' */
.icon-dollar:before {
  content: "\f155";
}

/* '' */
.icon-rupee:before {
  content: "\f156";
}

/* '' */
.icon-yen:before {
  content: "\f157";
}

/* '' */
.icon-rouble:before {
  content: "\f158";
}

/* '' */
.icon-won:before {
  content: "\f159";
}

/* '' */
.icon-bitcoin:before {
  content: "\f15a";
}

/* '' */
.icon-doc-inv:before {
  content: "\f15b";
}

/* '' */
.icon-doc-text-inv:before {
  content: "\f15c";
}

/* '' */
.icon-sort-name-up:before {
  content: "\f15d";
}

/* '' */
.icon-sort-name-down:before {
  content: "\f15e";
}

/* '' */
.icon-sort-alt-up:before {
  content: "\f160";
}

/* '' */
.icon-sort-alt-down:before {
  content: "\f161";
}

/* '' */
.icon-sort-number-up:before {
  content: "\f162";
}

/* '' */
.icon-sort-number-down:before {
  content: "\f163";
}

/* '' */
.icon-thumbs-up-alt:before {
  content: "\f164";
}

/* '' */
.icon-thumbs-down-alt:before {
  content: "\f165";
}

/* '' */
.icon-youtube-squared:before {
  content: "\f166";
}

/* '' */
.icon-youtube:before {
  content: "\f167";
}

/* '' */
.icon-xing:before {
  content: "\f168";
}

/* '' */
.icon-xing-squared:before {
  content: "\f169";
}

/* '' */
.icon-youtube-play:before {
  content: "\f16a";
}

/* '' */
.icon-dropbox:before {
  content: "\f16b";
}

/* '' */
.icon-stackoverflow:before {
  content: "\f16c";
}

/* '' */
.icon-instagram:before {
  content: "\f16d";
}

/* '' */
.icon-flickr:before {
  content: "\f16e";
}

/* '' */
.icon-adn:before {
  content: "\f170";
}

/* '' */
.icon-bitbucket:before {
  content: "\f171";
}

/* '' */
.icon-bitbucket-squared:before {
  content: "\f172";
}

/* '' */
.icon-tumblr:before {
  content: "\f173";
}

/* '' */
.icon-tumblr-squared:before {
  content: "\f174";
}

/* '' */
.icon-down:before {
  content: "\f175";
}

/* '' */
.icon-up:before {
  content: "\f176";
}

/* '' */
.icon-left:before {
  content: "\f177";
}

/* '' */
.icon-right:before {
  content: "\f178";
}

/* '' */
.icon-apple:before {
  content: "\f179";
}

/* '' */
.icon-windows:before {
  content: "\f17a";
}

/* '' */
.icon-android:before {
  content: "\f17b";
}

/* '' */
.icon-linux:before {
  content: "\f17c";
}

/* '' */
.icon-dribbble:before {
  content: "\f17d";
}

/* '' */
.icon-skype:before {
  content: "\f17e";
}

/* '' */
.icon-foursquare:before {
  content: "\f180";
}

/* '' */
.icon-trello:before {
  content: "\f181";
}

/* '' */
.icon-female:before {
  content: "\f182";
}

/* '' */
.icon-male:before {
  content: "\f183";
}

/* '' */
.icon-gittip:before {
  content: "\f184";
}

/* '' */
.icon-sun:before {
  content: "\f185";
}

/* '' */
.icon-moon:before {
  content: "\f186";
}

/* '' */
.icon-box:before {
  content: "\f187";
}

/* '' */
.icon-bug:before {
  content: "\f188";
}

/* '' */
.icon-vkontakte:before {
  content: "\f189";
}

/* '' */
.icon-weibo:before {
  content: "\f18a";
}

/* '' */
.icon-renren:before {
  content: "\f18b";
}

/* '' */
.icon-pagelines:before {
  content: "\f18c";
}

/* '' */
.icon-stackexchange:before {
  content: "\f18d";
}

/* '' */
.icon-right-circled2:before {
  content: "\f18e";
}

/* '' */
.icon-left-circled2:before {
  content: "\f190";
}

/* '' */
.icon-collapse-left:before {
  content: "\f191";
}

/* '' */
.icon-dot-circled:before {
  content: "\f192";
}

/* '' */
.icon-wheelchair:before {
  content: "\f193";
}

/* '' */
.icon-vimeo-squared:before {
  content: "\f194";
}

/* '' */
.icon-try:before {
  content: "\f195";
}

/* '' */
.icon-plus-squared-alt:before {
  content: "\f196";
}

/* '' */
.icon-space-shuttle:before {
  content: "\f197";
}

/* '' */
.icon-slack:before {
  content: "\f198";
}

/* '' */
.icon-mail-squared:before {
  content: "\f199";
}

/* '' */
.icon-wordpress:before {
  content: "\f19a";
}

/* '' */
.icon-openid:before {
  content: "\f19b";
}

/* '' */
.icon-bank:before {
  content: "\f19c";
}

/* '' */
.icon-graduation-cap:before {
  content: "\f19d";
}

/* '' */
.icon-yahoo:before {
  content: "\f19e";
}

/* '' */
.icon-google:before {
  content: "\f1a0";
}

/* '' */
.icon-reddit:before {
  content: "\f1a1";
}

/* '' */
.icon-reddit-squared:before {
  content: "\f1a2";
}

/* '' */
.icon-stumbleupon-circled:before {
  content: "\f1a3";
}

/* '' */
.icon-stumbleupon:before {
  content: "\f1a4";
}

/* '' */
.icon-delicious:before {
  content: "\f1a5";
}

/* '' */
.icon-digg:before {
  content: "\f1a6";
}

/* '' */
.icon-pied-piper-squared:before {
  content: "\f1a7";
}

/* '' */
.icon-pied-piper-alt:before {
  content: "\f1a8";
}

/* '' */
.icon-drupal:before {
  content: "\f1a9";
}

/* '' */
.icon-joomla:before {
  content: "\f1aa";
}

/* '' */
.icon-language:before {
  content: "\f1ab";
}

/* '' */
.icon-fax:before {
  content: "\f1ac";
}

/* '' */
.icon-building-filled:before {
  content: "\f1ad";
}

/* '' */
.icon-child:before {
  content: "\f1ae";
}

/* '' */
.icon-paw:before {
  content: "\f1b0";
}

/* '' */
.icon-spoon:before {
  content: "\f1b1";
}

/* '' */
.icon-cube:before {
  content: "\f1b2";
}

/* '' */
.icon-cubes:before {
  content: "\f1b3";
}

/* '' */
.icon-behance:before {
  content: "\f1b4";
}

/* '' */
.icon-behance-squared:before {
  content: "\f1b5";
}

/* '' */
.icon-steam:before {
  content: "\f1b6";
}

/* '' */
.icon-steam-squared:before {
  content: "\f1b7";
}

/* '' */
.icon-recycle:before {
  content: "\f1b8";
}

/* '' */
.icon-cab:before {
  content: "\f1b9";
}

/* '' */
.icon-taxi:before {
  content: "\f1ba";
}

/* '' */
.icon-tree:before {
  content: "\f1bb";
}

/* '' */
.icon-spotify:before {
  content: "\f1bc";
}

/* '' */
.icon-deviantart:before {
  content: "\f1bd";
}

/* '' */
.icon-soundcloud:before {
  content: "\f1be";
}

/* '' */
.icon-database:before {
  content: "\f1c0";
}

/* '' */
.icon-file-pdf:before {
  content: "\f1c1";
}

/* '' */
.icon-file-word:before {
  content: "\f1c2";
}

/* '' */
.icon-file-excel:before {
  content: "\f1c3";
}

/* '' */
.icon-file-powerpoint:before {
  content: "\f1c4";
}

/* '' */
.icon-file-image:before {
  content: "\f1c5";
}

/* '' */
.icon-file-archive:before {
  content: "\f1c6";
}

/* '' */
.icon-file-audio:before {
  content: "\f1c7";
}

/* '' */
.icon-file-video:before {
  content: "\f1c8";
}

/* '' */
.icon-file-code:before {
  content: "\f1c9";
}

/* '' */
.icon-vine:before {
  content: "\f1ca";
}

/* '' */
.icon-codeopen:before {
  content: "\f1cb";
}

/* '' */
.icon-jsfiddle:before {
  content: "\f1cc";
}

/* '' */
.icon-lifebuoy:before {
  content: "\f1cd";
}

/* '' */
.icon-circle-notch:before {
  content: "\f1ce";
}

/* '' */
.icon-rebel:before {
  content: "\f1d0";
}

/* '' */
.icon-empire:before {
  content: "\f1d1";
}

/* '' */
.icon-git-squared:before {
  content: "\f1d2";
}

/* '' */
.icon-git:before {
  content: "\f1d3";
}

/* '' */
.icon-hacker-news:before {
  content: "\f1d4";
}

/* '' */
.icon-tencent-weibo:before {
  content: "\f1d5";
}

/* '' */
.icon-qq:before {
  content: "\f1d6";
}

/* '' */
.icon-wechat:before {
  content: "\f1d7";
}

/* '' */
.icon-paper-plane:before {
  content: "\f1d8";
}

/* '' */
.icon-paper-plane-empty:before {
  content: "\f1d9";
}

/* '' */
.icon-history:before {
  content: "\f1da";
}

/* '' */
.icon-circle-thin:before {
  content: "\f1db";
}

/* '' */
.icon-header:before {
  content: "\f1dc";
}

/* '' */
.icon-paragraph:before {
  content: "\f1dd";
}

/* '' */
.icon-sliders:before {
  content: "\f1de";
}

/* '' */
.icon-share:before {
  content: "\f1e0";
}

/* '' */
.icon-share-squared:before {
  content: "\f1e1";
}

/* '' */
.icon-bomb:before {
  content: "\f1e2";
}

/* '' */
.icon-soccer-ball:before {
  content: "\f1e3";
}

/* '' */
.icon-tty:before {
  content: "\f1e4";
}

/* '' */
.icon-binoculars:before {
  content: "\f1e5";
}

/* '' */
.icon-plug:before {
  content: "\f1e6";
}

/* '' */
.icon-slideshare:before {
  content: "\f1e7";
}

/* '' */
.icon-twitch:before {
  content: "\f1e8";
}

/* '' */
.icon-yelp:before {
  content: "\f1e9";
}

/* '' */
.icon-newspaper:before {
  content: "\f1ea";
}

/* '' */
.icon-wifi:before {
  content: "\f1eb";
}

/* '' */
.icon-calc:before {
  content: "\f1ec";
}

/* '' */
.icon-paypal:before {
  content: "\f1ed";
}

/* '' */
.icon-gwallet:before {
  content: "\f1ee";
}

/* '' */
.icon-cc-visa:before {
  content: "\f1f0";
}

/* '' */
.icon-cc-mastercard:before {
  content: "\f1f1";
}

/* '' */
.icon-cc-discover:before {
  content: "\f1f2";
}

/* '' */
.icon-cc-amex:before {
  content: "\f1f3";
}

/* '' */
.icon-cc-paypal:before {
  content: "\f1f4";
}

/* '' */
.icon-cc-stripe:before {
  content: "\f1f5";
}

/* '' */
.icon-bell-off:before {
  content: "\f1f6";
}

/* '' */
.icon-bell-off-empty:before {
  content: "\f1f7";
}

/* '' */
.icon-trash:before {
  content: "\f1f8";
}

/* '' */
.icon-copyright:before {
  content: "\f1f9";
}

/* '' */
.icon-at:before {
  content: "\f1fa";
}

/* '' */
.icon-eyedropper:before {
  content: "\f1fb";
}

/* '' */
.icon-brush:before {
  content: "\f1fc";
}

/* '' */
.icon-birthday:before {
  content: "\f1fd";
}

/* '' */
.icon-chart-area:before {
  content: "\f1fe";
}

/* '' */
.icon-chart-pie:before {
  content: "\f200";
}

/* '' */
.icon-chart-line:before {
  content: "\f201";
}

/* '' */
.icon-lastfm:before {
  content: "\f202";
}

/* '' */
.icon-lastfm-squared:before {
  content: "\f203";
}

/* '' */
.icon-toggle-off:before {
  content: "\f204";
}

/* '' */
.icon-toggle-on:before {
  content: "\f205";
}

/* '' */
.icon-bicycle:before {
  content: "\f206";
}

/* '' */
.icon-bus:before {
  content: "\f207";
}

/* '' */
.icon-ioxhost:before {
  content: "\f208";
}

/* '' */
.icon-angellist:before {
  content: "\f209";
}

/* '' */
.icon-cc:before {
  content: "\f20a";
}

/* '' */
.icon-shekel:before {
  content: "\f20b";
}

/* '' */
.icon-meanpath:before {
  content: "\f20c";
}

/* '' */
.icon-buysellads:before {
  content: "\f20d";
}

/* '' */
.icon-connectdevelop:before {
  content: "\f20e";
}

/* '' */
.icon-dashcube:before {
  content: "\f210";
}

/* '' */
.icon-forumbee:before {
  content: "\f211";
}

/* '' */
.icon-leanpub:before {
  content: "\f212";
}

/* '' */
.icon-sellsy:before {
  content: "\f213";
}

/* '' */
.icon-shirtsinbulk:before {
  content: "\f214";
}

/* '' */
.icon-simplybuilt:before {
  content: "\f215";
}

/* '' */
.icon-skyatlas:before {
  content: "\f216";
}

/* '' */
.icon-cart-plus:before {
  content: "\f217";
}

/* '' */
.icon-cart-arrow-down:before {
  content: "\f218";
}

/* '' */
.icon-diamond:before {
  content: "\f219";
}

/* '' */
.icon-ship:before {
  content: "\f21a";
}

/* '' */
.icon-user-secret:before {
  content: "\f21b";
}

/* '' */
.icon-motorcycle:before {
  content: "\f21c";
}

/* '' */
.icon-street-view:before {
  content: "\f21d";
}

/* '' */
.icon-heartbeat:before {
  content: "\f21e";
}

/* '' */
.icon-venus:before {
  content: "\f221";
}

/* '' */
.icon-mars:before {
  content: "\f222";
}

/* '' */
.icon-mercury:before {
  content: "\f223";
}

/* '' */
.icon-transgender:before {
  content: "\f224";
}

/* '' */
.icon-transgender-alt:before {
  content: "\f225";
}

/* '' */
.icon-venus-double:before {
  content: "\f226";
}

/* '' */
.icon-mars-double:before {
  content: "\f227";
}

/* '' */
.icon-venus-mars:before {
  content: "\f228";
}

/* '' */
.icon-mars-stroke:before {
  content: "\f229";
}

/* '' */
.icon-mars-stroke-v:before {
  content: "\f22a";
}

/* '' */
.icon-mars-stroke-h:before {
  content: "\f22b";
}

/* '' */
.icon-neuter:before {
  content: "\f22c";
}

/* '' */
.icon-genderless:before {
  content: "\f22d";
}

/* '' */
.icon-facebook-official:before {
  content: "\f230";
}

/* '' */
.icon-pinterest:before {
  content: "\f231";
}

/* '' */
.icon-whatsapp:before {
  content: "\f232";
}

/* '' */
.icon-server:before {
  content: "\f233";
}

/* '' */
.icon-user-plus:before {
  content: "\f234";
}

/* '' */
.icon-user-times:before {
  content: "\f235";
}

/* '' */
.icon-bed:before {
  content: "\f236";
}

/* '' */
.icon-viacoin:before {
  content: "\f237";
}

/* '' */
.icon-train:before {
  content: "\f238";
}

/* '' */
.icon-subway:before {
  content: "\f239";
}

/* '' */
.icon-medium:before {
  content: "\f23a";
}

/* '' */
.icon-y-combinator:before {
  content: "\f23b";
}

/* '' */
.icon-optin-monster:before {
  content: "\f23c";
}

/* '' */
.icon-opencart:before {
  content: "\f23d";
}

/* '' */
.icon-expeditedssl:before {
  content: "\f23e";
}

/* '' */
.icon-battery-4:before {
  content: "\f240";
}

/* '' */
.icon-battery-3:before {
  content: "\f241";
}

/* '' */
.icon-battery-2:before {
  content: "\f242";
}

/* '' */
.icon-battery-1:before {
  content: "\f243";
}

/* '' */
.icon-battery-0:before {
  content: "\f244";
}

/* '' */
.icon-mouse-pointer:before {
  content: "\f245";
}

/* '' */
.icon-i-cursor:before {
  content: "\f246";
}

/* '' */
.icon-object-group:before {
  content: "\f247";
}

/* '' */
.icon-object-ungroup:before {
  content: "\f248";
}

/* '' */
.icon-sticky-note:before {
  content: "\f249";
}

/* '' */
.icon-sticky-note-o:before {
  content: "\f24a";
}

/* '' */
.icon-cc-jcb:before {
  content: "\f24b";
}

/* '' */
.icon-cc-diners-club:before {
  content: "\f24c";
}

/* '' */
.icon-clone:before {
  content: "\f24d";
}

/* '' */
.icon-balance-scale:before {
  content: "\f24e";
}

/* '' */
.icon-hourglass-o:before {
  content: "\f250";
}

/* '' */
.icon-hourglass-1:before {
  content: "\f251";
}

/* '' */
.icon-hourglass-2:before {
  content: "\f252";
}

/* '' */
.icon-hourglass-3:before {
  content: "\f253";
}

/* '' */
.icon-hourglass:before {
  content: "\f254";
}

/* '' */
.icon-hand-grab-o:before {
  content: "\f255";
}

/* '' */
.icon-hand-paper-o:before {
  content: "\f256";
}

/* '' */
.icon-hand-scissors-o:before {
  content: "\f257";
}

/* '' */
.icon-hand-lizard-o:before {
  content: "\f258";
}

/* '' */
.icon-hand-spock-o:before {
  content: "\f259";
}

/* '' */
.icon-hand-pointer-o:before {
  content: "\f25a";
}

/* '' */
.icon-hand-peace-o:before {
  content: "\f25b";
}

/* '' */
.icon-trademark:before {
  content: "\f25c";
}

/* '' */
.icon-registered:before {
  content: "\f25d";
}

/* '' */
.icon-creative-commons:before {
  content: "\f25e";
}

/* '' */
.icon-gg:before {
  content: "\f260";
}

/* '' */
.icon-gg-circle:before {
  content: "\f261";
}

/* '' */
.icon-tripadvisor:before {
  content: "\f262";
}

/* '' */
.icon-odnoklassniki:before {
  content: "\f263";
}

/* '' */
.icon-odnoklassniki-square:before {
  content: "\f264";
}

/* '' */
.icon-get-pocket:before {
  content: "\f265";
}

/* '' */
.icon-wikipedia-w:before {
  content: "\f266";
}

/* '' */
.icon-safari:before {
  content: "\f267";
}

/* '' */
.icon-chrome-1:before {
  content: "\f268";
}

/* '' */
.icon-firefox-1:before {
  content: "\f269";
}

/* '' */
.icon-opera-1:before {
  content: "\f26a";
}

/* '' */
.icon-internet-explorer:before {
  content: "\f26b";
}

/* '' */
.icon-television:before {
  content: "\f26c";
}

/* '' */
.icon-contao:before {
  content: "\f26d";
}

/* '' */
.icon-500px:before {
  content: "\f26e";
}

/* '' */
.icon-amazon:before {
  content: "\f270";
}

/* '' */
.icon-calendar-plus-o:before {
  content: "\f271";
}

/* '' */
.icon-calendar-minus-o:before {
  content: "\f272";
}

/* '' */
.icon-calendar-times-o:before {
  content: "\f273";
}

/* '' */
.icon-calendar-check-o:before {
  content: "\f274";
}

/* '' */
.icon-industry:before {
  content: "\f275";
}

/* '' */
.icon-map-pin:before {
  content: "\f276";
}

/* '' */
.icon-map-signs:before {
  content: "\f277";
}

/* '' */
.icon-map-o:before {
  content: "\f278";
}

/* '' */
.icon-map:before {
  content: "\f279";
}

/* '' */
.icon-commenting:before {
  content: "\f27a";
}

/* '' */
.icon-commenting-o:before {
  content: "\f27b";
}

/* '' */
.icon-houzz:before {
  content: "\f27c";
}

/* '' */
.icon-vimeo:before {
  content: "\f27d";
}

/* '' */
.icon-black-tie:before {
  content: "\f27e";
}

/* '' */
.icon-fonticons:before {
  content: "\f280";
}

/* '' */
.icon-reddit-alien:before {
  content: "\f281";
}

/* '' */
.icon-edge:before {
  content: "\f282";
}

/* '' */
.icon-credit-card-alt:before {
  content: "\f283";
}

/* '' */
.icon-codiepie:before {
  content: "\f284";
}

/* '' */
.icon-modx:before {
  content: "\f285";
}

/* '' */
.icon-fort-awesome:before {
  content: "\f286";
}

/* '' */
.icon-usb:before {
  content: "\f287";
}

/* '' */
.icon-product-hunt:before {
  content: "\f288";
}

/* '' */
.icon-mixcloud:before {
  content: "\f289";
}

/* '' */
.icon-scribd:before {
  content: "\f28a";
}

/* '' */
.icon-pause-circle:before {
  content: "\f28b";
}

/* '' */
.icon-pause-circle-o:before {
  content: "\f28c";
}

/* '' */
.icon-stop-circle:before {
  content: "\f28d";
}

/* '' */
.icon-stop-circle-o:before {
  content: "\f28e";
}

/* '' */
.icon-shopping-bag:before {
  content: "\f290";
}

/* '' */
.icon-shopping-basket:before {
  content: "\f291";
}

/* '' */
.icon-hashtag:before {
  content: "\f292";
}

/* '' */
.icon-bluetooth:before {
  content: "\f293";
}

/* '' */
.icon-bluetooth-b:before {
  content: "\f294";
}

/* '' */
.icon-percent:before {
  content: "\f295";
}

/* '' */
.icon-gitlab:before {
  content: "\f296";
}

/* '' */
.icon-wpbeginner:before {
  content: "\f297";
}

/* '' */
.icon-wpforms:before {
  content: "\f298";
}

/* '' */
.icon-envira:before {
  content: "\f299";
}

/* '' */
.icon-universal-access:before {
  content: "\f29a";
}

/* '' */
.icon-wheelchair-alt:before {
  content: "\f29b";
}

/* '' */
.icon-question-circle-o:before {
  content: "\f29c";
}

/* '' */
.icon-blind:before {
  content: "\f29d";
}

/* '' */
.icon-audio-description:before {
  content: "\f29e";
}

/* '' */
.icon-volume-control-phone:before {
  content: "\f2a0";
}

/* '' */
.icon-braille:before {
  content: "\f2a1";
}

/* '' */
.icon-assistive-listening-systems:before {
  content: "\f2a2";
}

/* '' */
.icon-american-sign-language-interpreting:before {
  content: "\f2a3";
}

/* '' */
.icon-asl-interpreting:before {
  content: "\f2a4";
}

/* '' */
.icon-glide:before {
  content: "\f2a5";
}

/* '' */
.icon-glide-g:before {
  content: "\f2a6";
}

/* '' */
.icon-sign-language:before {
  content: "\f2a7";
}

/* '' */
.icon-low-vision:before {
  content: "\f2a8";
}

/* '' */
.icon-viadeo:before {
  content: "\f2a9";
}

/* '' */
.icon-viadeo-square:before {
  content: "\f2aa";
}

/* '' */
.icon-snapchat:before {
  content: "\f2ab";
}

/* '' */
.icon-snapchat-ghost:before {
  content: "\f2ac";
}

/* '' */
.icon-snapchat-square:before {
  content: "\f2ad";
}

/* '' */
.icon-pied-piper:before {
  content: "\f2ae";
}

/* '' */
.icon-first-order:before {
  content: "\f2b0";
}

/* '' */
.icon-yoast:before {
  content: "\f2b1";
}

/* '' */
.icon-themeisle:before {
  content: "\f2b2";
}

/* '' */
.icon-google-plus-circle:before {
  content: "\f2b3";
}

/* '' */
.icon-font-awesome:before {
  content: "\f2b4";
}

/* '' */
.icon-handshake-o:before {
  content: "\f2b5";
}

/* '' */
.icon-envelope-open:before {
  content: "\f2b6";
}

/* '' */
.icon-envelope-open-o:before {
  content: "\f2b7";
}

/* '' */
.icon-linode:before {
  content: "\f2b8";
}

/* '' */
.icon-address-book:before {
  content: "\f2b9";
}

/* '' */
.icon-address-book-o:before {
  content: "\f2ba";
}

/* '' */
.icon-address-card:before {
  content: "\f2bb";
}

/* '' */
.icon-address-card-o:before {
  content: "\f2bc";
}

/* '' */
.icon-user-circle:before {
  content: "\f2bd";
}

/* '' */
.icon-user-circle-o:before {
  content: "\f2be";
}

/* '' */
.icon-user-o:before {
  content: "\f2c0";
}

/* '' */
.icon-id-badge:before {
  content: "\f2c1";
}

/* '' */
.icon-id-card:before {
  content: "\f2c2";
}

/* '' */
.icon-id-card-o:before {
  content: "\f2c3";
}

/* '' */
.icon-quora:before {
  content: "\f2c4";
}

/* '' */
.icon-free-code-camp:before {
  content: "\f2c5";
}

/* '' */
.icon-telegram:before {
  content: "\f2c6";
}

/* '' */
.icon-thermometer:before {
  content: "\f2c7";
}

/* '' */
.icon-thermometer-3:before {
  content: "\f2c8";
}

/* '' */
.icon-thermometer-2:before {
  content: "\f2c9";
}

/* '' */
.icon-thermometer-quarter:before {
  content: "\f2ca";
}

/* '' */
.icon-thermometer-0:before {
  content: "\f2cb";
}

/* '' */
.icon-shower:before {
  content: "\f2cc";
}

/* '' */
.icon-bath:before {
  content: "\f2cd";
}

/* '' */
.icon-podcast:before {
  content: "\f2ce";
}

/* '' */
.icon-window-maximize:before {
  content: "\f2d0";
}

/* '' */
.icon-window-minimize:before {
  content: "\f2d1";
}

/* '' */
.icon-window-restore:before {
  content: "\f2d2";
}

/* '' */
.icon-window-close:before {
  content: "\f2d3";
}

/* '' */
.icon-window-close-o:before {
  content: "\f2d4";
}

/* '' */
.icon-bandcamp:before {
  content: "\f2d5";
}

/* '' */
.icon-grav:before {
  content: "\f2d6";
}

/* '' */
.icon-etsy:before {
  content: "\f2d7";
}

/* '' */
.icon-imdb:before {
  content: "\f2d8";
}

/* '' */
.icon-ravelry:before {
  content: "\f2d9";
}

/* '' */
.icon-eercast:before {
  content: "\f2da";
}

/* '' */
.icon-microchip:before {
  content: "\f2db";
}

/* '' */
.icon-snowflake-o:before {
  content: "\f2dc";
}

/* '' */
.icon-superpowers:before {
  content: "\f2dd";
}

/* '' */
.icon-wpexplorer:before {
  content: "\f2de";
}

/* '' */
.icon-meetup:before {
  content: "\f2e0";
}

/* '' */
.icon-github-squared:before {
  content: "\f300";
}

/* '' */
.icon-twitter-squared:before {
  content: "\f304";
}

/* '' */
.icon-github-text:before {
  content: "\f307";
}

/* '' */
.icon-facebook-squared:before {
  content: "\f308";
}

/* '' */
.icon-linkedin-squared:before {
  content: "\f30c";
}

/* '' */
.icon-win8:before {
  content: "\f325";
}

/* '' */
.icon-codepen:before {
  content: "\f32c";
}

/* '' */
/*
 * Icon component
 */
/*
 * General theme styles
 */
.dark-palette a {
  color: #a3c0ff;
}

.light-palette a {
  color: #4078f2;
}

.dark-palette a:hover {
  color: #a3c0ff;
}

.light-palette a:hover {
  color: #30529c;
}

.dark-palette body {
  background-color: #0d1117;
  color: #c9d1d9;
}

.light-palette body {
  background-color: #fafafa;
  color: #3e4551;
}

button.button.is-outlined:not(.dummy):focus:not(:hover) {
  background-color: inherit;
  border-color: inherit;
  color: inherit;
}

dl {
  overflow: auto;
}

.dark-palette input.input,
.dark-palette .select select,
.dark-palette .textarea {
  background-color: transparent;
  border-color: #3e4551;
  color: #c9d1d9;
}

.light-palette input.input,
.light-palette .select select,
.light-palette .textarea {
  background-color: transparent;
  border-color: #e5dcdc;
  color: #3e4551;
}

input.input:-ms-input-placeholder,
.select select:-ms-input-placeholder,
.textarea:-ms-input-placeholder {
  color: inherit;
}
input.input::-ms-input-placeholder,
.select select::-ms-input-placeholder,
.textarea::-ms-input-placeholder {
  color: inherit;
}
input.input::-webkit-input-placeholder,
.select select::-webkit-input-placeholder,
.textarea::-webkit-input-placeholder {
  color: inherit;
}
input.input::placeholder,
.select select::placeholder,
.textarea::placeholder {
  color: inherit;
  opacity: 1;
}

main {
  padding-bottom: 5rem;
}
.dark-palette main {
  background-color: #0d1117;
}

.light-palette main {
  background-color: #fafafa;
}

main .container .columns .column {
  padding: 1rem;
}

.dark-palette p {
  color: #c9d1d9;
}

.light-palette p {
  color: #3e4551;
}

span.icon > i {
  content: "";
  font-family: "fontello";
  font-weight: 100;
}

.dark-palette strong {
  color: #c9d1d9;
}

.light-palette strong {
  color: #3e4551;
}

div.is-primary,
main.is-primary,
section.is-primary,
.button.is-primary,
.card.is-primary,
.content.is-primary,
.document.is-primary,
.dropdown.is-primary,
.icon.is-primary,
.icon-text.is-primary,
.message.is-primary,
.navbar.is-primary,
.notification.is-primary,
.panel.is-primary,
.progress.is-primary,
.table.is-primary,
.tag.is-primary,
.tag:not(body).is-primary,
.title.is-primary {
  background-color: var(--primary);
}
div.is-primary, div.has-text-primary,
main.is-primary,
main.has-text-primary,
section.is-primary,
section.has-text-primary,
.button.is-primary,
.button.has-text-primary,
.card.is-primary,
.card.has-text-primary,
.content.is-primary,
.content.has-text-primary,
.document.is-primary,
.document.has-text-primary,
.dropdown.is-primary,
.dropdown.has-text-primary,
.icon.is-primary,
.icon.has-text-primary,
.icon-text.is-primary,
.icon-text.has-text-primary,
.message.is-primary,
.message.has-text-primary,
.navbar.is-primary,
.navbar.has-text-primary,
.notification.is-primary,
.notification.has-text-primary,
.panel.is-primary,
.panel.has-text-primary,
.progress.is-primary,
.progress.has-text-primary,
.table.is-primary,
.table.has-text-primary,
.tag.is-primary,
.tag.has-text-primary,
.tag:not(body).is-primary,
.tag:not(body).has-text-primary,
.title.is-primary,
.title.has-text-primary {
  color: var(--primary-invert);
}

/*
 * Navbar styles
 */
#light-switch {
  margin-top: 1.75rem;
}
#light-switch span.icon::after {
  position: absolute;
  visibility: visible;
}
.dark-palette #light-switch span.icon::after {
  content: "\e900";
  font-family: "fontello";
  font-weight: 100;
}

.light-palette #light-switch span.icon::after {
  content: "\e902";
  font-family: "fontello";
  font-weight: 100;
}

a.navbar-item.logo {
  min-height: 6rem;
  padding: 0.5rem 0.75rem;
}
a.navbar-item.logo img {
  height: 5rem;
  max-height: 5rem;
}

nav.container.breadcrumb {
  margin-top: 5rem;
}
.dark-palette nav.container.breadcrumb {
  background-color: #0d1117;
}

.light-palette nav.container.breadcrumb {
  background-color: #fafafa;
}

.dark-palette nav.container.breadcrumb li.is-active a {
  color: #c9d1d9;
}

.light-palette nav.container.breadcrumb li.is-active a {
  color: #3e4551;
}

nav.navbar div.navbar-menu div.navbar-brand a.navbar-item.logo:hover {
  background-color: transparent;
}

.breadcrumb-aside {
  font-size: 0.7rem;
  position: absolute;
}
.breadcrumb-aside span.icon {
  margin-top: -0.25rem;
}

/*
 * Bulma responsiveness configuration
 */
@media screen and (max-width: 1023px) {
  .container:not(.navbar-menu) {
    background-color: inherit;
    margin: 3rem;
  }
}

@media screen and (max-width: 1023px) {
  .navbar,
.navbar-end,
.navbar-menu,
.navbar-start {
    align-items: stretch;
    display: flex;
  }
}

@media screen and (max-width: 1023px) {
  .navbar-menu.container {
    background-color: inherit;
    display: flex;
    padding: 1.5rem;
  }
  .navbar-menu.container .navbar-end {
    justify-content: flex-end;
    margin-left: auto;
  }
  .navbar-menu.container .navbar-start {
    justify-content: flex-start;
    margin-right: auto;
  }
}

/*
 * Side menu styles
 */
aside.menu {
  margin-bottom: 5rem;
}
aside.menu li {
  font-size: small;
  line-height: 1.6;
}
aside.menu ul {
  list-style-type: none;
  padding-right: 0;
}
aside.menu ul li a::after {
  font-size: 0.75rem;
  margin-left: 0.5rem;
}
.dark-palette aside.menu ul li a::after {
  color: #a3c0ff;
}

.light-palette aside.menu ul li a::after {
  color: #4078f2;
}

aside.menu ul .toctree-l1 a::after {
  content: "\f097";
  font-family: "fontello";
  font-weight: 100;
}
aside.menu ul .toctree-l2 a::after {
  content: "\f104";
  font-family: "fontello";
  font-weight: 100;
}
aside.menu ul ul {
  margin-right: 1.6rem;
}
aside.menu .caption {
  font-weight: bold;
}

.toctree-l1 > a {
  font-weight: 700;
}
.toctree-l1 > a::after {
  font-weight: 100;
}

/*
 * Util component
 */
/*
 * Document component
 */
#search-results a.headerlink,
.content a.headerlink,
.document a.headerlink {
  position: absolute;
  visibility: hidden;
}
#search-results a.headerlink::after,
.content a.headerlink::after,
.document a.headerlink::after {
  font-size: 0.8em;
  left: 0;
  padding-right: 0.4em;
  position: inherit;
  top: 0.25rem;
  content: "\e907";
  font-family: "fontello";
  font-weight: 100;
  -moz-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  -o-transform: scale(-1, 1);
  -webkit-transform: scale(-1, 1);
  transform: scale(-1, 1);
}
#search-results aside.sidebar,
.content aside.sidebar,
.document aside.sidebar {
  float: right;
  margin: 0 1rem 2.5rem 2.5rem;
  max-width: 40%;
  padding: 1.5rem;
}
.dark-palette #search-results aside.sidebar,
.dark-palette .content aside.sidebar,
.dark-palette .document aside.sidebar {
  background-color: #121921;
}

.light-palette #search-results aside.sidebar,
.light-palette .content aside.sidebar,
.light-palette .document aside.sidebar {
  background-color: #faf0f0;
}

#search-results aside.sidebar dd,
#search-results dd,
#search-results .topic dd,
.content aside.sidebar dd,
.content dd,
.content .topic dd,
.document aside.sidebar dd,
.document dd,
.document .topic dd {
  border-left: 1px solid var(--primary);
  font-size: 14px;
  line-height: 26px;
  margin-left: 1rem;
  margin-top: 0.25rem;
  padding-left: 1rem;
}
#search-results code.download,
#search-results tt.download,
.content code.download,
.content tt.download,
.document code.download,
.document tt.download {
  background: inherit;
  border: inherit;
  color: inherit;
  font-family: inherit;
  font-size: inherit;
  font-weight: 400;
  padding: inherit;
  white-space: inherit;
}
#search-results code.download::before,
#search-results tt.download::before,
.content code.download::before,
.content tt.download::before,
.document code.download::before,
.document tt.download::before {
  padding-right: 0.5rem;
  content: "\e824";
  font-family: "fontello";
  font-weight: 100;
}
#search-results div.viewcode-block a.viewcode-back,
.content div.viewcode-block a.viewcode-back,
.document div.viewcode-block a.viewcode-back {
  font-size: 0;
  margin-right: 0.5rem;
  visibility: hidden;
}
#search-results div.viewcode-block a.viewcode-back::before,
.content div.viewcode-block a.viewcode-back::before,
.document div.viewcode-block a.viewcode-back::before {
  font-size: medium;
  font-weight: 100;
  position: relative;
  visibility: visible;
  content: "\f0f6  \f177";
  font-family: "fontello";
  font-weight: 100;
}
#search-results h1,
#search-results h2,
#search-results h3,
#search-results h4,
#search-results h5,
#search-results h6,
.content h1,
.content h2,
.content h3,
.content h4,
.content h5,
.content h6,
.document h1,
.document h2,
.document h3,
.document h4,
.document h5,
.document h6 {
  padding-bottom: 0.25em;
}
.dark-palette #search-results h1,
.dark-palette #search-results h2,
.dark-palette #search-results h3,
.dark-palette #search-results h4,
.dark-palette #search-results h5,
.dark-palette #search-results h6,
.dark-palette .content h1,
.dark-palette .content h2,
.dark-palette .content h3,
.dark-palette .content h4,
.dark-palette .content h5,
.dark-palette .content h6,
.dark-palette .document h1,
.dark-palette .document h2,
.dark-palette .document h3,
.dark-palette .document h4,
.dark-palette .document h5,
.dark-palette .document h6 {
  border-bottom: #3e4551 solid 1px;
  color: #faf0f0;
}

.light-palette #search-results h1,
.light-palette #search-results h2,
.light-palette #search-results h3,
.light-palette #search-results h4,
.light-palette #search-results h5,
.light-palette #search-results h6,
.light-palette .content h1,
.light-palette .content h2,
.light-palette .content h3,
.light-palette .content h4,
.light-palette .content h5,
.light-palette .content h6,
.light-palette .document h1,
.light-palette .document h2,
.light-palette .document h3,
.light-palette .document h4,
.light-palette .document h5,
.light-palette .document h6 {
  border-bottom: #e5dcdc solid 1px;
  color: #0d1117;
}

#search-results h1:hover a.headerlink::after,
#search-results h2:hover a.headerlink::after,
#search-results h3:hover a.headerlink::after,
#search-results h4:hover a.headerlink::after,
#search-results h5:hover a.headerlink::after,
#search-results h6:hover a.headerlink::after,
.content h1:hover a.headerlink::after,
.content h2:hover a.headerlink::after,
.content h3:hover a.headerlink::after,
.content h4:hover a.headerlink::after,
.content h5:hover a.headerlink::after,
.content h6:hover a.headerlink::after,
.document h1:hover a.headerlink::after,
.document h2:hover a.headerlink::after,
.document h3:hover a.headerlink::after,
.document h4:hover a.headerlink::after,
.document h5:hover a.headerlink::after,
.document h6:hover a.headerlink::after {
  opacity: 0.6;
  visibility: visible;
}
#search-results ol.loweralpha,
.content ol.loweralpha,
.document ol.loweralpha {
  list-style-type: lower-alpha;
}
#search-results ol.lowerroman,
.content ol.lowerroman,
.document ol.lowerroman {
  list-style-type: lower-roman;
}
#search-results ol.upperalpha,
.content ol.upperalpha,
.document ol.upperalpha {
  list-style-type: upper-alpha;
}
#search-results ol.upperroman,
.content ol.upperroman,
.document ol.upperroman {
  list-style-type: upper-roman;
}
#search-results section,
.content section,
.document section {
  display: block;
  overflow: hidden;
}
#search-results section:not(:first-child),
.content section:not(:first-child),
.document section:not(:first-child) {
  margin-top: 2rem;
}
#search-results table,
.content table,
.document table {
  display: block;
  max-width: 100%;
  overflow-x: auto;
  width: 100%;
}
#search-results table td,
.content table td,
.document table td {
  border: none;
}
.dark-palette #search-results table tr.row-odd,
.dark-palette .content table tr.row-odd,
.dark-palette .document table tr.row-odd {
  background-color: #121921;
}

.light-palette #search-results table tr.row-odd,
.light-palette .content table tr.row-odd,
.light-palette .document table tr.row-odd {
  background-color: #faf0f0;
}

#search-results ul li p:not(:last-child),
.content ul li p:not(:last-child),
.document ul li p:not(:last-child) {
  margin: 0;
}
#search-results ul.simple,
.content ul.simple,
.document ul.simple {
  list-style: circle outside;
}
.dark-palette #search-results .admonition,
.dark-palette .content .admonition,
.dark-palette .document .admonition {
  background-color: #121921;
  margin: 0.5rem;
}
.dark-palette #search-results .admonition p,
.dark-palette .content .admonition p,
.dark-palette .document .admonition p {
  background-color: rgba(62, 69, 81, 0.25);
  color: white;
  padding: 0 0.75rem 0.25rem 0.75rem;
}
.dark-palette #search-results .admonition p.admonition-title,
.dark-palette .content .admonition p.admonition-title,
.dark-palette .document .admonition p.admonition-title {
  padding-top: 0.5rem;
}
.dark-palette #search-results .admonition p.admonition-title::before,
.dark-palette .content .admonition p.admonition-title::before,
.dark-palette .document .admonition p.admonition-title::before {
  margin-right: 0.5rem;
}
.dark-palette #search-results .admonition p:first-child,
.dark-palette .content .admonition p:first-child,
.dark-palette .document .admonition p:first-child {
  border-radius: 4px 4px 0 0;
}
.dark-palette #search-results .admonition p:last-child,
.dark-palette .content .admonition p:last-child,
.dark-palette .document .admonition p:last-child {
  border-radius: 0 0 4px 4px;
}
.dark-palette #search-results .admonition p:not(:last-child),
.dark-palette .content .admonition p:not(:last-child),
.dark-palette .document .admonition p:not(:last-child) {
  margin: 0;
}
.dark-palette #search-results .admonition.attention p, .dark-palette #search-results .admonition.caution p, .dark-palette #search-results .admonition.warning p,
.dark-palette .content .admonition.attention p,
.dark-palette .content .admonition.caution p,
.dark-palette .content .admonition.warning p,
.dark-palette .document .admonition.attention p,
.dark-palette .document .admonition.caution p,
.dark-palette .document .admonition.warning p {
  background-color: rgba(255, 123, 0, 0.25);
}
.dark-palette #search-results .admonition.attention p.admonition-title, .dark-palette #search-results .admonition.caution p.admonition-title, .dark-palette #search-results .admonition.warning p.admonition-title,
.dark-palette .content .admonition.attention p.admonition-title,
.dark-palette .content .admonition.caution p.admonition-title,
.dark-palette .content .admonition.warning p.admonition-title,
.dark-palette .document .admonition.attention p.admonition-title,
.dark-palette .document .admonition.caution p.admonition-title,
.dark-palette .document .admonition.warning p.admonition-title {
  color: #ffb066;
}
.dark-palette #search-results .admonition.attention p.admonition-title::before, .dark-palette #search-results .admonition.caution p.admonition-title::before, .dark-palette #search-results .admonition.warning p.admonition-title::before,
.dark-palette .content .admonition.attention p.admonition-title::before,
.dark-palette .content .admonition.caution p.admonition-title::before,
.dark-palette .content .admonition.warning p.admonition-title::before,
.dark-palette .document .admonition.attention p.admonition-title::before,
.dark-palette .document .admonition.caution p.admonition-title::before,
.dark-palette .document .admonition.warning p.admonition-title::before {
  content: "\e829";
  font-family: "fontello";
  font-weight: 100;
}
.dark-palette #search-results .admonition.danger p, .dark-palette #search-results .admonition.error p,
.dark-palette .content .admonition.danger p,
.dark-palette .content .admonition.error p,
.dark-palette .document .admonition.danger p,
.dark-palette .document .admonition.error p {
  background-color: rgba(227, 28, 81, 0.25);
}
.dark-palette #search-results .admonition.danger p.admonition-title, .dark-palette #search-results .admonition.error p.admonition-title,
.dark-palette .content .admonition.danger p.admonition-title,
.dark-palette .content .admonition.error p.admonition-title,
.dark-palette .document .admonition.danger p.admonition-title,
.dark-palette .document .admonition.error p.admonition-title {
  color: #ee7797;
}
.dark-palette #search-results .admonition.danger p.admonition-title::before, .dark-palette #search-results .admonition.error p.admonition-title::before,
.dark-palette .content .admonition.danger p.admonition-title::before,
.dark-palette .content .admonition.error p.admonition-title::before,
.dark-palette .document .admonition.danger p.admonition-title::before,
.dark-palette .document .admonition.error p.admonition-title::before {
  content: "\f188";
  font-family: "fontello";
  font-weight: 100;
}
.dark-palette #search-results .admonition.important p, .dark-palette #search-results .admonition.note p,
.dark-palette .content .admonition.important p,
.dark-palette .content .admonition.note p,
.dark-palette .document .admonition.important p,
.dark-palette .document .admonition.note p {
  background-color: rgba(0, 173, 107, 0.25);
}
.dark-palette #search-results .admonition.important p.admonition-title, .dark-palette #search-results .admonition.note p.admonition-title,
.dark-palette .content .admonition.important p.admonition-title,
.dark-palette .content .admonition.note p.admonition-title,
.dark-palette .document .admonition.important p.admonition-title,
.dark-palette .document .admonition.note p.admonition-title {
  color: #14ffa5;
}
.dark-palette #search-results .admonition.important p.admonition-title::before, .dark-palette #search-results .admonition.note p.admonition-title::before,
.dark-palette .content .admonition.important p.admonition-title::before,
.dark-palette .content .admonition.note p.admonition-title::before,
.dark-palette .document .admonition.important p.admonition-title::before,
.dark-palette .document .admonition.note p.admonition-title::before {
  content: "\e859";
  font-family: "fontello";
  font-weight: 100;
}
.dark-palette #search-results .admonition.hint p, .dark-palette #search-results .admonition.tip p,
.dark-palette .content .admonition.hint p,
.dark-palette .content .admonition.tip p,
.dark-palette .document .admonition.hint p,
.dark-palette .document .admonition.tip p {
  background-color: rgba(68, 156, 197, 0.25);
}
.dark-palette #search-results .admonition.hint p.admonition-title, .dark-palette #search-results .admonition.tip p.admonition-title,
.dark-palette .content .admonition.hint p.admonition-title,
.dark-palette .content .admonition.tip p.admonition-title,
.dark-palette .document .admonition.hint p.admonition-title,
.dark-palette .document .admonition.tip p.admonition-title {
  color: #92c5dd;
}
.dark-palette #search-results .admonition.hint p.admonition-title::before, .dark-palette #search-results .admonition.tip p.admonition-title::before,
.dark-palette .content .admonition.hint p.admonition-title::before,
.dark-palette .content .admonition.tip p.admonition-title::before,
.dark-palette .document .admonition.hint p.admonition-title::before,
.dark-palette .document .admonition.tip p.admonition-title::before {
  content: "\e823";
  font-family: "fontello";
  font-weight: 100;
}

.light-palette #search-results .admonition,
.light-palette .content .admonition,
.light-palette .document .admonition {
  background-color: #faf0f0;
  margin: 0.5rem;
}
.light-palette #search-results .admonition p,
.light-palette .content .admonition p,
.light-palette .document .admonition p {
  background-color: rgba(229, 220, 220, 0.25);
  color: #121417;
  padding: 0 0.75rem 0.25rem 0.75rem;
}
.light-palette #search-results .admonition p.admonition-title,
.light-palette .content .admonition p.admonition-title,
.light-palette .document .admonition p.admonition-title {
  padding-top: 0.5rem;
}
.light-palette #search-results .admonition p.admonition-title::before,
.light-palette .content .admonition p.admonition-title::before,
.light-palette .document .admonition p.admonition-title::before {
  margin-right: 0.5rem;
}
.light-palette #search-results .admonition p:first-child,
.light-palette .content .admonition p:first-child,
.light-palette .document .admonition p:first-child {
  border-radius: 4px 4px 0 0;
}
.light-palette #search-results .admonition p:last-child,
.light-palette .content .admonition p:last-child,
.light-palette .document .admonition p:last-child {
  border-radius: 0 0 4px 4px;
}
.light-palette #search-results .admonition p:not(:last-child),
.light-palette .content .admonition p:not(:last-child),
.light-palette .document .admonition p:not(:last-child) {
  margin: 0;
}
.light-palette #search-results .admonition.attention p, .light-palette #search-results .admonition.caution p, .light-palette #search-results .admonition.warning p,
.light-palette .content .admonition.attention p,
.light-palette .content .admonition.caution p,
.light-palette .content .admonition.warning p,
.light-palette .document .admonition.attention p,
.light-palette .document .admonition.caution p,
.light-palette .document .admonition.warning p {
  background-color: rgba(255, 123, 0, 0.25);
}
.light-palette #search-results .admonition.attention p.admonition-title, .light-palette #search-results .admonition.caution p.admonition-title, .light-palette #search-results .admonition.warning p.admonition-title,
.light-palette .content .admonition.attention p.admonition-title,
.light-palette .content .admonition.caution p.admonition-title,
.light-palette .content .admonition.warning p.admonition-title,
.light-palette .document .admonition.attention p.admonition-title,
.light-palette .document .admonition.caution p.admonition-title,
.light-palette .document .admonition.warning p.admonition-title {
  color: #994a00;
}
.light-palette #search-results .admonition.attention p.admonition-title::before, .light-palette #search-results .admonition.caution p.admonition-title::before, .light-palette #search-results .admonition.warning p.admonition-title::before,
.light-palette .content .admonition.attention p.admonition-title::before,
.light-palette .content .admonition.caution p.admonition-title::before,
.light-palette .content .admonition.warning p.admonition-title::before,
.light-palette .document .admonition.attention p.admonition-title::before,
.light-palette .document .admonition.caution p.admonition-title::before,
.light-palette .document .admonition.warning p.admonition-title::before {
  content: "\e829";
  font-family: "fontello";
  font-weight: 100;
}
.light-palette #search-results .admonition.danger p, .light-palette #search-results .admonition.error p,
.light-palette .content .admonition.danger p,
.light-palette .content .admonition.error p,
.light-palette .document .admonition.danger p,
.light-palette .document .admonition.error p {
  background-color: rgba(228, 86, 73, 0.25);
}
.light-palette #search-results .admonition.danger p.admonition-title, .light-palette #search-results .admonition.error p.admonition-title,
.light-palette .content .admonition.danger p.admonition-title,
.light-palette .content .admonition.error p.admonition-title,
.light-palette .document .admonition.danger p.admonition-title,
.light-palette .document .admonition.error p.admonition-title {
  color: #ad261a;
}
.light-palette #search-results .admonition.danger p.admonition-title::before, .light-palette #search-results .admonition.error p.admonition-title::before,
.light-palette .content .admonition.danger p.admonition-title::before,
.light-palette .content .admonition.error p.admonition-title::before,
.light-palette .document .admonition.danger p.admonition-title::before,
.light-palette .document .admonition.error p.admonition-title::before {
  content: "\f188";
  font-family: "fontello";
  font-weight: 100;
}
.light-palette #search-results .admonition.important p, .light-palette #search-results .admonition.note p,
.light-palette .content .admonition.important p,
.light-palette .content .admonition.note p,
.light-palette .document .admonition.important p,
.light-palette .document .admonition.note p {
  background-color: rgba(0, 173, 107, 0.25);
}
.light-palette #search-results .admonition.important p.admonition-title, .light-palette #search-results .admonition.note p.admonition-title,
.light-palette .content .admonition.important p.admonition-title,
.light-palette .content .admonition.note p.admonition-title,
.light-palette .document .admonition.important p.admonition-title,
.light-palette .document .admonition.note p.admonition-title {
  color: #00472c;
}
.light-palette #search-results .admonition.important p.admonition-title::before, .light-palette #search-results .admonition.note p.admonition-title::before,
.light-palette .content .admonition.important p.admonition-title::before,
.light-palette .content .admonition.note p.admonition-title::before,
.light-palette .document .admonition.important p.admonition-title::before,
.light-palette .document .admonition.note p.admonition-title::before {
  content: "\e859";
  font-family: "fontello";
  font-weight: 100;
}
.light-palette #search-results .admonition.hint p, .light-palette #search-results .admonition.tip p,
.light-palette .content .admonition.hint p,
.light-palette .content .admonition.tip p,
.light-palette .document .admonition.hint p,
.light-palette .document .admonition.tip p {
  background-color: rgba(68, 156, 197, 0.25);
}
.light-palette #search-results .admonition.hint p.admonition-title, .light-palette #search-results .admonition.tip p.admonition-title,
.light-palette .content .admonition.hint p.admonition-title,
.light-palette .content .admonition.tip p.admonition-title,
.light-palette .document .admonition.hint p.admonition-title,
.light-palette .document .admonition.tip p.admonition-title {
  color: #26617d;
}
.light-palette #search-results .admonition.hint p.admonition-title::before, .light-palette #search-results .admonition.tip p.admonition-title::before,
.light-palette .content .admonition.hint p.admonition-title::before,
.light-palette .content .admonition.tip p.admonition-title::before,
.light-palette .document .admonition.hint p.admonition-title::before,
.light-palette .document .admonition.tip p.admonition-title::before {
  content: "\e823";
  font-family: "fontello";
  font-weight: 100;
}

#search-results .citation-reference,
#search-results .footnote-reference,
.content .citation-reference,
.content .footnote-reference,
.document .citation-reference,
.document .footnote-reference {
  font-size: 10px;
  position: relative;
  top: -0.5rem;
}
#search-results .deprecated:not(.versionmodified),
#search-results .versionadded,
#search-results .versionchanged,
.content .deprecated:not(.versionmodified),
.content .versionadded,
.content .versionchanged,
.document .deprecated:not(.versionmodified),
.document .versionadded,
.document .versionchanged {
  margin-bottom: 0.5rem;
  padding: 0.5rem;
}
.dark-palette #search-results .deprecated:not(.versionmodified),
.dark-palette #search-results .versionadded,
.dark-palette #search-results .versionchanged,
.dark-palette .content .deprecated:not(.versionmodified),
.dark-palette .content .versionadded,
.dark-palette .content .versionchanged,
.dark-palette .document .deprecated:not(.versionmodified),
.dark-palette .document .versionadded,
.dark-palette .document .versionchanged {
  background-color: #202d3c;
  border-top: 4px solid #3e4551;
}
.dark-palette #search-results .deprecated:not(.versionmodified) .versionmodified.added,
.dark-palette #search-results .versionadded .versionmodified.added,
.dark-palette #search-results .versionchanged .versionmodified.added,
.dark-palette .content .deprecated:not(.versionmodified) .versionmodified.added,
.dark-palette .content .versionadded .versionmodified.added,
.dark-palette .content .versionchanged .versionmodified.added,
.dark-palette .document .deprecated:not(.versionmodified) .versionmodified.added,
.dark-palette .document .versionadded .versionmodified.added,
.dark-palette .document .versionchanged .versionmodified.added {
  color: #449cc5;
}
.dark-palette #search-results .deprecated:not(.versionmodified) .versionmodified.changed,
.dark-palette #search-results .versionadded .versionmodified.changed,
.dark-palette #search-results .versionchanged .versionmodified.changed,
.dark-palette .content .deprecated:not(.versionmodified) .versionmodified.changed,
.dark-palette .content .versionadded .versionmodified.changed,
.dark-palette .content .versionchanged .versionmodified.changed,
.dark-palette .document .deprecated:not(.versionmodified) .versionmodified.changed,
.dark-palette .document .versionadded .versionmodified.changed,
.dark-palette .document .versionchanged .versionmodified.changed {
  color: #ff7b00;
}
.dark-palette #search-results .deprecated:not(.versionmodified) .versionmodified.deprecated,
.dark-palette #search-results .versionadded .versionmodified.deprecated,
.dark-palette #search-results .versionchanged .versionmodified.deprecated,
.dark-palette .content .deprecated:not(.versionmodified) .versionmodified.deprecated,
.dark-palette .content .versionadded .versionmodified.deprecated,
.dark-palette .content .versionchanged .versionmodified.deprecated,
.dark-palette .document .deprecated:not(.versionmodified) .versionmodified.deprecated,
.dark-palette .document .versionadded .versionmodified.deprecated,
.dark-palette .document .versionchanged .versionmodified.deprecated {
  color: #e31c51;
}

.light-palette #search-results .deprecated:not(.versionmodified),
.light-palette #search-results .versionadded,
.light-palette #search-results .versionchanged,
.light-palette .content .deprecated:not(.versionmodified),
.light-palette .content .versionadded,
.light-palette .content .versionchanged,
.light-palette .document .deprecated:not(.versionmodified),
.light-palette .document .versionadded,
.light-palette .document .versionchanged {
  background-color: whitesmoke;
  border-top: 4px solid #e5dcdc;
}
.light-palette #search-results .deprecated:not(.versionmodified) .versionmodified.added,
.light-palette #search-results .versionadded .versionmodified.added,
.light-palette #search-results .versionchanged .versionmodified.added,
.light-palette .content .deprecated:not(.versionmodified) .versionmodified.added,
.light-palette .content .versionadded .versionmodified.added,
.light-palette .content .versionchanged .versionmodified.added,
.light-palette .document .deprecated:not(.versionmodified) .versionmodified.added,
.light-palette .document .versionadded .versionmodified.added,
.light-palette .document .versionchanged .versionmodified.added {
  color: #449cc5;
}
.light-palette #search-results .deprecated:not(.versionmodified) .versionmodified.changed,
.light-palette #search-results .versionadded .versionmodified.changed,
.light-palette #search-results .versionchanged .versionmodified.changed,
.light-palette .content .deprecated:not(.versionmodified) .versionmodified.changed,
.light-palette .content .versionadded .versionmodified.changed,
.light-palette .content .versionchanged .versionmodified.changed,
.light-palette .document .deprecated:not(.versionmodified) .versionmodified.changed,
.light-palette .document .versionadded .versionmodified.changed,
.light-palette .document .versionchanged .versionmodified.changed {
  color: #ff7b00;
}
.light-palette #search-results .deprecated:not(.versionmodified) .versionmodified.deprecated,
.light-palette #search-results .versionadded .versionmodified.deprecated,
.light-palette #search-results .versionchanged .versionmodified.deprecated,
.light-palette .content .deprecated:not(.versionmodified) .versionmodified.deprecated,
.light-palette .content .versionadded .versionmodified.deprecated,
.light-palette .content .versionchanged .versionmodified.deprecated,
.light-palette .document .deprecated:not(.versionmodified) .versionmodified.deprecated,
.light-palette .document .versionadded .versionmodified.deprecated,
.light-palette .document .versionchanged .versionmodified.deprecated {
  color: #e45649;
}

#search-results .field-list dd ul,
.content .field-list dd ul,
.document .field-list dd ul {
  margin-top: 0;
}
#search-results .line-block,
.content .line-block,
.document .line-block {
  margin-bottom: 1rem;
  margin-left: 1rem;
}
#search-results .rubric,
.content .rubric,
.document .rubric {
  font-weight: 700;
  margin-bottom: 1.25rem;
}
#search-results .tagmod, .light-palette #search-results .glossary dt,
.light-palette .content .glossary #search-results dt,
.light-palette .document .glossary #search-results dt, .light-palette #search-results span.guilabel,
#search-results .light-palette .content span.guilabel,
#search-results .light-palette .document span.guilabel, .light-palette #search-results dt,
.light-palette #search-results .label,
#search-results .light-palette .content dt,
#search-results .light-palette .content .label,
#search-results .light-palette .document dt,
#search-results .light-palette .document .label, .dark-palette #search-results .glossary dt,
.dark-palette .content .glossary #search-results dt,
.dark-palette .document .glossary #search-results dt, .dark-palette #search-results span.guilabel,
#search-results .dark-palette .content span.guilabel,
#search-results .dark-palette .document span.guilabel, .dark-palette #search-results dt,
.dark-palette #search-results .label,
#search-results .dark-palette .content dt,
#search-results .dark-palette .content .label,
#search-results .dark-palette .document dt,
#search-results .dark-palette .document .label,
.content .tagmod,
.light-palette .content .glossary dt,
.content .light-palette .document .glossary dt,
.light-palette .document .glossary .content dt,
.light-palette .content span.guilabel,
.content .light-palette .document span.guilabel,
.light-palette .document .content span.guilabel,
.light-palette .content dt,
.light-palette .content .label,
.content .light-palette .document dt,
.light-palette .document .content dt,
.content .light-palette .document .label,
.light-palette .document .content .label,
.dark-palette .content .glossary dt,
.content .dark-palette .document .glossary dt,
.dark-palette .document .glossary .content dt,
.dark-palette .content span.guilabel,
.content .dark-palette .document span.guilabel,
.dark-palette .document .content span.guilabel,
.dark-palette .content dt,
.dark-palette .content .label,
.content .dark-palette .document dt,
.dark-palette .document .content dt,
.content .dark-palette .document .label,
.dark-palette .document .content .label,
.document .tagmod,
.document .light-palette .content .glossary dt,
.light-palette .content .glossary .document dt,
.light-palette .document .glossary dt,
.document .light-palette .content span.guilabel,
.light-palette .content .document span.guilabel,
.light-palette .document span.guilabel,
.document .light-palette .content dt,
.light-palette .content .document dt,
.document .light-palette .content .label,
.light-palette .content .document .label,
.light-palette .document dt,
.light-palette .document .label,
.document .dark-palette .content .glossary dt,
.dark-palette .content .glossary .document dt,
.dark-palette .document .glossary dt,
.document .dark-palette .content span.guilabel,
.dark-palette .content .document span.guilabel,
.dark-palette .document span.guilabel,
.document .dark-palette .content dt,
.dark-palette .content .document dt,
.document .dark-palette .content .label,
.dark-palette .content .document .label,
.dark-palette .document dt,
.dark-palette .document .label {
  align-items: center;
  border-radius: 4px;
  display: inline-flex;
  height: 2em;
  justify-content: center;
  line-height: 1.5;
  padding-left: 0.75em;
  padding-right: 0.75em;
}
#search-results .viewcode-link span.pre,
.content .viewcode-link span.pre,
.document .viewcode-link span.pre {
  font-size: 0;
  margin-left: 0.5rem;
  visibility: hidden;
}
#search-results .viewcode-link span.pre::after,
.content .viewcode-link span.pre::after,
.document .viewcode-link span.pre::after {
  font-size: medium;
  font-weight: 100;
  position: relative;
  visibility: visible;
  content: "\f1c9";
  font-family: "fontello";
  font-weight: 100;
}
.dark-palette #search-results blockquote,
.dark-palette .content blockquote,
.dark-palette .document blockquote {
  background-color: #202d3c;
  border-left: 5px solid #3e4551;
}
.dark-palette #search-results dt,
.dark-palette #search-results .label,
.dark-palette .content dt,
.dark-palette .content .label,
.dark-palette .document dt,
.dark-palette .document .label {
  background-color: transparent;
  border: 1px solid #449cc5;
  color: #449cc5;
  margin-top: 0.5rem;
}
.dark-palette #search-results span.guilabel,
.dark-palette .content span.guilabel,
.dark-palette .document span.guilabel {
  background-color: transparent;
  border: 1px solid #885bfb;
  color: #885bfb;
  font-size: 0.8rem;
  font-weight: 100;
  height: 1.25rem;
}
.dark-palette #search-results .glossary dt,
.dark-palette .content .glossary dt,
.dark-palette .document .glossary dt {
  background-color: transparent;
  border: 1px solid #4078f2;
  color: #4078f2;
  margin-top: 0.5rem;
}
.dark-palette #search-results .topic,
.dark-palette .content .topic,
.dark-palette .document .topic {
  color: #c9d1d9;
}
.dark-palette #search-results .topic-title,
.dark-palette .content .topic-title,
.dark-palette .document .topic-title {
  color: #faf0f0;
}

.light-palette #search-results blockquote,
.light-palette .content blockquote,
.light-palette .document blockquote {
  background-color: whitesmoke;
  border-left: 5px solid #e5dcdc;
}
.light-palette #search-results dt,
.light-palette #search-results .label,
.light-palette .content dt,
.light-palette .content .label,
.light-palette .document dt,
.light-palette .document .label {
  background-color: #eff7fa;
  border: none;
  color: #449cc5;
  margin-top: 0.5rem;
}
.light-palette #search-results span.guilabel,
.light-palette .content span.guilabel,
.light-palette .document span.guilabel {
  background-color: #885bfb;
  border: none;
  color: #fafafa;
  font-size: 0.8rem;
  font-weight: 100;
  height: 1.25rem;
}
.light-palette #search-results .glossary dt,
.light-palette .content .glossary dt,
.light-palette .document .glossary dt {
  background-color: #4078f2;
  border: none;
  color: #fafafa;
  margin-top: 0.5rem;
}
.light-palette #search-results .topic,
.light-palette .content .topic,
.light-palette .document .topic {
  color: #3e4551;
}
.light-palette #search-results .topic-title,
.light-palette .content .topic-title,
.light-palette .document .topic-title {
  color: #0d1117;
}

/*
 * Footer component
 */
.dark-palette footer.footer {
  background-color: #202d3c;
}
.dark-palette footer.footer span.tag {
  font-family: "Josefin Sans", sans-serif;
  font-size: 0.75rem;
}
.dark-palette footer.footer span.tag.is-dark {
  background-color: #c9d1d9;
  color: #121921;
}

.light-palette footer.footer {
  background-color: whitesmoke;
}
.light-palette footer.footer span.tag {
  font-family: "Josefin Sans", sans-serif;
  font-size: 0.75rem;
}
.light-palette footer.footer span.tag.is-dark {
  background-color: #3e4551;
  color: #faf0f0;
}

/*
 * Default code styles
 */
code,
pre {
  font-family: "Courier Prime", monospace;
}
.dark-palette code,
.dark-palette pre {
  background-color: #121921;
}

.light-palette code,
.light-palette pre {
  background-color: #faf0f0;
}

div [class^=highlight-] {
  margin-bottom: 1rem;
  overflow-x: auto;
}

.dark-palette dt:not(footer),
.dark-palette span.guilabel:not(footer),
.dark-palette .glossary dt:not(footer),
.dark-palette .label:not(footer),
.dark-palette .tag:not(footer) {
  font-family: "Courier Prime", monospace;
  font-size: 14px;
  font-weight: 600;
  margin: 0.1rem;
  white-space: pre;
}
.dark-palette dt:not(footer) .property span.pre,
.dark-palette span.guilabel:not(footer) .property span.pre,
.dark-palette .glossary dt:not(footer) .property span.pre,
.dark-palette .label:not(footer) .property span.pre,
.dark-palette .tag:not(footer) .property span.pre {
  color: #d45ece;
}
.dark-palette dt:not(footer) .sig-name,
.dark-palette span.guilabel:not(footer) .sig-name,
.dark-palette .glossary dt:not(footer) .sig-name,
.dark-palette .label:not(footer) .sig-name,
.dark-palette .tag:not(footer) .sig-name {
  color: #e31c51;
}
.dark-palette dt:not(footer) .sig-param,
.dark-palette span.guilabel:not(footer) .sig-param,
.dark-palette .glossary dt:not(footer) .sig-param,
.dark-palette .label:not(footer) .sig-param,
.dark-palette .tag:not(footer) .sig-param {
  color: #c9d1d9;
}
.dark-palette dt:not(footer) .sig-prename,
.dark-palette span.guilabel:not(footer) .sig-prename,
.dark-palette .glossary dt:not(footer) .sig-prename,
.dark-palette .label:not(footer) .sig-prename,
.dark-palette .tag:not(footer) .sig-prename {
  color: #255bd0;
}

.light-palette dt:not(footer),
.light-palette span.guilabel:not(footer),
.light-palette .glossary dt:not(footer),
.light-palette .label:not(footer),
.light-palette .tag:not(footer) {
  font-family: "Courier Prime", monospace;
  font-size: 14px;
  font-weight: 600;
  margin: 0.1rem;
  white-space: pre;
}
.light-palette dt:not(footer) .property span.pre,
.light-palette span.guilabel:not(footer) .property span.pre,
.light-palette .glossary dt:not(footer) .property span.pre,
.light-palette .label:not(footer) .property span.pre,
.light-palette .tag:not(footer) .property span.pre {
  color: #f57fef;
}
.light-palette dt:not(footer) .sig-name,
.light-palette span.guilabel:not(footer) .sig-name,
.light-palette .glossary dt:not(footer) .sig-name,
.light-palette .label:not(footer) .sig-name,
.light-palette .tag:not(footer) .sig-name {
  color: #e45649;
}
.light-palette dt:not(footer) .sig-param,
.light-palette span.guilabel:not(footer) .sig-param,
.light-palette .glossary dt:not(footer) .sig-param,
.light-palette .label:not(footer) .sig-param,
.light-palette .tag:not(footer) .sig-param {
  color: #2f3546;
}
.light-palette dt:not(footer) .sig-prename,
.light-palette span.guilabel:not(footer) .sig-prename,
.light-palette .glossary dt:not(footer) .sig-prename,
.light-palette .label:not(footer) .sig-prename,
.light-palette .tag:not(footer) .sig-prename {
  color: #4078f2;
}

.dark-palette pre:not(.dummy) {
  color: #e31c51;
  padding: 1.5rem;
}

.light-palette pre:not(.dummy) {
  color: #e45649;
  padding: 1.5rem;
}

pre:not(.dummy) span {
  line-height: 20px;
}
pre:not(.dummy) span.linenos {
  font-size: 12px;
  padding-right: 20px;
}
.dark-palette pre:not(.dummy) span.linenos {
  color: #c9d1d9;
}

.light-palette pre:not(.dummy) span.linenos {
  color: #2f3546;
}

pre {
  padding: 2rem;
}

.highlight {
  margin: 1rem 0;
}
.highlight pre {
  padding: 1rem;
}
.dark-palette .highlight .bp,
.dark-palette .highlight .o,
.dark-palette .highlight .vc,
.dark-palette .highlight .vi,
.dark-palette .highlight .vg {
  color: #255bd0;
}
.dark-palette .highlight .c,
.dark-palette .highlight .cm {
  color: #5ea14f;
  font-style: italic;
}
.dark-palette .highlight .c1,
.dark-palette .highlight .cs {
  color: #5ea14f;
  font-style: italic;
}
.dark-palette .highlight .cp {
  font-style: italic;
  color: #00ad6b;
}
.dark-palette .highlight .err {
  color: #c9d1d9;
}
.dark-palette .highlight .g,
.dark-palette .highlight .gd,
.dark-palette .highlight .ge,
.dark-palette .highlight .gh,
.dark-palette .highlight .gi,
.dark-palette .highlight .go,
.dark-palette .highlight .gp,
.dark-palette .highlight .gr,
.dark-palette .highlight .gs,
.dark-palette .highlight .gt,
.dark-palette .highlight .gu {
  color: #a3c0ff;
}
.dark-palette .highlight .hll {
  background-color: #39040c;
}
.dark-palette .highlight .il,
.dark-palette .highlight .ld,
.dark-palette .highlight .m,
.dark-palette .highlight .mf,
.dark-palette .highlight .mh,
.dark-palette .highlight .mi,
.dark-palette .highlight .mo {
  color: #ff7b00;
}
.dark-palette .highlight .k,
.dark-palette .highlight .kc,
.dark-palette .highlight .kd {
  color: #d45ece;
}
.dark-palette .highlight .kc {
  color: #ff7b00;
}
.dark-palette .highlight .kn {
  color: #255bd0;
}
.dark-palette .highlight .kp,
.dark-palette .highlight .kr,
.dark-palette .highlight .kt {
  color: #d45ece;
}
.dark-palette .highlight .l {
  color: #5ea14f;
}
.dark-palette .highlight .n,
.dark-palette .highlight .x {
  color: #c9d1d9;
}
.dark-palette .highlight .na {
  color: #255bd0;
}
.dark-palette .highlight .nb {
  color: #449cc5;
}
.dark-palette .highlight .nc {
  color: #255bd0;
}
.dark-palette .highlight .nd,
.dark-palette .highlight .no {
  color: #d45ece;
}
.dark-palette .highlight .ne,
.dark-palette .highlight .ni {
  color: #c9d1d9;
}
.dark-palette .highlight .nf {
  color: #a3c0ff;
}
.dark-palette .highlight .nl {
  color: #a3c0ff;
}
.dark-palette .highlight .nn {
  color: #ff7b00;
}
.dark-palette .highlight .nt {
  color: #da990b;
}
.dark-palette .highlight .nv {
  color: #ff7b00;
}
.dark-palette .highlight .nx {
  color: #449cc5;
}
.dark-palette .highlight .ow {
  color: #d45ece;
}
.dark-palette .highlight .py {
  color: #c9d1d9;
}
.dark-palette .highlight .s,
.dark-palette .highlight .s1,
.dark-palette .highlight .s2,
.dark-palette .highlight .sb,
.dark-palette .highlight .sc,
.dark-palette .highlight .sd,
.dark-palette .highlight .se,
.dark-palette .highlight .sh,
.dark-palette .highlight .si,
.dark-palette .highlight .sr,
.dark-palette .highlight .sx {
  color: #5ea14f;
}
.dark-palette .highlight .ss {
  color: #449cc5;
}
.dark-palette .highlight .w {
  color: transparent;
}

.light-palette .highlight .bp,
.light-palette .highlight .o,
.light-palette .highlight .vc,
.light-palette .highlight .vi,
.light-palette .highlight .vg {
  color: #4078f2;
}
.light-palette .highlight .c,
.light-palette .highlight .cm {
  color: #5ea14f;
  font-style: italic;
}
.light-palette .highlight .c1,
.light-palette .highlight .cs {
  color: #5ea14f;
  font-style: italic;
}
.light-palette .highlight .cp {
  font-style: italic;
  color: #00ad6b;
}
.light-palette .highlight .err {
  color: #2f3546;
}
.light-palette .highlight .g,
.light-palette .highlight .gd,
.light-palette .highlight .ge,
.light-palette .highlight .gh,
.light-palette .highlight .gi,
.light-palette .highlight .go,
.light-palette .highlight .gp,
.light-palette .highlight .gr,
.light-palette .highlight .gs,
.light-palette .highlight .gt,
.light-palette .highlight .gu {
  color: #4078f2;
}
.light-palette .highlight .hll {
  background-color: #ffffcc;
}
.light-palette .highlight .il,
.light-palette .highlight .ld,
.light-palette .highlight .m,
.light-palette .highlight .mf,
.light-palette .highlight .mh,
.light-palette .highlight .mi,
.light-palette .highlight .mo {
  color: #ff7b00;
}
.light-palette .highlight .k,
.light-palette .highlight .kc,
.light-palette .highlight .kd {
  color: #f57fef;
}
.light-palette .highlight .kc {
  color: #ff7b00;
}
.light-palette .highlight .kn {
  color: #4078f2;
}
.light-palette .highlight .kp,
.light-palette .highlight .kr,
.light-palette .highlight .kt {
  color: #f57fef;
}
.light-palette .highlight .l {
  color: #5ea14f;
}
.light-palette .highlight .n,
.light-palette .highlight .x {
  color: #2f3546;
}
.light-palette .highlight .na {
  color: #4078f2;
}
.light-palette .highlight .nb {
  color: #449cc5;
}
.light-palette .highlight .nc {
  color: #4078f2;
}
.light-palette .highlight .nd,
.light-palette .highlight .no {
  color: #f57fef;
}
.light-palette .highlight .ne,
.light-palette .highlight .ni {
  color: #2f3546;
}
.light-palette .highlight .nf {
  color: #a3c0ff;
}
.light-palette .highlight .nl {
  color: #4078f2;
}
.light-palette .highlight .nn {
  color: #ff7b00;
}
.light-palette .highlight .nt {
  color: #c18401;
}
.light-palette .highlight .nv {
  color: #ff7b00;
}
.light-palette .highlight .nx {
  color: #449cc5;
}
.light-palette .highlight .ow {
  color: #f57fef;
}
.light-palette .highlight .py {
  color: #2f3546;
}
.light-palette .highlight .s,
.light-palette .highlight .s1,
.light-palette .highlight .s2,
.light-palette .highlight .sb,
.light-palette .highlight .sc,
.light-palette .highlight .sd,
.light-palette .highlight .se,
.light-palette .highlight .sh,
.light-palette .highlight .si,
.light-palette .highlight .sr,
.light-palette .highlight .sx {
  color: #5ea14f;
}
.light-palette .highlight .ss {
  color: #449cc5;
}
.light-palette .highlight .w {
  color: transparent;
}

/*
 * Components index file
 */
/*
 * Main theme styles
 */

/*# sourceMappingURL=theme.css.map */
